# All Global changes to build and install go here.
# Per the below section about __spec_install_pre, any rpm
# environment changes that affect %%install need to go
# here before the %%install macro is pre-built.

# Disable LTO in userspace packages.
%global _lto_cflags %{nil}

# Option to enable compiling with clang instead of gcc.
%bcond_with toolchain_clang

%if %{with toolchain_clang}
%global toolchain clang
%endif

# Compile the kernel with LTO (only supported when building with clang).
%bcond_with clang_lto

%if %{with clang_lto} && %{without toolchain_clang}
{error:clang_lto requires --with toolchain_clang}
%endif

# Cross compile on copr for arm
# See https://bugzilla.redhat.com/1879599
%if 0%{?_with_cross_arm:1}
%global _target_cpu armv7hl
%global _arch arm
%global _build_arch arm
%global _with_cross    1
%endif

# RPM macros strip everything in BUILDROOT, either with __strip
# or find-debuginfo.sh. Make use of __spec_install_post override
# and save/restore binaries we want to package as unstripped.
%define buildroot_unstripped %{_builddir}/root_unstripped
%define buildroot_save_unstripped() \
(cd %{buildroot}; cp -rav --parents -t %{buildroot_unstripped}/ %1 || true) \
%{nil}
%define __restore_unstripped_root_post \
    echo "Restoring unstripped artefacts %{buildroot_unstripped} -> %{buildroot}" \
    cp -rav %{buildroot_unstripped}/. %{buildroot}/ \
%{nil}

# The kernel's %%install section is special
# Normally the %%install section starts by cleaning up the BUILD_ROOT
# like so:
#
# %%__spec_install_pre %%{___build_pre}\
#     [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "${RPM_BUILD_ROOT}"\
#     mkdir -p `dirname "$RPM_BUILD_ROOT"`\
#     mkdir "$RPM_BUILD_ROOT"\
# %%{nil}
#
# But because of kernel variants, the %%build section, specifically
# BuildKernel(), moves each variant to its final destination as the
# variant is built.  This violates the expectation of the %%install
# section.  As a result we snapshot the current env variables and
# purposely leave out the removal section.  All global wide changes
# should be added above this line otherwise the %%install section
# will not see them.
%global __spec_install_pre %{___build_pre}

# Replace '-' with '_' where needed so that variants can use '-' in
# their name.
%define uname_suffix %{lua:
	local flavour = rpm.expand('%{?1:+%{1}}')
	flavour = flavour:gsub('-', '_')
	if flavour ~= '' then
		print(flavour)
	end
}

# This returns the main kernel tied to a debug variant. For example,
# kernel-debug is the debug version of kernel, so we return an empty
# string. However, kernel-64k-debug is the debug version of kernel-64k,
# in this case we need to return "64k", and so on. This is used in
# macros below where we need this for some uname based requires.
%define uname_variant %{lua:
	local flavour = rpm.expand('%{?1:%{1}}')
	_, _, main, sub = flavour:find("(%w+)-(.*)")
	if main then
		print("+" .. main)
	end
}


# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
#
# This is disabled on i686 as it triggers oom errors

%ifnarch i686
%define _binary_payload w3T.xzdio
%endif

Summary: The Linux kernel
%if 0%{?fedora}
%define secure_boot_arch x86_64
%else
%define secure_boot_arch x86_64 aarch64 s390x ppc64le
%endif

# Signing for secure boot authentication
%ifarch %{secure_boot_arch}
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%ifarch x86_64
%global efiuki 1
%else
%global efiuki 0
%endif

%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.xz/'
# for parallel xz processes, replace with 1 to go back to single process
%endif

%if 0%{?fedora}
%define primary_target fedora
%else
%define primary_target rhel
%endif

#
# genspec.sh variables
#

# Include Fedora files
%global include_fedora 0
# Include RHEL files
%global include_rhel 1
# Provide Patchlist.changelog file
%global patchlist_changelog 0
# Set debugbuildsenabled to 1 to build separate base and debug kernels
#  (on supported architectures). The kernel-debug-* subpackages will
#  contain the debug kernel.
# Set debugbuildsenabled to 0 to not build a separate debug kernel, but
#  to build the base kernel using the debug configuration. (Specifying
#  the --with-release option overrides this setting.)
%define debugbuildsenabled 1
# define buildid .local
%define specversion 5.14.0
%define patchversion 5.14
%define pkgrelease 284.25.1
%define kversion 5
%define tarfile_release 5.14.0-284.18.1.el9_2
# This is needed to do merge window version magic
%define patchlevel 14
# This allows pkg_release to have configurable %%{?dist} tag
%define specrelease 284.25.1%{?buildid}%{?dist}
# This defines the kabi tarball version
%define kabiversion 5.14.0-284.18.1.el9_2

#
# End of genspec.sh variables
#

%define pkg_release %{specrelease}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

%define _with_kabidupchk 1
# The following build options are enabled by default, but may become disabled
# by later architecture-specific checks. These can also be disabled by using
# --without <opt> in the rpmbuild command, or by forcing these values to 0.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel PAE (only valid for ARM (lpae))
%define with_pae       %{?_without_pae:       0} %{?!_without_pae:       1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-64k (aarch64 kernel with 64K page_size)
%define with_arm64_64k %{?_without_arm64_64k: 0} %{?!_without_arm64_64k: 1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the pae kernel (--with paeonly):
%define with_paeonly   %{?_with_paeonly:      1} %{?!_with_paeonly:      0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# Control whether to install the vdso directories.
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# verbose build, i.e. no silent rules and V=1
%define with_verbose %{?_with_verbose:        1} %{?!_with_verbose:      0}

#
# check for mismatched config options
%define with_configchecks %{?_without_configchecks:        0} %{?!_without_configchecks:        1}

#
# gcov support
%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

#
# ipa_clone support
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# Want to build a vanilla kernel build without any non-upstream patches?
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

%if 0%{?fedora}
# Kernel headers are being split out into a separate package
%define with_headers 0
%define with_cross_headers 0
# no ipa_clone for now
%define with_ipaclones 0
# no stablelist
%define with_kernel_abi_stablelists 0
# Fedora builds these separately
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
# selftests turns on bpftool
%define with_selftests 0
%endif

%if %{with_verbose}
%define make_opts V=1
%else
%define make_opts -s
%endif

%if %{with toolchain_clang}
%ifarch s390x ppc64le
%global llvm_ias 0
%else
%global llvm_ias 1
%endif
%global clang_make_opts HOSTCC=clang CC=clang LLVM_IAS=%{llvm_ias}
%if %{with clang_lto}
%global clang_make_opts %{clang_make_opts} LD=ld.lld HOSTLD=ld.lld AR=llvm-ar NM=llvm-nm HOSTAR=llvm-ar HOSTNM=llvm-nm
%endif
%global make_opts %{make_opts} %{clang_make_opts}
# clang does not support the -fdump-ipa-clones option
%global with_ipaclones 0
%endif

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{with_release}
%define debugbuildsenabled 1
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# kernel PAE is only built on ARMv7
%ifnarch armv7hl
%define with_pae 0
%endif

# if requested, only build base kernel
%if %{with_baseonly}
%define with_pae 0
%define with_debug 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%if %{with_vdso_install}
%define use_vdso 1
%endif

# selftests require bpftool to be built
%if %{with_selftests}
%define with_bpftool 1
%endif

%ifnarch x86_64
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch x86_64
%define with_doc 0
%define doc_build_fail true
%endif

%if 0%{?fedora}
# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# 64k variant only for aarch64
%ifnarch aarch64
%define with_arm64_64k 0
%endif

%if 0%{?fedora}
# This is not for Fedora
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define use_vdso 0
%define all_arch_configs kernel-%{version}-ppc64le*.config
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/compressed/vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define skip_nonpae_vdso 1
%define asmarch arm
%define hdrarch arm
%define make_target bzImage
%define kernel_image arch/arm/boot/zImage
# http://lists.infradead.org/pipermail/linux-arm-kernel/2012-March/091404.html
%define kernel_mflags KALLSYMS_EXTRA_PASS=1
# we only build headers/perf/tools on the base arm arches
# just like we used to only build them on i386 for x86
%ifnarch armv7hl
%define with_headers 0
%define with_cross_headers 0
%endif
# These currently don't compile on armv7
%define with_selftests 0
%endif

%ifarch aarch64
%define all_arch_configs kernel-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%if %{nopatches}
%define with_configchecks 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%if 0%{?fedora}
%define nobuildarches i386
%else
%define nobuildarches i386 i686 %{arm}
%endif

%ifarch %nobuildarches
# disable BuildKernel commands
%define with_up 0
%define with_debug 0
%define with_pae 0
%define with_zfcpdump 0
%define with_arm64_64k 0

%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%if 0%{?fedora}
%define cpupowerarchs %{ix86} x86_64 ppc64le %{arm} aarch64
%else
%define cpupowerarchs i686 x86_64 ppc64le aarch64
%endif

%if 0%{?use_vdso}

%if 0%{?skip_nonpae_vdso}
%define _use_vdso 0
%else
%define _use_vdso 1
%endif

%else
%define _use_vdso 0
%endif

# If build of debug packages is disabled, we need to know if we want to create
# meta debug packages or not, after we define with_debug for all specific cases
# above. So this must be at the end here, after all cases of with_debug or not.
%define with_debug_meta 0
%if !%{debugbuildsenabled}
%if %{with_debug}
%define with_debug_meta 1
%endif
%define with_debug 0
%endif


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel
License: GPLv2 and Redistributable, no modification permitted
URL: https://www.kernel.org/
Version: %{specversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
%if 0%{?fedora}
ExclusiveArch: noarch x86_64 s390x %{arm} aarch64 ppc64le
%else
ExclusiveArch: noarch i386 i686 x86_64 s390x %{arm} aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: kernel-core-uname-r = %{KVERREL}
Requires: kernel-modules-uname-r = %{KVERREL}
Requires: kernel-modules-core-uname-r = %{KVERREL}
%endif

Provides: almalinux(kernel-sig-key) = 202303
Conflicts: shim-ia32 <= 15.6-1.el9.alma
Conflicts: shim-x64 <= 15.6-1.el9.alma

#
# List the packages used during the kernel build
#
BuildRequires: kmod, bash, coreutils, tar, git-core, which
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, bison, flex, gcc-c++
BuildRequires: net-tools, hostname, bc, elfutils-devel
BuildRequires: dwarves
BuildRequires: python3-devel
BuildRequires: gcc-plugin-devel
BuildRequires: kernel-rpm-macros >= 185-9
# glibc-static is required for a consistent build environment (specifically
# CONFIG_CC_CAN_LINK_STATIC=y).
BuildRequires: glibc-static
%if %{with_headers}
BuildRequires: rsync
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx, python3-sphinx_rtd_theme
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel python3-setuptools
BuildRequires: java-devel
BuildRequires: libbpf-devel >= 0.6.0-1
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch %{arm} s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.0.0
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
BuildRequires: libcap-devel libcap-ng-devel
# The following are rtla requirements
BuildRequires: python3-docutils
BuildRequires: libtraceevent-devel
BuildRequires: libtracefs-devel

%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif
%if %{with_tools} || %{signmodules} || %{signkernel}
BuildRequires: openssl-devel
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: clang llvm fuse-devel
%ifarch x86_64
BuildRequires: lld
%endif
%ifnarch %{arm}
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-devel libcap-ng-devel rsync libmnl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
%global _find_debuginfo_opts -r
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl
%if %{signkernel}
# ELN uses Fedora signing process, so exclude
%if 0%{?rhel}%{?centos} && !0%{?eln}
BuildRequires: system-sb-certs
%endif
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%define __strip %{_build_arch}-linux-gnu-strip
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

%if %{with toolchain_clang}
BuildRequires: clang
%endif

%if %{with clang_lto}
BuildRequires: llvm
BuildRequires: lld
%endif

%if %{efiuki}
BuildRequires: dracut
# For dracut UEFI uki binaries
BuildRequires: binutils
# For the initrd
BuildRequires: lvm2
# For systemd-stub
BuildRequires: (systemd-boot-unsigned or (systemd-udev >= 250-13 and systemd-udev < 252-8))
# For systemd-pcrphase
BuildRequires: systemd-udev >= 252-1
# For TPM operations in UKI initramfs
BuildRequires: tpm2-tools
# For Azure CVM specific udev rules
BuildRequires: WALinuxAgent-cvm
%endif

# Because this is the kernel, it's hard to get a single upstream URL
# to represent the base without needing to do a bunch of patching. This
# tarball is generated from a src-git tree. If you want to see the
# exact git commit you can run
#
# xzcat -qq ${TARBALL} | git get-tar-commit-id
Source0: linux-%{tarfile_release}.tar.xz

Source1: Makefile.rhelver

%if %{signkernel}

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

%define secureboot_ca_0 %{_datadir}/pki/sb-certs/secureboot-ca-%{_arch}.cer
%define secureboot_key_0 %{_datadir}/pki/sb-certs/secureboot-kernel-%{_arch}.cer

%define pesign_name_0 almalinuxsecurebootca0

# signkernel
%endif

Source20: mod-denylist.sh
Source21: mod-sign.sh
Source22: parallel_xz.sh

%define modsign_cmd %{SOURCE21}

%if 0%{?include_rhel}
Source23: x509.genkey.rhel

Source24: kernel-aarch64-rhel.config
Source25: kernel-aarch64-debug-rhel.config
Source26: mod-extra.list.rhel

Source27: kernel-ppc64le-rhel.config
Source28: kernel-ppc64le-debug-rhel.config
Source29: kernel-s390x-rhel.config
Source30: kernel-s390x-debug-rhel.config
Source31: kernel-s390x-zfcpdump-rhel.config
Source32: kernel-x86_64-rhel.config
Source33: kernel-x86_64-debug-rhel.config

Source34: filter-x86_64.sh.rhel
Source35: filter-armv7hl.sh.rhel
Source37: filter-aarch64.sh.rhel
Source38: filter-ppc64le.sh.rhel
Source39: filter-s390x.sh.rhel
Source40: filter-modules.sh.rhel

Source41: x509.genkey.centos
# ARM64 64K page-size kernel config
Source42: kernel-aarch64-64k-rhel.config
Source43: kernel-aarch64-64k-debug-rhel.config
%endif

%if 0%{?include_fedora}
Source50: x509.genkey.fedora
Source51: mod-extra.list.fedora

Source52: kernel-aarch64-fedora.config
Source53: kernel-aarch64-debug-fedora.config
Source54: kernel-armv7hl-fedora.config
Source55: kernel-armv7hl-debug-fedora.config
Source56: kernel-armv7hl-lpae-fedora.config
Source57: kernel-armv7hl-lpae-debug-fedora.config
Source60: kernel-ppc64le-fedora.config
Source61: kernel-ppc64le-debug-fedora.config
Source62: kernel-s390x-fedora.config
Source63: kernel-s390x-debug-fedora.config
Source64: kernel-x86_64-fedora.config
Source65: kernel-x86_64-debug-fedora.config

Source67: filter-x86_64.sh.fedora
Source68: filter-armv7hl.sh.fedora
Source70: filter-aarch64.sh.fedora
Source71: filter-ppc64le.sh.fedora
Source72: filter-s390x.sh.fedora
Source73: filter-modules.sh.fedora
%endif

Source75: partial-kgcov-snip.config
Source80: generate_all_configs.sh
Source81: process_configs.sh

Source82: update_scripts.sh

Source84: mod-internal.list
Source85: mod-partner.list

Source100: almalinuxdup1.x509
Source101: almalinuxkpatch1.x509

Source150: dracut-virt.conf

Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-stablelists-%{kabiversion}.tar.bz2
Source301: kernel-kabi-dw-%{kabiversion}.tar.bz2

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config
Source2002: kvm_stat.logrotate

# Some people enjoy building customized kernels from the dist-git in Fedora and
# use this to override configuration options. One day they may all use the
# source tree, but in the mean time we carry this to support the legacy workflow
Source3000: merge.pl
Source3001: kernel-local
%if %{patchlist_changelog}
Source3002: Patchlist.changelog
%endif

Source4000: README.rst
Source4001: rpminspect.yaml
Source4002: gating.yaml

## Patches needed for building this package

%if !%{nopatches}

Patch1: patch-%{patchversion}-redhat.patch
%endif

# Patches from Oracle Linux kernel package
Patch1200: 1200-KVM-x86-mmu-Fix-race-condition-in-direct_page_fault.patch
Patch1201: 1201-prlimit-do_prlimit-needs-to-have-a-speculation-check.patch
Patch1202: 1202-x86-speculation-Allow-enabling-STIBP-with-legacy-IBR.patch
Patch1203: 1203-ipvlan-Fix-out-of-bounds-caused-by-unclear-skb-cb.patch
Patch1204: 1204-net-sched-flower-fix-possible-OOB-write-in-fl_set_ge.patch
  
# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

%description
The kernel meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf [-o] <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf(o) \
%if %{-o:0}%{!-o:1}\
Provides: kernel = %{specversion}-%{pkg_release}\
%endif\
Provides: kernel-%{_target_cpu} = %{specversion}-%{pkg_release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): ((linux-firmware >= 20150904-56.git6ebf5d57) if linux-firmware)\
Recommends: linux-firmware\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
BuildArch: noarch
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Requires: bzip2
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

# with_perf
%endif

%if %{with_tools}
%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
License: GPLv2
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: kernel-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
License: GPLv2
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
License: GPLv2
Requires: kernel-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/gpio-watch(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

%package -n rtla
Summary: Real-Time Linux Analysis tools
License: GPLv2
Requires: libtraceevent
Requires: libtracefs
%description -n rtla
The rtla meta-tool includes a set of commands that aims to analyze
the real-time properties of Linux. Instead of testing Linux as a black box,
rtla leverages kernel tracing capabilities to provide precise information
about the properties and root causes of unexpected results.

# with_tools
%endif

%if %{with_bpftool}

%define bpftoolversion 7.0.0

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
License: GPLv2
Version: %{bpftoolversion}
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Version: %{bpftoolversion}
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specversion}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

# Setting "Version:" above overrides the internal {version} macro,
# need to restore it here
%define version %{specversion}

# with_bpftool
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
License: GPLv2
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3, fuse-libs
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

%define __requires_exclude ^liburandom_read.so.*$

# with_selftests
%endif

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n kernel-abi-stablelists
Summary: The AlmaLinux kernel ABI symbol stablelists
BuildArch: noarch
AutoReqProv: no
%description -n kernel-abi-stablelists
The kABI package contains information pertaining to the AlmaLinux
kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the AlmaLinux
kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
# Explanation of the find_debuginfo_opts: We build multiple kernels (debug
# pae etc.) so the regex filters those kernels appropriately. We also
# have to package several binaries as part of kernel-devel but getting
# unique build-ids is tricky for these userspace binaries. We don't really
# care about debugging those so we just filter those out and remove it.
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} --keep-section '.BTF' -p '.*\/usr\/src\/kernels/.*|XXX' -o ignored-debuginfo.list -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_package(m) \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
Requires: openssl-devel\
Requires: elfutils-libelf-devel\
Requires: bison\
Requires: flex\
Requires: make\
Requires: gcc\
%if %{-m:1}%{!-m:0}\
Requires: kernel-devel-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates an empty kernel-<subpackage>-devel-matched package that
# requires both the core and devel packages locked on the same version.
#	%%kernel_devel_matched_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_matched_package(m) \
%package %{?1:%{1}-}devel-matched\
Summary: Meta package to install matching core and devel packages for a given %{?2:%{2} }kernel\
Requires: kernel%{?1:-%{1}}-devel = %{version}-%{release}\
Requires: kernel%{?1:-%{1}}-core = %{version}-%{release}\
%description %{?1:%{1}-}devel-matched\
This meta package is used to install matching core and devel packages for a given %{?2:%{2} }kernel.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-internal = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for AlmaLinux internal usage.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_extra_package(m) \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-extra = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-extra-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_package(m) \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-core package.
#	%%kernel_modules_core_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_core_package(m) \
%package %{?1:%{1}-}modules-core\
Summary: Core kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-core-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-core-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules-core = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-core\
This package provides essential kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
Requires: kernel-%{1}-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] [-m] [-o] <subpackage>
#
%define kernel_variant_package(n:mo) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Provides: kernel-%{?1:%{1}-}core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
%if %{-m:1}%{!-m:0}\
Requires: kernel-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
Requires: kernel-%{?1:%{1}-}-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%{expand:%%kernel_reqprovconf %{?1:%{1}} %{-o:%{-o}}}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_devel_matched_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_core_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%if %{-m:0}%{!-m:1}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%endif\
%if %{efiuki}\
%package %{?1:%{1}-}uki-virt\
Summary: %{variant_summary} unified kernel image for virtual machines\
Provides: installonlypkg(kernel)\
Provides: kernel-%{?1:%{1}-}uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%endif\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-partner package.
#	%%kernel_modules_partner_package <subpackage> <pretty-name>
#
%define kernel_modules_partner_package() \
%package %{?1:%{1}-}modules-partner\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-partner = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-partner-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-partner\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat partners usage.\
%{nil}

# Now, each variant package.

%if %{with_pae}
%define variant_summary The Linux kernel compiled for Cortex-A15
%kernel_variant_package lpae
%description lpae-core
This package includes a version of the Linux kernel with support for
Cortex-A15 devices with LPAE and HW virtualisation support
%endif

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package -o zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%if %{with_arm64_64k}
%define variant_summary The Linux kernel compiled for 64k pagesize usage
%kernel_variant_package 64k
%description 64k-core
The kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
%endif

%if %{with_arm64_64k} && %{with_debug}
%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m 64k-debug
%else
%kernel_variant_package 64k-debug
%endif
%description 64k-debug-core
The debug kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if !%{debugbuildsenabled}
%kernel_variant_package -m debug
%else
%kernel_variant_package debug
%endif
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{efiuki}
%description debug-uki-virt
Prebuilt debug unified kernel image for virtual machines.

%description uki-virt
Prebuilt default unified kernel image for virtual machines.
%endif

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='git apply'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME}.spec ; then
    if [ "${patch:0:8}" != "patch-%{kversion}." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-%{tarfile_release} -c
mv linux-%{tarfile_release} linux-%{KVERREL}

cd linux-%{KVERREL}
cp -a %{SOURCE1} .

%if !%{nopatches}

ApplyOptionalPatch patch-%{patchversion}-redhat.patch
%endif

ApplyPatch 1200-KVM-x86-mmu-Fix-race-condition-in-direct_page_fault.patch
ApplyPatch 1201-prlimit-do_prlimit-needs-to-have-a-speculation-check.patch
ApplyPatch 1202-x86-speculation-Allow-enabling-STIBP-with-legacy-IBR.patch
ApplyPatch 1203-ipvlan-Fix-out-of-bounds-caused-by-unclear-skb-cb.patch
ApplyPatch 1204-net-sched-flower-fix-possible-OOB-write-in-fl_set_ge.patch
ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}-%{release}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Mangle /usr/bin/python shebangs to /usr/bin/python3
# Mangle all Python shebangs to be Python 3 explicitly
# -p preserves timestamps
# -n prevents creating ~backup files
# -i specifies the interpreter for the shebang
# This fixes errors such as
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i "%{__python3} %{py3_shbang_opts}" -p -n \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	scripts/jobserver-exec \
	tools \
	Documentation \
	scripts/clang-tools

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE80} .
# merge.pl
cp %{SOURCE3000} .
# kernel-local
cp %{SOURCE3001} .
FLAVOR=%{primary_target} SPECVERSION=%{version} ./generate_all_configs.sh %{debugbuildsenabled}

# Merge in any user-provided local config option changes
%ifnarch %nobuildarches
for i in %{all_arch_configs}
do
  mv $i $i.tmp
  ./merge.pl %{SOURCE3001} $i.tmp > $i
%if %{with_gcov}
  echo "Merging with gcov options"
  cat %{SOURCE75}
  mv $i $i.tmp
  ./merge.pl %{SOURCE75} $i.tmp > $i
%endif
  rm $i.tmp
done
%endif

%if %{with clang_lto}
for i in *aarch64*.config *x86_64*.config; do
  sed -i 's/# CONFIG_LTO_CLANG_THIN is not set/CONFIG_LTO_CLANG_THIN=y/' $i
  sed -i 's/CONFIG_LTO_NONE=y/# CONFIG_LTO_NONE is not set/' $i
done
%endif

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%if %{signkernel}%{signmodules}
openssl x509 -inform der -in %{SOURCE100} -out rheldup3.pem
openssl x509 -inform der -in %{SOURCE101} -out rhelkpatch1.pem
cat rheldup3.pem rhelkpatch1.pem > ../certs/rhel.pem
%if %{signkernel}
%ifarch s390x ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
%endif
for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif
%endif

# Adjust FIPS module name for RHEL
%if 0%{?rhel}
for i in *.config; do
  sed -i 's/CONFIG_CRYPTO_FIPS_NAME=.*/CONFIG_CRYPTO_FIPS_NAME="AlmaLinux %{rhel} - Kernel Cryptographic API"/' $i
done
%endif

cp %{SOURCE81} .
OPTS=""
%if %{with_configchecks}
	OPTS="$OPTS -w -n -c"
%endif
%if %{with clang_lto}
for opt in %{clang_make_opts}; do
  OPTS="$OPTS -m $opt"
done
%endif
RHJOBS=$RPM_BUILD_NCPUS PACKAGE_NAME=kernel ./process_configs.sh $OPTS ${specversion}

cp %{SOURCE82} .
RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh %{primary_target}

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -delete >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -delete >/dev/null

cd ..

###
### build
###
%build

rm -rf %{buildroot_unstripped} || true
mkdir -p %{buildroot_unstripped}

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  %{?build_cflags}
%define build_hostldflags %{?build_ldflags}
%endif

%define make %{__make} %{?cross_opts} %{?make_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

InitBuildVars() {
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Variant=$1

    # Pick the right kernel config file
    Config=kernel-%{version}-%{_target_cpu}${Variant:+-${Variant}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Variant:++${Variant}}

    KernelVer=%{version}-%{release}.%{_target_cpu}${Variant:++${Variant}}

    # make sure EXTRAVERSION says what we want it to say
    # Trim the release if this is a CI build, since KERNELVERSION is limited to 64 characters
    ShortRel=$(perl -e "print \"%{release}\" =~ s/\.pr\.[0-9A-Fa-f]{32}//r")
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -${ShortRel}.%{_target_cpu}${Variant:++${Variant}}/" Makefile

    # if pre-rc1 devel kernel, must fix up PATCHLEVEL for our versioning scheme
    # if we are post rc1 this should match anyway so this won't matter
    perl -p -i -e 's/^PATCHLEVEL.*/PATCHLEVEL = %{patchlevel}/' Makefile

    %{make} %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp configs/x509.genkey certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Variant" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    DoVDSO=$3
    Variant=$4
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Variant" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    InitBuildVars $Variant

    echo BUILDING A KERNEL FOR ${Variant} %{_target_cpu}...

    %{make} ARCH=$Arch olddefconfig >/dev/null

    # This ensures build-ids are unique to allow parallel debuginfo
    perl -p -i -e "s/^CONFIG_BUILD_SALT.*/CONFIG_BUILD_SALT=\"%{KVERREL}\"/" .config
    %{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/systemtap
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch %{arm} aarch64
    %{make} ARCH=$Arch dtbs INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    %{make} ARCH=$Arch dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f -delete
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ "$DoModules" == "1" -a "%{signmodules}" == "1" ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    # signkernel
    %endif

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    (cd $RPM_BUILD_ROOT/%{image_install_path} && sha512hmac $InstallName-$KernelVer) > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT %{?_smp_mflags} modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    # add an a noop %%defattr statement 'cause rpm doesn't like empty file list files
    echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-ldsoconf.list
    if [ $DoVDSO -ne 0 ]; then
        %{make} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ -s ldconfig-kernel.conf ]; then
             install -D -m 444 ldconfig-kernel.conf \
                $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
	     echo /etc/ld.so.conf.d/kernel-$KernelVer.conf >> ../kernel${Variant:+-${Variant}}-ldsoconf.list
        fi

        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # CONFIG_KERNEL_HEADER_TEST generates some extra files in the process of
    # testing so just delete
    find . -name *.h.s -delete
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ ! -e Module.symvers ]; then
        touch Module.symvers
    fi
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Variant" != "zfcpdump" -a "$Variant" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Variant:+.${Variant}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Variant" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

%ifarch s390x
    # CONFIG_EXPOLINE_EXTERN=y produces arch/s390/lib/expoline/expoline.o
    # which is needed during external module build.
    if [ -f arch/s390/lib/expoline/expoline.o ]; then
      cp -a --parents arch/s390/lib/expoline/expoline.o $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%endif

    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Files for 'make prepare' to succeed with kernel-devel.
    cp -a --parents tools/include/linux/compiler* $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux/types.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/build/Build.include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/fixdep.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/sync-check.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp --parents security/selinux/include/policycap_names.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents security/selinux/include/policycap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp -a --parents tools/include/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/vdso $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/scripts/utilities.mak $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/subcmd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/*.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/*.[ch] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/include/objtool/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/bpf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/bpf/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -f tools/objtool/fixdep ]; then
      cp -a tools/objtool/fixdep $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # include the machine specific headers for ARM variants, if available.
%ifarch %{arm}
    if [ -d arch/%{asmarch}/mach-${Variant}/include ]; then
      cp -a --parents arch/%{asmarch}/mach-${Variant}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    # include a few files for 'make prepare'
    cp -a --parents arch/arm/tools/gen-mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/arm/tools/mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch i686 x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents scripts/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents scripts/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents tools/arch/x86/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/lib $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/lib/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/tools/gen-insn-attr-x86.awk $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%endif
    # Clean up intermediate tools files
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +

    # Make sure the Makefile, version.h, and auto.conf have a matching
    # timestamp so that external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    if [ -n "%{vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    remove_depmod_files()
    {
        # remove files that will be auto generated by depmod at rpm -i time
        pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
            rm -f modules.{alias,alias.bin,builtin.alias.bin,builtin.bin} \
                  modules.{dep,dep.bin,devname,softdep,symbols,symbols.bin}
        popd
    }

    remove_depmod_files

    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer $(realpath configs/mod-extra.list)
    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE84} internal
%if 0%{!?fedora:1}
    # Identify modules in the kernel-modules-partner package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE85} partner
%endif

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    cp configs/filter-*.sh $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if 0%{!?fedora:1}
    # don't include anything going int kernel-modules-partner in the file lists
    xargs rm -rf < mod-partner.list
%endif

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	./filter-modules.sh modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

%if %{efiuki}
    popd

    KernelUnifiedImageDir="$RPM_BUILD_ROOT/lib/modules/$KernelVer"
    KernelUnifiedImage="$KernelUnifiedImageDir/$InstallName-virt.efi"

    mkdir -p $KernelUnifiedImageDir

    dracut --conf=%{SOURCE150} \
           --confdir=$(mktemp -d) \
           --verbose \
           --kver "$KernelVer" \
           --kmoddir "$RPM_BUILD_ROOT/lib/modules/$KernelVer/" \
           --logfile=$(mktemp) \
           --uefi \
           --kernel-image $(realpath $KernelImage) \
           --kernel-cmdline 'console=tty0 console=ttyS0' \
	   $KernelUnifiedImage

%if %{signkernel}

    %pesign -s -i $KernelUnifiedImage -o $KernelUnifiedImage.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    if [ ! -s $KernelUnifiedImage.signed ]; then
      echo "pesigning failed"
      exit 1
    fi
    mv $KernelUnifiedImage.signed $KernelUnifiedImage

# signkernel
%endif

    pushd $RPM_BUILD_ROOT

# efiuki
%endif

    remove_depmod_files

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    # Just "cp -r" can be very slow: here, it rewrites _existing files_
    # with open(O_TRUNC). Many filesystems synchronously wait for metadata
    # update for such file rewrites (seen in strace as final close syscall
    # taking a long time). On a rotational disk, cp was observed to take
    # more than 5 minutes on ext4 and more than 15 minutes (!) on xfs.
    # With --remove-destination, we avoid this, and copying
    # (with enough RAM to cache it) takes 5 seconds:
    cp -r --remove-destination restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../kernel${Variant:+-${Variant}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../kernel${Variant:+-${Variant}}-modules-extra.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-internal.list >> ../kernel${Variant:+-${Variant}}-modules-internal.list
%if 0%{!?fedora:1}
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-partner.list >> ../kernel${Variant:+-${Variant}}-modules-partner.list
%endif

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if 0%{!?fedora:1}
    rm -f $RPM_BUILD_ROOT/mod-partner.list
%endif

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%ifnarch armv7hl
    # Generate vmlinux.h and put it to kernel-devel path
    # zfcpdump build does not have btf anymore
    if [ "$Variant" != "zfcpdump" ]; then
        # Build the bootstrap bpftool to generate vmlinux.h
        make -C tools/bpf/bpftool bootstrap
        tools/bpf/bpftool/bootstrap/bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h
    fi
%endif

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -delete

    # AlmaLinux UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
%if %{signkernel}
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
        install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
    fi
    %endif
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
        # Save the signing keys so we can sign the modules in __modsign_install_post
        cp certs/signing_key.pem certs/signing_key.pem.sign${Variant:++${Variant}}
        cp certs/signing_key.x509 certs/signing_key.x509.sign${Variant:++${Variant}}
        %ifarch s390x ppc64le
        if [ ! -x /usr/bin/rpm-sign ]; then
            install -m 0644 certs/signing_key.x509.sign${Variant:++${Variant}} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
            openssl x509 -in certs/signing_key.pem.sign${Variant:++${Variant}} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
            chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
        fi
        %endif
    fi
%endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Variant" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{_use_vdso} debug
%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k-debug
%endif
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{_use_vdso} zfcpdump
%endif

%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image %{use_vdso} lpae
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{_use_vdso}
%endif

%ifnarch noarch i686
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_pae} && !%{with_up} && !%{with_arm64_64k}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
InitBuildVars
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags} -Wl,-E" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%global tools_make \
  CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{make} %{?make_opts}

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make}
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}"
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
# build VM tools
pushd tools/vm/
%{tools_make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" slabinfo page_owner_sort
popd
pushd tools/tracing/rtla
%{tools_make}
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%global bpftool_make \
  %{__make} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT %{?make_opts} VMLINUX_H="${RPM_VMLINUX_H}" V=1
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} %{?_smp_mflags} headers_install

# If we re building only tools without kernel, we need to generate config
# headers and prepare tree for modules building. The modules_prepare target
# will cover both.
if [ ! -f include/generated/autoconf.h ]; then
   %{make} %{?_smp_mflags} modules_prepare
fi

%{make} %{?_smp_mflags} ARCH=$Arch V=1 M=samples/bpf/ VMLINUX_H="${RPM_VMLINUX_H}" || true

# Prevent bpf selftests to build bpftool repeatedly:
export BPFTOOL=$(pwd)/tools/bpf/bpftool/bpftool

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="bpf vm livepatch net net/forwarding net/mptcp netfilter tc-testing memfd" SKIP_TARGETS="" FORCE_TARGETS=1 INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests VMLINUX_H="${RPM_VMLINUX_H}" DEFAULT_INSTALL_HDR_PATH=0 install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
for dir in bpf bpf/no_alu32 bpf/progs; do
	# In ARK, the rpm build continues even if some of the selftests
	# cannot be built. It's not always possible to build selftests,
	# as upstream sometimes dependens on too new llvm version or has
	# other issues. If something did not get built, just skip it.
	test -d $dir || continue
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 -type f \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir || true
done
ln -sr  %{buildroot}%{_libexecdir}/kselftests/bpf/bpftool %{buildroot}%{_libexecdir}/kselftests/bpf/no_alu32/bpftool
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs"
popd
export -n BPFTOOL
%endif

%if %{with_doc}
# Make the HTML pages.
%{__make} PYTHON=/usr/bin/python3 htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "variant" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that variant.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump variant as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_pae}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+lpae certs/signing_key.x509.sign+lpae $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+lpae/ \
    fi \
    if [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+64k certs/signing_key.x509.sign+64k $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ] && [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+64k-debug certs/signing_key.x509.sign+64k-debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k-debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    echo "Compressing kernel modules ..." \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs -n 16 -P${RPM_BUILD_NCPUS} -r xz; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
# Delete the debuginfo for kernel-devel files
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
  rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/src; \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__restore_unstripped_root_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{__make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

%endif

%if %{with_cross_headers}
%if 0%{?fedora}
HDR_ARCH_LIST='arm arm64 powerpc s390 x86'
%else
HDR_ARCH_LIST='arm64 powerpc s390 x86'
%endif
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers

for arch in $HDR_ARCH_LIST; do
	mkdir $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}
	%{__make} ARCH=${arch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch} headers_install
done

find $RPM_BUILD_ROOT/usr/tmp-headers \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
	mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
	mv $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}" DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
%{__make} INSTALL_ROOT=%{buildroot} install-tools
%{__make} INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/vm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
pushd tools/tracing/rtla/
%{tools_make} DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_bindir}/osnoise
rm -f %{buildroot}%{_bindir}/timerlat
(cd %{buildroot}

        ln -sf rtla ./%{_bindir}/osnoise
        ln -sf rtla ./%{_bindir}/timerlat
)
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf || true
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install vm selftests
pushd tools/testing/selftests/vm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install netfilter selftests
pushd tools/testing/selftests/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
popd

# install memfd selftests
pushd tools/testing/selftests/memfd
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
popd
%endif

###
### clean
###

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools
%systemd_post cpupower.service

%preun -n kernel-tools
%systemd_preun cpupower.service

%postun -n kernel-tools
%systemd_postun cpupower.service

%post -n kernel-tools-libs
/sbin/ldconfig

%postun -n kernel-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
# Note we don't run hardlink if ostree is in use, as ostree is
# a far more sophisticated hardlink implementation.
# https://github.com/projectatomic/rpm-ostree/commit/58a79056a889be8814aa51f507b2c7a4dccee526
#
# The deletion of *.hardlink-temporary files is a temporary workaround
# for this bug in the hardlink binary (fixed in util-linux 2.38):
# https://github.com/util-linux/util-linux/issues/1602
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/bin/hardlink -a ! -e /run/ostree-booted ] \
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f > /dev/null\
     done;\
     /usr/bin/find /usr/src/kernels -type f -name '*.hardlink-temporary' -delete\
    )\
fi\
%if %{with_cross}\
    echo "Building scripts"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-partner package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_partner_post [<subpackage>]
#
%define kernel_modules_partner_post() \
%{expand:%%post %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-core package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_core_post [<subpackage>]
#
# FIXME: /bin/kernel-install can't handle UKIs (yet), so cleanup depmod files in %postun for now.
#
%define kernel_modules_core_post() \
%{expand:%%posttrans %{?1:%{1}-}modules-core}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-core}\
rm -f /lib/modules/%{KVERREL}%{?1:+%{1}}/modules.*\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1:%{1}-}core}\
%if 0%{!?fedora:1}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}}\
/bin/kernel-install add %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
if [[ ! -e "/boot/symvers-%{KVERREL}%{?1:+%{1}}.gz" ]]; then\
    ln -s "/lib/modules/%{KVERREL}%{?1:+%{1}}/symvers.gz" "/boot/symvers-%{KVERREL}%{?1:+%{1}}.gz"\
    command -v restorecon &>/dev/null && restorecon "/boot/symvers-%{KVERREL}%{?1:+%{1}}.gz" \
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_core_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_post %{?-v*}}\
%endif\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
%{nil}

#
# This macro defines scripts for a kernel*-uki-virt package
#
# FIXME: /bin/kernel-install can't handle UKIs (yet), so just cp/rm as temporary stop-gap
#
%define kernel_uki_virt_scripts() \
%{expand:%%posttrans %{?1:%{1}-}uki-virt}\
mkdir -p /boot/efi/EFI/Linux\
cp /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz-virt.efi /boot/efi/EFI/Linux/vmlinuz-%{KVERREL}%{?1:+%{1}}-virt.efi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}uki-virt}\
rm -f /boot/efi/EFI/Linux/vmlinuz-%{KVERREL}%{?1:+%{1}}-virt.efi\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1:%{1}-}core}\
/bin/kernel-install remove %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%{nil}

%if %{efiuki}
%kernel_uki_virt_scripts
%endif

%kernel_variant_preun
%kernel_variant_post -r kernel-smp

%if %{with_pae}
%kernel_variant_preun lpae
%kernel_variant_post -v lpae -r (kernel|kernel-smp)
%endif

%if %{with_zfcpdump}
%kernel_variant_preun zfcpdump
%kernel_variant_post -v zfcpdump
%endif

%if %{with_arm64_64k}
%kernel_variant_preun 64k
%kernel_variant_post -v 64k
%endif

%if %{with_debug} && %{with_arm64_64k}
%kernel_variant_preun 64k-debug
%kernel_variant_post -v 64k-debug
%endif

%if %{with_debug}
%if %{efiuki}
%kernel_uki_virt_scripts debug
%endif
%kernel_variant_preun debug
%kernel_variant_post -v debug
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%endif

%if %{with_cross_headers}
%files cross-headers
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n kernel-abi-stablelists
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}
%endif

%if %{with_perf}
%files -n perf
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%endif
# with_perf
%endif

%if %{with_tools}
%ifnarch %{cpupowerarchs}
%files -n kernel-tools
%else
%files -n kernel-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_bindir}/gpio-watch
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo

%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.1

%files -n kernel-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif

%files -n rtla
%{_bindir}/rtla
%{_bindir}/osnoise
%{_bindir}/timerlat
%{_mandir}/man1/rtla-osnoise-hist.1.gz
%{_mandir}/man1/rtla-osnoise-top.1.gz
%{_mandir}/man1/rtla-osnoise.1.gz
%{_mandir}/man1/rtla-timerlat-hist.1.gz
%{_mandir}/man1/rtla-timerlat-top.1.gz
%{_mandir}/man1/rtla-timerlat.1.gz
%{_mandir}/man1/rtla.1.gz

# with_tools
%endif

%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-gen.8.gz
%{_mandir}/man8/bpftool-iter.8.gz
%{_mandir}/man8/bpftool-link.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz
%{_mandir}/man8/bpftool-struct_ops.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%ifnarch %nobuildarches noarch
%files
%endif

%if %{with_gcov}
%ifnarch %nobuildarches noarch
%files gcov
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <use_vdso> <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files %{?1:-f kernel-%{?3:%{3}-}ldsoconf.list} %{?3:%{3}-}core}\
%{!?_licensedir:%global license %%doc}\
%license linux-%{KVERREL}/COPYING-%{version}-%{release}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch %{arm} aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-core.list %{?3:%{3}-}modules-core}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/systemtap\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.block\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.drm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.modesetting\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.networking\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.order\
%{expand:%%files -f kernel-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%{expand:%%files %{?3:%{3}-}devel}\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}devel-matched}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-internal.list %{?3:%{3}-}modules-internal}\
%if 0%{!?fedora:1}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-partner.list %{?3:%{3}-}modules-partner}\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%endif\
%endif\
%if %{efiuki}\
%{expand:%%files %{?3:%{3}-}uki-virt}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi\
%ghost /%{image_install_path}/efi/EFI/Linux/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}-virt.efi\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%endif\
%endif\
%{nil}

%kernel_variant_files %{_use_vdso} %{with_up}
%kernel_variant_files %{_use_vdso} %{with_debug} debug
%if %{with_arm64_64k}
%kernel_variant_files %{_use_vdso} %{with_debug} 64k-debug
%endif
%if %{with_debug_meta}
%files debug
%files debug-core
%files debug-devel
%files debug-devel-matched
%files debug-modules
%files debug-modules-core
%files debug-modules-extra
%if %{with_arm64_64k}
%files 64k-debug
%files 64k-debug-core
%files 64k-debug-devel
%files 64k-debug-devel-matched
%files 64k-debug-modules
%files 64k-debug-modules-extra
%endif
%endif
%kernel_variant_files %{use_vdso} %{with_pae} lpae
%kernel_variant_files %{_use_vdso} %{with_zfcpdump} zfcpdump
%kernel_variant_files %{_use_vdso} %{with_arm64_64k} 64k

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Tue Aug 01 2023 Nagappan Ramasamy Palaniappan <nagappan.ramasamy.palaniappan@oracle.com> - [5.14.0-284.25.1.el9_2]	
- KVM x86 mmuFix race condition in direct_page_fault
- prlimit do_prlimit needs to have a speculation check
- x86 speculation Allow enabling STIBP with legacy IBR
- ipvlan Fix out of bounds caused by unclear skb cb
- net sched flower fix possible OOB write in fl_set_geneve_opt

* Wed May 31 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.18.1.el9_2]
- x86/i8259: Mark legacy PIC interrupts with IRQ_LEVEL (Baoquan He) [2210614 2116317]
- bluetooth: Perform careful capability checks in hci_sock_ioctl() (Ricardo Robaina) [2196340 2196341] {CVE-2023-2002}
- perf vendor events intel: Refresh jaketown metrics and events (Michael Petlan) [2207471 2190010]
- perf vendor events: Update Intel jaketown (Michael Petlan) [2207471 2190010]
- perf vendor events intel: Refresh ivytown metrics and events (Michael Petlan) [2207471 2190010]
- perf vendor events: Update Intel ivytown (Michael Petlan) [2207471 2190010]
- hugetlbfs: don't delete error page from pagecache (Aristeu Rozanski) [2192348 2184858]

* Thu May 25 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.17.1.el9_2]
- cifs: fix wrong unlock before return from cifs_tree_connect() (Ronnie Sahlberg) [2209045 2182524]
- CI: Use GA builder container (Michael Hofmann)
- Remove the unnecessary unicode character (Tao Liu) [2208242 2187350]
- workqueue: Fold rebind_worker() within rebind_workers() (Waiman Long) [2203229 2182337]
- workqueue: Unbind kworkers before sending them to exit() (Waiman Long) [2203229 2182337]
- workqueue: Don't hold any lock while rcuwait'ing for !POOL_MANAGER_ACTIVE (Waiman Long) [2203229 2182337]
- workqueue: Convert the idle_timer to a timer + work_struct (Waiman Long) [2203229 2182337]
- workqueue: Factorize unbind/rebind_workers() logic (Waiman Long) [2203229 2182337]
- workqueue: Protects wq_unbound_cpumask with wq_pool_attach_mutex (Waiman Long) [2203229 2182337]
- workqueue: don't skip lockdep work dependency in cancel_work_sync() (Waiman Long) [2203229 2182337]
- workqueue: Change the comments of the synchronization about the idle_list (Waiman Long) [2203229 2182337]
- workqueue: Remove the mb() pair between wq_worker_sleeping() and insert_work() (Waiman Long) [2203229 2182337]
- workqueue: Remove the cacheline_aligned for nr_running (Waiman Long) [2203229 2182337]
- workqueue: Move the code of waking a worker up in unbind_workers() (Waiman Long) [2203229 2182337]
- workqueue: Remove the outdated comment before wq_worker_sleeping() (Waiman Long) [2203229 2182337]
- workqueue: Fix unbind_workers() VS wq_worker_sleeping() race (Waiman Long) [2203229 2182337]
- NFSD: RHEL-only bug introduced in fix for COMMIT and NFS4ERR_DELAY loop (Benjamin Coddington) [2203335 2196432]
- NFSD: Fix problem of COMMIT and NFS4ERR_DELAY in infinite loop (Benjamin Coddington) [2203335 2196432]
- net: tls: fix possible race condition between do_tls_getsockopt_conf() and do_tls_setsockopt_conf() (Sabrina Dubroca) [2184152 2179816] {CVE-2023-28466}
- netfilter: nf_tables: deactivate anonymous set from preparation phase (Florian Westphal) [2196134 2196135] {CVE-2023-32233}
- xfs: verify buffer contents when we skip log replay (Andrey Albershteyn) [2187447 2187448] {CVE-2023-2124}
- watchdog: wdat_wdt: Avoid unimplemented get_timeleft (David Arcari) [2192585 2189867]
- watchdog: wdat_wdt: Set the min and max timeout values properly (David Arcari) [2192585 2189867]
- watchdog: wdat_wdt: Remove #ifdef guards for PM related functions (David Arcari) [2192585 2189867]
- watchdog: wdat_wdt: Stop watchdog when uninstalling module (David Arcari) [2192585 2189867]
- watchdog: wdat_wdt: Stop watchdog when rebooting the system (David Arcari) [2192585 2189867]
- watchdog: wdat_wdt: Using the existing function to check parameter timeout (David Arcari) [2192585 2189867]
- i2c: xgene-slimpro: Fix out-of-bounds bug in xgene_slimpro_i2c_xfer() (Tony Camuso) [2189487 2188409] {CVE-2023-2194}
- mm/filemap: fix page end in filemap_get_read_batch (Nico Pache) [2189349 2181263]

* Thu May 18 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.16.1.el9_2]
- perf: Fix check before add_event_to_groups() in perf_group_detach() (Michael Petlan) [2192659 2192660] {CVE-2023-2235}
- sched/core: Fix arch_scale_freq_tick() on tickless systems (Phil Auld) [2203178 1996625]
- ice: sleep, don't busy-wait, in the SQ send retry loop (Michal Schmidt) [2203154 RHEL-406]
- ice: remove unused buffer copy code in ice_sq_send_cmd_retry() (Michal Schmidt) [2203154 RHEL-406]
- ice: sleep, don't busy-wait, for ICE_CTL_Q_SQ_CMD_TIMEOUT (Michal Schmidt) [2203154 RHEL-406]
- ice: remove ice_ctl_q_info::sq_cmd_timeout (Michal Schmidt) [2203154 RHEL-406]
- ice: increase the GNSS data polling interval to 20 ms (Michal Schmidt) [2203154 RHEL-406]
- ice: do not busy-wait to read GNSS data (Michal Schmidt) [2203154 RHEL-406]
- redhat: set default zstream brew target for 9.2 (Herton R. Krzesinski)

* Thu May 11 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.15.1.el9_2]
- redhat/configs: Fix incorrect configs location and content (Vladis Dronov)
- wifi: iwlwifi: mvm: protect TXQ list manipulation (Jose Ignacio Tornos Martinez) [2186723 2183490]
- wifi: iwlwifi: mvm: fix mvmtxq->stopped handling (Jose Ignacio Tornos Martinez) [2186723 2183490]

* Fri May 05 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.14.1.el9_2]
- cpufreq: intel_pstate: hybrid: Use known scaling factor for P-cores (David Arcari) [2178857 2155861]
- cpufreq: intel_pstate: Read all MSRs on the target CPU (David Arcari) [2178857 2155861]

* Thu Apr 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.13.1.el9_2]
- sched/deadline: Add more reschedule cases to prio_changed_dl() (Valentin Schneider) [2188655 2123590]
- sched/rt: Fix bad task migration for rt tasks (Valentin Schneider) [2187709 2182900]
- crypto: qat - add support for 402xx devices (Vladis Dronov) [2176846 2144528]
- crypto: qat - drop log level of msg in get_instance_node() (Vladis Dronov) [2176846 2144528]
- crypto: qat - fix out-of-bounds read (Vladis Dronov) [2176846 2144528]
- Documentation: qat: change kernel version (Vladis Dronov) [2176846 2144528]
- crypto: qat - add qat_zlib_deflate (Vladis Dronov) [2176846 2144528]
- crypto: qat - extend buffer list logic interface (Vladis Dronov) [2176846 2144528]
- crypto: qat - fix spelling mistakes from 'bufer' to 'buffer' (Vladis Dronov) [2176846 2144528]
- crypto: qat - add resubmit logic for decompression (Vladis Dronov) [2176846 2144528]
- crypto: acomp - define max size for destination (Vladis Dronov) [2176846 2144528]
- crypto: qat - enable deflate for QAT GEN4 (Vladis Dronov) [2176846 2144528]
- crypto: qat - expose deflate through acomp api for QAT GEN2 (Vladis Dronov) [2176846 2144528]
- crypto: qat - rename and relocate GEN2 config function (Vladis Dronov) [2176846 2144528]
- crypto: qat - relocate qat_algs_alloc_flags() (Vladis Dronov) [2176846 2144528]
- crypto: qat - relocate backlog related structures (Vladis Dronov) [2176846 2144528]
- crypto: qat - extend buffer list interface (Vladis Dronov) [2176846 2144528]
- crypto: qat - generalize crypto request buffers (Vladis Dronov) [2176846 2144528]
- crypto: qat - change bufferlist logic interface (Vladis Dronov) [2176846 2144528]
- crypto: qat - rename bufferlist functions (Vladis Dronov) [2176846 2144528]
- crypto: qat - relocate bufferlist logic (Vladis Dronov) [2176846 2144528]
- crypto: qat - Use helper to set reqsize (Vladis Dronov) [2176846 2144528]
- crypto: kpp - Add helper to set reqsize (Vladis Dronov) [2176846 2144528]
- crypto: qat - fix error return code in adf_probe (Vladis Dronov) [2176846 2144528]
- crypto: qat - remove ADF_STATUS_PF_RUNNING flag from probe (Vladis Dronov) [2176846 2144528]

* Thu Apr 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.12.1.el9_2]
- blk-mq: directly poll requests (Ming Lei) [2187536 2186507]
- crypto: drbg - Only fail when jent is unavailable in FIPS mode (Vladis Dronov) [2181727 2175240]
- crypto: jitter - permanent and intermittent health errors (Vladis Dronov) [2181727 2175240]
- crypto: jitter - quit sample collection loop upon RCT failure (Vladis Dronov) [2181727 2175240]
- crypto: jitter - don't limit ->health_failure check to FIPS mode (Vladis Dronov) [2181727 2175240]
- crypto: jitter - drop kernel-doc notation (Vladis Dronov) [2181727 2175240]
- KVM: VMX: Fix crash due to uninitialized current_vmcs (Vitaly Kuznetsov) [2186822 2181329]

* Wed Apr 12 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.11.1.el9_2]
- vfio: Make the group FD disassociate from the iommu_group (Alex Williamson) [2180649]
- vfio: Hold a reference to the iommu_group in kvm for SPAPR (Alex Williamson) [2180649]
- vfio: Add vfio_file_is_group() (Alex Williamson) [2180649]
- vfio: Change vfio_group->group_rwsem to a mutex (Alex Williamson) [2180649]
- vfio: Remove the vfio_group->users and users_comp (Alex Williamson) [2180649]
- vfio: Follow a strict lifetime for struct iommu_group (Alex Williamson) [2180649]

* Wed Apr 05 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.10.1.el9_2]
- dm: fix __send_duplicate_bios() to always allow for splitting IO (Benjamin Marzinski) [2184420]
- dm: fix improper splitting for abnormal bios (Benjamin Marzinski) [2184420]

* Tue Apr 04 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.9.1.el9_2]
- ovl: fail on invalid uid/gid mapping at copy up (Miklos Szeredi) [2165345] {CVE-2023-0386}

* Mon Apr 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.8.1.el9_2]
- Reinstate "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2181344]
- iavf: fix hang on reboot with ice (Stefan Assmann) [2175775]
- xfs: fix off-by-one-block in xfs_discard_folio() (Carlos Maiolino) [2178173]

* Thu Mar 30 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.7.1.el9_2]
- rxrpc: Fix wrong error return in rxrpc_connect_call() (Marc Dionne) [2170099]
- rxrpc: Fix incoming call setup race (Marc Dionne) [2170099]
- rxrpc: Move client call connection to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Move the client conn cache management to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Remove call->state_lock (Marc Dionne) [2170099]
- rxrpc: Move call state changes from recvmsg to I/O thread (Marc Dionne) [2170099]
- rxrpc: Move call state changes from sendmsg to I/O thread (Marc Dionne) [2170099]
- rxrpc: Wrap accesses to get call state to put the barrier in one place (Marc Dionne) [2170099]
- rxrpc: Split out the call state changing functions into their own file (Marc Dionne) [2170099]
- rxrpc: Set up a connection bundle from a call, not rxrpc_conn_parameters (Marc Dionne) [2170099]
- rxrpc: Offload the completion of service conn security to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Make the set of connection IDs per local endpoint (Marc Dionne) [2170099]
- rxrpc: Tidy up abort generation infrastructure (Marc Dionne) [2170099]
- rxrpc: Clean up connection abort (Marc Dionne) [2170099]
- rxrpc: Implement a mechanism to send an event notification to a connection (Marc Dionne) [2170099]
- rxrpc: Only disconnect calls in the I/O thread (Marc Dionne) [2170099]
- rxrpc: Only set/transmit aborts in the I/O thread (Marc Dionne) [2170099]
- rxrpc: Separate call retransmission from other conn events (Marc Dionne) [2170099]
- rxrpc: Make the local endpoint hold a ref on a connected call (Marc Dionne) [2170099]
- rxrpc: Stash the network namespace pointer in rxrpc_local (Marc Dionne) [2170099]
- rxrpc: Fix a couple of potential use-after-frees (Marc Dionne) [2170099]
- rxrpc: Fix the return value of rxrpc_new_incoming_call() (Marc Dionne) [2170099]
- rxrpc: rxperf: Fix uninitialised variable (Marc Dionne) [2170099]
- rxrpc: Fix I/O thread stop (Marc Dionne) [2170099]
- rxrpc: Fix switched parameters in peer tracing (Marc Dionne) [2170099]
- rxrpc: Fix locking issues in rxrpc_put_peer_locked() (Marc Dionne) [2170099]
- rxrpc: Fix I/O thread startup getting skipped (Marc Dionne) [2170099]
- rxrpc: Fix NULL deref in rxrpc_unuse_local() (Marc Dionne) [2170099]
- rxrpc: Fix security setting propagation (Marc Dionne) [2170099]
- rxrpc: Fix missing unlock in rxrpc_do_sendmsg() (Marc Dionne) [2170099]
- rxrpc: Transmit ACKs at the point of generation (Marc Dionne) [2170099]
- rxrpc: Fold __rxrpc_unuse_local() into rxrpc_unuse_local() (Marc Dionne) [2170099]
- rxrpc: Move the cwnd degradation after transmitting packets (Marc Dionne) [2170099]
- rxrpc: Trace/count transmission underflows and cwnd resets (Marc Dionne) [2170099]
- rxrpc: Remove the _bh annotation from all the spinlocks (Marc Dionne) [2170099]
- rxrpc: Make the I/O thread take over the call and local processor work (Marc Dionne) [2170099]
- rxrpc: Extract the peer address from an incoming packet earlier (Marc Dionne) [2170099]
- rxrpc: Reduce the use of RCU in packet input (Marc Dionne) [2170099]
- rxrpc: Simplify skbuff accounting in receive path (Marc Dionne) [2170099]
- rxrpc: Remove RCU from peer->error_targets list (Marc Dionne) [2170099]
- rxrpc: Move DATA transmission into call processor work item (Marc Dionne) [2170099]
- rxrpc: Copy client call parameters into rxrpc_call earlier (Marc Dionne) [2170099]
- rxrpc: Implement a mechanism to send an event notification to a call (Marc Dionne) [2170099]
- rxrpc: Don't use sk->sk_receive_queue.lock to guard socket state changes (Marc Dionne) [2170099]
- rxrpc: Remove call->input_lock (Marc Dionne) [2170099]
- rxrpc: Move error processing into the local endpoint I/O thread (Marc Dionne) [2170099]
- rxrpc: Move packet reception processing into I/O thread (Marc Dionne) [2170099]
- rxrpc: Create a per-local endpoint receive queue and I/O thread (Marc Dionne) [2170099]
- rxrpc: Split the receive code (Marc Dionne) [2170099]
- rxrpc: Don't hold a ref for connection workqueue (Marc Dionne) [2170099]
- rxrpc: Don't hold a ref for call timer or workqueue (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for sk_buff tracing (Marc Dionne) [2170099]
- rxrpc: Trace rxrpc_bundle refcount (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_call tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_conn tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_peer tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_local tracing (Marc Dionne) [2170099]
- rxrpc: Extract the code from a received ABORT packet much earlier (Marc Dionne) [2170099]
- rxrpc: Drop rxrpc_conn_parameters from rxrpc_connection and rxrpc_bundle (Marc Dionne) [2170099]
- rxrpc: Remove the [_k]net() debugging macros (Marc Dionne) [2170099]
- rxrpc: Remove the [k_]proto() debugging macros (Marc Dionne) [2170099]
- rxrpc: Remove handling of duplicate packets in recvmsg_queue (Marc Dionne) [2170099]
- rxrpc: Fix call leak (Marc Dionne) [2170099]
- rxrpc: Enable rxperf test module (Marc Dionne) [2170099]
- rxrpc: Implement an in-kernel rxperf server for testing purposes (Marc Dionne) [2170099]
- rxrpc: Fix checker warning (Marc Dionne) [2170099]
- rxrpc: Fix race between conn bundle lookup and bundle removal [ZDI-CAN-15975] (Marc Dionne) [2170099]
- rxrpc: uninitialized variable in rxrpc_send_ack_packet() (Marc Dionne) [2170099]
- rxrpc: fix rxkad_verify_response() (Marc Dionne) [2170099]
- rxrpc: Fix network address validation (Marc Dionne) [2170099]
- rxrpc: Fix oops from calling udpv6_sendmsg() on AF_INET socket (Marc Dionne) [2170099]
- rxrpc: Allocate an skcipher each time needed rather than reusing (Marc Dionne) [2170099]
- rxrpc: Fix congestion management (Marc Dionne) [2170099]
- rxrpc: Remove the rxtx ring (Marc Dionne) [2170099]
- rxrpc: Save last ACK's SACK table rather than marking txbufs (Marc Dionne) [2170099]
- rxrpc: Remove call->lock (Marc Dionne) [2170099]
- rxrpc: Don't use a ring buffer for call Tx queue (Marc Dionne) [2170099]
- rxrpc: Get rid of the Rx ring (Marc Dionne) [2170099]
- rxrpc: Clone received jumbo subpackets and queue separately (Marc Dionne) [2170099]
- rxrpc: Split the rxrpc_recvmsg tracepoint (Marc Dionne) [2170099]
- rxrpc: Clean up ACK handling (Marc Dionne) [2170099]
- rxrpc: Allocate ACK records at proposal and queue for transmission (Marc Dionne) [2170099]
- rxrpc: Define rxrpc_txbuf struct to carry data to be transmitted (Marc Dionne) [2170099]
- rxrpc: Remove call->tx_phase (Marc Dionne) [2170099]
- rxrpc: Remove the flags from the rxrpc_skb tracepoint (Marc Dionne) [2170099]
- rxrpc: Remove unnecessary header inclusions (Marc Dionne) [2170099]
- rxrpc: Call udp_sendmsg() directly (Marc Dionne) [2170099]
- rxrpc: Fix ack.bufferSize to be 0 when generating an ack (Marc Dionne) [2170099]
- rxrpc: Record stats for why the REQUEST-ACK flag is being set (Marc Dionne) [2170099]
- rxrpc: Record statistics about ACK types (Marc Dionne) [2170099]
- rxrpc: Add stats procfile and DATA packet stats (Marc Dionne) [2170099]
- rxrpc: Track highest acked serial (Marc Dionne) [2170099]
- rxrpc: Split call timer-expiration from call timer-set tracepoint (Marc Dionne) [2170099]
- rxrpc: Trace setting of the request-ack flag (Marc Dionne) [2170099]
- rxrpc: Automatically generate trace tag enums (Marc Dionne) [2170099]
- rxrpc: remove rxrpc_max_call_lifetime declaration (Marc Dionne) [2170099]
- rxrpc: Remove rxrpc_get_reply_time() which is no longer used (Marc Dionne) [2170099]
- rxrpc: Fix calc of resend age (Marc Dionne) [2170099]
- rxrpc: Fix local destruction being repeated (Marc Dionne) [2170099]
- rxrpc: Fix an insufficiently large sglist in rxkad_verify_packet_2() (Marc Dionne) [2170099]
- rxrpc: Fix locking in rxrpc's sendmsg (Marc Dionne) [2170099]
- net: rxrpc: fix clang -Wformat warning (Marc Dionne) [2170099]
- rxrpc: Fix decision on when to generate an IDLE ACK (Marc Dionne) [2170099]
- rxrpc: Don't let ack.previousPacket regress (Marc Dionne) [2170099]
- rxrpc: Fix overlapping ACK accounting (Marc Dionne) [2170099]
- rxrpc: Don't try to resend the request if we're receiving the reply (Marc Dionne) [2170099]
- rxrpc: Fix listen() setting the bar too high for the prealloc rings (Marc Dionne) [2170099]
- rxrpc, afs: Fix selection of abort codes (Marc Dionne) [2170099]
- rxrpc: Return an error to sendmsg if call failed (Marc Dionne) [2170099]
- rxrpc: Fix locking issue (Marc Dionne) [2170099]
- rxrpc: Use refcount_t rather than atomic_t (Marc Dionne) [2170099]
- rxrpc: Allow list of in-use local UDP endpoints to be viewed in /proc (Marc Dionne) [2170099]
- rxrpc: Enable IPv6 checksums on transport socket (Marc Dionne) [2170099]
- rxrpc: Restore removed timer deletion (Marc Dionne) [2170099]
- rxrpc: fix a race in rxrpc_exit_net() (Marc Dionne) [2170099]
- rxrpc: fix some null-ptr-deref bugs in server_key.c (Marc Dionne) [2170099]
- rxrpc: Fix call timer start racing with call destruction (Marc Dionne) [2170099]
- rxrpc: Adjust retransmission backoff (Marc Dionne) [2170099]
- rxrpc: Fix rxrpc_local leak in rxrpc_lookup_peer() (Marc Dionne) [2170099]
- rxrpc: Fix rxrpc_peer leak in rxrpc_look_up_bundle() (Marc Dionne) [2170099]
- rxrpc: Fix _usecs_to_jiffies() by using usecs_to_jiffies() (Marc Dionne) [2170099]
- net: RxRPC: make dependent Kconfig symbols be shown indented (Marc Dionne) [2170099]

* Mon Mar 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.6.1.el9_2]
- NFS: Correct timing for assigning access cache timestamp (Benjamin Coddington) [2180882]
- nfsd: don't replace page in rq_pages if it's a continuation of last page (Jeffrey Layton) [2179342]
- tun: avoid double free in tun_free_netdev (Jon Maloy) [2156374] {CVE-2022-4744}

* Thu Mar 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.5.1.el9_2]
- redhat: fix trivial syntax error in 64k-debug modules signing (Herton R. Krzesinski)
- redhat/configs: Revert "enable DAMON configs" (Vladis Dronov)
- block: bio-integrity: Copy flags when bio_integrity_payload is cloned (Ming Lei) [2164903]
- afs: remove afs_cache_netfs and afs_zap_permits() declarations (Marc Dionne) [2166628]
- afs: remove variable nr_servers (Marc Dionne) [2166628]
- afs: Fix lost servers_outstanding count (Marc Dionne) [2166628]
- afs: Fix server->active leak in afs_put_server (Marc Dionne) [2166628]
- afs: Fix fileserver probe RTT handling (Marc Dionne) [2166628]
- afs: Return -EAGAIN, not -EREMOTEIO, when a file already locked (Marc Dionne) [2166628]
- afs: Use the operation issue time instead of the reply time for callbacks (Marc Dionne) [2166628]
- afs: Enable multipage folio support (Marc Dionne) [2166628]
- afs: Fix access after dec in put functions (Marc Dionne) [2166628]
- afs: Use refcount_t rather than atomic_t (Marc Dionne) [2166628]
- afs: Fix dynamic root getattr (Marc Dionne) [2166628]
- afs: Remove check of PageError (Marc Dionne) [2166628]
- afs: Fix some checker issues (Marc Dionne) [2166628]
- afs: Fix infinite loop found by xfstest generic/676 (Marc Dionne) [2166628]
- afs: Adjust ACK interpretation to try and cope with NAT (Marc Dionne) [2166628]
- afs: Prefer struct_size over open coded arithmetic (Marc Dionne) [2166628]
- afs: Convert invalidatepage to invalidate_folio (Marc Dionne) [2166628]
- afs: Convert directory aops to invalidate_folio (Marc Dionne) [2166628]
- blk-mq: fix "bad unlock balance detected" on q->srcu in __blk_mq_run_dispatch_ops (Chris Leech) [2170101]
- KVM: VMX: Execute IBPB on emulated VM-exit when guest has IBRS (Jon Maloy) [2160029] {CVE-2022-2196}
- ice: fix lost multicast packets in promisc mode (Petr Oros) [2170694]
- net: use indirect calls helpers for sk_exit_memory_pressure() (Florian Westphal) [2155182]
- bpf: pull before calling skb_postpull_rcsum() (Felix Maurer) [2164806]
- bpf, sockmap: fix race in sock_map_free() (Felix Maurer) [2164806]
- bpf, sock_map: Move cancel_work_sync() out of sock lock (Felix Maurer) [2164806]
- xsk: Inherit need_wakeup flag for shared sockets (Felix Maurer) [2164806]
- xsk: Fix backpressure mechanism on Tx (Felix Maurer) [2164806]

* Mon Mar 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.4.1.el9_2]
- gfs2: Improve gfs2_make_fs_rw error handling (Andreas Gruenbacher) [2109548]
- Revert "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2109548]
- gfs2: Evict inodes cooperatively (Andreas Gruenbacher) [2109548]
- gfs2: Flush delete work before shrinking inode cache (Andreas Gruenbacher) [2109548]
- gfs2: Cease delete work during unmount (Bob Peterson) [2109548]
- gfs2: Add SDF_DEACTIVATING super block flag (Bob Peterson) [2109548]
- gfs2: check gl_object in rgrp glops (Bob Peterson) [2109548]
- gfs2: Split the two kinds of glock "delete" work (Andreas Gruenbacher) [2109548]
- gfs2: Move delete workqueue into super block (Andreas Gruenbacher) [2109548]
- gfs2: Get rid of GLF_PENDING_DELETE flag (Andreas Gruenbacher) [2109548]
- gfs2: Make glock lru list scanning safer (Andreas Gruenbacher) [2109548]
- gfs2: Clean up gfs2_scan_glock_lru (Andreas Gruenbacher) [2109548]
- gfs2: Improve gfs2_upgrade_iopen_glock comment (Andreas Gruenbacher) [2109548]
- gfs2: gl_object races fix (Andreas Gruenbacher) [2109548]
- iomap/gfs2: Unlock and put folio in page_done handler (Andreas Gruenbacher) [2109548]
- iomap: Add __iomap_put_folio helper (Andreas Gruenbacher) [2109548]
- Revert "gfs2: stop using generic_writepages in gfs2_ail1_start_one" (Andreas Gruenbacher) [2109548]
- gfs2: Remove support for glock holder auto-demotion (2) (Andreas Gruenbacher) [2109548]
- gfs2: Remove support for glock holder auto-demotion (Andreas Gruenbacher) [2109548]
- gfs2: Minor gfs2_try_evict cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Partially revert gfs2_inode_lookup change (Andreas Gruenbacher) [2109548]
- gfs2: Add gfs2_inode_lookup comment (Andreas Gruenbacher) [2109548]
- gfs2: Uninline and improve glock_{set,clear}_object (Andreas Gruenbacher) [2109548]
- gfs2: Simply dequeue iopen glock in gfs2_evict_inode (Andreas Gruenbacher) [2109548]
- gfs2: Clean up after gfs2_create_inode rework (Andreas Gruenbacher) [2109548]
- gfs2: Avoid dequeuing GL_ASYNC glock holders twice (Andreas Gruenbacher) [2109548]
- gfs2: Make gfs2_glock_hold return its glock argument (Andreas Gruenbacher) [2109548]
- gfs2: Always check inode size of inline inodes (Andreas Gruenbacher) [2109548]
- gfs2: Cosmetic gfs2_dinode_{in,out} cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Handle -EBUSY result of insert_inode_locked4 (Andreas Gruenbacher) [2109548]
- gfs2: Fix and clean up create / evict interaction (Andreas Gruenbacher) [2109548]
- gfs2: Clean up initialization of "ip" in gfs2_create_inode (Andreas Gruenbacher) [2109548]
- gfs2: Get rid of ghs[] in gfs2_create_inode (Andreas Gruenbacher) [2109548]
- gfs2: Add extra error check in alloc_dinode (Andreas Gruenbacher) [2109548]
- gfs2: Check sb_bsize_shift after reading superblock (Andrew Price) [2109548]
- gfs2: Switch from strlcpy to strscpy (Andreas Gruenbacher) [2109548]
- gfs2: Clear flags when withdraw prevents xmote (Bob Peterson) [2109548]
- gfs2: Dequeue waiters when withdrawn (Bob Peterson) [2109548]
- gfs2: Prevent double iput for journal on error (Bob Peterson) [2109548]
- gfs2: Convert gfs2_jhead_process_page() to use a folio (Andreas Gruenbacher) [2109548]
- gfs2: remove ->writepage (Andreas Gruenbacher) [2109548]
- gfs2: stop using generic_writepages in gfs2_ail1_start_one (Andreas Gruenbacher) [2109548]
- gfs2: List traversal in do_promote is safe (Andreas Gruenbacher) [2109548]
- gfs2: do_promote glock holder stealing fix (Bob Peterson) [2109548]
- gfs2: Use better variable name (Andreas Gruenbacher) [2109548]
- gfs2: Make go_instantiate take a glock (Andreas Gruenbacher) [2109548]
- gfs2: Add new go_held glock operation (Andreas Gruenbacher) [2109548]
- gfs2: Revert 'Fix "truncate in progress" hang' (Andreas Gruenbacher) [2109548]
- gfs2: Instantiate glocks ouside of glock state engine (Andreas Gruenbacher) [2109548]
- gfs2: Fix up gfs2_glock_async_wait (Andreas Gruenbacher) [2109548]
- gfs2: Mark the remaining process-independent glock holders as GL_NOPID (Andreas Gruenbacher) [2109548]
- gfs2: Mark flock glock holders as GL_NOPID (Andreas Gruenbacher) [2109548]
- gfs2: Add GL_NOPID flag for process-independent glock holders (Andreas Gruenbacher) [2109548]
- gfs2: Add flocks to glockfd debugfs file (Andreas Gruenbacher) [2109548]
- gfs2: Add glockfd debugfs file (Andreas Gruenbacher) [2109548]
- gfs2: Minor gfs2_glock_nq_m cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Fix spelling mistake in comment (Andreas Gruenbacher) [2109548]
- gfs2: Rewrap overlong comment in do_promote (Bob Peterson) [2109548]
- gfs2: Remove redundant NULL check before kfree (Andreas Gruenbacher) [2109548]
- gfs2: Use container_of() for gfs2_glock(aspace) (Andreas Gruenbacher) [2109548]
- gfs2: dump inode object for iopen glocks (Bob Peterson) [2109548]

* Fri Mar 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.3.1.el9_2]
- cpufreq: ACPI: Remove unused variables 'acpi_cpufreq_online' and 'ret' (Mark Langsdorf) [2170475]
- cpufreq: ACPI: Only set boost MSRs on supported CPUs (Mark Langsdorf) [2170475]
- Drivers: vmbus: Check for channel allocation before looking up relids (Mohammed Gamal) [2156126]
- NFSD: copy the whole verifier in nfsd_copy_write_verifier (Jeffrey Layton) [2166658]
- nfsd: don't fsync nfsd_files on last close (Jeffrey Layton) [2166658]
- NFSD: fix problems with cleanup on errors in nfsd4_copy (Jeffrey Layton) [2166658]
- nfsd: fix race to check ls_layouts (Jeffrey Layton) [2166658]
- nfsd: don't hand out delegation on setuid files being opened for write (Jeffrey Layton) [2127406]
- nfsd: remove fs/nfsd/fault_inject.c (Jeffrey Layton) [2166658]
- NFSD: fix leaked reference count of nfsd4_ssc_umount_item (Jeffrey Layton) [2166658]
- nfsd: clean up potential nfsd_file refcount leaks in COPY codepath (Jeffrey Layton) [2166658]
- nfsd: zero out pointers after putting nfsd_files on COPY setup error (Jeffrey Layton) [2166658]
- nfsd: eliminate __nfs4_get_fd (Jeffrey Layton) [2166658]
- nfsd: add some kerneldoc comments for stateid preprocessing functions (Jeffrey Layton) [2166658]
- nfsd: eliminate find_deleg_file_locked (Jeffrey Layton) [2166658]
- nfsd: don't take nfsd4_copy ref for OP_OFFLOAD_STATUS (Jeffrey Layton) [2166658]
- nfsd: move reply cache initialization into nfsd startup (Jeffrey Layton) [2166658]
- nfsd: fix potential race in nfs4_find_file (Jeffrey Layton) [1997177]
- nfsd: allow nfsd_file_get to sanely handle a NULL pointer (Jeffrey Layton) [2166658]
- NFSD: enhance inter-server copy cleanup (Jeffrey Layton) [2166658]
- NFSD: Rename the fields in copy_stateid_t (Jeffrey Layton) [2166658]

* Wed Mar 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.2.1.el9_2]
- net/mlx5: Serialize module cleanup with reload and remove (Mohammad Kabat) [2166480]
- net/mlx5e: Remove redundant allocation of spec in create indirect fwd group (Mohammad Kabat) [2168640]
- net/mlx5e: Support Geneve and GRE with VF tunnel offload (Mohammad Kabat) [2168640]
- net/mlx5e: Fix crash unsetting rx-vlan-filter in switchdev mode (Amir Tzin) [2055536]
- ice/ptp: fix the PTP worker retrying indefinitely if the link went down (Petr Oros) [2173049]
- ice: reschedule ice_ptp_wait_for_offset_valid during reset (Petr Oros) [2173049]
- ice: make Tx and Rx vernier offset calibration independent (Petr Oros) [2173049]
- ice: only check set bits in ice_ptp_flush_tx_tracker (Petr Oros) [2173049]
- ice: handle flushing stale Tx timestamps in ice_ptp_tx_tstamp (Petr Oros) [2173049]
- ice: cleanup allocations in ice_ptp_alloc_tx_tracker (Petr Oros) [2173049]
- ice: protect init and calibrating check in ice_ptp_request_ts (Petr Oros) [2173049]
- ice: check Tx timestamp memory register for ready timestamps (Petr Oros) [2173049]
- ice: handle discarding old Tx requests in ice_ptp_tx_tstamp (Petr Oros) [2173049]
- ice: always call ice_ptp_link_change and make it void (Petr Oros) [2173049]
- ice: fix misuse of "link err" with "link status" (Petr Oros) [2173049]
- ice: Reset TS memory for all quads (Petr Oros) [2173049]
- ice: Remove the E822 vernier "bypass" logic (Petr Oros) [2173049]
- ice: Use more generic names for ice_ptp_tx fields (Petr Oros) [2173049]
- ice: Merge pin initialization of E810 and E810T adapters (Petr Oros) [2173049]
- ice: Check if reset in progress while waiting for offsets (Petr Oros) [2173049]
- drm/nouveau/fb/tu102-: fix register used to determine scrub status (Karol Herbst) [2168647]
- drm/nouveau/devinit/tu102-: wait for GFW_BOOT_PROGRESS == COMPLETED (Karol Herbst) [2168647]
- l2tp: Avoid possible recursive deadlock in l2tp_tunnel_register() (Guillaume Nault) [2174451]
- self-tests: more rps self tests (Paolo Abeni) [2168875]
- net: make default_rps_mask a per netns attribute (Paolo Abeni) [2168875]
- self-tests: introduce self-tests for RPS default mask (Paolo Abeni) [2168875]
- net: introduce default_rps_mask netns attribute (Paolo Abeni) [2168875]
- net-sysctl: factor-out rpm mask manipulation helpers (Paolo Abeni) [2168875]
- net-sysctl: factor out cpumask parsing helper (Paolo Abeni) [2168875]
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2172863]
- crypto: rng - Use a different crypto_rng for reseeding (Herbert Xu) [2174928]

* Mon Mar 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.1.1.el9_2]
- NFSD: fix use-after-free in __nfs42_ssc_open() (Jeffrey Layton) [2152816] {CVE-2022-4379}
- NFSD enforce filehandle check for source file in COPY (Jeffrey Layton) [2152816]
- cgroup: Use cgroup_attach_{lock,unlock}() from cgroup_attach_task_all() (Torez Smith) [2166988]
- powerpc/powernv: Get L1D flush requirements from device-tree (Torez Smith) [2166988]
- x86/speculation/srbds: Do not try to turn mitigation off when not supported (Torez Smith) [2166988]
- powerpc/watchdog: help remote CPUs to flush NMI printk output (Torez Smith) [2166988]
- powerpc/watchdog: Fix wd_smp_last_reset_tb reporting (Torez Smith) [2166988]
- powerpc/watchdog: read TB close to where it is used (Torez Smith) [2166988]
- powerpc/watchdog: Avoid holding wd_smp_lock over printk and smp_send_nmi_ipi (Torez Smith) [2166988]
- powerpc/watchdog: tighten non-atomic read-modify-write access (Torez Smith) [2166988]
- powerpc/watchdog: Fix missed watchdog reset due to memory ordering race (Torez Smith) [2166988]
- powerpc/powernv: Remove POWER9 PVR version check for entry and uaccess flushes (Torez Smith) [2166988]
- powerpc/vas: Fix potential NULL pointer dereference (Torez Smith) [2166988]
- serial: 8250_dw: drop bogus uartclk optimisation (Torez Smith) [2166988]
- serial: 8250: fix racy uartclk update (Torez Smith) [2166988]
- serial: 8250_lpss: Enable PSE UART Auto Flow Control (Torez Smith) [2166988]
- serial: 8250_dw: Fix the trivial typo in the comment (Torez Smith) [2166988]
- serial: 8250_dw: Re-use temporary variable for of_node (Torez Smith) [2166988]
- serial: 8250_dw: Drop wrong use of ACPI_PTR() (Torez Smith) [2166988]
- powerpc/iommu: Report the correct most efficient DMA mask for PCI devices (Torez Smith) [2166988]
- ABI: sysfs-devices-removable: make a table valid as ReST markup (Torez Smith) [2166988]
- x86/mce: Avoid infinite loop for copy from user recovery (Torez Smith) [2166988]
- x86/platform: Increase maximum GPIO number for X86_64 (Torez Smith) [2166988]
- powerpc/pseries/vas: Declare pseries_vas_fault_thread_fn() as static (Torez Smith) [2166988]
- cpufreq: powernv: Fix init_chip_info initialization in numa=off (Torez Smith) [2166988]
- counter: Rename counter_count_function to counter_function (Torez Smith) [2166988]
- counter: Rename counter_signal_value to counter_signal_level (Torez Smith) [2166988]
- counter: Standardize to ERANGE for limit exceeded errors (Torez Smith) [2166988]
- powerpc/stacktrace: Include linux/delay.h (Torez Smith) [2166988]
- redhat: change default dist suffix for RHEL 9.2 (Herton R. Krzesinski)
- redhat: enable zstream release numbering for rhel 9.2 (Herton R. Krzesinski)
- kernel.spec: make rhel depend on systemd-boot-unsigned (Herton R. Krzesinski) [2174371]
- NFSv4/pNFS: Always return layout stats on layout return for flexfiles (Benjamin Coddington) [2154879]
- NFSv4: Fix a potential state reclaim deadlock (Benjamin Coddington) [2154879]
- NFSv4.1: Handle RECLAIM_COMPLETE trunking errors (Benjamin Coddington) [2154879]
- NFSv4.1: We must always send RECLAIM_COMPLETE after a reboot (Benjamin Coddington) [2154879]
- SUNRPC: Fix null-ptr-deref when xps sysfs alloc failed (Benjamin Coddington) [2154879]
- NFSv4.2: Fixup CLONE dest file size for zero-length count (Benjamin Coddington) [2154879]
- nfs4: Fix kmemleak when allocate slot failed (Benjamin Coddington) [2154879]
- NFSD: Fix reads with a non-zero offset that don't end on a page boundary (Benjamin Coddington) [2154879]
- NFSv4.2: Clear FATTR4_WORD2_SECURITY_LABEL when done decoding (Benjamin Coddington) [2154879]
- NFSv4.2: Always decode the security label (Benjamin Coddington) [2154879]
- NFSv4.2: Fix a memory stomp in decode_attr_security_label (Benjamin Coddington) [2154879]
- NFSv4.2: Fix initialisation of struct nfs4_label (Benjamin Coddington) [2154879]
- NFSv4: Fix a credential leak in _nfs4_discover_trunking() (Benjamin Coddington) [2154879]
- NFSv4: Fix a deadlock between nfs4_open_recover_helper() and delegreturn (Benjamin Coddington) [2154879]
- NFS: Fix an Oops in nfs_d_automount() (Benjamin Coddington) [2154879]
- NFSD: Finish converting the NFSv2 GETACL result encoder (Benjamin Coddington) [2154879]
- NFSD: Finish converting the NFSv3 GETACL result encoder (Benjamin Coddington) [2154879]
- xprtrdma: Fix regbuf data not freed in rpcrdma_req_create() (Benjamin Coddington) [2154879]
- SUNRPC: Fix missing release socket in rpc_sockname() (Benjamin Coddington) [2154879]
- NFSv4.x: Fail client initialisation if state manager thread can't run (Benjamin Coddington) [2154879]
- lockd: set other missing fields when unlocking files (Benjamin Coddington) [2154879]
- SUNRPC: Don't leak netobj memory when gss_read_proxy_verf() fails (Benjamin Coddington) [2154879]
- SUNRPC: ensure the matching upcall is in-flight upon downcall (Benjamin Coddington) [2154879]
- NLM: Defend against file_lock changes after vfs_test_lock() (Benjamin Coddington) [2154879]
- NFS: Judge the file access cache's timestamp in rcu path (Benjamin Coddington) [2154879]
- NFS: Trigger the "ls -l" readdir heuristic sooner (Benjamin Coddington) [2154879]
- NFS: Clear the file access cache upon login (Benjamin Coddington) [2154879]
- NFSv4: Retry LOCK on OLD_STATEID during delegation return (Benjamin Coddington) [2154879]

* Mon Feb 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.el9]
- kernel.spec: move modules.builtin to kernel-core (Jan Stancek) [2172376]

* Thu Feb 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-283.el9]
- redhat: fix duplicate jira issues in the resolves line (Herton R. Krzesinski)
- redhat/kernel.spec.template: Parallelize compression (Herton R. Krzesinski)
- Revert "block: freeze the queue earlier in del_gendisk" (Ming Lei) [2155901]
- redhat: configs: Enable UCSI_CCG support (David Marlin) [2122414]
- i2c: nvidia-gpu: Remove ccgx,firmware-build property (David Marlin) [2122414]
- i2c: nvidia-gpu: Add ACPI property to align with device-tree (David Marlin) [2122414]
- usb: typec: ucsi_ccg: Add OF support (David Marlin) [2122414]
- gpio: tegra186: add Tegra234 PMC compatible in GPIO driver (David Marlin) [2122414]
- usb: gadget: tegra-xudc: Add Tegra234 support (David Marlin) [2122414]
- xhci: tegra: USB2 pad power controls (David Marlin) [2122414]
- xhci: Add hub_control to xhci_driver_overrides (David Marlin) [2122414]
- xhci: hub: export symbol on xhci_hub_control (David Marlin) [2122414]
- usb: host: xhci-tegra: Add Tegra234 XHCI support (David Marlin) [2122414]
- phy: tegra: xusb: Support USB role default mode (David Marlin) [2122414]
- phy: tegra: xusb: Add Tegra234 support (David Marlin) [2122414]
- phy: tegra: xusb: Disable trk clk when not in use (David Marlin) [2122414]
- phy: tegra: xusb: Remove usb3 supply (David Marlin) [2122414]
- phy: tegra: xusb: Fix crash during pad power on/down (David Marlin) [2122414]
- usb: typec: ucsi_ccg: Disable UCSI ALT support on Tegra (David Marlin) [2122414]
- usb: typec: ucsi: Don't warn on probe deferral (David Marlin) [2122414]
- phy: tegra: xusb: Enable usb role switch attribute (David Marlin) [2122414]
- usb: gadget: tegra: Reduce pad power (David Marlin) [2122414]
- phy: tegra: xusb: add utmi pad power on/down ops (David Marlin) [2122414]
- redhat/configs: Enable CONFIG_PCIE_PTM (Corinna Vinschen) [2100606]
- net: stmmac: Fix queue statistics reading (Corinna Vinschen) [2100606]
- stmmac: intel: Update PCH PTP clock rate from 200MHz to 204.8MHz (Corinna Vinschen) [2100606]
- net: stmmac: Disable automatic FCS/Pad stripping (Corinna Vinschen) [2100606]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2100606]
- stmmac: intel: remove unused 'has_crossts' flag (Corinna Vinschen) [2100606]
- net: phylink: Convert to mdiobus_c45_{read|write} (Corinna Vinschen) [2100606]
- net: phy: marvell: add sleep time after enabling the loopback bit (Corinna Vinschen) [2100606]
- net: phy: marvell: add Marvell specific PHY loopback (Corinna Vinschen) [2100606]
- net: phy: dp83867: retrigger SGMII AN when link change (Corinna Vinschen) [2100606]
- net: phy: marvell: Add WAKE_PHY support to WOL event (Corinna Vinschen) [2100606]
- net: phy: marvell10g: enable WoL for 88X3310 and 88E2110 (Corinna Vinschen) [2100606]
- netfilter: nft_payload: incorrect arithmetics when fetching VLAN header bits (Florian Westphal) [2161725] {CVE-2023-0179}

* Thu Feb 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-282.el9]
- net/mlx5e: TC, Restore pkt rate policing support (Amir Tzin) [2028809]
- net/mlx5e: TC, ignore match level for post meter rules (Amir Tzin) [2028809]
- net/mlx5e: TC, add support for meter mtu offload (Amir Tzin) [2028809]
- net/mlx5e: meter, add mtu post meter tables (Amir Tzin) [2028809]
- net/mlx5e: meter, refactor to allow multiple post meter tables (Amir Tzin) [2028809]
- net/mlx5: DR, Add support for range match action (Amir Tzin) [2028809]
- net/mlx5: DR, Add function that tells if STE miss addr has been initialized (Amir Tzin) [2028809]
- net/mlx5: DR, Some refactoring of miss address handling (Amir Tzin) [2028809]
- net/mlx5: DR, Manage definers with refcounts (Amir Tzin) [2028809]
- net/mlx5: DR, Handle FT action in a separate function (Amir Tzin) [2028809]
- net/mlx5: DR, Rework is_fw_table function (Amir Tzin) [2028809]
- net/mlx5: DR, Add functions to create/destroy MATCH_DEFINER general object (Amir Tzin) [2028809]
- net/mlx5: fs, add match on ranges API (Amir Tzin) [2028809]
- net/mlx5: mlx5_ifc updates for MATCH_DEFINER general object (Amir Tzin) [2028809]
- net/mlx5e: TC, allow meter jump control action (Amir Tzin) [2028809]
- net/mlx5e: TC, init post meter rules with branching attributes (Amir Tzin) [2028809]
- net/mlx5e: TC, rename post_meter actions (Amir Tzin) [2028809]
- net/mlx5e: TC, initialize branching action with target attr (Amir Tzin) [2028809]
- net/mlx5e: TC, initialize branch flow attributes (Amir Tzin) [2028809]
- net/mlx5e: TC, set control params for branching actions (Amir Tzin) [2028809]
- net/mlx5e: TC, validate action list per attribute (Amir Tzin) [2028809]
- net/mlx5e: TC, add terminating actions (Amir Tzin) [2028809]
- net/mlx5e: TC, reuse flow attribute post parser processing (Amir Tzin) [2028809]
- net/mlx5: fs, assert null dest pointer when dest_num is 0 (Amir Tzin) [2028809]
- net/mlx5e: E-Switch, handle flow attribute with no destinations (Amir Tzin) [2028809]
- net/mlx5: E-Switch, Allow offloading fwd dest flow table with vport (Amir Tzin) [2028809]
- net/mlx5e: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Amir Tzin) [2028809]
- rtc: efi: Enable SET/GET WAKEUP services as optional (Donald Dutile) [2166449]
- tee: optee: do not check memref size on return from Secure World (Chris von Recklinghausen) [2166659]
- tee: optee: Fix incorrect page free bug (Chris von Recklinghausen) [2166659]
- optee: smc_abi.c: add missing #include <linux/mm.h> (Chris von Recklinghausen) [2166659]
- optee: isolate smc abi (Chris von Recklinghausen) [2166659]
- optee: refactor driver with internal callbacks (Chris von Recklinghausen) [2166659]
- optee: simplify optee_release() (Chris von Recklinghausen) [2166659]
- tee: optee: Fix missing devices unregister during optee_remove (Chris von Recklinghausen) [2166659]
- tee/optee/shm_pool: fix application of sizeof to pointer (Chris von Recklinghausen) [2166659]
- lib/test_scanf: Handle n_bits == 0 in random tests (Chris von Recklinghausen) [2166659]
- sctp: sysctl: make extra pointers netns aware (Xin Long) [2160516]
- sctp: clear out_curr if all frag chunks of current msg are pruned (Xin Long) [2160516]
- sctp: remove the unnecessary sinfo_stream check in sctp_prsctp_prune_unsent (Xin Long) [2160516]
- inet6: Clean up failure path in do_ipv6_setsockopt(). (Xin Long) [2160516]
- inet6: Remove inet6_destroy_sock(). (Xin Long) [2160516]
- sctp: Call inet6_destroy_sock() via sk->sk_destruct(). (Xin Long) [2160516]
- dccp: Call inet6_destroy_sock() via sk->sk_destruct(). (Xin Long) [2160516]
- inet6: Remove inet6_destroy_sock() in sk->sk_prot->destroy(). (Xin Long) [2160516]

* Wed Feb 22 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-281.el9]
- virtio_console: break out of buf poll on remove (Michael S. Tsirkin) [1786239]
- cpufreq: intel_pstate: Add Sapphire Rapids support in no-HWP mode (David Arcari) [2170574]
- net: mana: Fix accessing freed irq affinity_hint (Emanuele Giuseppe Esposito) [2168970]
- net: mana: Assign interrupts to CPUs based on NUMA nodes (Emanuele Giuseppe Esposito) [2168970]
- be2net: Fix buffer overflow in be_get_module_eeprom (Izabela Bakollari) [2167725]
- nfsd: don't destroy global nfs4_file table in per-net shutdown (Jeffrey Layton) [2169017]
- x86/module: Fix the paravirt vs alternative order (Waiman Long) [2170197]
- dt-bindings: dmaengine: Add compatible for Tegra234 (d.marlin) [2129115]
- dt-bindings: dmaengine: Add doc for tegra gpcdma (d.marlin) [2129115]
- icmp: Add counters for rate limits (Jamie Bainbridge) [2155801]
- Revert "ethernet: Remove vf rate limit check for drivers" (Ken Cox) [2168599]
- selftests: net: udpgso_bench_tx: Cater for pending datagrams zerocopy benchmarking (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench: Fix racing bug between the rx/tx programs (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench_rx/tx: Stop when wrong CLI args are provided (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench_rx: Fix 'used uninitialized' compiler warning (Hangbin Liu) [RHEL-221]
- igb: Initialize mailbox message for VF reset (Corinna Vinschen) [2104469]
- igb: Allocate MSI-X vector when testing (Corinna Vinschen) [2104469]
- igb: Proactively round up to kmalloc bucket size (Corinna Vinschen) [2104469]
- igb: Do not free q_vector unless new one was allocated (Corinna Vinschen) [2104469]
- ptp: introduce helpers to adjust by scaled parts per million (Corinna Vinschen) [2104469]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2104469]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2104469]
- igb: convert .adjfreq to .adjfine (Corinna Vinschen) [2104469]
- igb: add xdp frags support to ndo_xdp_xmit (Corinna Vinschen) [2104469]
- dt-bindings: serial: Document Tegra234 TCU (d.marlin) [2122413]
- dt-bindings: serial: 8250: Document Tegra234 UART (d.marlin) [2122413]
- dt-bindings: serial: tegra-tcu: Convert to json-schema (d.marlin) [2122413]
- ipv6: Remove extra counter pull before gc (Hangbin Liu) [2161118]
- ipv6: remove max_size check inline with ipv4 (Hangbin Liu) [2161118]
- redhat/configs: enable coresight driver for nvidia/grace (Mark Salter) [2128086]
- perf: arm_cspmu: Fix module cyclic dependency (Mark Salter) [2128086]
- perf: arm_cspmu: Fix build failure on x86_64 (Mark Salter) [2128086]
- perf: arm_cspmu: Fix modular builds due to missing MODULE_LICENSE()s (Mark Salter) [2128086]
- perf: arm_cspmu: Add support for NVIDIA SCF and MCF attribute (Mark Salter) [2128086]
- perf: arm_cspmu: Add support for ARM CoreSight PMU driver (Mark Salter) [2128086]
- redhat: add support for Jira issues in changelog (Herton R. Krzesinski) [RHEL-186]
- ice: fix handling of burst Tx timestamps (Petr Oros) [2161201]
- ice: synchronize the misc IRQ when tearing down Tx tracker (Petr Oros) [2161204]
- ice: Add low latency Tx timestamp read (Petr Oros) [2161204]
- ice: introduce ice_ptp_reset_cached_phctime function (Petr Oros) [2161204]
- ice: re-arrange some static functions in ice_ptp.c (Petr Oros) [2161204]
- ice: track and warn when PHC update is late (Petr Oros) [2161204]
- ice: track Tx timestamp stats similar to other Intel drivers (Petr Oros) [2161204]
- net-sysfs: add check for netdevice being present to speed_show (Beniamino Galvani) [2148349]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_reassemble_sdu (Ricardo Robaina) [2152931] {CVE-2022-3564}
- proc: proc_skip_spaces() shouldn't think it is working on C strings (Wander Lairson Costa) [2152581] {CVE-2022-4378}
- proc: avoid integer type confusion in get_proc_long (Wander Lairson Costa) [2152581] {CVE-2022-4378}
- xen-netfront: restore __skb_queue_tail() positioning in xennet_get_responses() (Izabela Bakollari) [2118313] {CVE-2022-33743}

* Tue Feb 21 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-280.el9]
- redhat/configs: enable neoverse and cortex errata (Jeremy Linton) [2055405]
- coresight: syscfg: Update load and unload operations (Jeremy Linton) [2055405]
- coresight: configfs: Fix unload of configurations on module exit (Jeremy Linton) [2055405]
- coresight: syscfg: Fix memleak on registration failure in cscfg_create_device (Jeremy Linton) [2055405]
- coresight: core: Fix typo in a comment (Jeremy Linton) [2055405]
- Documentation: coresight: Update coresight configuration docs (Jeremy Linton) [2055405]
- coresight: configfs: Allow configfs to activate configuration (Jeremy Linton) [2055405]
- coresight: syscfg: Example CoreSight configuration loadable module (Jeremy Linton) [2055405]
- coresight: syscfg: Update load API for config loadable modules (Jeremy Linton) [2055405]
- coresight: configuration: Update API to permit dynamic load/unload (Jeremy Linton) [2055405]
- coresight: configuration: Update API to introduce load owner concept (Jeremy Linton) [2055405]
- Documentation: coresight: Fix documentation issue (Jeremy Linton) [2055405]
- coresight: Use devm_bitmap_zalloc when applicable (Jeremy Linton) [2055405]
- coresight: trbe: Work around write to out of range (Jeremy Linton) [2055405]
- coresight: trbe: Make sure we have enough space (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to determine the minimum buffer size (Jeremy Linton) [2055405]
- coresight: trbe: Workaround TRBE errata overwrite in FILL mode (Jeremy Linton) [2055405]
- coresight: trbe: Add infrastructure for Errata handling (Jeremy Linton) [2055405]
- coresight: trbe: Allow driver to choose a different alignment (Jeremy Linton) [2055405]
- coresight: trbe: Decouple buffer base from the hardware base (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to pad a given buffer area (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to calculate the trace generated (Jeremy Linton) [2055405]
- coresight: trbe: Defer the probe on offline CPUs (Jeremy Linton) [2055405]
- coresight: trbe: Fix incorrect access of the sink specific data (Jeremy Linton) [2055405]
- coresight: etm4x: Add ETM PID for Kryo-5XX (Jeremy Linton) [2055405]
- coresight: trbe: Prohibit trace before disabling TRBE (Jeremy Linton) [2055405]
- coresight: trbe: End the AUX handle on truncation (Jeremy Linton) [2055405]
- coresight: trbe: Do not truncate buffer on IRQ (Jeremy Linton) [2055405]
- coresight: trbe: Fix handling of spurious interrupts (Jeremy Linton) [2055405]
- coresight: trbe: irq handler: Do not disable TRBE if no action is needed (Jeremy Linton) [2055405]
- coresight: trbe: Unify the enabling sequence (Jeremy Linton) [2055405]
- coresight: trbe: Drop duplicate TRUNCATE flags (Jeremy Linton) [2055405]
- coresight: trbe: Ensure the format flag is always set (Jeremy Linton) [2055405]
- coresight: etm-pmu: Ensure the AUX handle is valid (Jeremy Linton) [2055405]
- coresight: etm4x: Use Trace Filtering controls dynamically (Jeremy Linton) [2055405]
- coresight: etm4x: Save restore TRFCR_EL1 (Jeremy Linton) [2055405]
- coresight: Don't immediately close events that are run on invalid CPU/sink combos (Jeremy Linton) [2055405]
- coresight: tmc-etr: Speed up for bounce buffer in flat mode (Jeremy Linton) [2055405]
- coresight: Update comments for removing cs_etm_find_snapshot() (Jeremy Linton) [2055405]
- coresight: tmc-etr: Use perf_output_handle::head for AUX ring buffer (Jeremy Linton) [2055405]
- coresight: tmc-etf: Add comment for store ordering (Jeremy Linton) [2055405]
- coresight: tmc-etr: Add barrier after updating AUX ring buffer (Jeremy Linton) [2055405]
- coresight: tmc: Configure AXI write burst size (Jeremy Linton) [2055405]
- dt-bindings: coresight: Add burst size for TMC (Jeremy Linton) [2055405]
- coresight: cpu-debug: Control default behavior via Kconfig (Jeremy Linton) [2055405]
- coresight: cti: Correct the parameter for pm_runtime_put (Jeremy Linton) [2055405]
- coresight: syscfg: Fix compiler warning (Jeremy Linton) [2055405]
- Documentation: coresight: Add documentation for CoreSight config (Jeremy Linton) [2055405]
- coresight: syscfg: Add initial configfs support (Jeremy Linton) [2055405]
- coresight: config: Add preloaded configurations (Jeremy Linton) [2055405]
- coresight: etm4x: Add complex configuration handlers to etmv4 (Jeremy Linton) [2055405]
- coresight: etm-perf: Update to activate selected configuration (Jeremy Linton) [2055405]
- coresight: syscfg: Add API to activate and enable configurations (Jeremy Linton) [2055405]
- coresight: etm-perf: Update to handle configuration selection (Jeremy Linton) [2055405]
- coresight: config: Add configuration and feature generic functions (Jeremy Linton) [2055405]
- coresight: syscfg: Add registration and feature loading for cs devices (Jeremy Linton) [2055405]
- coresight: syscfg: Initial coresight system configuration (Jeremy Linton) [2055405]

* Mon Feb 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-279.el9]
- redhat/configs: enable Octeon TX2 network drivers for RHEL (Michal Schmidt) [2040643]
- octeontx2: mark the AF/PF/VF drivers as tech-preview (Michal Schmidt) [2040643]
- octeontx2-af: Fix devlink unregister (Michal Schmidt) [2040643]
- octeontx2-pf: Fix the use of GFP_KERNEL in atomic context on rt (Michal Schmidt) [2040643]
- octeontx2-pf: Avoid use of GFP_KERNEL in atomic context (Michal Schmidt) [2040643]
- octeontx2-pf: Fix resource leakage in VF driver unbind (Michal Schmidt) [2040643]
- octeontx2-af: Fix LMAC config in cgx_lmac_rx_tx_enable (Michal Schmidt) [2040643]
- octeontx2-pf: Fix lmtst ID used in aura free (Michal Schmidt) [2040643]
- net: ethernet: marvell: octeontx2: Fix uninitialized variable warning (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix a resource leak in the probe and remove functions (Michal Schmidt) [2040643]
- octeontx2-af: Add FEC stats for RPM/RPM_USX block (Michal Schmidt) [2040643]
- octeontx2-pf: ethtool: Implement get_fec_stats (Michal Schmidt) [2040643]
- octeontx2-af: cn10kb: Add RPM_USX MAC support (Michal Schmidt) [2040643]
- octeontx2-af: Support variable number of lmacs (Michal Schmidt) [2040643]
- octeontx2-af: Simplify a size computation in rvu_npc_exact_init() (Michal Schmidt) [2040643]
- octeontx2-af: Fix the size of memory allocated for the 'id_bmap' bitmap (Michal Schmidt) [2040643]
- octeontx2-af: Use the bitmap API to allocate bitmaps (Michal Schmidt) [2040643]
- octeontx2-af: Slightly simplify rvu_npc_exact_init() (Michal Schmidt) [2040643]
- octeontx2-af: Fix a potentially spurious error message (Michal Schmidt) [2040643]
- octeontx2-pf: Add support to filter packet based on IP fragment (Michal Schmidt) [2040643]
- octeontx2-pf: Add additional checks while configuring ucast/bcast/mcast rules (Michal Schmidt) [2040643]
- marvell: octeontx2: build error: unknown type name 'u64' (Michal Schmidt) [2040643]
- octeontx2-af: Allow mkex profile without DMAC and add L2M/L2B header extraction support (Michal Schmidt) [2040643]
- octeontx2-pf: Fix potential memory leak in otx2_init_tc() (Michal Schmidt) [2040643]
- octeontx2-pf: Fix pfc_alloc_status array overflow (Michal Schmidt) [2040643]
- octeontx2-af: Fix reference count issue in rvu_sdp_init() (Michal Schmidt) [2040643]
- octeontx2-pf: Add check for devm_kcalloc (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix copy and paste bug in mcs_bbe_intr_handler() (Michal Schmidt) [2040643]
- octeontx2-af: debugsfs: fix pci device refcount leak (Michal Schmidt) [2040643]
- octeontx2-pf: Fix SQE threshold checking (Michal Schmidt) [2040643]
- octeontx2-pf: NIX TX overwrites SQ_CTX_HW_S[SQ_INT] (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix error return code in mcs_register_interrupts() (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Add debugfs support (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Handle MCS block interrupts (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Support for stats collection (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Install a default TCAM for normal traffic (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Manage the MCS block hardware resources (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Add mailboxes for port related operations (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Introduce driver for macsec block. (Michal Schmidt) [2040643]
- octeontx2-pf: Fix unused variable build error (Michal Schmidt) [2040643]
- octeontx2-af: Initialize PTP_SEC_ROLLOVER register properly (Michal Schmidt) [2040643]
- octeontx2-af: Add PTP PPS Errata workaround on CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for ptp 1-step mode on CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-af: return correct ptp timestamp for CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-pf: Add egress PFC support (Michal Schmidt) [2040643]
- octeontx2: ethernet: move from strlcpy with unused retval to strscpy (Michal Schmidt) [2040643]
- octeontx2-pf: Fix NIX_AF_TL3_TL2X_LINKX_CFG register configuration (Michal Schmidt) [2040643]
- octeontx2-af: Fix key checking for source mac (Michal Schmidt) [2040643]
- octeontx2-af: Fix mcam entry resource leak (Michal Schmidt) [2040643]
- octeontx2-af: suppress external profile loading warning (Michal Schmidt) [2040643]
- octeontx2-af: Apply tx nibble fixup always (Michal Schmidt) [2040643]
- octeontx2-pf: Reduce minimum mtu size to 60 (Michal Schmidt) [2040643]
- octeontx2-af: Set NIX link credits based on max LMAC (Michal Schmidt) [2040643]
- octeontx2-af: Fixes static warnings (Michal Schmidt) [2040643]
- octeontx2-af: Limit link bringup time at firmware (Michal Schmidt) [2040643]
- octeontx2-af: returning uninitialized variable (Michal Schmidt) [2040643]
- octeontx2-af: Remove duplicate include (Michal Schmidt) [2040643]
- octeontx2-af: Skip CGX/RPM probe incase of zero lmac count (Michal Schmidt) [2040643]
- octeontx2-af: Enable Exact match flag in kex profile (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for exact match table. (Michal Schmidt) [2040643]
- octeontx2-af: Invoke exact match functions if supported (Michal Schmidt) [2040643]
- octeontx2-af: Wrapper functions for MAC addr add/del/update/reset (Michal Schmidt) [2040643]
- octeontx2: Modify mbox request and response structures (Michal Schmidt) [2040643]
- octeontx2-af: Debugsfs support for exact match. (Michal Schmidt) [2040643]
- octeontx2-af: Drop rules for NPC MCAM (Michal Schmidt) [2040643]
- octeontx2-af: FLR handler for exact match table. (Michal Schmidt) [2040643]
- octeontx2-af: devlink configuration support (Michal Schmidt) [2040643]
- octeontx2-af: Exact match scan from kex profile (Michal Schmidt) [2040643]
- octeontx2-af: Exact match support (Michal Schmidt) [2040643]
- octeontx2-af: Use hashed field in MCAM key (Michal Schmidt) [2040643]
- octeontx2-af: Don't reset previous pfc config (Michal Schmidt) [2040643]
- octeontx2-af: fix operand size in bitwise operation (Michal Schmidt) [2040643]
- marvell/octeontx2/af: fix repeated words in comments (Michal Schmidt) [2040643]
- octeontx2-pf: Fix UDP/TCP src and dst port tc filters (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Fix egress ratelimit configuration (Michal Schmidt) [2040643]
- octeontx2-vf: Add support for adaptive interrupt coalescing (Michal Schmidt) [2040643]
- octeontx2-pf: replace bitmap_weight with bitmap_empty where appropriate (Michal Schmidt) [2040643]
- octeontx2-af: fix error code in is_valid_offset() (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for adaptive interrupt coalescing (Michal Schmidt) [2040643]
- octeontx2-pf: Use memset_startat() helper in otx2_stop() (Michal Schmidt) [2040643]
- octeontx2-pf: Remove unnecessary synchronize_irq() before free_irq() (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: fix error return of allocations (Michal Schmidt) [2040643]
- octeontx2-af: initialize action variable (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: add workaround for ptp errata (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: add support for new ptp timestamp format (Michal Schmidt) [2040643]
- octeontx2-af: fix array bound error (Michal Schmidt) [2040643]
- octeontx2-pf: Add TC feature for VFs (Michal Schmidt) [2040643]
- octeontx2-pf: PFC config support with DCBx (Michal Schmidt) [2040643]
- octeontx2-af: Flow control resource management (Michal Schmidt) [2040643]
- octeontx2-af: Priority flow control configuration support (Michal Schmidt) [2040643]
- octeontx2-af: Don't enable Pause frames by default (Michal Schmidt) [2040643]
- octeontx2-pf: Change receive buffer size using ethtool (Michal Schmidt) [2040643]
- octeontx2: Replace zero-length arrays with flexible-array members (Michal Schmidt) [2040643]
- octeontx2-af: Add KPU changes to parse NGIO as separate layer (Michal Schmidt) [2040643]
- octeontx2-pf: Forward error codes to VF (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Do not enable RPM loopback for LPC interfaces (Michal Schmidt) [2040643]
- octeontx2-af: Increase link credit restore polling timeout (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Ensure valid pointers are freed to aura (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Use appropriate register for LMAC enable (Michal Schmidt) [2040643]
- octeontx2-af: Retry until RVU block reset complete (Michal Schmidt) [2040643]
- octeontx2-af: Fix LBK backpressure id count (Michal Schmidt) [2040643]
- octeontx2-af: Do not fixup all VF action entries (Michal Schmidt) [2040643]
- octeontx2-af: Fix interrupt name strings (Michal Schmidt) [2040643]
- octeontx2-nicvf: Free VF PTP resources. (Michal Schmidt) [2040643]
- octeontx2-af: Increment ptp refcount before use (Michal Schmidt) [2040643]
- octeontx2-af: Fix a memleak bug in rvu_mbox_init() (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: don't corrupt user memory (Michal Schmidt) [2040643]
- octeontx2-nicvf: fix ioctl callback (Michal Schmidt) [2040643]
- octeontx2-pf: select CONFIG_NET_DEVLINK (Michal Schmidt) [2040643]
- octeontx2-af: use swap() to make code cleaner (Michal Schmidt) [2040643]
- octeontx2-af: Fix possible null pointer dereference. (Michal Schmidt) [2040643]
- octeontx2-af: Display all enabled PF VF rsrc_alloc entries. (Michal Schmidt) [2040643]
- octeontx2-af: Check whether ipolicers exists (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: Add channel and channel mask. (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: debugfs for dumping LMTST map table (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: Minor changes. (Michal Schmidt) [2040643]
- octeontx2: net: convert users of bitmap_foo() to linkmode_foo() (Michal Schmidt) [2040643]
- octeontx2-af: Increase number of reserved entries in KPU (Michal Schmidt) [2040643]
- octeontx2-nic: fix mixed module build (Michal Schmidt) [2040643]
- octeontx2-af: Add support to flush full CPT CTX cache (Michal Schmidt) [2040643]
- octeontx2-af: Perform cpt lf teardown in non FLR path (Michal Schmidt) [2040643]
- octeontx2-af: Enable CPT HW interrupts (Michal Schmidt) [2040643]
- octeontx2-pf: Simplify the receive buffer size calculation (Michal Schmidt) [2040643]
- ethernet: Remove redundant 'flush_workqueue()' calls (Michal Schmidt) [2040643]
- octeontx2: use eth_hw_addr_set() for dev->addr_len cases (Michal Schmidt) [2040643]
- octeontx2-af: Remove redundant initialization of variable pin (Michal Schmidt) [2040643]
- octeontx2: bpf: Let bpf_warn_invalid_xdp_action() report more info (Michal Schmidt) [2040643]
- octeontx2-pf: Add XDP support to netdev PF (Michal Schmidt) [2040643]
- octeontx2-af: Adjust LA pointer for cpt parse header (Michal Schmidt) [2040643]
- octeontx2-nicvf: Add PTP hardware clock support to NIX VF (Michal Schmidt) [2040643]
- octeontx2-pf: Enable promisc/allmulti match MCAM entries. (Michal Schmidt) [2040643]
- octeontx2-pf: Use hardware register for CQE count (Michal Schmidt) [2040643]
- octeontx2-af: Add external ptp input clock (Michal Schmidt) [2040643]
- octeontx2-af: Use ptp input clock info from firmware data (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: RPM hardware timestamp configuration (Michal Schmidt) [2040643]
- octeontx2-af: Reset PTP config in FLR handler (Michal Schmidt) [2040643]
- octeontx2-af: Optimize KPU1 processing for variable-length headers (Michal Schmidt) [2040643]
- octeontx2-af: Limit KPU parsing for GTPU packets (Michal Schmidt) [2040643]
- octeontx2-af: verify CQ context updates (Michal Schmidt) [2040643]
- octeontx2-af: Remove redundant initialization of variable blkaddr (Michal Schmidt) [2040643]
- octeontx2-af: Fix uninitialized variable val (Michal Schmidt) [2040643]
- octeontx2-af: Hardware configuration for inline IPsec (Michal Schmidt) [2040643]
- octeontx2-pf: CN10K: Hide RPM stats over ethtool (Michal Schmidt) [2040643]
- octeontx2-af: Fix some memory leaks in the error handling path of 'cgx_lmac_init()' (Michal Schmidt) [2040643]
- octeontx2-af: Add a 'rvu_free_bitmap()' function (Michal Schmidt) [2040643]
- octeontx2-pf: cn10K: Reserve LMTST lines per core (Michal Schmidt) [2040643]
- octeontx2-af: Add additional register check to rvu_poll_reg() (Michal Schmidt) [2040643]
- octeontx2-af: Set proper errorcode for IPv4 checksum errors (Michal Schmidt) [2040643]
- octeontx2-af: Fix static code analyzer reported issues (Michal Schmidt) [2040643]
- octeontx2-af: Fix mailbox errors in nix_rss_flowkey_cfg (Michal Schmidt) [2040643]
- octeontx2-af: Fix loop in free and unmap counter (Michal Schmidt) [2040643]
- octeontx2-af: Use NDC TX for transmit packet data (Michal Schmidt) [2040643]
- octeontx2-pf: Add vlan-etype to ntuple filters (Michal Schmidt) [2040643]
- octeontx2-af: Fix inconsistent license text (Michal Schmidt) [2040643]
- octeontx2-pf: Fix inconsistent license text (Michal Schmidt) [2040643]
- octeontx2-af: cn10K: support for sched lmtst and other features (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Fix error return code in otx2_set_flowkey_cfg() (Michal Schmidt) [2040643]
- octeontx2-af: Add mbox to retrieve bandwidth profile free count (Michal Schmidt) [2040643]
- octeontx2-af: Remove channel verification while installing MCAM rules (Michal Schmidt) [2040643]
- octeontx2-af: Add PTP device id for CN10K and 95O silcons (Michal Schmidt) [2040643]
- octeontx2-af: Add free rsrc count mbox msg (Michal Schmidt) [2040643]
- octeontx2-af: Add SDP interface support (Michal Schmidt) [2040643]
- octeontx2-af: nix and lbk in loop mode in 98xx (Michal Schmidt) [2040643]
- octeontx2-pf: cleanup transmit link deriving logic (Michal Schmidt) [2040643]
- octeontx2-af: Allow to configure flow tag LSB byte as RSS adder (Michal Schmidt) [2040643]
- octeontx2-af: enable tx shaping feature for 96xx C0 (Michal Schmidt) [2040643]
- octeontx2-af: Wait for TX link idle for credits change (Michal Schmidt) [2040643]
- octeontx2-af: Change the order of queue work and interrupt disable (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Set cache lines for NPA batch alloc (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Use FLIT0 register instead of FLIT1 (Michal Schmidt) [2040643]
- octeontx2-pf: Fix algorithm index in MCAM rules with RSS action (Michal Schmidt) [2040643]
- octeontx2-pf: Don't install VLAN offload rule if netdev is down (Michal Schmidt) [2040643]
- octeontx2-af: Check capability flag while freeing ipolicer memory (Michal Schmidt) [2040643]
- octeontx2-af: Use DMA_ATTR_FORCE_CONTIGUOUS attribute in DMA alloc (Michal Schmidt) [2040643]
- octeontx2-pf: send correct vlan priority mask to npc_install_flow_req (Michal Schmidt) [2040643]
- octeontx2-pf: Don't mask out supported link modes (Michal Schmidt) [2040643]
- octeontx2-af: Handle return value in block reset. (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Fix SDP base channel number (Michal Schmidt) [2040643]
- octeontx2-pf: Fix NIX1_RX interface backpressure (Michal Schmidt) [2040643]
- octeontx2-pf: Add check for non zero mcam flows (Michal Schmidt) [2040643]
- octeontx2-af: remove redudant second error check on variable err (Michal Schmidt) [2040643]
- octeontx2-pf: Allow VLAN priority also in ntuple filters (Michal Schmidt) [2040643]
- octeontx2-af: configure npc for cn10k to allow packets from cpt (Michal Schmidt) [2040643]
- octeontx2-af: cn10K: Get NPC counters value (Michal Schmidt) [2040643]
- octeontx2-af: Allocate low priority entries for PF (Michal Schmidt) [2040643]
- octeontx2: Move devlink registration to be last devlink command (part 2) (Michal Schmidt) [2040643]
- octeontx2: otx2_devlink: Make devlink_register to be void (Michal Schmidt) [2040643]
- octeontx2-pf: devlink params support to set mcam entry count (Michal Schmidt) [2040643]
- octeontx2-pf: Unify flow management variables (Michal Schmidt) [2040643]
- octeontx2-pf: Sort the allocated MCAM entry indices (Michal Schmidt) [2040643]
- octeontx2-pf: Ntuple filters support for VF netdev (Michal Schmidt) [2040643]
- octeontx2-pf: Enable NETIF_F_RXALL support for VF driver (Michal Schmidt) [2040643]
- octeontx2-af: Add debug messages for failures (Michal Schmidt) [2040643]
- octeontx2-af: add proper return codes for AF mailbox handlers (Michal Schmidt) [2040643]
- octeontx2-af: Modify install flow error codes (Michal Schmidt) [2040643]
- octeontx2-af: Fix spelling mistake "Makesure" -> "Make sure" (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Config DWRR weight based on MTU (Michal Schmidt) [2040643]
- octeontx2: Move devlink registration to be last devlink command (part 1) (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: DWRR MTU configuration (Michal Schmidt) [2040643]
- octeontx2-af: Enhance mailbox trace entry (Michal Schmidt) [2040643]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-278.el9]
- RDMA/irdma: Cap MSIX used to online CPUs + 1 (Kamal Heib) [2125810]
- KVM: arm64: GICv4.1: Fix race with doorbell on VPE activation/deactivation (Eric Auger) [2166453]
- ASoC: amd: ps: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: ps: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- ASoC: amd: renoir: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: renoir: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- ASoC: amd: yc: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: yc: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- Revert "vdpa/mlx5: Add RX MAC VLAN filter support" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Fix wrong mac address deletion" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Use eth_broadcast_addr() to assign broadcast address" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: fix error code for deleting vlan" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: clean up indenting in handle_ctrl_vlan()" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Fix rule forwarding VLAN to TIR" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Return error on vlan ctrl commands if not supported" (Cindy Lu) [2169174]
- kernel.spec: package unstripped kselftests/bpf/test_progs (Jan Stancek) [2161464]
- kernel.spec: allow to package some binaries as unstripped (Jan Stancek) [2161464]
- cpufreq: tegra194: Enable CPUFREQ thermal cooling (Joel Slebodnick) [2165104]
- mm/kmemleak: fix UAF bug in kmemleak_scan() (Waiman Long) [2151065]
- mm/kmemleak: simplify kmemleak_cond_resched() usage (Waiman Long) [2151065]
- mm: percpu: use kmemleak_ignore_phys() instead of kmemleak_free() (Waiman Long) [2151065]
- mm: kfence: apply kmemleak_ignore_phys on early allocated pool (Waiman Long) [2151065]
- mm/kmemleak.c: fix a comment (Waiman Long) [2151065]
- mm: kmemleak: check physical address when scan (Waiman Long) [2151065]
- mm: kmemleak: add rbtree and store physical address for objects allocated with PA (Waiman Long) [2151065]
- mm: kmemleak: add OBJECT_PHYS flag for objects allocated with physical address (Waiman Long) [2151065]
- mm: kmemleak: remove kmemleak_not_leak_phys() and the min_count argument to kmemleak_alloc_phys() (Waiman Long) [2151065]
- mm: kmemleak: take a full lowmem check in kmemleak_*_phys() (Waiman Long) [2151065]
- memblock tests: Add skeleton of the memblock simulator (Waiman Long) [2151065]
- usb: mon: make mmapped memory read only (Desnes Nunes) [2157698] {CVE-2022-43750}
- selftests/net: give more time to udpgro bg processes to complete startup (Adrien Thierry) [2143407]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-277.el9]
- virtio_net: notify MAC address change on device initialization (Laurent Vivier) [2153210]
- virtio_net: disable VIRTIO_NET_F_STANDBY if VIRTIO_NET_F_MAC is not set (Laurent Vivier) [2153210]
- virtio-net: fix race between ndo_open() and virtio_device_ready() (Laurent Vivier) [2153210]
- x86/hyperv: Remove unregister syscore call from Hyper-V cleanup (Mohammed Gamal) [2168542]
- drm/ast: Fix start address computation (Jocelyn Falempe) [2166219]
- arm64-64k: Increase max NR_IRQS from 64+8192 to 2^^19 (Donald Dutile) [2166450]
- thunderbolt: Add DP OUT resource when DP tunnel is discovered (Desnes Nunes) [2107603]
- net: sched: fix race condition in qdisc_graft() (Davide Caratti) [2165745] {CVE-2023-0590}
- xfs: drop write error injection is unfixable, remove it (Carlos Maiolino) [2155605]
- xfs: use iomap_valid method to detect stale cached iomaps (Carlos Maiolino) [2155605]
- iomap: write iomap validity checks (Carlos Maiolino) [2155605]
- xfs: xfs_bmap_punch_delalloc_range() should take a byte range (Carlos Maiolino) [2155605]
- iomap: buffered write failure should not truncate the page cache (Carlos Maiolino) [2155605]
- xfs,iomap: move delalloc punching to iomap (Carlos Maiolino) [2155605]
- xfs: use byte ranges for write cleanup ranges (Carlos Maiolino) [2155605]
- xfs: punching delalloc extents on write failure is racy (Carlos Maiolino) [2155605]
- xfs: write page faults in iomap are not buffered writes (Carlos Maiolino) [2155605]
- pinctrl: qcom: remove duplicate included header files (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8280xp: Rectify UFS reset pins (Alessandro Carminati) [2164821]
- pinctrl: qcom: lpass-lpi: Add missed bitfield.h (Alessandro Carminati) [2164821]
- arm64: dts: qcom: sc7180: revert "arm64: dts: qcom: sc7180: Avoid glitching SPI CS at bootup on trogdor" (Alessandro Carminati) [2164821]
- pinctrl: qcom: sdm670: change sdm670_reserved_gpios to static (Alessandro Carminati) [2164821]
- pinctrl: qcom: Avoid glitching lines when we first mux to output (Alessandro Carminati) [2164821]
- pinctrl: qcom: add sdm670 pinctrl (Alessandro Carminati) [2164821]
- pinctrl: qcom: do not reinitialize gpio valid mask (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add missing header(s) (Alessandro Carminati) [2164821]
- pinctrl: qcom: restrict drivers per ARM/ARM64 (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Add compatible for PM7250B (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Fix the GPIO strength mapping (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: add support for LV_VIN2 and MV_VIN3 subtypes (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Make irqchip immutable (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add sc8280xp lpass lpi pinctrl driver (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add sm8450 lpass lpi pinctrl driver (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8180x: Fix wrong pin numbers (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8180x: Fix gpio_wakeirq_map (Alessandro Carminati) [2164821]
- pinctrl: qcom: sm8250: Fix PDC map (Alessandro Carminati) [2164821]
- pinctrl: qcom: Make PINCTRL_SM8450 depend on PINCTRL_MSM (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add SM6375 TLMM driver (Alessandro Carminati) [2164821]
- pinctrl: qcom-pmic-gpio: add support for PMP8074 (Alessandro Carminati) [2164821]
- gpio: thunderx: Don't directly include asm-generic/msi.h (Alessandro Carminati) [2164821]
- gpio: Remove dynamic allocation from populate_parent_alloc_arg() (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Fix compile bug (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add pinctrl driver for MSM8909 (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Fix compile bug (Alessandro Carminati) [2164821]
- pinctrl: qcom: msm8916: Allow CAMSS GP clocks to be muxed (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Add clock optional check for ADSP bypass targets (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Add pm8226 compatibility (Alessandro Carminati) [2164821]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-276.el9]
- blk-cgroup: don't update io stat for root cgroup (Ming Lei) [2167245]
- sctp: do not check hb_timer.expires when resetting hb_timer (Xin Long) [2167094]
- netfilter: conntrack: handle tcp challenge acks during connection reuse (Florian Westphal) [2159642]
- redhat: Include Azure CVM specific udev rules into UKI's initramfs (Vitaly Kuznetsov) [2165913]
- r8169: fix dmar pte write access is not set error (Jose Ignacio Tornos Martinez) [2159618]
- r8169: move rtl_wol_enable_rx() and rtl_prepare_power_down() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: enable GRO software interrupt coalescing per default (Jose Ignacio Tornos Martinez) [2159618]
- r8169: use tp_to_dev instead of open code (Jose Ignacio Tornos Martinez) [2159618]
- drivers: net: convert to boolean for the mac_managed_pm flag (Jose Ignacio Tornos Martinez) [2159618]
- r8169: add rtl_disable_rxdvgate() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove rtl_wol_shutdown_quirk() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: merge support for chip versions 10, 13, 16 (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove not needed net_ratelimit() check (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove useless PCI region size check (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove comment about apparently non-existing chip versions (Jose Ignacio Tornos Martinez) [2159618]
- r8169: merge handling of chip versions 12 and 17 (RTL8168B) (Jose Ignacio Tornos Martinez) [2159618]
- net: ethernet: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2159618]
- r8169: fix accessing unset transport header (Jose Ignacio Tornos Martinez) [2159618]
- net: phy: realtek: add support for RTL8365MB-VC internal PHYs (Jose Ignacio Tornos Martinez) [2159618]
- cifs: refcount only the selected iface during interface update (Ronnie Sahlberg) [2151418]
- cifs: drop the lease for cached directories on rmdir or rename (Ronnie Sahlberg) [2151418]
- cifs: find and use the dentry for cached non-root directories also (Ronnie Sahlberg) [2151418]
- cifs: enable caching of directories for which a lease is held (Ronnie Sahlberg) [2151418]
- cifs: fix skipping to incorrect offset in emit_cached_dirents (Ronnie Sahlberg) [2151418]
- cifs: store a pointer to a fid in the cfid structure instead of the struct (Ronnie Sahlberg) [2151418]
- cifs: improve handlecaching (Ronnie Sahlberg) [2151418]
- cifs: Make tcon contain a wrapper structure cached_fids instead of cached_fid (Ronnie Sahlberg) [2151418]
- cifs: Add helper function to check smb1+ server (Ronnie Sahlberg) [2151418]
- cifs: Use help macro to get the mid header size (Ronnie Sahlberg) [2151418]
- cifs: Use help macro to get the header preamble size (Ronnie Sahlberg) [2151418]
- cifs: Do not access tcon->cfids->cfid directly from is_path_accessible (Ronnie Sahlberg) [2151418]
- cifs: Add constructor/destructors for tcon->cfid (Ronnie Sahlberg) [2151418]
- cifs: Do not use tcon->cfid directly, use the cfid we get from open_cached_dir (Ronnie Sahlberg) [2151418]
- cifs: Move cached-dir functions into a separate file (Ronnie Sahlberg) [2151418]
- cifs: when insecure legacy is disabled shrink amount of SMB1 code (Ronnie Sahlberg) [2151418]
- cifs: remove unnecessary locking of chan_lock while freeing session (Ronnie Sahlberg) [2151418]
- cifs: avoid use of global locks for high contention data (Ronnie Sahlberg) [2151418]
- cifs: add missing spinlock around tcon refcount (Ronnie Sahlberg) [2151418]
- cifs: avoid deadlocks while updating iface (Ronnie Sahlberg) [2151418]
- cifs: Use after free in debug code (Ronnie Sahlberg) [2151418]
- cifs: during reconnect, update interface if necessary (Ronnie Sahlberg) [2151418]
- cifs: fix race condition with delayed threads (Ronnie Sahlberg) [2151418]
- cifs: change iface_list from array to sorted linked list (Ronnie Sahlberg) [2151418]
- cifs: update cifs_ses::ip_addr after failover (Ronnie Sahlberg) [2151418]
- cifs: avoid parallel session setups on same channel (Ronnie Sahlberg) [2151418]
- cifs: fix potential deadlock in direct reclaim (Ronnie Sahlberg) [2151418]
- smb3: remove unneeded null check in cifs_readdir (Ronnie Sahlberg) [2151418]
- cifs: cache the dirents for entries in a cached directory (Ronnie Sahlberg) [2151418]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-275.el9]
- cifs: serialize all mount attempts (Ronnie Sahlberg) [2165757]
- cifs: fix potential double free during failed mount (Ronnie Sahlberg) [2165755]
- EDAC/amd64: Handle three rank interleaving mode (Aristeu Rozanski) [2165633]
- memory: tegra: Add DLA clients for Tegra234 (Joel Slebodnick) [2144645]
- dt-bindings: tegra: Update headers for Tegra234 (Joel Slebodnick) [2144645]
- KVM: x86: smm: preserve interrupt shadow in SMRAM (Maxim Levitsky) [2035694]
- KVM: x86: SVM: don't save SVM state to SMRAM when VM is not long mode capable (Maxim Levitsky) [2035694]
- KVM: x86: SVM: use smram structs (Maxim Levitsky) [2035694]
- KVM: svm: drop explicit return value of kvm_vcpu_map (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram struct for 64 bit smram load/restore (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram struct for 32 bit smram load/restore (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram structs in the common code (Maxim Levitsky) [2035694]
- KVM: x86: smm: add structs for KVM's smram layout (Maxim Levitsky) [2035694]
- KVM: x86: smm: check for failures on smm entry (Maxim Levitsky) [2035694]
- KVM: x86: do not go through ctxt->ops when emulating rsm (Maxim Levitsky) [2035694]
- KVM: x86: move SMM exit to a new file (Maxim Levitsky) [2035694]
- KVM: x86: move SMM entry to a new file (Maxim Levitsky) [2035694]
- KVM: x86: start moving SMM-related functions to new files (Maxim Levitsky) [2035694]
- bug: introduce ASSERT_STRUCT_OFFSET (Maxim Levitsky) [2035694]
- KVM: x86: Rename and expose helper to detect if INIT/SIPI are allowed (Maxim Levitsky) [2035694]
- KVM: x86: smm: number of GPRs in the SMRAM image depends on the image format (Maxim Levitsky) [2035694]
- KVM: x86: emulator: update the emulation mode after CR0 write (Maxim Levitsky) [2035694]
- KVM: x86: emulator: update the emulation mode after rsm (Maxim Levitsky) [2035694]
- KVM: x86: emulator: introduce emulator_recalc_and_set_mode (Maxim Levitsky) [2035694]
- KVM: x86: emulator: em_sysexit should update ctxt->mode (Maxim Levitsky) [2035694]
- tty: serial: qcom_geni: avoid duplicate struct member init (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Add support for Hibernation feature (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Replace hardcoded icc flags with macros. (Alessandro Carminati) [2162957]
- serial: Make ->set_termios() old ktermios const (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Fix %%lu -> %%u in print statements (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Fix get_clk_div_rate() which otherwise could return a sub-optimal clock rate. (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Implement start_rx callback (Alessandro Carminati) [2162957]
- serial: core: Introduce callback for start_rx and do stop_rx in suspend only if this callback implementation is present. (Alessandro Carminati) [2162957]
- serial: qcom_geni_serial: Disable MMIO tracing for geni serial (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Remove uart frequency table. Instead, find suitable frequency with call to clk_round_rate. (Alessandro Carminati) [2162957]
- serial: core: Do stop_rx in suspend path for console if console_suspend is disabled (Alessandro Carminati) [2162957]
- serial: qcom: use check for empty instead of pending (Alessandro Carminati) [2162957]
- serial: make uart_console_write->putchar()'s character an unsigned char (Alessandro Carminati) [2162957]
- PCI: qcom-ep: Setup PHY to work in EP mode (Shawn Doherty) [2164511]
- PCI: qcom: Setup PHY to work in RC mode (Shawn Doherty) [2164511]
- PCI: qcom: Fix error message for reset_control_assert() (Shawn Doherty) [2164511]
- PCI: qcom: Add basic interconnect support (Shawn Doherty) [2164511]
- dt-bindings: PCI: qcom: Allow 'dma-coherent' property (Shawn Doherty) [2164511]
- dt-bindings: PCI: qcom: Add SC8280XP/SA8540P interconnects (Shawn Doherty) [2164511]
- ASoC: tegra: Add binding doc for OPE module (Joel Slebodnick) [2122417]
- ASoC: tegra: Add binding doc for ASRC module (Joel Slebodnick) [2122417]
- ASoC: Document Tegra234 APE support (Joel Slebodnick) [2122417]
- ASoC: dt-bindings: tegra: Few more Tegra210 AHUB modules (Joel Slebodnick) [2122417]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-274.el9]
- arm64: dts: qcom: sc8280xp: fix UFS DMA coherency (Adrien Thierry) [2159516]
- arm64: dts: qcom: sa8540p-ride: enable PCIe support (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SA8540P ride(Qdrive-3) (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop reference-clock source (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add bwmon instances (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Set up L3 scaling (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add epss_l3 node (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: update UFS PHY nodes (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM4250 support (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM8550 to rpmpd binding (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix UFS reference clocks (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix PCIe DMA coherency (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused type header (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop sc8280xp reference-clock source (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename DP_PHY register pointer (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename common-register pointers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP clock callbacks (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate clock and provider registration (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add clock registration helper (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant clock structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: generate pipe clock name (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop v4 reference-clock source (Adrien Thierry) [2159516]
- dt-bindings: phy: qcom,qmp-usb3-dp: fix sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP callback names (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: merge USB and DP configurations (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop lanes config parameter (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add DP configuration tables (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename sc8280xp config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP configurations (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add dedicated DP iomem pointers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP devicetree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up serdes initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP power-on ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename DP PHY ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP init ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unnecessary debug message (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename USB PHY ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused DP PHY mode op (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename PHY ops structures (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: move pm ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: sort device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up common initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix runtime suspend (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix broken power on (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sc8180x reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sdm845 reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix out-of-bounds clock access (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp/sa8540p: add PCIe2-4 nodes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Fix sm8450_qmp_gen4x2_pcie_pcs_tbl[] register names (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Fix high latency with 4x2 PHY when ASPM is enabled (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split pcs_misc init cfg for ipq8074 pcs table (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for sc8280xp 4-lane PHYs (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for sc8280xp (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for pipediv2 clock (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix initialisation reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add register init helper (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: use shorter tables identifiers (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up PHY lane init (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: sort device-id table (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB MP QMP PHY nodes (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add QDU1000/QRU1000 to rpmpd binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up PHY init (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: move pm ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: sort device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: fix sc8280xp PCS_USB offset (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add TCSR node (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up PHY init (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix NULL-deref on runtime resume (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: correct registers layout for IPQ8074 USB3 PHY (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add config sanity checks (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop start-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: increase ready polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up ready polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused phy-status config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: clean up ready and status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix ipq6018 initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix ipq8074-gen3 initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix sc8180x initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop sc8280xp power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop sc8280xp power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: replace power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop redundant ipq8074 power on (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop superfluous comments (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop regulator error message (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add rpmh-stats node (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix UFS PHY serdes size (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop broken DP PHY nodes (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB PHY PCS registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB1 PHY RX1 registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB0 PHY PCS_MISC registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: correct ref clock for ufs_mem_phy (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix ufs_card_phy ref clock (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: add sdm670 power domains (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop bogus register update (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up clock lists (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: move power-down update (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused common-block registers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused UFS reset (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix obsolete lane comments (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Support SM8450 PCIe1 PHY in EP mode (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: support separate tables for EP mode (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split register tables into common and extra parts (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix resource mapping for SDM845 QHP PHY (Adrien Thierry) [2159516]
- phy: rockchip-snps-pcie3: only look for rockchip,pipe-grf on rk3588 (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qualcomm: call clk_disable_unprepare in the error handling (Adrien Thierry) [2159516]
- phy: qcom-snps: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qusb2: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant DP config flag (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: rename nlanes config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused index field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused config field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused mode field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused kernel doc (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused forward declarations (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop init and exit wrappers (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop init and exit wrappers (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sc8280xp PCS_USB offset (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused pcs_misc handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add pcs_misc sanity check (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused secondary init tables (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp: silence noisy probe (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: disable runtime PM on unbind (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: disable runtime PM on unbind (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM6375 power domains (Adrien Thierry) [2159516]
- phy: qcom-snps: Add support for overriding phy tuning parameters (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop dual-lane comments (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop if (table) conditions (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: mark USB controllers as wakeup-sources (Adrien Thierry) [2159516]
- phy: rockchip: Support PCIe v3 (Adrien Thierry) [2159516]
- phy: qcom: edp: Postpone clk_set_rate until the PLL is up (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop reset lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused lane reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Add sc8280xp USB/DP combo phys (Adrien Thierry) [2159516]
- phy: qcom-qmp: Add SC8280XP USB3 UNI phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Parameterize swing and pre_emphasis tables (Adrien Thierry) [2159516]
- phy: qualcomm: phy-qcom-qmp: add support for combo USB3+DP phy on SDM845 (Adrien Thierry) [2159516]
- phy: qcom: edp: Add SC8280XP eDP and DP PHYs (Adrien Thierry) [2159516]
- phy: qcom: edp: Introduce support for DisplayPort (Adrien Thierry) [2159516]
- phy: qcom: edp: Perform lane configuration (Adrien Thierry) [2159516]
- phy: qcom: edp: Generate unique clock names (Adrien Thierry) [2159516]
- dt-bindings: gpio: add pull-disable flag (Adrien Thierry) [2159516]
- dt-bindings: power: qcom-rpmpd: Add MSM8909 power domains (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add missing 300MHz (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB interrupts (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB clock order and naming (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix usb_1 ssphy irq (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Fix PMU interrupt (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix the smmu interrupt values (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: statify qmp_phy_vreg_l (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add lost ranges for timer (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix DP PHY node unit addresses (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix usb_0 HS PHY ref clock (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: define QPHY_V2_PCS_PLL_LOCK_CHK_DLY_TIME register (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: replace FLL layout writes for msm8996 (Adrien Thierry) [2159516]
- phy: qcom-qmp: pcs-pcie-v4: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: pcs-v3: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v5: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v4: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v3: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: split PCS_UFS V3 symbols to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: split allegedly 4.20 and 5.20 PCS registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: split allegedly 4.20 and 5.20 TX/RX registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCIE QHP registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V5 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V4 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V3 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V2 registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES PLL registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V5 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V4 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V3 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: use QPHY_V4_PCS for ipq6018/ipq8074 PCIe gen3 (Adrien Thierry) [2159516]
- phy: qcom-qmp: rename QMP V2 PCS registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop special QMP V2 PCIE gen3 defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split pcs_misc region for ipq6018 pcie gen3 (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo,usb: add support for separate PCS_USB region (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: remove spurious register write in the msm8996 table (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix the QSERDES_V5_COM_CMN_MODE register (Adrien Thierry) [2159516]
- phy: qcom-qmp: add regulator_set_load to dp phy (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop UFS PHY clock-cells (Adrien Thierry) [2159516]
- phy: qcom-edp: add regulator_set_load to edp phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add IPQ8074 PCIe Gen3 QMP PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: make pipe clock rate configurable (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up hex defines (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up define alignment (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up v4 and v5 define order (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up pipe clock handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop obsolete pipe clock type check (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop obsolete pipe clock type check (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SA8540P and ADP (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SC8280XP platform (Adrien Thierry) [2159516]
- dt-bindings: mailbox: qcom-ipcc: Add NSP1 client (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix PCIe PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix msm8996 PCIe PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop support for non-USB PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop support for non-UFS PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop support for non-PCIe PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop support for non-PCIe PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop support for PCIe,UFS PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop old QMP PHY driver source (Adrien Thierry) [2159516]
- phy: qcom-qmp: switch to new split QMP PHY driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: change symbol prefix to qcom_qmp_phy_usb (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: change symbol prefix to qcom_qmp_phy_ufs (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: change symbol prefix to qcom_qmp_phy_pcie_msm8996 (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: change symbol prefix to qcom_qmp_phy_pcie (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: change symbol prefix to qcom_qmp_phy_combo (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop all non-combo compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop all non-USB compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop all non-UFS compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop all compatibles except msm8996-pcie-phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop all non-PCIe compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp: create copies of QMP PHY driver (Adrien Thierry) [2159516]
- dt-bindings: mailbox: Add more protocol and client ID (Adrien Thierry) [2159516]
- clk: qcom: rpmh: Add support for RPMH clocks on SM6350 (Adrien Thierry) [2159516]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-273.el9]
- kernfs: fix use-after-free in __kernfs_remove (Ian Kent) [2143947]
- iommu/arm-smmu-qcom: Add SM6350 SMMUv2 (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Add generic qcom,smmu-500 match entry (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Stop using mmu500 reset for v2 MMUs (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Merge table from arm-smmu-qcom-debug into match data (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: provide separate implementation for SDM845-smmu-500 (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Move the qcom,adreno-smmu check into qcom_smmu_create (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Move implementation data into match data (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Add SM6115 support (Adrien Thierry) [2164639]
- drivers: arm-smmu-impl: Add QDU1000 and QRU1000 iommu implementation (Adrien Thierry) [2164639]
- netfilter: nf_tables: honor set timeout and garbage collection updates (Florian Westphal) [2164485]
- netfilter: nf_tables: perform type checking for existing sets (Florian Westphal) [2164485]
- netfilter: nf_tables: add function to create set stateful expressions (Florian Westphal) [2164485]
- netfilter: nf_tables: consolidate set description (Florian Westphal) [2164485]
- net: atlantic: remove aq_nic_deinit() when resume (Íñigo Huguet) [2162022]
- net: atlantic: remove deep parameter on suspend/resume functions (Íñigo Huguet) [2162022]
- atlantic: Fix issue in the pm resume flow. (Íñigo Huguet) [2162022]
- atlantic: Fix driver resume flow. (Íñigo Huguet) [2162022]
- net: atlantic: always deep reset on pm op, fixing up my null deref regression (Íñigo Huguet) [2162022]
- net: atlantic: invert deep par in pm functions, preventing null derefs (Íñigo Huguet) [2162022]
- ACPI: CPPC: Disable FIE if registers in PCC regions (Mark Langsdorf) [2153646]
- net: mlx5: eliminate anonymous module_init & module_exit (Mohammad Kabat) [2157856]
- net/mlx5: E-switch, Fix switchdev mode after devlink reload (Mohammad Kabat) [2157856]
- net/mlx5e: Set decap action based on attr for sample (Mohammad Kabat) [2157856]
- net/mlx5e: QoS, Fix wrongfully setting parent_element_id on MODIFY_SCHEDULING_ELEMENT (Mohammad Kabat) [2157856]
- net/mlx5: E-switch, Fix setting of reserved fields on MODIFY_SCHEDULING_ELEMENT (Mohammad Kabat) [2157856]
- net/mlx5e: Avoid false lock dependency warning on tc_ht even more (Mohammad Kabat) [2157856]
- net/mlx5: fix missing mutex_unlock in mlx5_fw_fatal_reporter_err_work() (Mohammad Kabat) [2157856]
- net/mlx5: Fix ptp max frequency adjustment range (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Fix child PKEY interface stats on rx path (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Block PKEY interfaces with less rx queues than parent (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Block queue count configuration when sub interfaces are present (Mohammad Kabat) [2157856]
- net/mlx5e: Verify dev is present for fix features ndo (Mohammad Kabat) [2157856]
- net/mlx5: Fix command stats access after free (Mohammad Kabat) [2157856]
- net/mlx5e: TC, Keep mod hdr actions after mod hdr alloc (Mohammad Kabat) [2157856]
- net/mlx5: check attr pointer validity before dereferencing it (Mohammad Kabat) [2157856]
- RDMA/mlx5: Fix validation of max_rd_atomic caps for DC (Mohammad Kabat) [2157856]
- RDMA/mlx5: Fix mlx5_ib_get_hw_stats when used for device (Mohammad Kabat) [2157856]
- net/mlx5e: Set geneve_tlv_option_0_exist when matching on geneve option (Mohammad Kabat) [2157856]
- net/mlx5e: Fix hw mtu initializing at XDP SQ allocation (Mohammad Kabat) [2157856]
- net/mlx5e: Always clear dest encap in neigh-update-del (Mohammad Kabat) [2157856]
- net/mlx5e: CT: Fix ct debugfs folder name (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Don't allow CQE compression to be turned on by default (Mohammad Kabat) [2157856]
- net/mlx5: Fix RoCE setting at HCA level (Mohammad Kabat) [2157856]
- net/mlx5: Avoid recovery in probe flows (Mohammad Kabat) [2157856]
- net/mlx5: Fix io_eq_size and event_eq_size params validation (Mohammad Kabat) [2157856]
- net/mlx5: Add forgotten cleanup calls into mlx5_init_once() error path (Mohammad Kabat) [2157856]
- net/mlx5: E-Switch, properly handle ingress tagged packets on VST (Mohammad Kabat) [2157856 2158371]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-272.el9]
- Split partner modules into a sub-package (Alice Mitchell) [2039020]
- Enable kAFS and it's dependancies in RHEL (Alice Mitchell) [2039020]
- netfilter: ipset: Fix overflow before widen in the bitmap_ip_create() function. (Florian Westphal) [2161695]
- netfilter: ipset: fix hash:net,port,net hang with /0 subnet (Florian Westphal) [2161695]
- ipvs: use u64_stats_t for the per-cpu counters (Florian Westphal) [2161695]
- netfilter: flowtable: really fix NAT IPv6 offload (Florian Westphal) [2161695]
- netfilter: conntrack: fix using __this_cpu_add in preemptible (Florian Westphal) [2161695]
- netfilter: flowtable_offload: fix using __this_cpu_add in preemptible (Florian Westphal) [2161695]
- netfilter: nft_set_pipapo: Actually validate intervals in fields after the first one (Florian Westphal) [2161695]
- netfilter: flowtable_offload: add missing locking (Florian Westphal) [2161695]
- netfilter: ipset: restore allowing 64 clashing elements in hash:net,iface (Florian Westphal) [2161695]
- netfilter: ipset: regression in ip_set_hash_ip.c (Florian Westphal) [2161695]
- netfilter: Cleanup nft_net->module_list from nf_tables_exit_net() (Florian Westphal) [2161695]
- netfilter: nfnetlink: fix potential dead lock in nfnetlink_rcv_msg() (Florian Westphal) [2161695]
- netfilter: nf_tables: nft_parse_register can return a negative value (Florian Westphal) [2161695]
- intel_th: msu: Use memset_startat() for clearing hw header (Eric Chanudet) [2159468]
- redhat/configs: leave -Werror off for now (Eric Chanudet) [2159468]
- gcc-12: disable '-Warray-bounds' universally for now (Eric Chanudet) [2159468]
- kbuild: Fix -Wimplicit-fallthrough=5 error for GCC 5.x and 6.x (Eric Chanudet) [2159468]
- s390: disable -Warray-bounds (Eric Chanudet) [2159468]
- gcc-12: disable '-Wdangling-pointer' warning for now (Eric Chanudet) [2159468]
- Makefile: fix 2 typos (Eric Chanudet) [2159468]
- Makefile: Enable -Wzero-length-bounds (Eric Chanudet) [2159468]
- Makefile: Enable -Warray-bounds (Eric Chanudet) [2159468]
- sparc: Unbreak the build (Eric Chanudet) [2159468]
- Makefile: Enable -Wcast-function-type (Eric Chanudet) [2159468]
- kconfig: Add support for -Wimplicit-fallthrough (Eric Chanudet) [2159468]
- Makefile: use -Wno-main in the full kernel tree (Eric Chanudet) [2159468]
- s390: remove WARN_DYNAMIC_STACK (Eric Chanudet) [2159468]
- Enable '-Werror' by default for all kernel builds (Eric Chanudet) [2159468]
- kbuild: Shuffle blank line to improve comment meaning (Eric Chanudet) [2159468]
- x86/boot: Wrap literal addresses in absolute_pointer() (Eric Chanudet) [2159468]
- scsi: lpfc: Use struct_group() to initialize struct lpfc_cgn_info (Eric Chanudet) [2159468]
- bnx2x: Use struct_group() for memcpy() region (Eric Chanudet) [2159468]
- RDMA/cxgb4: fix accept failure due to increased cpl_t5_pass_accept_rpl size (Eric Chanudet) [2159468]
- iw_cxgb4: Use memset_startat() for cpl_t5_pass_accept_rpl (Eric Chanudet) [2159468]
- dm integrity: Use struct_group() to zero struct journal_sector (Eric Chanudet) [2159468]
- bnxt_en: Use struct_group_attr() for memcpy() region (Eric Chanudet) [2159468]
- ipv6: Use memset_after() to zero rt6_info (Eric Chanudet) [2159468]
- xfrm: Use memset_after() to clear padding (Eric Chanudet) [2159468]
- virtio-pci: Remove wrong address verification in vp_del_vqs() (Eric Chanudet) [2159468]
- ipv4: ip_output.c: Fix out-of-bounds warning in ip_copy_addrs() (Eric Chanudet) [2159468]
- skbuff: Switch structure bounds to struct_group() (Eric Chanudet) [2159468]
- tracing: Use memset_startat() to zero struct trace_iterator (Eric Chanudet) [2159468]
- kernel/sysctl.c: fixup printk sysctl constants (Eric Chanudet) [2159468]
- crypto: dh - constify struct dh's pointer members (Eric Chanudet) [2159468]
- cert host tools: Stop complaining about deprecated OpenSSL functions (Eric Chanudet) [2159468]
- kernel/sysctl.c: remove unused variable ten_thousand (Eric Chanudet) [2159468]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-271.el9]
- spi: bcm2835: bcm2835_spi_handle_err(): fix NULL pointer deref for non DMA transfers (Mark Salter) [2071848 2122415]
- spi: bcm2835aux: Convert to use GPIO descriptors (Mark Salter) [2071848 2122415]
- spi: bcm2835aux: use 'unsigned int' instead of 'unsigned' (Mark Salter) [2071848 2122415]
- redhat/configs: enable CONFIG_SPI_TEGRA210_QUAD (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_transfer_one(): check for DMA transfer first (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix duplicate resource error (Mark Salter) [2071848 2122415]
- spi: spi-imx: Fix spi_bus_clk if requested clock is higher than input clock (Mark Salter) [2071848 2122415]
- spi: amd: Fix SPI_SPD7 value (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Don't initialise DMA if not supported (Mark Salter) [2071848 2122415]
- spi: qup: support using GPIO as chip select line (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix combined sequence (Mark Salter) [2071848 2122415]
- spi: Ensure that sg_table won't be used after being freed (Mark Salter) [2071848 2122415]
- spi: Split transfers larger than max size (Mark Salter) [2071848 2122415]
- spi: Fix cache corruption due to DMA/PIO overlap (Mark Salter) [2071848 2122415]
- spi: Save current RX and TX DMA devices (Mark Salter) [2071848 2122415]
- spi: spi-fsl-qspi: Use devm_platform_ioremap_resource_byname() (Mark Salter) [2071848 2122415]
- spi: spi-fsl-lpspi: Use devm_platform_get_and_ioremap_resource() (Mark Salter) [2071848 2122415]
- spi: Group cs_change and cs_off flags together in struct spi_transfer (Mark Salter) [2071848 2122415]
- spi: lpspi: Remove the unneeded result variable (Mark Salter) [2071848 2122415]
- spi: Add capability to perform some transfer with chipselect off (Mark Salter) [2071848 2122415]
- spi: nxp-fspi: Do not dereference fwnode in struct device (Mark Salter) [2071848 2122415]
- spi: qup: add missing clk_disable_unprepare on error in spi_qup_pm_resume_runtime() (Mark Salter) [2071848 2122415]
- spi: qup: add missing clk_disable_unprepare on error in spi_qup_resume() (Mark Salter) [2071848 2122415]
- spi: amd: Fix speed selection (Mark Salter) [2071848 2122415]
- spi: amd: Configure device speed (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Remove the unneeded result variable (Mark Salter) [2071848 2122415]
- spi: move from strlcpy with unused retval to strscpy (Mark Salter) [2071848 2122415]
- spi: amd: Setup all xfers before opcode execution (Mark Salter) [2071848 2122415]
- spi: lpspi: Simplify some error message (Mark Salter) [2071848 2122415]
- spi: spi: Fix queue hang if previous transfer failed (Mark Salter) [2071848 2122415]
- spi: mux: Fix mux interaction with fast path optimisations (Mark Salter) [2071848 2122415]
- spi: spi.c: Add missing __percpu annotations in users of spi_statistics (Mark Salter) [2071848 2122415]
- spi: Fix simplification of devm_spi_register_controller (Mark Salter) [2071848 2122415]
- spi: remove duplicate parameters check in acpi_spi_add_resource() (Mark Salter) [2071848 2122415]
- spi: propagate error code to the caller of acpi_spi_device_alloc() (Mark Salter) [2071848 2122415]
- spi: amd: Add struct and enum kernel-doc comments (Mark Salter) [2071848 2122415]
- spi: amd: Drop io_base_addr member from struct amd_spi (Mark Salter) [2071848 2122415]
- spi: amd: Make use of dev_err_probe() (Mark Salter) [2071848 2122415]
- spi: amd: Make use of devm_spi_alloc_master() (Mark Salter) [2071848 2122415]
- spi: Use device_find_any_child() instead of custom approach (Mark Salter) [2071848 2122415]
- spi: spi.c: Remove redundant else block (Mark Salter) [2071848 2122415]
- spi: spi.c: Fix comment style (Mark Salter) [2071848 2122415]
- spi: spi.c: White-space fix in __spi_pump_messages() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Add support for Intel Meteor Lake-P (Mark Salter) [2071848 2122415]
- spi: opportunistically skip ctlr->cur_msg_completion (Mark Salter) [2071848 2122415]
- spi: Ensure the io_mutex is held until spi_finalize_current_message() (Mark Salter) [2071848 2122415]
- spi: Set ctlr->cur_msg also in the sync transfer case (Mark Salter) [2071848 2122415]
- spi: Remove unneeded READ_ONCE for ctlr->busy flag (Mark Salter) [2071848 2122415]
- spi: Remove the now unused ctlr->idling flag (Mark Salter) [2071848 2122415]
- spi: Remove check for idling in __spi_pump_messages() (Mark Salter) [2071848 2122415]
- spi: Remove check for controller idling in spi sync path (Mark Salter) [2071848 2122415]
- spi: __spi_pump_messages: Consolidate spin_unlocks to goto target (Mark Salter) [2071848 2122415]
- spi: Lock controller idling transition inside the io_mutex (Mark Salter) [2071848 2122415]
- spi: Don't use the message queue if possible in spi_sync (Mark Salter) [2071848 2122415]
- spi: Move ctlr->cur_msg_prepared to struct spi_message (Mark Salter) [2071848 2122415]
- spi: core: Fix error code in spi_register_controller() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Multi-cs support (Mark Salter) [2071848 2122415]
- spi: Fix per-cpu stats access on 32 bit systems (Mark Salter) [2071848 2122415]
- spi: <linux/spi/spi.h>: Add missing documentation for struct members (Mark Salter) [2071848 2122415]
- spi: spi.c: Convert statistics to per-cpu u64_stats_t (Mark Salter) [2071848 2122415]
- spi: fix typo in comment (Mark Salter) [2071848 2122415]
- spi: amd: Limit max transfer and message size (Mark Salter) [2071848 2122415]
- spi: spi-imx: mx51_ecspi_prepare_message(): skip writing MX51_ECSPI_CONFIG register if unchanged (Mark Salter) [2071848 2122415]
- spi: spi-imx: add PIO polling support (Mark Salter) [2071848 2122415]
- spi: spi-imx: replace struct spi_imx_data::bitbang by pointer to struct spi_controller (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_buf_rx_swap_u32(): replace open coded swahw32s() (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_buf_rx_swap_u32(): fix sparse warning: use swab32s() instead of cpu_to_be32() (Mark Salter) [2071848 2122415]
- spi: spi-imx: mx51_ecspi_intctrl(): prefer 'unsigned int' to bare use of 'unsigned' (Mark Salter) [2071848 2122415]
- spi: spi-imx: avoid unnecessary line continuations (Mark Salter) [2071848 2122415]
- spi: spi-imx: fix sparse warning: add identifier name to function definition (Mark Salter) [2071848 2122415]
- spi: spi-fsl-qspi: check return value after calling platform_get_resource_byname() (Mark Salter) [2071848 2122415]
- spi: spi-imx: complete conversion from master -> controller (Mark Salter) [2071848 2122415]
- spi: core: Display return code when failing to transfer message (Mark Salter) [2071848 2122415]
- spi: Doc fix - Describe add_lock and dma_map_dev in spi_controller (Mark Salter) [2071848 2122415]
- spi: Use helper for safer setting of driver_override (Mark Salter) [2071848 2122415]
- spi: spi-imx: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2071848 2122415]
- spi: core: Initialize returned status in spi_setup (Mark Salter) [2071848 2122415]
- spi: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2071848 2122415]
- spi: spi-imx: add support for SPI_RX_CPHA_FLIP (Mark Salter) [2071848 2122415]
- spi: add SPI_RX_CPHA_FLIP mode bit (Mark Salter) [2071848 2122415]
- spi: core: Only check bits_per_word validity when explicitly provided (Mark Salter) [2071848 2122415]
- spi: core: add dma_map_dev for __spi_unmap_msg() (Mark Salter) [2071848 2122415]
- spi: Fix erroneous sgs value with min_t() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: combined sequence mode (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: add acpi support (Mark Salter) [2071848 2122415]
- spi: qup: replace spin_lock_irqsave by spin_lock in hard IRQ (Mark Salter) [2071848 2122415]
- spi: use specific last_cs instead of last_cs_enable (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: add new chips to compatible (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: use device_reset method (Mark Salter) [2071848 2122415]
- spi: use sysfs_emit() for printing statistics and add trailing newline (Mark Salter) [2071848 2122415]
- spi: amd: Fix building without ACPI enabled (Mark Salter) [2071848 2122415]
- spi: Retire legacy GPIO handling (Mark Salter) [2071848 2122415]
- spi: amd: Add support for version AMDI0062 (Mark Salter) [2071848 2122415]
- spi: amd: Remove needless rom_addr variable (Mark Salter) [2071848 2122415]
- spi: amd: Use iopoll for busy waiting (Mark Salter) [2071848 2122415]
- spi: spi-mem: Introduce a capability structure (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix missin IRQ check in tegra_qspi_probe (Mark Salter) [2071848 2122415]
- spi: Make spi_alloc_device and spi_add_device public again (Mark Salter) [2071848 2122415]
- spi: pxa2xx_spi: Convert to use GPIO descriptors (Mark Salter) [2071848 2122415]
- spi: Fix invalid sgs value (Mark Salter) [2071848 2122415]
- spi: don't include ptp_clock_kernel.h in spi.h (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Propagate firmware node (Mark Salter) [2071848 2122415]
- spi: Fix incorrect cs_setup delay handling (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Get rid of unused enable_loopback member (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Get rid of unused ->cs_control() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: use devm call for cdata memory (Mark Salter) [2071848 2122415]
- spi: Fix condition in the __spi_register_driver() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Remove redundant ->read() and ->write() in struct chip_data (Mark Salter) [2071848 2122415]
- spi: Fix multi-line comment style (Mark Salter) [2071848 2122415]
- spi: Replace memset() with __GFP_ZERO (Mark Salter) [2071848 2122415]
- spi: deduplicate spi_match_id() in __spi_register_driver() (Mark Salter) [2071848 2122415]
- spi: xlp: Remove Netlogic XLP variants (Mark Salter) [2071848 2122415]
- spi: lpspi: release requested DMA channels (Mark Salter) [2071848 2122415]
- spi: fix use-after-free of the add_lock mutex (Mark Salter) [2071848 2122415]
- spi: lpspi: Silence error message upon deferred probe (Mark Salter) [2071848 2122415]
- rtc: ds1390: Add SPI ID table (Mark Salter) [2071848 2122415]
- rtc: mcp795: Add SPI ID table (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Put device into suspend on driver removal (Mark Salter) [2071848 2122415]
- spi: Check we have a spi_device_id for each DT compatible (Mark Salter) [2071848 2122415]
- spi: Make several public functions private to spi.c (Mark Salter) [2071848 2122415]
- spi: Reorder functions to simplify the next commit (Mark Salter) [2071848 2122415]
- spi: Remove unused function spi_busnum_to_master() (Mark Salter) [2071848 2122415]
- spi: Move comment about chipselect check to the right place (Mark Salter) [2071848 2122415]
- spi: amd: Don't wait for a write-only transfer to finish (Mark Salter) [2071848 2122415]
- spi: amd: Remove unneeded variable (Mark Salter) [2071848 2122415]
- spi: amd: Refactor amd_spi_busy_wait (Mark Salter) [2071848 2122415]
- spi: amd: Refactor code to use less spi_master_get_devdata (Mark Salter) [2071848 2122415]
- spi: spl022: fix Microwire full duplex mode (Mark Salter) [2071848 2122415]
- spi-mux: Fix false-positive lockdep splats (Mark Salter) [2071848 2122415]
- spi: Fix deadlock when adding SPI controllers on SPI buses (Mark Salter) [2071848 2122415]
- spi: spi-nxp-fspi: don't depend on a specific node name erratum workaround (Mark Salter) [2071848 2122415]
- nfc: st-nci: Add SPI ID matching DT compatible (Mark Salter) [2071848 2122415]
- spi: Revert modalias changes (Mark Salter) [2071848 2122415]
- spi: <linux/spi/spi.h>: add missing struct kernel-doc entry (Mark Salter) [2071848 2122415]
- spi: move cs spi_delay to spi_device (Mark Salter) [2071848 2122415]
- spi: imx: Implement support for CS_WORD (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Adapt reset_sccr1() to the case when no message available (Mark Salter) [2071848 2122415]
- spi: imx: remove ERR009165 workaround on i.mx6ul (Mark Salter) [2071848 2122415]
- spi: imx: fix ERR009165 (Mark Salter) [2071848 2122415]
- spi: imx: Simplify logic in spi_imx_push() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Reuse int_stop_and_reset() in couple of places (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Reset DMA bits in CR1 in reset_sccr1() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Convert reset_sccr1() to use pxa2xx_spi_update() (Mark Salter) [2071848 2122415]
- i2c: qcom-geni: add support for I2C Master Hub variant (Andrew Halaney) [2164495]
- i2c: qcom-geni: add desc struct to prepare support for I2C Master Hub variant (Andrew Halaney) [2164495]
- i2c: qcom-geni: fix error return code in geni_i2c_gpi_xfer (Andrew Halaney) [2164495]
- clk: qcom: rpmh: add support for SM6350 rpmh IPA clock (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq4019: switch to devm_clk_notifier_register (Adrien Thierry) [2158909]
- clk: qcom: rpmh: remove usage of platform name (Adrien Thierry) [2158909]
- clk: qcom: rpmh: rename VRM clock data (Adrien Thierry) [2158909]
- clk: qcom: rpmh: rename ARC clock data (Adrien Thierry) [2158909]
- clk: qcom: rpmh: support separate symbol name for the RPMH clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: remove platform names from BCM clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: drop all _ao names (Adrien Thierry) [2158909]
- clk: qcom: rpmh: reuse common duplicate clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: group clock definitions together (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop the platform from clock definitions (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop the _clk suffix completely (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop separate active-only names (Adrien Thierry) [2158909]
- clk: qcom: rpm: remove unused active-only clock names (Adrien Thierry) [2158909]
- clk: qcom: Add GCC driver for SM8550 (Adrien Thierry) [2158909]
- clk: qcom: Add LUCID_OLE PLL type for SM8550 (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Increase status poll timeout (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add rates to the GP clocks (Adrien Thierry) [2158909]
- clk: qcom: hfpll: use devm_platform_get_and_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: populate fw_name for all parents (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: convert to parent_data API (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: convert to devm_clk_hw_register (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: handle secondary mux sourcing out of acpu_aux (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: also enable secondary mux and div clk (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: fix wrong parent order for secondary mux (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: use devm variant for clk notifier register (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: fix wrong div2 functions (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: register it as clk provider (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add missing networking resets (Adrien Thierry) [2158909]
- clk: qcom: reset: support resetting multiple bits (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7180: Avoid an extra "struct dev_pm_ops" (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7180: Fix pm_runtime usage (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7280: Fix pm_runtime usage (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: add cxo as parent for three ufs ref clks (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6375 (Adrien Thierry) [2158909]
- clk: qcom: Add SC8280XP display clock controller (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: convert to parent data (Adrien Thierry) [2158909]
- clk: qcom: Add support for QDU1000 and QRU1000 RPMh clocks (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Disable link_div_clk_src for sm8150 (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add missing EDP clocks for sm8350 (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add RETAIN_FF_ENABLE flag for mdss_gdsc (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Disable EDP_GTC for sm8350 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8250: Use retention mode for USB GDSCs (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm6350: Add CLK_OPS_PARENT_ENABLE to pixel&byte src (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6125: Remove gpll7 from sdcc2_apps (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: use parent_data for the last remaining entry (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Remove direct runtime PM calls (Adrien Thierry) [2158909]
- clk: qcom: Update the force mem core bit for GPU clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: Drop hardcoded fixed board clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6375: Ensure unsigned long type (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6375: Remove unused variables (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: convert to parent data API (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: use parent_hws where possible (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Update the .pwrsts for usb gdscs (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use retention for USB power domains (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add missing error handling (Adrien Thierry) [2158909]
- clk: qcom: Add global clock controller driver for SM6375 (Adrien Thierry) [2158909]
- clk: qcom: alpha: Add support for programming the PLL_FSM_LEGACY_MODE bit (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Update the .pwrsts for usb gdscs (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7180: Update the .pwrsts for usb gdsc (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Fix the handling of PWRSTS_RET support (Adrien Thierry) [2158909]
- clk: qcom: Add SC8280XP GPU clock controller (Adrien Thierry) [2158909]
- clk: qcom: smd: Add SM6375 clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmhcc: add sdm670 clocks (Adrien Thierry) [2158909]
- clk: qcom: Merge alt alpha plls for qcm2260, sm6115 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Move alpha pll bramo overrides (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Override default Alpha PLL regs (Adrien Thierry) [2158909]
- clk: qcom: Add support for Display Clock Controller on SM8450 (Adrien Thierry) [2158909]
- clk: qcom: alpha-pll: add support for power off mode for lucid evo PLL (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6115 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Update the .pwrsts for PCIe GDSC (Adrien Thierry) [2158909]
- clk: qcom: lpass: Fix lpass audiocc probe (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: add support for IPQ8074 (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: update IPQ6018 Alpha PLL config (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: use OF match data for Alpha PLL config (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq6018: mark apcs_alias0_core_clk as critical (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq6018: fix apcs_alias0_clk_src (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: add rcg2 mux ops (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: convert to parent data (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: add reset definition (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: use constant mask for pmux (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: don't store parents in clk_cpu_8996_pmux (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: move ACD logic to clk_cpu_8996_pmux_determine_rate (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: declare ACD clocks (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: switch to devm_clk_notifier_register (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Use parent_data/_hws for all clocks (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Convert secondary muxes to clk_regmap_mux (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Unify cluster order (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Statically define PLL dividers (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Rename DIV_2_INDEX to SMUX_INDEX (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Take clock boundaries into consideration for gfx3d (Adrien Thierry) [2158909]
- clk: Introduce the clk_hw_get_rate_range function (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add clocks for MSM8909 (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8909: Increase delay for USB PHY reset (Adrien Thierry) [2158909]
- clk: qcom: reset: Allow specifying custom reset delay (Adrien Thierry) [2158909]
- clk: qcom: Add driver for MSM8909 GCC (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: lcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: lcc-msm8960: use macros to implement mi2s clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: clk-rpmh: Remove redundant if statement (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm845: add sdm670 global clock data (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm845: use device tree match data (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: convert to use parent_data rather than parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: sm6115: Select QCOM_GDSC (Adrien Thierry) [2158909]
- clk: qcom: lpass: Add support for resets & external mclk for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: lpass: Handle the regmap overlap of lpasscc and lpass_aon (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Use floor ops for SDCC1 clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: move gcc_mss_q6_bimc_axi_clk down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: move GPLL definitions up (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: gcc-sc8280xp: keep USB power-domains always-on (Adrien Thierry) [2158909]
- clk: gcc-sc8280xp: keep PCIe power-domains always-on (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: use parent_hws for gpll0/4 (Adrien Thierry) [2158909]
- clk: qcom: clk-rpm: convert to parent_data API (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing USB HS system clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing MDSS MDP clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing CAMSS CPP clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix venus0_vcodec0_clk frequency definitions (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing CAMSS CCI bus clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix weird field spacing in ftbl_gcc_camss_cci_clk (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Bump parent usage count when GDSC is found enabled (Adrien Thierry) [2158909]
- clk: qcom: Drop mmcx gdsc supply for dispcc and videocc (Adrien Thierry) [2158909]
- clk: qcom: fix build error initializer element is not constant (Adrien Thierry) [2158909]
- clk: qcom: add support for SM8350 DISPCC (Adrien Thierry) [2158909]
- clk: qcom: add support for SM8350 GPUCC (Adrien Thierry) [2158909]
- clk: qcom: add camera clock controller driver for SM8450 SoC (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: add Rivian EVO PLL configuration interfaces (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: add Lucid EVO PLL configuration interfaces (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: limit exported symbols to GPL licensed code (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: fix clk_trion_pll_configure description (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: create tsens device if there are no child nodes (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: Add rates to the GP clocks (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Make sure to not write d=0 to the NMD register (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Fail Duty-Cycle configuration if MND divider is not enabled. (Adrien Thierry) [2158909]
- clk: qcom: camcc-sm8250: Fix topology around titan_top power domain (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: Fix topology around titan_top power domain (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: dont disable gcc_sleep_clk_src (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add USB GDSCs (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: set BRANCH_HALT_DELAY flag for UBI clocks (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add PPE crypto clock (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix NSS port frequency tables (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: SW workaround for UBI32 PLL lock (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix NSS core PLL-s (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Point MM peripherals to system_mm_noc clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing system_mm_noc_bfdcd_clk_src (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix bimc_ddr_clk_src rcgr base address (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use phy-mux clock for PCIe (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: add apq/ipq8064 errata workaround (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: unlock spin after mux completion (Adrien Thierry) [2158909]
- clk: qcom: clk-hfpll: use poll_timeout macro (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Drop extra semicolon (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use collapse-voting for PCIe GDSCs (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add support for collapse-vote registers (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add collapse-bit helper (Adrien Thierry) [2158909]
- clk: qcom: camcc-sm8250: Fix halt on boot by reducing driver's init level (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: use new clk_regmap_phy_mux_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8450: use new clk_regmap_phy_mux_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: regmap: add PHY clock source implementation (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: rpmh: Add note about sleep/wake state for BCMs (Adrien Thierry) [2158909]
- Revert "clk: qcom: regmap-mux: add pipe clk implementation" (Adrien Thierry) [2158909]
- Revert "clk: qcom: gcc-sc7280: use new clk_regmap_mux_safe_ops for PCIe pipe clocks" (Adrien Thierry) [2158909]
- Revert "clk: qcom: gcc-sm8450: use new clk_regmap_mux_safe_ops for PCIe pipe clocks" (Adrien Thierry) [2158909]
- clk: qcom: rcg2: Cache CFG register updates for parked RCGs (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8976: Add modem reset (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8976: Set floor ops for SDCC (Adrien Thierry) [2158909]
- clk: qcom: smd: Update MSM8976 RPM clocks. (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: fix gfx3d frequency calculation (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: add SSC-related clocks (Adrien Thierry) [2158909]
- clk: qcom: lpass: Add support for LPASS clock controller for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: use new clk_regmap_mux_safe_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8450: use new clk_regmap_mux_safe_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: regmap-mux: add pipe clk implementation (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Fix gpll4 width (Adrien Thierry) [2158909]
- clk: qcom: sm6125-gcc: fix typos in comments (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6125 (Adrien Thierry) [2158909]
- clk: qcom: Fix sorting of SDX_GCC_65 in Makefile and Kconfig (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add emac GDSC support for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: gcc: sm8150: Fix some identation issues (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add UFS_CARD and UFS_PHY GDSCs for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add PCIe0 and PCIe1 GDSC for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Update the frac table for pixel clock (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Update logic to calculate D value for RCG (Adrien Thierry) [2158909]
- clk: qcom: smd: Add missing MSM8998 RPM clocks (Adrien Thierry) [2158909]
- clk: qcom: smd: Add missing RPM clocks for msm8992/4 (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add CryptoEngine resets (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add CryptoEngine clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add additional freq for sdc table (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg: add clk_rcg_floor_ops ops (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add unusued flag for critical clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add additional freq nss cores (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: convert parent_names to parent_data (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: fix wrong naming for gcc_pxo_pll8_pll0 (Adrien Thierry) [2158909]
- clk: qcom: Add SDX65 APCS clock controller support (Adrien Thierry) [2158909]
- clk: qcom: Add A7 PLL support for SDX65 (Adrien Thierry) [2158909]
- clk: qcom: Add GPU clock controller driver for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: Declare mux table as const u32[] (Adrien Thierry) [2158909]
- clk: qcom: dispcc: Update the transition delay for MDSS GDSC (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Add support to update GDSC transition delay (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: Use floor ops for SDCC1 clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Remove NoC clocks (Adrien Thierry) [2158909]
- clk: qcom: Add MSM8226 Multimedia Clock Controller support (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: start getting rid of xo clk (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: drop unsupported clock sources (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: videocc-sc7180: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: convert to parent_hws/_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: fix two clocks with parent_names (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for QCM2290 (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix PCI-E clock oops (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Mark gcc_cfg_noc_lpass_clk always enabled (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: Increase PLL lock detect poll time (Adrien Thierry) [2158909]
- clk: qcom: turingcc-qcs404: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: q6sstop-qcs404: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: mmcc-apq8084: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: lpasscc-sdm845: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: lpasscc-sc7280: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8350: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: Add MSM8976/56 Global Clock Controller (GCC) driver (Adrien Thierry) [2158909]
- clk: qcom: Add clock driver for SM8450 (Adrien Thierry) [2158909]
- clk: qcom: Add SDX65 GCC support (Adrien Thierry) [2158909]
- clk: qcom: Add LUCID_EVO PLL type for SDX65 (Adrien Thierry) [2158909]
- clk: qcom: sm6125-gcc: Swap ops of ice and apps on sdcc1 (Adrien Thierry) [2158909]
- clk: qcom: rpmh: add support for SM8450 rpmh clocks (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop binary value handling for buffered clock (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop the use of struct rpm_cc (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop MFD qcom-rpm reference (Adrien Thierry) [2158909]
- clk: qcom: Add support for SDX65 RPMh clocks (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: Don't reconfigure running Trion (Adrien Thierry) [2158909]
- clk: qcom: regmap-mux: fix parent clock lookup (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: Drop (again) gcc_aggre1_pnoc_ahb_clk (Adrien Thierry) [2158909]
- clk: qcom: gdsc: enable optional power domain support (Adrien Thierry) [2158909]
- clk: qcom: videocc-sm8250: use runtime PM for the clock controller (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: use runtime PM for the clock controller (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Drop unused array (Adrien Thierry) [2158909]
- clk: qcom: camcc: Add camera clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add lpass clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Kconfig: Sort the symbol for SC_LPASS_CORECC_7180 (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Add hw_ctrl flag to venus_core0_gdsc (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Add necessary CXCs to venus_gdsc (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Use ARRAY_SIZE() for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add proper msm8992 support (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add modem reset (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Remove the inexistent GDSC_PCIE (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add missing clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add missing NoC clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Fix up SPI QUP clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Modernize the driver (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add QCM2290 RPM clock support (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add .recalc_rate hook for clk_smd_rpm_branch_ops (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock Controller driver for QCM2290 (Adrien Thierry) [2158909]
- clk: qcom: add select QCOM_GDSC for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Fix offset for hlos1_vote_turing_mmu_tbu0_gdsc (Adrien Thierry) [2158909]
- clk: qcom: gcc: Remove CPUSS clocks control for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Remove redundant .owner (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8998: Remove unnecessary fallbacks to global clocks (Adrien Thierry) [2158909]
- clk: qcom: gpucc-msm8998: Remove unnecessary fallbacks to global clocks (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8998: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-msm8998: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Remove transient global "xo" clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Use parent_data/hws for internal clock relations (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Move parent names and mapping below GPLLs (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: common: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: Remove fallback to global clock names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Remove unused variable (Adrien Thierry) [2158909]
- clk: qcom: Add SM6350 GCC driver (Adrien Thierry) [2158909]
- clk: qcom: rpmh: Add support for RPMH clocks on SM6350 (Adrien Thierry) [2158909]
- clk: qcom: adjust selects for SM_VIDEOCC_8150 and SM_VIDEOCC_8250 (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock controller (GCC) driver for SM6115 (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8994: Add MSM8992 support (Adrien Thierry) [2158909]
- clk: qcom: Add msm8994 MMCC driver (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock Controller driver for MSM8953 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Replace usage of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Move parent tables after PLLs (Adrien Thierry) [2158909]
- clk: qcom: use devm_pm_runtime_enable and devm_pm_clk_create (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: Add MSM8939 a53pll support (Adrien Thierry) [2158909]
- clk: qcom: a53pll/mux: Use unique clock name (Adrien Thierry) [2158909]
- clk: qcom: apcs-msm8916: Flag a53mux instead of a53pll as critical (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sm8150: Add SC8180x support (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add mdm9607 clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmcc: Add support for MSM8953 RPM clocks. (Adrien Thierry) [2158909]
- clk: qcom: smd: Add support for SM6115 rpm clocks (Adrien Thierry) [2158909]
- clk: qcom: smd: Add support for SM6125 rpm clocks (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add additional parent clocks for DP (Adrien Thierry) [2158909]
- clk: qcom: Add video clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add graphics clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SC7280 (Adrien Thierry) [2158909]
- soc: qcom: geni-se: add support for I2C Master Hub wrapper variant (Brian Masney) [2158216]
- soc: qcom: geni-se: add desc struct to specify clocks from device match data (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM6115 / SM4250 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM8150 and SA8155 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: Select REMAP_MMIO for ICC_BWMON driver (Brian Masney) [2158216]
- soc: qcom: Select REMAP_MMIO for LLCC driver (Brian Masney) [2158216]
- soc: qcom: rpmpd: Add SM4250 support (Brian Masney) [2158216]
- soc: qcom: llcc: Add configuration data for SM8550 (Brian Masney) [2158216]
- soc: qcom: llcc: Add v4.1 HW version support (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM8550 ID (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Avoid unnecessary checks on irq-done response (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Add support for RSC v3 register offsets (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Add SM8550 power domains (Brian Masney) [2158216]
- soc: qcom: socinfo: Add MSM8956/76 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Write CONTROL_TCS with next timer wakeup (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Save base address of drv (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Attach RSC to cluster PM domain (Brian Masney) [2158216]
- soc: qcom: apr: Add check for idr_alloc and of_property_read_string_index (Brian Masney) [2158216]
- soc: qcom: socinfo: Add QDU1000/QRU1000 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Add QDU1000/QRU1000 power domains (Brian Masney) [2158216]
- soc: qcom: spm: Implement support for SAWv2.3, MSM8976 L2 PM (Brian Masney) [2158216]
- soc: qcom: llcc: make irq truly optional (Brian Masney) [2158216]
- soc: qcom: spm: Add MSM8939 SPM register data (Brian Masney) [2158216]
- soc: qcom: stats: Mark device as having no PM support (Brian Masney) [2158216]
- soc: qcom: cmd-db: Mark device as having no PM support (Brian Masney) [2158216]
- soc: qcom: pdr: Make QMI message rules const (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Use highest corner until sync_state (Brian Masney) [2158216]
- soc: qcom: smd-rpm: Add SM6375 compatible (Brian Masney) [2158216]
- soc: qcom: smd-rpm: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Brian Masney) [2158216]
- soc: qcom: rpmhpd: add sdm670 power domains (Brian Masney) [2158216]
- soc: qcom: socinfo: create soc_id table from bindings (Brian Masney) [2158216]
- soc: qcom: move from strlcpy with unused retval to strscpy (Brian Masney) [2158216]
- soc: qcom: rpmpd: Add SM6375 support (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: force clear counter/irq registers (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add support for sc7280 LLCC BWMON (Brian Masney) [2158216]
- soc: qcom: llcc: Pass LLCC version based register offsets to EDAC driver (Brian Masney) [2158216]
- soc: qcom: llcc: Rename reg_offset structs to reflect LLCC version (Brian Masney) [2158216]
- soc: qcom: qmi: use const for struct qmi_elem_info (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: remove redundant ret variable (Brian Masney) [2158216]
- soc: qcom: stats: Add SDM845 stats config and compatible (Brian Masney) [2158216]
- soc: qcom: socinfo: Add PM6125 ID (Brian Masney) [2158216]
- soc: qcom: socinfo: Add an ID for SM6375 (Brian Masney) [2158216]
- soc: qcom: smem_state: Add refcounting for the 'state->of_node' (Brian Masney) [2158216]
- soc: qcom: smsm: Fix refcount leak bugs in qcom_smsm_probe() (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add support for SDM845 LLCC BWMON (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add per-variant quirks (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: use regmap and prepare for BWMON v5 (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: store count unit per variant (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: clear all registers on init (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: store reference to variant data in container (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: drop unused registers (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: re-use IRQ enable/clear define (Brian Masney) [2158216]
- PM: domains: Store the next hrtimer wakeup in genpd (Brian Masney) [2158216]
- soc: dt-bindings: qcom: add gpr bindings (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM4250 support (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM8550 to rpmpd binding (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add QDU1000/QRU1000 to rpmpd binding (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: add sdm670 power domains (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM6375 power domains (Brian Masney) [2158216]
- dt-bindings: power: qcom-rpmpd: Add MSM8909 power domains (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for SM6115 / SM4250 and variants (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for SM8150 and SA8155 (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for MSM8956 and MSM8976 (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for QDU1000/QRU1000 (Brian Masney) [2158216]
- dt-bindings: arm: qcom: document qcom,msm-id and qcom,board-id (Brian Masney) [2158216]
- regulator: qcom-labibb: Fix missing of_node_put() in qcom_labibb_regulator_probe() (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Add support for PM8550 regulators (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Fix PMR735a S3 regulator spec (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix PMR735a S3 regulator spec (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PMR735a regulators (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: add pm660 and pm660l pmics (Adrien Thierry) [2157968]
- regulator: qcom_rpm: Fix circular deferral regression (Adrien Thierry) [2157968]
- regulator: core: Don't err if allow-set-load but no allowed-modes (Adrien Thierry) [2157968]
- regulator: core: Require regulator drivers to check uV for get_optimum_mode() (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PM6125 RPM regulators (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 3) (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 2) (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 1) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add PM6125 PMIC support (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Sort pmics alphabetically (part 2) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Sort pmics alphabetically (part 1) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add support for LDO_510 and FTSMPS (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add support for HFSMPS regulator type (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Implement get_optimum_mode(), not set_load() (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for PMP8074 regulators (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for HT_P600 (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for HT_P150 (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PM8909 RPM regulators (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix pm8916_pldo range (Adrien Thierry) [2157968]
- regulator: qcom_smd: add get_voltage to MP5496 (Adrien Thierry) [2157968]
- regulator: qcom_smd: correct MP5496 ranges (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix up PM8950 regulator configuration (Adrien Thierry) [2157968]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-270.el9]
- rtmutex: Add acquire semantics for rtmutex lock acquisition slow path (Brian Masney) [2163507]
- xfs: estimate post-merge refcounts correctly (Bill O'Donnell) [2161676]
- xfs: hoist refcount record merge predicates (Bill O'Donnell) [2161676]
- arm64: tegra: Add PWM fan for Jetson AGX Orin (Al Stone) [2144639]
- arm64: tegra: Populate Tegra234 PWMs (Al Stone) [2144639]
- dt-bindings: arm: qcom: Document additional sa8540p device (Adrien Thierry) [2152721]
- dt-bindings: arm: qcom: Document additional sc8280xp devices (Adrien Thierry) [2152721]
- dt-bindings: arm: qcom: Document sa8540p, sc8180x and sc8280xp (Adrien Thierry) [2152721]
- cpufreq: Add SM6115 to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: Add MT8186 to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: blocklist Qualcomm sc8280xp and sa8540p in cpufreq-dt-platdev (Adrien Thierry) [2152669]
- cpufreq: Add i.MX7S to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: blocklist more Qualcomm platforms in cpufreq-dt-platdev (Adrien Thierry) [2152669]
- net/mlx4_en: Fix wrong return value on ioctl EEPROM query failure (Mohammad Kabat) [2112965]
- RDMA/mlx4: Avoid flush_scheduled_work() usage (Mohammad Kabat) [2112965]
- mlx4: support BIG TCP packets (Mohammad Kabat) [2112965]
- net: mellanox: fix open-coded for_each_set_bit() (Mohammad Kabat) [2112965]
- dt-bindings: Fix incorrect "the the" corrections (Eric Chanudet) [2150444]
- remoteproc: qcom_q6v5_pas: Do not fail if regulators are not found (Eric Chanudet) [2150444]
- dt-bindings: Fix typo in comment (Eric Chanudet) [2150444]
- remoteproc: qcom_q6v5_pas: Deal silently with optional px and cx regulators (Eric Chanudet) [2150444]
- remoteproc: qcom: q6v5: Set q6 state to offline on receiving wdog irq (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Check if coredump is enabled (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Mark devices as wakeup capable (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Mark va as io memory (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add decrypt shutdown support for modem (Eric Chanudet) [2150444]
- Revert "revert remoteproc: qcom: pas: Carry PAS metadata context" (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Convert SC7180 MSS bindings to YAML (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Convert SC7280 MSS bindings to YAML (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: q6v5: fix example (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,glink-edge: define re-usable schema for glink-edge (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: use GIC_SPI defines in example (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: simplify SM8150 power domains (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: simplify interrupts (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: add interconnects (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: remove unneeded ref for names (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add MSM8226 ADSP support (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add MSM8226 adsp (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add sc8280xp remoteprocs (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add sc8280xp adsp and nsp pair (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SM8450 PAS compatibles (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SM6350 adsp, cdsp & mpss (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Update Q6V5 Modem PIL binding (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SC7280 MPSS support (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Add QMP property (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add QMP property (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: adsp: Add SDM660 ADSP (Eric Chanudet) [2150444]
- etherdevice: Adjust ether_addr* prototypes to silence -Wstringop-overead (Eric Chanudet) [2142659]

* Tue Feb 14 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-269.el9]
- redhat: Add sub-RPM with a EFI unified kernel image for virtual machines (Vitaly Kuznetsov) [2142102]
- redhat: split sub-rpm kernel-modules-core from kernel-core (Gerd Hoffmann) [2142102]

* Tue Feb 14 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-268.el9]
- drm/i915/fbdev: do not create fbdev if HPD is suspended (Karol Herbst) [2156007]
- drm/i915/fbdev: suspend HPD before fbdev unregistration (Karol Herbst) [2156007]
- drm/i915/hpd: suspend MST at the end of intel_modeset_driver_remove (Karol Herbst) [2156007]
- drm/i915: Fix CFI violations in gt_sysfs (Karol Herbst) [2115902]
- drm/i915/gvt: fix gvt debugfs destroy (Karol Herbst) [2115902]
- drm/amdkfd: Fix kernel warning during topology setup (Karol Herbst) [2115902]
- Revert "drm/amd/display: Enable Freesync Video Mode by default" (Karol Herbst) [2115902]
- drm/amdkfd: Fix double release compute pasid (Karol Herbst) [2115902]
- drm/amdkfd: Fix kfd_process_device_init_vm error handling (Karol Herbst) [2115902]
- drm/amdgpu: Fix size validation for non-exclusive domains (v4) (Karol Herbst) [2115902]
- drm/i915/gvt: fix double free bug in split_2MB_gtt_entry (Karol Herbst) [2115902]
- drm/i915: unpin on error in intel_vgpu_shadow_mm_pin() (Karol Herbst) [2115902]
- drm/imx: ipuv3-plane: Fix overlay plane width (Karol Herbst) [2115902]
- drm/meson: Reduce the FIFO lines held when AFBC is not used (Karol Herbst) [2115902]
- drm/panfrost: Fix GEM handle creation ref-counting (Karol Herbst) [2115902]
- drm/amd/pm: correct the fan speed retrieving in PWM for some SMU13 asics (Karol Herbst) [2115902]
- drm/amd/pm: bump SMU13.0.0 driver_if header to version 0x34 (Karol Herbst) [2115902]
- drm/amd/pm: add missing SMU13.0.7 mm_dpm feature mapping (Karol Herbst) [2115902]
- drm/amd/pm: add missing SMU13.0.0 mm_dpm feature mapping (Karol Herbst) [2115902]
- drm/i915/migrate: Account for the reserved_space (Karol Herbst) [2115902]
- drm/i915: improve the catch-all evict to handle lock contention (Karol Herbst) [2115902]
- drm/amdgpu: make display pinning more flexible (v2) (Karol Herbst) [2115902]
- drm/amdgpu: handle polaris10/11 overlap asics (v2) (Karol Herbst) [2115902]
- drm/amd/display: Add DCN314 display SG Support (Karol Herbst) [2115902]
- drm/i915/ttm: consider CCS for backup objects (Karol Herbst) [2115902]
- drm/etnaviv: reap idle mapping if it doesn't match the softpin address (Karol Herbst) [2115902]
- drm/ingenic: Fix missing platform_driver_unregister() call in ingenic_drm_init() (Karol Herbst) [2115902]
- drm/i915/dsi: fix VBT send packet port selection for dual link DSI (Karol Herbst) [2115902]
- drm/vmwgfx: Validate the box size for the snooped cursor (Karol Herbst) [2115902]
- drm/connector: send hotplug uevent on connector cleanup (Karol Herbst) [2115902]
- drm/amdgpu: fix mmhub register base coding error (Karol Herbst) [2115902]
- drm/amd/pm: correct SMU13.0.0 pstate profiling clock settings (Karol Herbst) [2115902]
- drm/amd/pm: update SMU13.0.0 reported maximum shader clock (Karol Herbst) [2115902]
- drm/amdgpu: skip MES for S0ix as well since it's part of GFX (Karol Herbst) [2115902]
- drm/amd/display: revert Disable DRR actions during state commit (Karol Herbst) [2115902]
- drm/amd/pm: avoid large variable on kernel stack (Karol Herbst) [2115902]
- drm/i915/display: Don't disable DDI/Transcoder when setting phy test pattern (Karol Herbst) [2115902]
- drm/sti: Fix return type of sti_{dvo,hda,hdmi}_connector_mode_valid() (Karol Herbst) [2115902]
- drm/fsl-dcu: Fix return type of fsl_dcu_drm_connector_mode_valid() (Karol Herbst) [2115902]
- drm/amd/display: Fix DTBCLK disable requests and SRC_SEL programming (Karol Herbst) [2115902]
- drm/amd/display: Use the largest vready_offset in pipe group (Karol Herbst) [2115902]
- drm/amd/display: fix array index out of bound error in bios parser (Karol Herbst) [2115902]
- drm/amd/display: Workaround to increase phantom pipe vactive in pipesplit (Karol Herbst) [2115902]
- drm/mediatek: Fix return type of mtk_hdmi_bridge_mode_valid() (Karol Herbst) [2115902]
- drm/sti: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/rockchip: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/msm: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/amd/display: Disable DRR actions during state commit (Karol Herbst) [2115902]
- drm/amdgpu: Fix type of second parameter in odn_edit_dpm_table() callback (Karol Herbst) [2115902]
- drm/amdgpu: Fix type of second parameter in trans_msg() callback (Karol Herbst) [2115902]
- Revert "drm/amd/display: Limit max DSC target bpp for specific monitors" (Karol Herbst) [2115902]
- drm/edid: add a quirk for two LG monitors to get them to work on 10bpc (Karol Herbst) [2115902]
- drm/amd/display: prevent memory leak (Karol Herbst) [2115902]
- drm/etnaviv: add missing quirks for GC300 (Karol Herbst) [2115902]
- drm/i915/bios: fix a memory leak in generate_lfp_data_ptrs (Karol Herbst) [2115902]
- drm/amdkfd: Fix memory leakage (Karol Herbst) [2115902]
- drm/amdgpu: Fix PCI device refcount leak in amdgpu_atrm_get_bios() (Karol Herbst) [2115902]
- drm/radeon: Fix PCI device refcount leak in radeon_atrm_get_bios() (Karol Herbst) [2115902]
- amdgpu/nv.c: Corrected typo in the video capabilities resolution (Karol Herbst) [2115902]
- drm/amd/pm/smu11: BACO is supported when it's in BACO state (Karol Herbst) [2115902]
- drm/tegra: Add missing clk_disable_unprepare() in tegra_dc_probe() (Karol Herbst) [2115902]
- drm/i915/guc: make default_lists const data (Karol Herbst) [2115902]
- drm/amdgpu: fix pci device refcount leak (Karol Herbst) [2115902]
- drm/fourcc: Fix vsub/hsub for Q410 and Q401 (Karol Herbst) [2115902]
- amdgpu/pm: prevent array underflow in vega20_odn_edit_dpm_table() (Karol Herbst) [2115902]
- drm/radeon: Add the missed acpi_put_table() to fix memory leak (Karol Herbst) [2115902]
- drm/ttm: fix undefined behavior in bit shift for TTM_TT_FLAG_PRIV_POPULATED (Karol Herbst) [2115902]
- drm/panel/panel-sitronix-st7701: Remove panel on DSI attach failure (Karol Herbst) [2115902]
- drm/rockchip: lvds: fix PM usage counter unbalance in poweron (Karol Herbst) [2115902]
- drm/amd/display: wait for vblank during pipe programming (Karol Herbst) [2115902]
- drm/i915/guc: Fix GuC error capture sizing estimation and reporting (Karol Herbst) [2115902]
- drm/i915/guc: Add error-capture init warnings when needed (Karol Herbst) [2115902]
- drm/i915/guc: Make GuC log sizes runtime configurable (Karol Herbst) [2115902]
- drm/i915/guc: Fix capture size warning and bump the size (Karol Herbst) [2115902]
- drm/i915/guc: Add a helper for log buffer size (Karol Herbst) [2115902]
- drm/i915: Fix compute pre-emption w/a to apply to compute engines (Karol Herbst) [2115902]
- drm/i915/guc: Limit scheduling properties to avoid overflow (Karol Herbst) [2115902]
- drm/bridge: it6505: Initialize AUX channel in it6505_i2c_probe (Karol Herbst) [2115902]
- drm/amdgpu/powerplay/psm: Fix memory leak in power state init (Karol Herbst) [2115902]
- drm/bridge: adv7533: remove dynamic lane switching from adv7533 bridge (Karol Herbst) [2115902]
- drm/atomic-helper: Don't allocate new plane state in CRTC check (Karol Herbst) [2115902]
- drm/amdgpu/vcn: update vcn4 fw shared data structure (Karol Herbst) [2115902]
- drm: bridge: dw_hdmi: fix preference of RGB modes over YUV420 (Karol Herbst) [2115902]
- drm/bridge: ti-sn65dsi86: Fix output polarity setting bug (Karol Herbst) [2115902]
- drm/vmwgfx: Fix race issue calling pin_user_pages (Karol Herbst) [2115902]
- drm/shmem-helper: Avoid vm_open error paths (Karol Herbst) [2115902]
- drm/shmem-helper: Remove errant put in error path (Karol Herbst) [2115902]
- drm/amd/display: fix array index out of bound error in DCN32 DML (Karol Herbst) [2115902]
- drm/amdgpu/sdma_v4_0: turn off SDMA ring buffer in the s2idle suspend (Karol Herbst) [2115902]
- drm/vmwgfx: Don't use screen objects when SEV is active (Karol Herbst) [2115902]
- drm/amdgpu: fix use-after-free during gpu recovery (Karol Herbst) [2115902]
- drm/amd/display: Use new num clk levels struct for max mclk index (Karol Herbst) [2115902]
- drm/amd/display: Avoid setting pixel rate divider to N/A (Karol Herbst) [2115902]
- drm/amd/display: Use viewport height for subvp mall allocation size (Karol Herbst) [2115902]
- drm/i915: Remove non-existent pipes from bigjoiner pipe mask (Karol Herbst) [2115902]
- drm/i915: Never return 0 if not all requests retired (Karol Herbst) [2115902]
- drm/i915: Fix negative value passed as remaining time (Karol Herbst) [2115902]
- drm/amdgpu: enable Vangogh VCN indirect sram mode (Karol Herbst) [2115902]
- drm/amdgpu: temporarily disable broken Clang builds due to blown stack-frame (Karol Herbst) [2115902]
- drm/amd/pm: update driver if header for smu_13_0_7 (Karol Herbst) [2115902]
- drm/amd/pm: update driver-if header for smu_v13_0_10 (Karol Herbst) [2115902]
- drm/amd/pm: add smu_v13_0_10 driver if version (Karol Herbst) [2115902]
- drm/amdgpu: fix userptr HMM range handling v2 (Karol Herbst) [2115902]
- drm/amdgpu: cleanup error handling in amdgpu_cs_parser_bos (Karol Herbst) [2115902]
- drm/amdgpu: move setting the job resources (Karol Herbst) [2115902]
- drm/amdgpu: Partially revert "drm/amdgpu: update drm_display_info correctly when the edid is read" (Karol Herbst) [2115902]
- drm/amdgpu: always register an MMU notifier for userptr (Karol Herbst) [2115902]
- drm/amd/display: Update soc bounding box for dcn32/dcn321 (Karol Herbst) [2115902]
- drm/amd/amdgpu: reserve vm invalidation engine for firmware (Karol Herbst) [2115902]
- drm/amdgpu: Enable Aldebaran devices to report CU Occupancy (Karol Herbst) [2115902]
- drm/amdgpu/psp: don't free PSP buffers on suspend (Karol Herbst) [2115902]
- drm/amd/display: No display after resume from WB/CB (Karol Herbst) [2115902]
- drm/amd/dc/dce120: Fix audio register mapping, stop triggering KASAN (Karol Herbst) [2115902]
- drm/display/dp_mst: Fix drm_dp_mst_add_affected_dsc_crtcs() return code (Karol Herbst) [2115902]
- drm/i915/ttm: never purge busy objects (Karol Herbst) [2115902]
- gpu: host1x: Avoid trying to use GART on Tegra20 (Karol Herbst) [2115902]
- drm/amdkfd: Fix a memory limit issue (Karol Herbst) [2115902]
- drm/amdgpu: disable BACO support on more cards (Karol Herbst) [2115902]
- drm/amd/display: use uclk pstate latency for fw assisted mclk validation dcn32 (Karol Herbst) [2115902]
- drm/i915/gvt: Get reference to KVM iff attachment to VM is successful (Karol Herbst) [2115902]
- drm/amd/display: Fix calculation for cursor CAB allocation (Karol Herbst) [2115902]
- drm/amd/display: Update MALL SS NumWays calculation (Karol Herbst) [2115902]
- drm/amd/display: Add debug option for allocating extra way for cursor (Karol Herbst) [2115902]
- drm/amd/display: Added debug option for forcing subvp num ways (Karol Herbst) [2115902]
- drm/amdkfd: update GFX11 CWSR trap handler (Karol Herbst) [2115902]
- drm/amdgpu: Enable SA software trap. (Karol Herbst) [2115902]
- dma-buf: Use dma_fence_unwrap_for_each when importing fences (Karol Herbst) [2115902]
- dma-buf: fix racing conflict of dma_heap_add() (Karol Herbst) [2115902]
- drm/i915: Fix warn in intel_display_power_*_domain() functions (Karol Herbst) [2115902]
- drm/amd/display: only fill dirty rectangles when PSR is enabled (Karol Herbst) [2115902]
- drm/amdgpu: Drop eviction lock when allocating PT BO (Karol Herbst) [2115902]
- Revert "drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm for vega10 properly"" (Karol Herbst) [2115902]
- drm/amd/display: Fix gpio port mapping issue (Karol Herbst) [2115902]
- drm/amd/display: Fix FCLK deviation and tool compile issues (Karol Herbst) [2115902]
- drm/amd/display: Zeromem mypipe heap struct before using it (Karol Herbst) [2115902]
- drm: panel-orientation-quirks: Add quirk for Acer Switch V 10 (SW5-017) (Karol Herbst) [2115902]
- drm: panel-orientation-quirks: Add quirk for Nanote UMPC-01 (Karol Herbst) [2115902]
- drm/amd/display: Fix prefetch calculations for dcn32 (Karol Herbst) [2115902]
- drm/amd/display: don't enable DRM CRTC degamma property for DCE (Karol Herbst) [2115902]
- drm/amd/display: Fix optc2_configure warning on dcn314 (Karol Herbst) [2115902]
- drm/amd/display: Support parsing VRAM info v3.0 from VBIOS (Karol Herbst) [2115902]
- drm/amd/display: Fix access timeout to DPIA AUX at boot time (Karol Herbst) [2115902]
- drm/amd/display: Add HUBP surface flip interrupt handler (Karol Herbst) [2115902]
- drm/amd/display: Fix invalid DPIA AUX reply causing system hang (Karol Herbst) [2115902]
- drm/display: Don't assume dual mode adaptors support i2c sub-addressing (Karol Herbst) [2115902]
- drm/amd/pm: fix SMU13 runpm hang due to unintentional workaround (Karol Herbst) [2115902]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.0 (Karol Herbst) [2115902]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.7 (Karol Herbst) [2115902]
- drm: Fix potential null-ptr-deref in drm_vblank_destroy_worker() (Karol Herbst) [2115902]
- drm/drv: Fix potential memory leak in drm_dev_init() (Karol Herbst) [2115902]
- drm/panel: simple: set bpc field for logic technologies displays (Karol Herbst) [2115902]
- drm/vc4: kms: Fix IS_ERR() vs NULL check for vc4_kms (Karol Herbst) [2115902]
- drm/amd/display: Investigate tool reported FCLK P-state deviations (Karol Herbst) [2115902]
- drm/amd/display: Round up DST_after_scaler to nearest int (Karol Herbst) [2115902]
- drm/amd/display: Use forced DSC bpp in DML (Karol Herbst) [2115902]
- drm/amd/display: Fix DCN32 DSC delay calculation (Karol Herbst) [2115902]
- drm/amd: Fail the suspend if resources can't be evicted (Karol Herbst) [2115902]
- drm/amdgpu: set fb_modifiers_not_supported in vkms (Karol Herbst) [2115902]
- drm/amd/display: Enable timing sync on DCN32 (Karol Herbst) [2115902]
- drm/amd/display: Ignore Cable ID Feature (Karol Herbst) [2115902]
- drm/imx: imx-tve: Fix return type of imx_tve_connector_mode_valid (Karol Herbst) [2115902]
- drm/scheduler: fix fence ref counting (Karol Herbst) [2115902]
- drm/amd/display: Don't return false if no stream (Karol Herbst) [2115902]
- drm/amd/display: Remove wrong pipe control lock (Karol Herbst) [2115902]
- drm/amdgpu: Adjust MES polling timeout for sriov (Karol Herbst) [2115902]
- drm/amdkfd: Migrate in CPU page fault use current mm (Karol Herbst) [2115902]
- drm/amdkfd: Fix error handling in kfd_criu_restore_events (Karol Herbst) [2115902]
- drm/amdkfd: Fix error handling in criu_checkpoint (Karol Herbst) [2115902]
- drm/amdgpu: disable BACO on special BEIGE_GOBY card (Karol Herbst) [2115902]
- drm/amdgpu: workaround for TLB seq race (Karol Herbst) [2115902]
- drm/amd/display: Update SR watermarks for DCN314 (Karol Herbst) [2115902]
- drm/amd/pm: update SMU IP v13.0.4 msg interface header (Karol Herbst) [2115902]
- drm/amd/display: Fix reg timeout in enc314_enable_fifo (Karol Herbst) [2115902]
- drm/i915/dmabuf: fix sg_table handling in map_dma_buf (Karol Herbst) [2115902]
- drm/amdgpu: Fix the lpfn checking condition in drm buddy (Karol Herbst) [2115902]
- drm/i915: Do not set cache_dirty for DGFX (Karol Herbst) [2115902]
- drm/i915/psr: Send update also on invalidate (Karol Herbst) [2115902]
- drm/vc4: Fix missing platform_unregister_drivers() call in vc4_drm_register() (Karol Herbst) [2115902]
- drm/amdkfd: Fix NULL pointer dereference in svm_migrate_to_ram() (Karol Herbst) [2115902]
- drm/amdkfd: handle CPU fault on COW mapping (Karol Herbst) [2115902]
- drm/amd/display: Set memclk levels to be at least 1 for dcn32 (Karol Herbst) [2115902]
- drm/amd/display: Limit dcn32 to 1950Mhz display clock (Karol Herbst) [2115902]
- drm/amd/display: Acquire FCLK DPM levels on DCN32 (Karol Herbst) [2115902]
- drm/i915/sdvo: Grab mode_config.mutex during LVDS init to avoid WARNs (Karol Herbst) [2115902]
- drm/i915: Simplify intel_panel_add_edid_alt_fixed_modes() (Karol Herbst) [2115902]
- drm/i915: Allow more varied alternate fixed modes for panels (Karol Herbst) [2115902]
- drm/i915/gvt: Add missing vfio_unregister_group_dev() call (Karol Herbst) [2115902]

* Mon Feb 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-267.el9]
- mmc: sdhci-tegra: Issue CMD and DAT resets together (Mark Salter) [2144641]
- mmc: sdhci-tegra: Add support to program MC stream ID (Mark Salter) [2144641]
- iommu/tegra: Add tegra_dev_iommu_get_stream_id() helper (Mark Salter) [2144641]
- mmc: sdhci-tegra: Sort includes alphabetically (Mark Salter) [2144641]
- mmc: sdhci-tegra: Separate Tegra194 and Tegra234 SoC data (Mark Salter) [2144641]
- mmc: sdhci: Centralize CMD and DATA reset handling (Mark Salter) [2144641]
- mmc: sdhci: Get rid of SDHCI_QUIRK_RESET_CMD_DATA_ON_IOS (Mark Salter) [2144641]
- mmc: sdhci: Remove misleading comment about resets (Mark Salter) [2144641]
- mmc: sdhci: Separate out sdhci_reset_for_all() (Mark Salter) [2144641]
- mmc: sdhci: Fix ADMA for PAGE_SIZE >= 64KiB (Mark Salter) [2144641]
- mmc: sdhci-pci: Remove dead code (rst_n_gpio et al) (Mark Salter) [2144641]
- mmc: sdhci-pci: Remove dead code (cd_gpio, cd_irq et al) (Mark Salter) [2144641]
- mmc: sdhci: Remove unused prototype declaration in the header (Mark Salter) [2144641]
- mmc: sdhci: Deduplicate sdhci_get_cd_nogpio() (Mark Salter) [2144641]
- mmc: sdhci-pci: Read card detect from ACPI for Intel Merrifield (Mark Salter) [2144641]
- mmc: sdhci: Return true only when timeout exceeds capacity of the HW timer (Mark Salter) [2144641]
- mmc: sdhci: Change the code to check auto_cmd23 (Mark Salter) [2144641]
- mmc: sdhci: Map more voltage level to SDHCI_POWER_330 (Mark Salter) [2144641]
- mmc: sdhci: Correct the tuning command handle for PIO mode (Mark Salter) [2144641]
- mmc: sdhci: Fix issue with uninitialized dma_slave_config (Mark Salter) [2144641]
- mmc: sdhci: Introduce max_timeout_count variable in sdhci_host (Mark Salter) [2144641]
- power: supply: samsung-sdi-battery: Add missing charge restart voltages (Al Stone) [2071846]
- power: supply: bq256xx: Handle OOM correctly (Al Stone) [2071846]
- power: supply: fix table problem in sysfs-class-power (Al Stone) [2071846]
- set proper default for Samsung batteries (Al Stone) [2071846]
- power: supply: Fix typo in power_supply_check_supplies (Al Stone) [2071846]
- power: supply: core: Fix boundary conditions in interpolation (Al Stone) [2071846]
- power: supply: core: Initialize struct to zero (Al Stone) [2071846]
- power: supply: Reset err after not finding static battery (Al Stone) [2071846]
- power: supply: Static data for Samsung batteries (Al Stone) [2071846]
- power: supply: Support VBAT-to-Ri lookup tables (Al Stone) [2071846]
- power: supply: ab8500: Standardize BTI resistance (Al Stone) [2071846]
- power: supply: ab8500: Standardize alert mode charging (Al Stone) [2071846]
- power: supply: ab8500: Standardize maintenance charging (Al Stone) [2071846]
- power: supply: Provide stubs for charge_behaviour helpers (Al Stone) [2071846]
- power: supply: core: Add kerneldoc to battery struct (Al Stone) [2071846]
- power: supply: sbs-charger: Don't cancel work that is not initialized (Al Stone) [2071846]
- power: supply: Introduces bypass charging property (Al Stone) [2071846]
- power: supply: core: Use device_property_string_array_count() (Al Stone) [2071846]
- power: supply: core: Simplify hwmon memory allocation (Al Stone) [2071846]
- power: supply: core: Add support for generic fwnodes to power_supply_get_battery_info() (Al Stone) [2071846]
- power: supply: core: Use fwnode_property_*() in power_supply_get_battery_info() (Al Stone) [2071846]
- power: supply: core: Refactor power_supply_set_input_current_limit_from_supplier() (Al Stone) [2071846]
- power: supply: core: fix application of sizeof to pointer (Al Stone) [2071846]
- power: supply: fix charge_behaviour attribute initialization (Al Stone) [2071846]
- power: supply_core: Pass pointer to battery info (Al Stone) [2071846]
- power: supply: add helpers for charge_behaviour sysfs (Al Stone) [2071846]
- power: supply: add charge_behaviour attributes (Al Stone) [2071846]
- power: supply: core: Use library interpolation (Al Stone) [2071846]
- power: supply: core: add POWER_SUPPLY_HEALTH_NO_BATTERY (Al Stone) [2071846]
- power: supply: core: Break capacity loop (Al Stone) [2071846]
- power: supply: core: Move psy_has_property() to fix build (Al Stone) [2071846]
- power: supply: core: Add psy_has_property() (Al Stone) [2071846]
- power: supply: core: Fix parsing of battery chemistry/technology (Al Stone) [2071846]
- power: supply: core: Parse battery chemistry/technology (Al Stone) [2071846]
- power: supply: sbs-battery: add support for time_to_empty_now attribute (Al Stone) [2071846]
- power: supply: sbs-battery: relax voltage limit (Al Stone) [2071846]

* Mon Feb 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-266.el9]
- crypto: jitter - consider 32 LSB for APT (Vladis Dronov) [2164067]
- xhci-pci: Set runtime PM as default policy on all xHC 1.2 or later devices (Torez Smith) [2130063 2139486]
- thunderbolt: Explicitly enable lane adapter hotplug events at startup (Torez Smith) [2130063 2139486]
- net: gso: fix panic on frag_list with mixed head alloc types (Jiri Benc) [2166641]
- docs: networking: Fix bridge documentation URL (Ivan Vecera) [2149448]
- vfio: Extend the device migration protocol with PRE_COPY (Alex Williamson) [2165989]
- vfio/iova_bitmap: refactor iova_bitmap_set() to better handle page boundaries (Alex Williamson) [2165989]
- vfio/iova_bitmap: Fix PAGE_SIZE unaligned bitmaps (Alex Williamson) [2165989]
- vfio: Introduce the DMA logging feature support (Alex Williamson) [2165989]
- vfio: Add an IOVA bitmap support (Alex Williamson) [2165989]
- vfio: Introduce DMA logging uAPIs (Alex Williamson) [2165989]
- selftests: rtnetlink: correct xfrm policy rule in kci_test_ipsec_offload (Hangbin Liu) [2161904]
- selftests: netfilter: Fix and review rpath.sh (Hangbin Liu) [2161904]
- Revert "xfrm: xfrm_state_mtu should return at least 1280 for ipv6" (Hangbin Liu) [2161893]
- xfrm: fix MTU regression (Hangbin Liu) [2161893]
- ipv6: fix reachability confirmation with proxy_ndp (Hangbin Liu) [2161893]
- ipv6: avoid use-after-free in ip6_fragment() (Hangbin Liu) [2161893]
- ipv6: addrlabel: fix infoleak when sending struct ifaddrlblmsg to network (Hangbin Liu) [2161893]
- ipv6: fix WARNING in ip6_route_net_exit_late() (Hangbin Liu) [2161893]
- ipv6: ensure sane device mtu in tunnels (Hangbin Liu) [2161893]
- userfaultfd: update documentation to describe /dev/userfaultfd (Peter Xu) [2158706]
- userfaultfd: add /dev/userfaultfd for fine grained access control (Peter Xu) [2158706]
- futex: Resend potentially swallowed owner death notification (Rafael Aquini) [2161817]
- iavf: schedule watchdog immediately when changing primary MAC (Stefan Assmann) [2163707]
- iavf: Move netdev_update_features() into watchdog task (Stefan Assmann) [2163707]
- iavf: fix temporary deadlock and failure to set MAC address (Stefan Assmann) [2163707]
- perf/x86/uncore: Don't WARN_ON_ONCE() for a broken discovery table (Michael Petlan) [2154045]
- perf/x86/uncore: Add a quirk for UPI on SPR (Michael Petlan) [2154045]
- perf/x86/uncore: Ignore broken units in discovery table (Michael Petlan) [2154045]
- perf/x86/uncore: Fix potential NULL pointer in uncore_get_alias_name (Michael Petlan) [2154045]
- perf/x86/uncore: Factor out uncore_device_to_die() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in __uncore_imc_init_box() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in snr_uncore_mmio_map() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in hswep_has_limit_sbox() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in sad_cfg_iio_topology() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Make set_mapping() procedure void (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Update sysfs-devices-mapping file (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Sapphire Rapids (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Icelake Server (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Get UPI NodeID and GroupID (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Skylake Server (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Generalize get_topology() for SKX PMUs (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Disable I/O stacks to PMU mapping on ICX-D (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Clear attr_update properly (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Introduce UPI topology type (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Generalize IIO topology support (Michael Petlan) [2154045]
- perf vendor events power10: Fix hv-24x7 metric events (Mamatha Inamdar) [2149193]
- Add taint flag for partner supported GPL modules (Alice Mitchell) [2038999]

* Thu Feb 09 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-265.el9]
- CI: Add pipelines for kernel-64k variant for RHEL (Veronika Kabatova)
- CI: Enable pipelines for 64k variant (Veronika Kabatova)
- arm64-64k: Add new kernel variant to RHEL9/CS9 for 64K page-size'd ARM64 (Donald Dutile) [2153073]

* Wed Feb 08 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-264.el9]
- uapi: add missing ip/ipv6 header dependencies for linux/stddef.h (Herton R. Krzesinski) [2166738]
- redhat: make selftests build install headers under tools/testing/selftests/usr/include (Herton R. Krzesinski) [2166738]
- uapi: Fix undefined __always_inline on non-glibc systems (Herton R. Krzesinski) [2166738]
- panic, kexec: make __crash_kexec() NMI safe (Valentin Schneider) [2166717]
- kexec: turn all kexec_mutex acquisitions into trylocks (Valentin Schneider) [2166717]
- sched: Always inline is_percpu_thread() (Phil Auld) [2166660]
- vhost/net: Clear the pending messages when the backend is removed (Eric Auger) [2093791]
- net: Return errno in sk->sk_prot->get_port(). (Paolo Abeni) [2166482]
- Revert "mm/compaction: fix set skip in fast_find_migrateblock" (Nico Pache) [2166447]
- aio: fix mremap after fork null-deref (Jeff Moyer) [2165730]
- net: ena: Update NUMA TPH hint register upon NUMA node update (Petr Oros) [2155690]
- net: ena: Set default value for RX interrupt moderation (Petr Oros) [2155690]
- net: ena: Fix rx_copybreak value update (Petr Oros) [2155690]
- net: ena: Use bitmask to indicate packet redirection (Petr Oros) [2155690]
- net: ena: Account for the number of processed bytes in XDP (Petr Oros) [2155690]
- net: ena: Don't register memory info on XDP exchange (Petr Oros) [2155690]
- net: ena: Fix toeplitz initial hash value (Petr Oros) [2155690]
- net: ena: Fix error handling in ena_init() (Petr Oros) [2155690]
- dmaengine: idxd: Fix crc_val field for completion record (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Make read buffer sysfs attributes invisible for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Make max batch size attributes in sysfs invisible for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Do not call DMX TX callbacks during workqueue disable (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Prevent use after free on completion memory (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Let probe fail when workqueue cannot be enabled (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Fix max batch size for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add configuration for concurrent batch descriptor processing (Jerry Snitselaar) [2144376]
- dmanegine: idxd: reformat opcap output to match bitmap_parse() input (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add configuration for concurrent work descriptor processing (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add WQ operation cap restriction support (Jerry Snitselaar) [2144376]
- dmaengine: idxd: convert ats_dis to a wq flag (Jerry Snitselaar) [2144376]
- dmaengine: idxd: track enabled workqueues in bitmap (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Set wq state to disabled in idxd_wq_disable_cleanup() (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Do not enable user type Work Queue without Shared Virtual Addressing (Jerry Snitselaar) [2144376]
- dmaengine: idxd: fix RO device state error after been disabled/reset (Jerry Snitselaar) [2144376]
- dmaengine: idxd: avoid deadlock in process_misc_interrupts() (Jerry Snitselaar) [2144376]
- redhat: configs: enable DWMAC_TEGRA (d.marlin) [2122405]
- net: stmmac: tegra: Add MGBE support (d.marlin) [2122405]
- net: stmmac: Power up SERDES after the PHY link (d.marlin) [2122405]
- net: stmmac: power up/down serdes in stmmac_open/release (d.marlin) [2122405]
- clk: tegra: Support BPMP-FW ABI deny flags (Joel Slebodnick) [2144640]
- firmware: tegra: Update BPMP ABI (Joel Slebodnick) [2144640]
- vlan: fix memory leak in vlan_newlink() (Xin Long) [2155365]
- vlan: move dev_put into vlan_dev_uninit (Xin Long) [2155365]
- vlan: introduce vlan_dev_free_egress_priority (Xin Long) [2155365]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104473]
- intel/ixgbevf:fix repeated words in comments (Ken Cox) [2104473]
- intel: remove unused macros (Ken Cox) [2104473]
- ixgbevf: add disable link state (Ken Cox) [2104473]
- clk: tegra: Register clocks from root to leaf (Joel Slebodnick) [2122346]
- clk: tegra: Replace .round_rate() with .determine_rate() (Joel Slebodnick) [2122346]

* Wed Feb 08 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-263.el9]
- ipv6: Document that max_size sysctl is deprecated (Hangbin Liu) [2164260]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2164217]
- Revert "ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked" (Mark Langsdorf) [2164217]
- net: add netdev_sw_irq_coalesce_default_on() (Dan Campbell) [2161921]
- net: sched: add helper support in act_ct (Xin Long) [2106859]
- net: sched: call tcf_ct_params_free to free params in tcf_ct_init (Xin Long) [2106859]
- net: move add ct helper function to nf_conntrack_helper for ovs and tc (Xin Long) [2106859]
- net: move the ct helper function to nf_conntrack_helper for ovs and tc (Xin Long) [2106859]
- veth: Fix race with AF_XDP exposing old or uninitialized descriptors (Davide Caratti) [2164865]
- unix: Fix race in SOCK_SEQPACKET's unix_dgram_sendmsg() (Davide Caratti) [2164865]
- af_unix: call proto_unregister() in the error path in af_unix_init() (Davide Caratti) [2164865]
- af_unix: Get user_ns from in_skb in unix_diag_get_exact(). (Davide Caratti) [2164865]
- af_key: Fix send_acquire race with pfkey_register (Davide Caratti) [2164865]
- ethtool: eeprom: fix null-deref on genl_info in dump (Davide Caratti) [2164865]
- ipv6/addrconf: fix a null-ptr-deref bug for ip6_ptr (Davide Caratti) [2164865]
- Bluetooth: L2CAP: Fix memory leak in vhci_write (Wander Lairson Costa) [2155874] {CVE-2022-3619}
- ASoC: Intel: soc-acpi: add configuration for variant of 0C11 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add configuration for variant of 0C40 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: use common helpers for all Realtek amps (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C11 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C4F product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C40 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C10 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw_rt1316: add BQ params for the Dell models (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw_rt1308: add BQ params for the Dell models (Jaroslav Kysela) [2140419]
- ASoC: intel: sof_sdw: add rt1318 codec support. (Jaroslav Kysela) [2140419]
- ASoC: rt1318: Add RT1318 SDCA vendor-specific driver (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: update codec addr on 0C11/0C4F product (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C11 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C40 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C10 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi-intel-rpl-match: add rpl_sdca_3_in_1 support (Jaroslav Kysela) [2140419]
- crypto: ccp - Failure on re-initialization due to duplicate sysfs filename (Vladis Dronov) [2130715]
- crypto: ccp - Avoid page allocation failure warning for SEV_GET_ID2 (Vladis Dronov) [2130715]
- crypto: ccp - Add support for TEE for PCI ID 0x14CA (Vladis Dronov) [2130715]
- crypto: ccp - Remove unused struct ccp_crypto_cpu (Vladis Dronov) [2130715]
- crypto: ccp - Add __init/__exit annotations to module init/exit funcs (Vladis Dronov) [2130715]
- RDMA/mlx5: Enable ATS support for MRs and umems (Kamal Heib) [2123401]
- RDMA/mlx5: Add support for dmabuf to devx umem (Kamal Heib) [2123401]
- RDMA/core: Add UVERBS_ATTR_RAW_FD (Kamal Heib) [2123401]
- net/mlx5: Add IFC bits for mkey ATS (Kamal Heib) [2123401]
- xfs: reserve quota for dir expansion when linking/unlinking files (Bill O'Donnell) [2086881]
- mm/selftest: uffd: explain the write missing fault check (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: use hugetlb_pte_stable in migration race check (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: fix race condition of uffd missing/minor handling (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: handle pte markers in page faults (Rafael Aquini) [2158123] {CVE-2022-3522}
- xfs: add selinux labels to whiteout inodes (Andrey Albershteyn) [2103234]

* Tue Feb 07 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-262.el9]
- wifi: rtw89: Add missing check for alloc_workqueue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix potential leak in rtw89_append_probe_req_ie() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix initialization of rx->link and rx->link_sta (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Drop stations iterator where the iterator function may sleep (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: use proper statements in conditionals (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix MLO + AP_VLAN check (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix coverity uninit_use_in_call in mt76_connac2_reverse_frag0_hdr_trans() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: Add checks for nla_nest_start() in nl80211_send_iface() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: Add missing __packed annotation of struct mt7921_clc (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: do not send firmware FW_FEATURE_NON_DL region (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix use after rcu_read_unlock in rtl8xxxu_bss_info_changed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix physts IE page check (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix wrong power after multiple SAR set (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: Fix some error handling path in rtw89_core_sta_assoc() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix maybe-unused warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: use u32_encode_bits() to fill MAC quota value (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix reporting of TX AGGR histogram (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix ifdef symbol name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix firmware assert during bandwidth change for peer sta (Jose Ignacio Tornos Martinez) [2136124]
- Revert "mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD" (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Turn on the rate control (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix warning in dma_free_coherent() of memory chunks while recovery (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: check link ID in auth/assoc continuation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: fix null-ptr deref on failed assoc (Jose Ignacio Tornos Martinez) [2136124]
- wifi: fix multi-link element subelement iteration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix antenna signal are way off in monitor mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac8021: fix possible oob access in ieee80211_get_rate_duration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: don't allow multi-BSSID in S1G (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix buffer overflow in elem comparison (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate number of channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate length of IEEE80211_P2P_ATTR_CHANNEL_LIST attribute (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate length of IEEE80211_P2P_ATTR_OPER_CHANNEL attribute (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate pairwise and authentication suite offsets (Jose Ignacio Tornos Martinez) [2136124]
- net: mhi: Fix memory leak in mhi_net_dellink() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix QCN9074 firmware boot on x86 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Set TWT Information Frame Disabled bit as 1 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Fix ack frame idr leak when mesh has no route (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix general-protection-fault in ieee80211_subif_start_xmit() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix debugfs attribute ps with rc table support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Fix bitrates overflow issue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix memory leak in query_regdb_file() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix memory free error when registering wiphy fail (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: silence a sparse RCU warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: use explicitly signed or unsigned types (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: mac: fix reading 16 bytes from a region of size 0 warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix rx checksum offload on mt7615/mt7915/mt7921 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix receiving LLC packets on mt7615/mt7915 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: update hidden BSSes to avoid WARN_ON (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix crash in beacon protection for P2P-device (Jose Ignacio Tornos Martinez) [2134580 2136124] {CVE-2022-42722}
- wifi: mac80211_hwsim: avoid mac80211 warning on bad rate (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: avoid nontransmitted BSS list corruption (Jose Ignacio Tornos Martinez) [2134509 2136124] {CVE-2022-42721}
- wifi: cfg80211: fix BSS refcounting bugs (Jose Ignacio Tornos Martinez) [2134458 2136124] {CVE-2022-42720}
- wifi: cfg80211: ensure length byte is present before access (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix MBSSID parsing use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211/mac80211: reject bad MBSSID elements (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix u8 overflow in cfg80211_update_notlisted_nontrans() (Jose Ignacio Tornos Martinez) [2134383 2136124] {CVE-2022-41674}
- wifi: nl80211: Split memcpy() of struct nl80211_wowlan_tcp_data_token flexible array (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wext: use flex array destination for memcpy() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix ieee80211_data_to_8023_exthdr handling of small packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: netdev compatible TX stop for iTXQ drivers (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix decap offload for stations on AP_VLAN interfaces (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: unlock on error in ieee80211_can_powered_addr_change() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: remove/avoid misleading prints (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix probe req HE capabilities access (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: do not drop packets smaller than the LLC-SNAP header on fast-rx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix rate reporting / throughput regression on mt7915 and newer (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Improve rtl8xxxu_queue_select (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix AIFS written to REG_EDCA_*_PARAM (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Enable 40 MHz channel width (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852b: configure DLE mem (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: check DLE FIFO size with reserved size (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: correct register of report IMR (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: set power cut closed for 8852be (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: add to do PCI auto calibration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852b: implement chip_ops::{enable,disable}_bb_rf (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add DMA busy checking bits to chip info (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: define DMA channel mask to avoid unsupported channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: mask out unsupported TX channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: Track scan_cmd allocation size explicitly (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: Remove the call to "dtim_assoc" IOVAR (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: increase dcmd maximum buffer size (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: Support 89459 pcie (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: increase default max WOWL patterns to 16 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix deadlock during WoWLAN suspend (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Remove redundant ath11k_mac_drain_tx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add spectral scan support for 160 MHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add support to get power save duration for each client (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix peer addition/deletion error on sta band migration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for enable/disable MSDU aggregation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: disable 26-tone RU HE TB PPDU transmissions (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for processing P2P power saving (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support WMM-PS in P2P GO mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: set wifi_role of P2P (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: send OFDM rate only in P2P mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support P2P (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: correctly set BBP register 86 for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set SoC wmac clock register (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set VGC gain for both chains of MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set correct TX_SW_CFG1 MAC register for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: fix HT20/HT40 bandwidth switch on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: move helper functions up in file (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add TX LOFT calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: don't run Rt5592 IQ calibration on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RXIQ calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RXDCOC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add r calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RF self TXDC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: move up and reuse busy wait functions (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add support for external PA on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add throughput LED trigger (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: define RF5592 in init_eeprom routine (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix number of VHT beamformee spatial streams (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: retrieve MAC address from system firmware if provided (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: add get_txpower mac ops (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: move firmware stats out of debugfs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: fix repeated the words in a comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: fix repeated to words in a comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: reset pointer after memory free to avoid potential use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix failed to find the peer with peer_id 0 when disconnected (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: change complete() to complete_all() for scan.completed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: update coexistence to 6.3.0 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add logic to control BT scan priority (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: summarize Wi-Fi to BT scoreboard and inform BT one time a cycle (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: modify LNA2 setting to avoid BT destroyed Wi-Fi aggregation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add WL_S0 hardware TX/RX mask to allow WL_S0 TX/RX during GNT_BT (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 Wi-Fi firmware steps report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 summary info to parse the traffic status from firmware (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: translate slot ID to readable name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 cycle report to parsing Bluetooth A2DP status (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix array of flexible structures warnings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rndis_wlan: fix array of flexible structures warning (Jose Ignacio Tornos Martinez) [2136124]
- mwifiex: fix sleep in atomic context bugs caused by dev_coredumpv (Jose Ignacio Tornos Martinez) [2136124]
- bus: mhi: host: pci_generic: Add a secondary AT port to Telit FN990 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add WoW support for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Include STA_KEEPALIVE_ARP_RESPONSE TLV header by default (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: uninitialized variable on error in rtw89_early_fw_feature_recognize() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: Fix "Error - Attempt to send packet over invalid queue 2" (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: add multi-port ID to TX descriptor (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix rx filter after scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: free unused skb to prevent memory leak (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: reset halt registers before turn on wifi CPU (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: update LTR settings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: set NAV upper to 25ms (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: initialize DMA of CMAC (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support SER L1 simulation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: support fw crash simulation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introudce functions to drop packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: unify use of rtw89_h2c_tx() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: concentrate control function of TX DMA channel (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct enable functions of HCI/PCI DMA (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: L1 DMA reset has offloaded to FW (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for setting TID specific configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for setting HE GI and LTF (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: show connecting state in debug message (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Combine set grant WL/BT and correct the debug log (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Remove trace_step at COEX-MECH control structure for RTL8852C (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Parsing Wi-Fi firmware TDMA info from reports (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Parsing Wi-Fi firmware error message from reports (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Move coexistence firmware buffer size parameter to chip info (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Add v1 Wi-Fi firmware power-saving null data report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: use void pointer as temporal type to copy report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4378 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Support PCIe core revisions >= 64 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: msgbuf: Increase RX ring sizes to 1024 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Allow platform to override macaddr (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Perform firmware selection for Apple platforms (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: of: Fetch Apple properties (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Read Apple OTP information (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Support passing in multiple board_types (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie/sdio/usb: Get CLM blob via standard firmware mechanism (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Handle per-board clm_blob files (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: d3: parse keys from wowlan info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: iterate over interfaces after an assert in d3 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: trigger resume flow before wait for notifications (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add handling for scan offload match info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: enable resume based on notifications (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for d3 end notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for wowlan wake packet notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for wowlan info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: don't check D0I3 version (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: cfg: remove IWL_DEVICE_BZ_COMMON macro (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: refactor iwl_mvm_set_sta_rate() a bit (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: rxmq: further unify some VHT/HE code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: rxmq: refactor mac80211 rx_status setting (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: fix typo in struct iwl_rx_no_data API (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: pcie: add support for BZ devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix kernel-doc issues (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136124]
- bus: mhi: host: always print detected modem name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7663s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix random fw download fail (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: introduce Country Location Control support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix rmmod crash in driver reload test (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: reset msta->airtime_ac while clearing up hw value (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: do not check state before configuring implicit beamform (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix uninitialized pointer in mt7921_mac_fill_rx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix mcs value in ht mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: get rid of the false positive reset (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: fix in comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: add PPDU based TxS support for WED device (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: move move mt76_sta_stats to mt76_wcid (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix the firmware version report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_[start, stop]_ap (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt76_usb.mt76u_mcu.burst is always false remove related code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7663s: add rx_check callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: fix possible unaligned access in mt76_connac_mcu_add_nested_tlv (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix possible unaligned access in mt7915_mac_add_twt_setup (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7615: add mt7615_mutex_acquire/release in mt7615_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: fix transmitting packet hangs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: add rx_check callback for sdio devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: delete stray if statement (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix use after free in mt7921_acpi_read() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix an uninitialized variable bug (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: poll sta stat when device transmits data (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: fix the deadlock caused by sdio->stat_work (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: move mt7921_rx_check and mt7921_queue_rx_skb in mac.c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921u: remove unnecessary MT76_STATE_SUSPEND (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921u: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921s: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: add rx_check callback for usb devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: testmode: use random payload for tx packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: introduce mt76_connac_reg_map structure (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Remove copy-paste leftover in gen2_update_rate_mask (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Fix mistake in path B IQ calibration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: split scan including lots of channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: support hw_scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: call tx_wake notify for 8852c in deep ps mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support deep ps mode for rtw8852c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: set response rate selection (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: set TX to single path TX on path B in 6GHz band (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: enlarge polling timeout of RX DCK (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: enable the interference cancellation of MU-MIMO on 6GHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add DIG register struct to share common algorithm (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support TX diversity for 1T2R chipset (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: record signal strength per RF path (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: configure TX path via H2C command (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: parse phycap of TX/RX antenna number (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: use u32_get_bits to access C2H content of PHY capability (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Increase TCL data ring size for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add multi TX ring support for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Enable threaded NAPI (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: mhi: fix potential memory leak in ath11k_mhi_register() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: implement SRAM dump debugfs interface (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Split PCI write/read functions (Jose Ignacio Tornos Martinez) [2136124]
- ath11k: Enable remain-on-channel support on WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix endian annotations in casts (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix endian conversion (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: mark a variable unused (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix skb misuse in TX queue selection (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: remove redundant variable err (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: add 43439 SDIO ids and initialization (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Simplify the error handling code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: Fix comment typo (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Add DMI nvram filename quirk for Chuwi Hi8 Pro tablet (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Use ISO3166 country code and rev 0 as fallback on 43430 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix use-after-free bug in brcmf_netdev_start_xmit() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: calib: Refactor iwl_calib_result usage for clarity (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: always activate all links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: implement link switching (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: keep A-MSDU data in sta and per-link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set up beacon timing config on links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add vif/sta link RCU dereference macros (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: send NDP for link (de)activation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: extend ieee80211_nullfunc_get() for MLO (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: track active STA links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: skip inactive links on TX (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add ieee80211_find_sta_by_link_addrs API (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: isolate driver from inactive links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: make smps_mode per-link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use correct rx link_sta instead of default (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link_sta in reorder timeout (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix multi-channel handling in netlink RX (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: call drv_sta_state() under sdata_lock() in reconfig (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: add MLD address to assoc BSS entries (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: refactor QoS settings code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: warn on invalid link address (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix double SW scan stop (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: assign link address correctly (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: move link code to a new file (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: refactor RX a bit (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: check STA magic in change_sta_links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: remove unused arg to ieee80211_chandef_eht_oper (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: remove multicast workaround (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: remove redundant err variable (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Support POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: Add POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: prevent 4-addr use on MLDs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: prevent VLANs on MLDs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add support to connect to non-transmit MBSSID profiles (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix hardware restart failure due to twt debugfs failure (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add TWT debugfs support for STA interface (Jose Ignacio Tornos Martinez) [2136124]
- wifi: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: remove redundant ret variable (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add missing destroy_workqueue() on error path in rtw_core_init() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: tighten bounds checking in rtl8xxxu_read_efuse() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: declare to support beamformee above bandwidth 80MHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct polling address of address CAM (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: no HTC field if TX rate might fallback to legacy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: correct TX resource checking in low power mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: fix interrupt stuck after leaving low power mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: enlarge the CFO tracking boundary (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: correct suspend/resume setting for variant chips (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: enable CLK_REQ, ASPM, L1 and L1ss for 8852c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: fix PCI PHY auto adaption by using software restore (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: set TBTT shift configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add retry to change power_mode state (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct BA CAM allocation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: initialize and correct BA CAM content (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: declare correct BA CAM number (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: update TX power tables to R49 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: update RF radio A/B parameters to R49 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: TX power limit/limit_ru consider negative (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Update Wi-Fi driver/firmware TDMA cycle report for RTL8852c (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add v1 Wi-Fi SCC coexistence policy (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Move _set_policy to chip_ops (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: update WL role info v1 for RTL8852C branch using (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add v1 version TDMA format and parameters (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Define BT B1 slot length (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add logic to parsing rtl8852c firmware type ctrl report (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Move Wi-Fi firmware coexistence matching version to chip (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: update radio state for RTL8852A/RTL8852C (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: adjust mactxen delay of mac/phy interface (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: modify PCIE prebkf time (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: ser: leave lps with mutex (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: declare support HE HTC always (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852a: update HW setting on BB (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: disable dma during mac init (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: early recognize FW feature to decide if chanctx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: declare support for mac80211 chanctx ops by chip (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add skeleton of mac80211 chanctx ops support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introduce entity mode and its recalculated prototype (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: initialize entity and configure default chandef (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: concentrate chandef setting to stack callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: concentrate parameter control for setting channel callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: rfk: concentrate parameter control while set_channel() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: txpwr: concentrate channel related control to top (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: create rtw89_chan centrally to avoid breakage (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: re-arrange channel related stuffs under HAL (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introduce rtw89_chan for channel stuffs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: rewrite decision on channel by entity state (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add cold boot calibration support on WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix incorrect QMI message ID mappings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Register shutdown handler for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: avoid uninit memory read in ath9k_htc_rx_msg() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix potential deadlock in ieee80211_key_link() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix uninitialized use of primary channel index (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use full 'unsigned int' type (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: read ethtool's sta_stats from sinfo (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: correct SMPS mode in HE 6 GHz capability (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Add link_id to cfg80211_ch_switch_started_notify() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: send MLO links channel info in GET_INTERFACE (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: allow bw change during channel switch in mesh (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: clean up a needless assignment in ieee80211_sta_activate_link() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: allow link address A2 in TXQ dequeue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix control port frame addressing (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link ID in TX info for beacons (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix link change handling (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: maintain link_id in link_sta (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211/mac80211: check EHT capability size correctly (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: split iftype data into AP/non-AP (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: don't add empty EML capabilities (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use link ID for MLO in queued frames (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use the corresponding link for stats update (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add link information in ieee80211_rx_status (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: properly implement MLO key handling (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Add link_id parameter to various key operations for MLO (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Prevent cfg80211_wext_siwencodeext() on MLD (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: reject connect response with MLO params for WEP (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use link in TXQ parameter configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: add link id to txq params (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link BSSID (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: get correct AP link chandef (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Update RNR parsing to align with Draft P802.11be_D2.0 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: properly set old_links when removing a link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: accept STA changes without link changes (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: prohibit enter IPS during HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add flag check before enter or leave IPS (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add flushing queue before HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix WARNING:rtw_get_tx_power_params() during HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add the update channel flow to support setting by parameters (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add mutex when set regulatory and get Tx power table (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add mutex when set SAR (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Fix to add skb free for TIM update info when tx is completed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Fix to add brcmf_clear_assoc_ies when rmmod (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix invalid address access when enabling SCAN log level (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix scheduling while atomic issue when deleting flowring (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix continuous 802.1x tx pending timeout error (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: add peer map clean up for peer delete in ath10k_sta_state() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: Set tx credit to one for WCN3990 snoc based devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852a: correct WDE IMR settings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: refine leaving LPS function (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtlwifi: 8192de: correct checking of IQK reload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmsmac: remove duplicate words (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: access chip_info by const pointer (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: phy: fix warning of possible buffer overflow (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix store OP channel info timing when HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix stopping queues in wrong timing when HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: 8822c: extend supported probe request size (Jose Ignacio Tornos Martinez) [2136124]

* Tue Feb 07 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-261.el9]
- act_mirred: use the backlog for nested calls to mirred ingress (Davide Caratti) [2150278] {CVE-2022-4269}
- net/sched: act_mirred: better wording on protection against excessive stack growth (Davide Caratti) [2150278]
- net: openvswitch: release vport resources on failure (Antoine Tenart) [2163678]
- net: openvswitch: Add support to count upcall packets (Antoine Tenart) [2163678]
- openvswitch: Fix flow lookup to use unmasked key (Antoine Tenart) [2163374]
- openvswitch: return NF_DROP when fails to add nat ext in ovs_ct_nat (Antoine Tenart) [2163374]
- openvswitch: return NF_ACCEPT when OVS_CT_NAT is not set in info nat (Antoine Tenart) [2163374]
- openvswitch: delete the unncessary skb_pull_rcsum call in ovs_ct_nat_execute (Antoine Tenart) [2163374]
- openvswitch: Use kmalloc_size_roundup() to match ksize() usage (Antoine Tenart) [2163374]
- openvswitch: switch from WARN to pr_warn (Antoine Tenart) [2163374]
- bnxt: make sure we return pages to the pool (Ken Cox) [2112187]
- bnxt_en: fix memory leak in bnxt_nvm_test() (Ken Cox) [2112187]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112187]
- bnxt_en: fix LRO/GRO_HW features in ndo_fix_features callback (Ken Cox) [2112187]
- bnxt_en: fix NQ resource accounting during vf creation on 57500 chips (Ken Cox) [2112187]
- bnxt_en: set missing reload flag in devlink features (Ken Cox) [2112187]
- bnxt_en: Use PAGE_SIZE to init buffer when multi buffer XDP is not in use (Ken Cox) [2112187]
- bnxt_en: Remove duplicated include bnxt_devlink.c (Ken Cox) [2112187]
- bnxt_en: implement callbacks for devlink selftests (Ken Cox) [2112187]
- bnxt_en: Fix and simplify XDP transmit path (Ken Cox) [2112187]
- bnxt: Use the bitmap API to allocate bitmaps (Ken Cox) [2112187]
- bnxt: Fix typo in comments (Ken Cox) [2112187]
- ethernet: Remove vf rate limit check for drivers (Ken Cox) [2112187]
- bnxt: XDP multibuffer enablement (Ken Cox) [2112187]
- bnxt: support transmit and free of aggregation buffers (Ken Cox) [2112187]
- bnxt: adding bnxt_xdp_build_skb to build skb from multibuffer xdp_buff (Ken Cox) [2112187]
- bnxt: set xdp_buff pfmemalloc flag if needed (Ken Cox) [2112187]
- bnxt: adding bnxt_rx_agg_pages_xdp for aggregated xdp (Ken Cox) [2112187]
- bnxt_en: extract coredump command line from current task (Ken Cox) [2112187]
- bnxt_en: Add compression flags information in coredump segment header (Ken Cox) [2112187]
- bnxt_en: Use struct_group_attr() for memcpy() region (Ken Cox) [2112187]
- dm cache: free background tracker's queued work in btracker_destroy (Benjamin Marzinski) [2163655]
- dm thin: Use last transaction's pmd->root when commit failed (Benjamin Marzinski) [2162536]
- dm thin: resume even if in FAIL mode (Benjamin Marzinski) [2162536]
- dm cache: set needs_check flag after aborting metadata (Benjamin Marzinski) [2162536]
- dm cache: Fix ABBA deadlock between shrink_slab and dm_cache_metadata_abort (Benjamin Marzinski) [2162536]
- dm thin: Fix ABBA deadlock between shrink_slab and dm_pool_abort_metadata (Benjamin Marzinski) [2162536]
- dm integrity: Fix UAF in dm_integrity_dtr() (Benjamin Marzinski) [2162536]
- dm cache: Fix UAF in destroy() (Benjamin Marzinski) [2162536]
- dm clone: Fix UAF in clone_dtr() (Benjamin Marzinski) [2162536]
- dm thin: Fix UAF in run_timer_softirq() (Benjamin Marzinski) [2162536]
- dm integrity: clear the journal on suspend (Benjamin Marzinski) [2162536]
- dm integrity: flush the journal on suspend (Benjamin Marzinski) [2162536]
- dm bufio: Fix missing decrement of no_sleep_enabled if dm_bufio_client_create failed (Benjamin Marzinski) [2162536]
- dm ioctl: fix misbehavior if list_versions races with module loading (Benjamin Marzinski) [2162536]

* Mon Feb 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-260.el9]
- platform/x86/amd: Fix refcount leak in amd_pmc_probe (David Arcari) [2104173]
- platform/x86/amd: pmc: Add a workaround for an s0i3 issue on Cezanne (David Arcari) [2104173]
- platform/x86/amd: pmc: Add new ACPI ID AMDI0009 (David Arcari) [2104173]
- platform/x86/amd: pmc: Remove more CONFIG_DEBUG_FS checks (David Arcari) [2104173]
- platform/x86/amd: pmc: Read SMU version during suspend on Cezanne systems (David Arcari) [2104173]
- platform/x86/amd: pmc: Dump idle mask during "check" stage instead (David Arcari) [2104173]
- platform/x86/amd: pmc: remove CONFIG_DEBUG_FS checks (David Arcari) [2104173]
- platform/x86/amd: pmc: Fix build without debugfs (David Arcari) [2104173]
- platform/x86/amd: pmc: Add sysfs files for SMU (David Arcari) [2104173]
- platform/x86/amd: pmc: Add an extra STB message for checking s2idle entry (David Arcari) [2104173]
- platform/x86/amd: pmc: Always write to the STB (David Arcari) [2104173]
- platform/x86/amd: pmc: Add defines for STB events (David Arcari) [2104173]
- platform/x86/amd/pmc: Add new platform support (David Arcari) [2104173]
- platform/x86/amd/pmc: Add new acpi id for PMC controller (David Arcari) [2104173]
- platform/x86: Move AMD platform drivers to separate directory (David Arcari) [2104173]
- platform/x86: amd-pmc: Fix build error unused-function (David Arcari) [2104173]
- platform/x86: amd-pmc: Shuffle location of amd_pmc_get_smu_version() (David Arcari) [2104173]
- platform/x86: amd-pmc: Avoid reading SMU version at probe time (David Arcari) [2104173]
- platform/x86: amd-pmc: Move FCH init to first use (David Arcari) [2104173]
- platform/x86: amd-pmc: Move SMU logging setup out of init (David Arcari) [2104173]
- platform/x86: amd-pmc: Fix compilation without CONFIG_SUSPEND (David Arcari) [2104173]
- platform/x86: amd-pmc: Only report STB errors when STB enabled (David Arcari) [2104173]
- platform/x86: amd-pmc: Drop CPU QoS workaround (David Arcari) [2104173]
- platform/x86: amd-pmc: Output error codes in messages (David Arcari) [2104173]
- platform/x86: amd-pmc: Move to later in the suspend process (David Arcari) [2104173]
- platform/x86: amd-pmc: Validate entry into the deepest state on resume (David Arcari) [2104173]
- platform/x86: amd-pmc: uninitialized variable in amd_pmc_s2d_init() (David Arcari) [2104173]
- platform/x86: amd-pmc: Set QOS during suspend on CZN w/ timer wakeup (David Arcari) [2104173]
- platform/x86: amd-pmc: Add support for AMD Spill to DRAM STB feature (David Arcari) [2104173]
- platform/x86: amd-pmc: Correct usage of SMU version (David Arcari) [2104173]
- platform/x86: amd-pmc: Make amd_pmc_stb_debugfs_fops static (David Arcari) [2104173]
- nvme: fix multipath crash caused by flush request when blktrace is enabled (Maurizio Lombardi) [2161609]
- nvme: return err on nvme_init_non_mdts_limits fail (Maurizio Lombardi) [2161609]
- nvme-rdma: stop auth work after tearing down queues in error recovery (Maurizio Lombardi) [2161609]
- nvme-tcp: stop auth work after tearing down queues in error recovery (Maurizio Lombardi) [2161609]
- nvme initialize core quirks before calling nvme_init_subsystem (Maurizio Lombardi) [2161609]
- nvme-pci: clear the prp2 field when not used (Maurizio Lombardi) [2161609]
- nvmet: fix a memory leak in nvmet_auth_set_key (Maurizio Lombardi) [2161609]
- nvmet: fix a memory leak (Maurizio Lombardi) [2161609]
- nvmet: fix memory leak in nvmet_subsys_attr_model_store_locked (Maurizio Lombardi) [2161609]
- nvme-tcp: fix possible circular locking when deleting a controller under memory pressure (Maurizio Lombardi) [2161609]
- nvmet: fix invalid memory reference in nvmet_subsys_attr_qid_max_show (Maurizio Lombardi) [2161609]
- nvmet: fix workqueue MEM_RECLAIM flushing dependency (Maurizio Lombardi) [2161609]
- nvme-multipath: fix possible hang in live ns resize with ANA access (Maurizio Lombardi) [2161609]
- nvme-tcp: fix possible hang caused during ctrl deletion (Maurizio Lombardi) [2161609]
- nvme-rdma: fix possible hang caused during ctrl deletion (Maurizio Lombardi) [2161609]
- nvmet-tcp: remove nvmet_tcp_finish_cmd (Maurizio Lombardi) [2161609]
- nvmet-tcp: add bounds check on Transfer Tag (Maurizio Lombardi) [2161609]
- nvmet-tcp: fix NULL pointer dereference during release (Maurizio Lombardi) [2161609]
- nvmet-tcp: don't map pages which can't come from HIGHMEM (Maurizio Lombardi) [2161609]
- crypto: octeontx2 - Remove the unneeded result variable (Vladis Dronov) [2153763]
- crypto: drivers - move from strlcpy with unused retval to strscpy (Vladis Dronov) [2153763]

* Mon Feb 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-259.el9]
- net: Fix return value of qdisc ingress handling on success (Paolo Abeni) [2162711]
- net: sched: gred: prevent races when adding offloads to stats (Davide Caratti) [2162634]
- net/sched: sch_taprio: do not schedule in taprio_reset() (Davide Caratti) [2162634]
- net/sched: sch_taprio: fix possible use-after-free (Davide Caratti) [2162634]
- sch_htb: Avoid grafting on htb_destroy_class_offload when destroying htb (Davide Caratti) [2162634]
- net: sched: disallow noqueue for qdisc classes (Davide Caratti) [2162634]
- net: sched: fix memory leak in tcindex_set_parms (Davide Caratti) [2162634]
- net: sched: cake: fix null pointer access issue when cake_init() fails (Davide Caratti) [2162634]
- cifs: fix use-after-free caused by invalid pointer `hostname` (Ronnie Sahlberg) [2154174]
- KVM: SVM: Only dump VMSA to klog at KERN_DEBUG level (Vitaly Kuznetsov) [2160005]
- fs/buffer: remove bh_submit_read() helper (Lukas Czerner) [2160719]
- ext2: replace bh_submit_read() helper with bh_read() (Lukas Czerner) [2160719]
- fs/buffer: remove ll_rw_block() helper (Lukas Czerner) [2160719]
- udf: replace ll_rw_block() (Lukas Czerner) [2160719]
- jbd2: replace ll_rw_block() (Lukas Czerner) [2160719]
- isofs: replace ll_rw_block() (Lukas Czerner) [2160719]
- gfs2: replace ll_rw_block() (Lukas Czerner) [2160719]
- fs/buffer: replace ll_rw_block() (Lukas Czerner) [2160719]
- fs/buffer: add some new buffer read helpers (Lukas Czerner) [2160719]
- fs/buffer: remove __breadahead_gfp() (Lukas Czerner) [2160719]
- tipc: fix an use-after-free issue in tipc_recvmsg (Xin Long) [2160540]
- tipc: keep the skb in rcv queue until the whole data is read (Xin Long) [2160540]
- tipc: fix unexpected link reset due to discovery messages (Xin Long) [2160540]
- tipc: call tipc_lxc_xmit without holding node_read_lock (Xin Long) [2160540]
- tipc: Fix potential OOB in tipc_link_proto_rcv() (Xin Long) [2160540]
- tipc: check skb_linearize() return value in tipc_disc_rcv() (Xin Long) [2160540]
- tipc: add an extra conn_get in tipc_conn_alloc (Xin Long) [2160540]
- tipc: set con sock in tipc_conn_alloc (Xin Long) [2160540]
- tipc: fix the msg->req tlv len check in tipc_nl_compat_name_table_dump_header (Xin Long) [2160540]
- tipc: fix a null-ptr-deref in tipc_topsrv_accept (Xin Long) [2160540]
- thermal/drivers/qcom/tsens: Rework debugfs file structure (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens: Fix wrong version id dbg_version_show (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens: Init debugfs only with successful probe (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Allow configuring min and max trips (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Add support for combined interrupt (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens-v0_1: Fix MSM8939 fourth sensor hw_id (Eric Chanudet) [2159524]
- thermal/drivers/qcom: Remove get_trend function (Eric Chanudet) [2159524]
- iio: adc: qcom-vadc-common: add reverse scaling for PMIC5 Gen2 ADC_TM (Eric Chanudet) [2159524]
- thermal/drivers/tsens: register thermal zones as hwmon sensors (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Add timeout to get_temp_tsens_valid (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Fix wrong check for tzd in irq handlers (Eric Chanudet) [2159524]
- RDMA/siw: Always consume all skbuf data in sk_data_ready() upcall. (Kamal Heib) [2131780]
- mailbox: qcom-ipcc: flag IRQ NO_THREAD (Eric Chanudet) [2135552]
- fbmem: Check virtual screen sizes in fb_set_var() (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbcon: Prevent that screen size is smaller than font size (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbcon: Disallow setting font bigger than screen size (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- video: of_display_timing.h: include errno.h (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbdev: fbmem: Fix logo center image dx issue (Wander Lairson Costa) [2109118] {CVE-2021-33655}

* Fri Feb 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-258.el9]
- HID: amd_sfh: Fix warning unwind goto (Benjamin Tissoires) [2122844]
- HID: revert CHERRY_MOUSE_000C quirk (Benjamin Tissoires) [2122844]
- HID: i2c: let RMI devices decide what constitutes wakeup event (Benjamin Tissoires) [2122844]
- HID: plantronics: Additional PIDs for double volume key presses quirk (Benjamin Tissoires) [2122844]
- HID: multitouch: fix Asus ExpertBook P2 P2451FA trackpoint (Benjamin Tissoires) [2122844]
- HID: mcp2221: don't connect hidraw (Benjamin Tissoires) [2122844]
- HID: wacom: Ensure bootloader PID is usable in hidraw mode (Benjamin Tissoires) [2122844]
- HID: logitech-hidpp: Guard FF init code against non-USB devices (Benjamin Tissoires) [2122844]
- HID: input: do not query XP-PEN Deco LW battery (Benjamin Tissoires) [2122844]
- HID: apple: enable APPLE_ISO_TILDE_QUIRK for the keyboards of Macs with the T2 chip (Benjamin Tissoires) [2122844]
- HID: apple: fix key translations where multiple quirks attempt to translate the same key (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add missing check for dma_alloc_coherent (Benjamin Tissoires) [2122844]
- HID: hid-sensor-custom: set fixed size for custom attributes (Benjamin Tissoires) [2122844]
- Input: elants_i2c - properly handle the reset GPIO when power is off (Benjamin Tissoires) [2122844]
- Input: i8042 - apply probe defer to more ASUS ZenBook models (Benjamin Tissoires) [2122844]
- Input: synaptics - switch touchpad on HP Laptop 15-da3001TU to RMI mode (Benjamin Tissoires) [2122844]
- Input: i8042 - fix leaking of platform device on module removal (Benjamin Tissoires) [2122844]
- Input: document the units for resolution of size axes (Benjamin Tissoires) [2122844]
- Input: synaptics - disable Intertouch for Lenovo T14 and P14s AMD G1 (Benjamin Tissoires) [2122844]
- Input: deactivate MT slots when inhibiting or suspending devices (Benjamin Tissoires) [2122844]
- Input: properly queue synthetic events (Benjamin Tissoires) [2122844]
- Input: i8042 - add dritek quirk for Acer Aspire One AO532 (Benjamin Tissoires) [2122844]
- Input: i8042 - add additional TUXEDO devices to i8042 quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - add TUXEDO devices to i8042 quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - add debug output for quirks (Benjamin Tissoires) [2122844]
- Input: i8042 - merge quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - move __initconst to fix code styling warning (Benjamin Tissoires) [2122844]
- Input: usbtouchscreen - add driver_info sanity check (Benjamin Tissoires) [2122844]
- HID: ite: Enable QUIRK_TOUCHPAD_ON_OFF_REPORT on Acer Aspire Switch V 10 (Benjamin Tissoires) [2122844]
- HID: core: fix shift-out-of-bounds in hid_report_raw_event (Benjamin Tissoires) [2122844]
- HID: hid-lg4ff: Add check for empty lbuf (Benjamin Tissoires) [2122844]
- HID: uclogic: Add HID_QUIRK_HIDINPUT_FORCE quirk (Benjamin Tissoires) [2122844]
- HID: fix I2C_HID not selected when I2C_HID_OF_ELAN is (Benjamin Tissoires) [2122844]
- HID: usbhid: Add ALWAYS_POLL quirk for some mice (Benjamin Tissoires) [2122844]
- HID: uclogic: Fix frame templates for big endian architectures (Benjamin Tissoires) [2122844]
- HID: wacom: Fix logic used for 3rd barrel switch emulation (Benjamin Tissoires) [2122844]
- HID: saitek: add madcatz variant of MMO7 mouse device ID (Benjamin Tissoires) [2122844]
- HID: magicmouse: Do not set BTN_MOUSE on double report (Benjamin Tissoires) [2122844]
- HID: playstation: add initial DualSense Edge controller support (Benjamin Tissoires) [2122844]
- HID: playstation: stop DualSense output work on remove. (Benjamin Tissoires) [2122844]
- HID: nintendo: check analog user calibration for plausibility (Benjamin Tissoires) [2122844]
- HID: roccat: Fix use-after-free in roccat_read() (Benjamin Tissoires) [2122844]
- hid: topre: Add driver fixing report descriptor (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Handle condition of "no sensors" for SFH1.1 (Benjamin Tissoires) [2122844]
- HID: uclogic: Fix warning in uclogic_rdesc_template_apply (Benjamin Tissoires) [2122844]
- HID: uclogic: Add missing suffix for digitalizers (Benjamin Tissoires) [2122844]
- HID: multitouch: Add memory barriers (Benjamin Tissoires) [2122844]
- HID: nintendo: fix rumble worker null pointer deref (Benjamin Tissoires) [2122844]
- HID: input: fix uclogic tablets (Benjamin Tissoires) [2122844]
- HID: Add Apple Touchbar on T2 Macs in hid_have_special_driver list (Benjamin Tissoires) [2122844]
- HID: add Lenovo Yoga C630 battery quirk (Benjamin Tissoires) [2122844]
- HID: AMD_SFH: Add a DMI quirk entry for Chromebooks (Benjamin Tissoires) [2122844]
- HID: thrustmaster: Add sparco wheel and fix array length (Benjamin Tissoires) [2122844]
- HID: asus: ROG NKey: Ignore portion of 0x5a report (Benjamin Tissoires) [2122844]
- HID: hidraw: fix memory leak in hidraw_release() (Benjamin Tissoires) [2122844]
- HID: steam: Prevent NULL pointer dereference in steam_{recv,send}_report (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Handle condition of "no sensors" (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Fix implicit declaration error on i386 (Benjamin Tissoires) [2122844]
- HID: apple: Add "GANSS" to the non-Apple list (Benjamin Tissoires) [2122844]
- HID: alps: Declare U1_UNICORN_LEGACY support (Benjamin Tissoires) [2122844]
- HID: wacom: Force pen out of prox if no events have been received in a while (Benjamin Tissoires) [2122844]
- HID: nintendo: Add missing array termination (Benjamin Tissoires) [2122844]
- HID: lg-g15: Fix comment typo (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Implement SFH1.1 functionality (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move interrupt handling to common interface (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move amd_sfh_work to common interface (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move global functions to static (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add remove operation in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add PM operations in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add descriptor operations in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move request_list variable to client data (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move request_list struct to header file (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move common macros and structures (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add NULL check for hid device (Benjamin Tissoires) [2122844]
- HID: core: remove unneeded assignment in hid_process_report() (Benjamin Tissoires) [2122844]
- HID: mcp2221: prevent a buffer overflow in mcp_smbus_write() (Benjamin Tissoires) [2122844]
- HID: nintendo: Set phys property of input device based on HID phys (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for XP-PEN Deco L (Benjamin Tissoires) [2122844]
- HID: uclogic: Allow to generate frame templates (Benjamin Tissoires) [2122844]
- HID: uclogic: Add KUnit tests for uclogic_rdesc_template_apply() (Benjamin Tissoires) [2122844]
- HID: uclogic: Make template placeholder IDs generic (Benjamin Tissoires) [2122844]
- HID: surface-hid: Add support for hot-removal (Benjamin Tissoires) [2122844]
- HID: multitouch: new device class fix Lenovo X12 trackpad sticky (Benjamin Tissoires) [2122844]
- HID: cp2112: prevent a buffer overflow in cp2112_xfer() (Benjamin Tissoires) [2122844]
- HID: hid-input: add Surface Go battery quirk (Benjamin Tissoires) [2122844]
- HID: logitech-hidpp: Fix syntax errors in comments (Benjamin Tissoires) [2122844]
- HID: uclogic: properly format kernel-doc comment for hid_dbg() wrappers (Benjamin Tissoires) [2122844]
- HID: apple: Properly handle function keys on non-Apple keyboard (Benjamin Tissoires) [2122844]
- HID: nintendo: fix unused const warning (Benjamin Tissoires) [2122844]
- HID: i2c-hid: elan: Add support for Elan eKTH6915 i2c-hid touchscreens (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Don't show client init failed as error when discovery fails (Benjamin Tissoires) [2122844]
- HID: wacom: Don't register pad_input for touch switch (Benjamin Tissoires) [2122844]
- HID: wacom: Only report rotation for art pen (Benjamin Tissoires) [2122844]
- HID: apple: Properly handle function keys on Keychron keyboards (Benjamin Tissoires) [2122844]
- HID: uclogic: Switch to Digitizer usage for styluses (Benjamin Tissoires) [2122844]
- HID: uclogic: Add pen support for XP-PEN Star 06 (Benjamin Tissoires) [2122844]
- HID: uclogic: Differentiate touch ring and touch strip (Benjamin Tissoires) [2122844]
- HID: uclogic: Always shift touch reports to zero (Benjamin Tissoires) [2122844]
- HID: uclogic: Do not focus on touch ring only (Benjamin Tissoires) [2122844]
- HID: uclogic: Return raw parameters from v2 pen init (Benjamin Tissoires) [2122844]
- HID: uclogic: Move param printing to a function (Benjamin Tissoires) [2122844]
- HID: core: Display "SENSOR HUB" for sensor hub bus string in hid_info (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move bus declaration outside of amd-sfh (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add physical location to HID device (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add sensor name by index for debug info (Benjamin Tissoires) [2122844]
- Hid: wacom: Fix kernel test robot warning (Benjamin Tissoires) [2122844]
- HID: uclogic: Disable pen usage for Huion keyboard interfaces (Benjamin Tissoires) [2122844]
- HID: uclogic: Support disabling pen usage (Benjamin Tissoires) [2122844]
- HID: uclogic: Pass keyboard reports as is (Benjamin Tissoires) [2122844]
- HID: uclogic: Clarify pen/frame desc_ptr description (Benjamin Tissoires) [2122844]
- HID: uclogic: Clarify params desc_size description (Benjamin Tissoires) [2122844]
- HID: Add support for Mega World controller force feedback (Benjamin Tissoires) [2122844]
- HID: lenovo: Add note about different report numbers (Benjamin Tissoires) [2122844]
- HID: lenovo: Sync Fn-lock state on button press for Compact and TrackPoint II keyboards (Benjamin Tissoires) [2122844]
- HID: lenovo: Add support for ThinkPad TrackPoint Keyboard II (Benjamin Tissoires) [2122844]
- HID: amd_sfh: change global variables to static (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for Huion Q620M (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for bitmap dials (Benjamin Tissoires) [2122844]
- HID: uclogic: Reduce indent for params format str/args (Benjamin Tissoires) [2122844]
- HID: uclogic: Compress params format string (Benjamin Tissoires) [2122844]
- HID: wacom: Correct power_supply type (Benjamin Tissoires) [2122844]
- HID: wacom: Adding Support for new usages (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for Huion touch ring reports (Benjamin Tissoires) [2122844]
- HID: uclogic: Allow three frame parameter sets (Benjamin Tissoires) [2122844]
- HID: uclogic: Support custom device suffix for frames (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for touch ring reports (Benjamin Tissoires) [2122844]

* Fri Feb 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-257.el9]
- net/mlx5e: TC, Fix slab-out-of-bounds in parse_tc_actions (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix wrong rejection of packet-per-second policing (Mohammad Kabat) [2112947]
- net/mlx5: ASO, Create the ASO SQ with the correct timestamp format (Mohammad Kabat) [2112947]
- net/mlx5e: Fix use-after-free when reverting termination table (Mohammad Kabat) [2112947]
- net/mlx5: Fix uninitialized variable bug in outlen_write() (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix uninitialized var warning (Mohammad Kabat) [2112947]
- net/mlx5e: Offload rule only when all encaps are valid (Mohammad Kabat) [2112947]
- net/mlx5: E-Switch, Set correctly vport destination (Mohammad Kabat) [2112947]
- net/mlx5: Fix handling of entry refcount when command is not issued to FW (Mohammad Kabat) [2112947]
- net/mlx5: cmdif, Print info on any firmware cmd failure to tracepoint (Mohammad Kabat) [2112947]
- net/mlx5: SF: Fix probing active SFs during driver probe phase (Mohammad Kabat) [2112947]
- net/mlx5: Fix FW tracer timestamp calculation (Mohammad Kabat) [2112947]
- net/mlx5: Do not query pci info while pci disabled (Mohammad Kabat) [2112947 2133099]
- net/mlx5e: E-Switch, Fix comparing termination table instance (Mohammad Kabat) [2112947]
- net/mlx5e: Fix tc acts array not to be dependent on enum order (Mohammad Kabat) [2112947]
- net/mlx5e: Add missing sanity checks for max TX WQE size (Mohammad Kabat) [2112947]
- net/mlx5: Allow async trigger completion execution on single CPU systems (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, verify LAG state when adding bond to bridge (Mohammad Kabat) [2112947]
- net/mlx5: Fix crash during sync firmware reset (Mohammad Kabat) [2112947]
- net/mlx5: Update fw fatal reporter state on PCI handlers successful recover (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix cloned flow attr instance dests are not zeroed (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Reject forwarding from internal port to internal port (Mohammad Kabat) [2112947]
- net/mlx5: Fix possible use-after-free in async command interface (Mohammad Kabat) [2112947]
- net/mlx5e: Update restore chain id for slow path packets (Mohammad Kabat) [2112947]
- net/mlx5e: Extend SKB room check to include PTP-SQ (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix matcher disconnect error flow (Mohammad Kabat) [2112947]
- net/mlx5: Wait for firmware to enable CRS before pci_restore_state (Mohammad Kabat) [2112947]
- net/mlx5e: Do not increment ESN when updating IPsec ESN state (Mohammad Kabat) [2112947]
- net/mlx5e: Clean up and fix error flows in mlx5e_alloc_rq (Mohammad Kabat) [2112947]
- net/mlx5e: Fix calculations for ICOSQ size (Mohammad Kabat) [2112947]
- net/mlx5: Fix spelling mistake "syndrom" -> "syndrome" (Mohammad Kabat) [2112947]
- net/mlx5e: Fix a typo in mlx5e_xdp_mpwqe_is_full (Mohammad Kabat) [2112947]
- RDMA/mlx5: Don't compare mkey tags in DEVX indirect mkey (Mohammad Kabat) [2112947]
- net/mlx5e: Fix build warning, detected write beyond size of field (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Remove MLX5E_XDP_TX_DS_COUNT (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Permit XDP with non-linear legacy RQ (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Support multi buffer XDP_TX (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Unindent the else-block in mlx5e_xmit_xdp_buff (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Implement sending multi buffer XDP frames (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Don't prefill WQEs in XDP SQ in the multi buffer mode (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Remove assignment of inline_hdr.sz on XDP TX (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Move mlx5e_xdpi_fifo_push out of xmit_xdp_frame (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Store DMA address inside struct page (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Add XDP multi buffer support to the non-linear legacy RQ (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Use page-sized fragments with XDP multi buffer (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Use fragments of the same size in non-linear legacy RQ with XDP (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Prepare non-linear legacy RQ for XDP multi buffer support (Mohammad Kabat) [2049859 2112947]
- RDMA/mlx5: Fix UMR cleanup on error flow of driver init (Mohammad Kabat) [2112947]
- RDMA/mlx5: Set local port to one when accessing counters (Mohammad Kabat) [2112947]
- RDMA/mlx5: Rely on RoCE fw cap instead of devlink when setting profile (Mohammad Kabat) [2112947]
- net/mlx5e: Fix use after free in mlx5e_fs_init() (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Use _safe() iterator in mlx5e_tls_priv_tx_list_cleanup() (Mohammad Kabat) [2112947]
- net/mlx5e: Fix wrong tc flag used when set hw-tc-offload off (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Add missing policer validation (Mohammad Kabat) [2112947]
- net/mlx5e: Fix wrong application of the LRO state (Mohammad Kabat) [2112947]
- net/mlx5: Avoid false positive lockdep warning by adding lock_class_key (Mohammad Kabat) [2112947]
- net/mlx5: Fix cmd error logging for manage pages cmd (Mohammad Kabat) [2112947]
- net/mlx5: Disable irq when locking lag_lock (Mohammad Kabat) [2112947]
- net/mlx5: LAG, fix logic over MLX5_LAG_FLAG_NDEVS_READY (Mohammad Kabat) [2112947]
- net/mlx5e: Properly disable vlan strip on non-UL reps (Mohammad Kabat) [2112947]
- net/mlx5e: Allocate flow steering storage during uplink initialization (Mohammad Kabat) [2112947]
- mlx5: do not use RT_TOS for IPv6 flowlabel (Mohammad Kabat) [2112947]
- RDMA/mlx5: Add missing check for return value in get namespace flow (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Dynamically re-size TX recycling pool (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Recycle objects of device-offloaded TLS TX connections (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Take stats out of OOO handler (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Introduce TLS-specific create TIS (Mohammad Kabat) [2112947]
- net/mlx5e: Move mlx5e_init_l2_addr to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Split en_fs ndo's and move to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Separate mlx5e_set_rx_mode_work and move caller to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Add mdev to flow_steering struct (Mohammad Kabat) [2112947]
- net/mlx5e: Report flow steering errors with mdev err report API (Mohammad Kabat) [2112947]
- net/mlx5e: Convert mlx5e_flow_steering member of mlx5e_priv to pointer (Mohammad Kabat) [2112947]
- net/mlx5e: Allocate VLAN and TC for featured profiles only (Mohammad Kabat) [2112947]
- net/mlx5e: Make mlx5e_tc_table private (Mohammad Kabat) [2112947]
- net/mlx5e: Convert mlx5e_tc_table member of mlx5e_flow_steering to pointer (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Support tc action api for police (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Separate get/update/replace meter functions (Mohammad Kabat) [2112947]
- net/mlx5e: Add red and green counters for metering (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Allocate post meter ft per rule (Mohammad Kabat) [2112947]
- net/mlx5: DR, Add support for flow metering ASO (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix SMFS steering info dump format (Mohammad Kabat) [2112947]
- net/mlx5: Adjust log_max_qp to be 18 at most (Mohammad Kabat) [2112947]
- net/mlx5e: Modify slow path rules to go to slow fdb (Mohammad Kabat) [2112947]
- net/mlx5e: Fix calculations related to max MPWQE size (Mohammad Kabat) [2112947]
- net/mlx5e: xsk: Account for XSK RQ UMRs when calculating ICOSQ size (Mohammad Kabat) [2112947]
- net/mlx5e: Fix the value of MLX5E_MAX_RQ_NUM_MTTS (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix post_act to not match on in_port metadata (Mohammad Kabat) [2112947]
- net/mlx5e: Remove WARN_ON when trying to offload an unsupported TLS cipher/version (Mohammad Kabat) [2112947]
- RDMA/mlx5: Rename the mkey cache variables and functions (Mohammad Kabat) [2112947]
- RDMA/mlx5: Store in the cache mkeys instead of mrs (Mohammad Kabat) [2112947]
- RDMA/mlx5: Store the number of in_use cache mkeys instead of total_mrs (Mohammad Kabat) [2112947]
- RDMA/mlx5: Replace cache list with Xarray (Mohammad Kabat) [2112947]
- RDMA/mlx5: Replace ent->lock with xa_lock (Mohammad Kabat) [2112947]
- net/mlx5: CT: Remove warning of ignore_flow_level support for non PF (Mohammad Kabat) [2112947]
- net/mlx5e: Add resiliency for PTP TX port timestamp (Mohammad Kabat) [2112947]
- net/mlx5: Expose ts_cqe_metadata_size2wqe_counter (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move htb functions to a new file (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, change functions name to follow convention (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, remove priv from htb function calls (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, hide and dynamically allocate mlx5e_htb structure (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move stats and max_sqs to priv (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move section comment to the right place (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move ids to selq_params struct (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, reduce visibility of htb functions (Mohammad Kabat) [2112947]
- net/mlx5e: Fix mqprio_rl handling on devlink reload (Mohammad Kabat) [2112947]
- net/mlx5e: Report header-data split state through ethtool (Mohammad Kabat) [2112947]
- RDMA/mlx5: Expose steering anchor to userspace (Mohammad Kabat) [2112947]
- RDMA/mlx5: Refactor get flow table function (Mohammad Kabat) [2112947]
- net/mlx5: fs, allow flow table creation with a UID (Mohammad Kabat) [2112947]
- net/mlx5: fs, expose flow table ID to users (Mohammad Kabat) [2112947]
- net/mlx5: Expose the ability to point to any UID from shared UID (Mohammad Kabat) [2112947]
- net/mlx5e: Remove the duplicating check for striding RQ when enabling LRO (Mohammad Kabat) [2112947]
- net/mlx5e: Move the LRO-XSK check to mlx5e_fix_features (Mohammad Kabat) [2112947]
- net/mlx5e: Extend flower police validation (Mohammad Kabat) [2112947]
- net/mlx5e: configure meter in flow action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Removed useless code in function (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, implement QinQ support (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, implement infrastructure for VLAN protocol change (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, extract VLAN push/pop actions creation (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, rename filter fg to vlan_filter (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, refactor groups sizes and indices (Mohammad Kabat) [2112947]
- net/mlx5: debugfs, Add num of in-use FW command interface slots (Mohammad Kabat) [2112947]
- net/mlx5: Expose vnic diagnostic counters for eswitch managed vports (Mohammad Kabat) [2049884 2112947]
- net/mlx5: Use software VHCA id when it's supported (Mohammad Kabat) [2112947]
- net/mlx5: Introduce ifc bits for using software vhca id (Mohammad Kabat) [2112947]
- net/mlx5: Use the bitmap API to allocate bitmaps (Mohammad Kabat) [2112947]
- net/mlx5: fix 32bit build (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: TC, Support offloading police action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add flow_action to parse state (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add post meter table for flow metering (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add generic macros to use metadata register mapping (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Get or put meter by the index of tc police action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add support to modify hardware flow meter parameters (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Prepare for flow meter offload if hardware supports it (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Implement interfaces to control ASO SQ and CQ (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Add support to create SQ and CQ for ASO (Mohammad Kabat) [2049629 2112947]
- net/mlx5: delete dead code in mlx5_esw_unlock() (Mohammad Kabat) [2112947]
- net/mlx5: Delete ipsec_fs header file as not used (Mohammad Kabat) [2112947]
- net/mlx5: Add bits and fields to support enhanced CQE compression (Mohammad Kabat) [2112947]
- net/mlx5: Remove not used MLX5_CAP_BITS_RW_MASK (Mohammad Kabat) [2112947]
- net/mlx5: group fdb cleanup to single function (Mohammad Kabat) [2112947]
- net/mlx5: Add support EXECUTE_ASO action for flow entry (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Add HW definitions of vport debug counters (Mohammad Kabat) [2112947]
- net/mlx5: Add IFC bits and enums for flow meter (Mohammad Kabat) [2049629 2112947]
- RDMA/mlx5: Support handling of modify-header pattern ICM area (Mohammad Kabat) [2112947]
- net/mlx5: Manage ICM of type modify-header pattern (Mohammad Kabat) [2112947]
- net/mlx5: Introduce header-modify-pattern ICM properties (Mohammad Kabat) [2112947]
- RDMA/mlx5: Add a umr recovery flow (Mohammad Kabat) [2112947]
- mlx5: support BIG TCP packets (Mohammad Kabat) [2112947]
- fortify: Provide a memcpy trap door for sharp corners (Mohammad Kabat) [2112947]
- net/mlx5e: Use XFRM state direction instead of flags (Mohammad Kabat) [2112947]

* Thu Feb 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-256.el9]
- KVM: arm64: Work out supported block level at compile time (Cornelia Huck) [2128973]
- KVM: arm64: Limit stage2_apply_range() batch size to largest block (Cornelia Huck) [2128973]
- KVM: arm64: selftests: Fix multiple versions of GIC creation (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Fix build with profile optimization (Cornelia Huck) [2128973]
- KVM: arm64: Preserve PSTATE.SS for the guest while single-step is enabled (Cornelia Huck) [2128973]
- KVM: arm64: Clear PSTATE.SS when the Software Step state was Active-pending (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Fix exit condition in scan_its_table() (Cornelia Huck) [2128973]
- KVM: arm64: Use correct accessor to parse stage-1 PTEs (Cornelia Huck) [2128973]
- KVM: arm64: Fix bad dereference on MTE-enabled systems (Cornelia Huck) [2128973]
- KVM: arm64: Fix SMPRI_EL1/TPIDR2_EL0 trapping on VHE (Cornelia Huck) [2128973]
- Documentation: Fix index.rst after psci.rst renaming (Cornelia Huck) [2128973]
- KVM: selftests: Gracefully handle empty stack traces (Cornelia Huck) [2128973]
- KVM: arm64: Use kmemleak_free_part_phys() to unregister hyp_mem_base (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM header from the kernel sources (Cornelia Huck) [2128973]
- KVM: arm64: Reject 32bit user PSTATE on asymmetric systems (Cornelia Huck) [2128973]
- KVM: arm64: Treat PMCR_EL1.LC as RES1 on asymmetric systems (Cornelia Huck) [2128973]
- KVM: arm64: Fix compile error due to sign extension (Cornelia Huck) [2128973]
- KVM: arm64: Don't open code ARRAY_SIZE() (Cornelia Huck) [2128973]
- KVM: arm64: Move nVHE-only helpers into kvm/stacktrace.c (Cornelia Huck) [2128973]
- KVM: arm64: Make unwind()/on_accessible_stack() per-unwinder functions (Cornelia Huck) [2128973]
- KVM: arm64: Move nVHE stacktrace unwinding into its own compilation unit (Cornelia Huck) [2128973]
- KVM: arm64: Move PROTECTED_NVHE_STACKTRACE around (Cornelia Huck) [2128973]
- KVM: arm64: Introduce pkvm_dump_backtrace() (Cornelia Huck) [2128973]
- KVM: arm64: Implement protected nVHE hyp stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Save protected-nVHE (pKVM) hyp stacktrace (Cornelia Huck) [2128973]
- KVM: arm64: Stub implementation of pKVM HYP stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Allocate shared pKVM hyp stacktrace buffers (Cornelia Huck) [2128973]
- KVM: arm64: Add PROTECTED_NVHE_STACKTRACE Kconfig (Cornelia Huck) [2128973]
- KVM: arm64: Introduce hyp_dump_backtrace() (Cornelia Huck) [2128973]
- KVM: arm64: Implement non-protected nVHE hyp stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Prepare non-protected nVHE hypervisor stacktrace (Cornelia Huck) [2128973]
- KVM: arm64: Stub implementation of non-protected nVHE HYP stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: On stack overflow switch to hyp overflow_stack (Cornelia Huck) [2128973]
- arm64: stacktrace: Add description of stacktrace/common.h (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out common unwind() (Cornelia Huck) [2128973]
- arm64: stacktrace: Handle frame pointer from different address spaces (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out unwind_next_common() (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out on_accessible_stack_common() (Cornelia Huck) [2128973]
- arm64: stacktrace: Add shared header for common stack unwinding code (Cornelia Huck) [2128973]
- arm64: Copy the task argument to unwind_state (Cornelia Huck) [2128973]
- arm64: Split unwind_init() (Cornelia Huck) [2128973]
- arm64: stacktrace: use non-atomic __set_bit (Cornelia Huck) [2128973]
- arm64: kasan: do not instrument stacktrace.c (Cornelia Huck) [2128973]
- KVM: arm64: Get rid or outdated comments (Cornelia Huck) [2128973]
- KVM: arm64: Descope kvm_arm_sys_reg_{get,set}_reg() (Cornelia Huck) [2128973]
- KVM: arm64: Get rid of find_reg_by_id() (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Tidy-up calls to vgic_{get,set}_common_attr() (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Consolidate userspace access for base address setting (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v2: Add helper for legacy dist/cpuif base address setting (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Use {get,put}_user() instead of copy_{from.to}_user (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v2: Consolidate userspace access for MMIO registers (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Consolidate userspace access for MMIO registers (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Use u32 to manage the line level from userspace (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Convert userspace accessors over to FIELD_GET/FIELD_PREP (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Make the userspace accessors use sysreg API (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Push user access into vgic_v3_cpu_sysregs_uaccess() (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Simplify vgic_v3_has_cpu_sysregs_attr() (Cornelia Huck) [2128973]
- KVM: arm64: Get rid of reg_from/to_user() (Cornelia Huck) [2128973]
- KVM: arm64: Consolidate sysreg userspace accesses (Cornelia Huck) [2128973]
- KVM: arm64: Rely on index_to_param() for size checks on userspace access (Cornelia Huck) [2128973]
- KVM: arm64: Introduce generic get_user/set_user helpers for system registers (Cornelia Huck) [2128973]
- KVM: arm64: Reorder handling of invariant sysregs from userspace (Cornelia Huck) [2128973]
- KVM: arm64: Add get_reg_by_id() as a sys_reg_desc retrieving helper (Cornelia Huck) [2128973]
- KVM: arm64: Fix hypervisor address symbolization (Cornelia Huck) [2128973]
- KVM: arm64: selftests: Add support for GICv2 on v3 (Cornelia Huck) [2128973]
- KVM: arm64: Don't return from void function (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Add intermediates to 'targets' instead of extra-y (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Rename confusing obj-y (Cornelia Huck) [2128973]
- KVM: arm64: Move the handling of !FP outside of the fast path (Cornelia Huck) [2128973]
- KVM: arm64: Document why pause cannot be turned into a flag (Cornelia Huck) [2128973]
- KVM: arm64: Reduce the size of the vcpu flag members (Cornelia Huck) [2128973]
- KVM: arm64: Add build-time sanity checks for flags (Cornelia Huck) [2128973]
- KVM: arm64: Warn when PENDING_EXCEPTION and INCREMENT_PC are set together (Cornelia Huck) [2128973]
- KVM: arm64: Convert vcpu sysregs_loaded_on_cpu to a state flag (Cornelia Huck) [2128973]
- KVM: arm64: Kill unused vcpu flags field (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu WFIT flag to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu ON_UNSUPPORTED_CPU flag to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu SVE/SME flags to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu debug/SPE/TRBE flags to the input flag set (Cornelia Huck) [2128973]
- KVM: arm64: Add a flag to disable MMIO trace for nVHE KVM (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu PC/Exception flags to the input flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu configuration flags into their own set (Cornelia Huck) [2128973]
- KVM: arm64: Add three sets of flags to the vcpu state (Cornelia Huck) [2128973]
- KVM: arm64: Add helpers to manipulate vcpu flags among a set (Cornelia Huck) [2128973]
- KVM: arm64: Move FP state ownership from flag to a tristate (Cornelia Huck) [2128973]
- KVM: arm64: Drop FP_FOREIGN_STATE from the hypervisor code (Cornelia Huck) [2128973]
- KVM: arm64: Prevent kmemleak from accessing pKVM memory (Cornelia Huck) [2128973]
- KVM: arm64: Drop stale comment (Cornelia Huck) [2128973]
- KVM: arm64: Remove redundant hyp_assert_lock_held() assertions (Cornelia Huck) [2128973]
- KVM: arm64: Extend comment in has_vhe() (Cornelia Huck) [2128973]
- KVM: arm64: Ignore 'kvm-arm.mode=protected' when using VHE (Cornelia Huck) [2128973]
- KVM: arm64: Handle all ID registers trapped for a protected VM (Cornelia Huck) [2128973]
- KVM: arm64: Return error from kvm_arch_init_vm() on allocation failure (Cornelia Huck) [2128973]
- KVM: arm64: Fix inconsistent indenting (Cornelia Huck) [2128973]
- KVM: arm64: Always start with clearing SME flag on load (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Undo work in failed ITS restores (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Do not ignore vgic_its_restore_cte failures (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Add more checks when restoring ITS tables (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Check that new ITEs could be saved in guest memory (Cornelia Huck) [2128973]
- KVM: arm64: pmu: Restore compilation when HW_PERF_EVENTS isn't selected (Cornelia Huck) [2128973]
- KVM: arm64: Hide KVM_REG_ARM_*_BMAP_BIT_COUNT from userspace (Cornelia Huck) [2128973]
- KVM: arm64: Reenable pmu in Protected Mode (Cornelia Huck) [2128973]
- KVM: arm64: Pass pmu events to hyp via vcpu (Cornelia Huck) [2128973]
- KVM: arm64: Repack struct kvm_pmu to reduce size (Cornelia Huck) [2128973]
- KVM: arm64: Wrapper for getting pmu_events (Cornelia Huck) [2128973]
- KVM: arm64: pkvm: Don't mask already zeroed FEAT_SVE (Cornelia Huck) [2128973]
- KVM: arm64: pkvm: Drop unnecessary FP/SIMD trap handler (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Eliminate kernel-doc warnings (Cornelia Huck) [2128973]
- KVM: arm64: Avoid unnecessary absolute addressing via literals (Cornelia Huck) [2128973]
- KVM: arm64: Print emulated register table name when it is unsorted (Cornelia Huck) [2128973]
- KVM: arm64: Don't BUG_ON() if emulated register table is unsorted (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Advertise GICR_CTLR.{IR, CES} as a new GICD_IIDR revision (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Implement MMIO-based LPI invalidation (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Expose GICR_CTLR.RWP when disabling LPIs (Cornelia Huck) [2128973]
- KVM: arm64: Fix new instances of 32bit ESRs (Cornelia Huck) [2128973]
- KVM: arm64: Hide AArch32 PMU registers when not available (Cornelia Huck) [2128973]
- KVM: arm64: Start trapping ID registers for 32 bit guests (Cornelia Huck) [2128973]
- KVM: arm64: Plumb cp10 ID traps through the AArch64 sysreg handler (Cornelia Huck) [2128973]
- KVM: arm64: Wire up CP15 feature registers to their AArch64 equivalents (Cornelia Huck) [2128973]
- KVM: arm64: Don't write to Rt unless sys_reg emulation succeeds (Cornelia Huck) [2128973]
- KVM: arm64: Return a bool from emulate_cp() (Cornelia Huck) [2128973]
- KVM: arm64: uapi: Add kvm_debug_exit_arch.hsr_high (Cornelia Huck) [2128973]
- KVM: arm64: Treat ESR_EL2 as a 64-bit register (Cornelia Huck) [2128973]
- KVM: arm64: Symbolize the nVHE HYP addresses (Cornelia Huck) [2128973]
- KVM: arm64: Detect and handle hypervisor stack overflows (Cornelia Huck) [2128973]
- KVM: arm64: Add guard pages for pKVM (protected nVHE) hypervisor stack (Cornelia Huck) [2128973]
- KVM: arm64: Add guard pages for KVM nVHE hypervisor stack (Cornelia Huck) [2128973]
- KVM: arm64: Introduce pkvm_alloc_private_va_range() (Cornelia Huck) [2128973]
- KVM: arm64: Introduce hyp_alloc_private_va_range() (Cornelia Huck) [2128973]
- KVM: arm64: Handle SME host state when running guests (Cornelia Huck) [2128973]
- KVM: arm64: Trap SME usage in guest (Cornelia Huck) [2128973]
- KVM: arm64: Hide SME system registers from guests (Cornelia Huck) [2128973]
- KVM: arm64: Expose the WFXT feature to guests (Cornelia Huck) [2128973]
- KVM: arm64: Offer early resume for non-blocking WFxT instructions (Cornelia Huck) [2128973]
- KVM: arm64: Handle blocking WFIT instruction (Cornelia Huck) [2128973]
- KVM: arm64: Introduce kvm_counter_compute_delta() helper (Cornelia Huck) [2128973]
- KVM: arm64: Simplify kvm_cpu_has_pending_timer() (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Cornelia Huck) [2128973]

* Thu Feb 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-255.el9]
- can: kvaser_usb: kvaser_usb_set_bittiming(): fix redundant initialization warning for err (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_set_{,data}bittiming(): remove empty lines in variable declaration (Al Stone) [2071839]
- can: af_can: can_exit(): add missing dev_remove_pack() of canxl_packet (Al Stone) [2071839]
- can: can327: flush TX_work on ldisc .close() (Al Stone) [2071839]
- can: slcan: fix freed work crash (Al Stone) [2071839]
- can: can327: can327_feed_frame_to_netdev(): fix potential skb leak when netdev is down (Al Stone) [2071839]
- can: dev: fix skb drop check (Al Stone) [2071839]
- can: kvaser_usb: Compare requested bittiming parameters with actual parameters in do_set_{,data}_bittiming (Al Stone) [2071839]
- can: kvaser_usb: Add struct kvaser_usb_busparams (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix bogus restart events (Al Stone) [2071839]
- can: kvaser_usb_leaf: Ignore stale bus-off after start (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix wrong CAN state after stopping (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix improved state not being reported (Al Stone) [2071839]
- can: kvaser_usb_leaf: Set Warning state even without bus errors (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Handle CMD_ERROR_EVENT (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Rename {leaf,usbcan}_cmd_error_event to {leaf,usbcan}_cmd_can_error_event (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Get capabilities from device (Al Stone) [2071839]
- can: remove obsolete PCH CAN driver (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix CAN state after restart (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix TX queue out of sync after restart (Al Stone) [2071839]
- can: kvaser_usb: Fix use of uninitialized completion (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix overread with an invalid command (Al Stone) [2071839]
- can: gs_usb: gs_can_open(): initialize time counter before starting device (Al Stone) [2071839]
- can: gs_usb: add missing lock to protect struct timecounter::cycle_last (Al Stone) [2071839]
- can: gs_usb: gs_usb_get_timestamp(): fix endpoint parameter for usb_control_msg_recv() (Al Stone) [2071839]
- can: gs_usb: gs_usb_set_phys_id(): return with error if identify is not supported (Al Stone) [2071839]
- can: gs_usb: gs_can_open(): fix race dev->can.state condition (Al Stone) [2071839]
- can: canxl: update CAN infrastructure for CAN XL frames (Al Stone) [2071839]
- can: dev: add CAN XL support to virtual CAN (Al Stone) [2071839]
- can: canxl: introduce CAN XL data structure (Al Stone) [2071839]
- can: skb: add skb CAN frame data length helpers (Al Stone) [2071839]
- can: set CANFD_FDF flag in all CAN FD frame structures (Al Stone) [2071839]
- can: skb: unify skb CAN frame identification helpers (Al Stone) [2071839]
- can: gs_usb: add RX and TX hardware timestamp support (Al Stone) [2071839]
- rhel: Set initial defaults for CAN configs (Al Stone) [2071839]
- can: rcar_canfd: Add missing ECC error checks for channels 2-7 (Al Stone) [2071839]
- can: gs_usb: use common spelling of GS_USB in macros (Al Stone) [2071839]
- can: flexcan: fix typo: FLEXCAN_QUIRK_SUPPPORT_* -> FLEXCAN_QUIRK_SUPPORT_* (Al Stone) [2071839]
- can: rcar_canfd: fix channel specific IRQ handling for (Al Stone) [2071839]
- can: c_can: don't cache TX messages for C_CAN cores (Al Stone) [2071839]
- can: flexcan: flexcan_mailbox_read() fix return value for drop = true (Al Stone) [2071839]
- can: mcp251x: Fix race condition on receive interrupt (Al Stone) [2071839]
- can: ems_usb: fix clang's -Wunaligned-access warning (Al Stone) [2071839]
- can: can327: fix a broken link to Documentation (Al Stone) [2071839]
- can: etas_es58x: remove useless calls to usb_fill_bulk_urb() (Al Stone) [2071839]
- can: peak_usb: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: peak_canfd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: kvaser_usb: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: kvaser_pciefd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: etas_es58x: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: mcp251xfd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: dev: add generic function can_eth_ioctl_hwts() (Al Stone) [2071839]
- can: dev: add generic function can_ethtool_op_get_ts_info_hwts() (Al Stone) [2071839]
- can: dev: add hardware TX timestamp (Al Stone) [2071839]
- can: tree-wide: advertise software timestamping capabilities (Al Stone) [2071839]
- can: v(x)can: add software tx timestamps (Al Stone) [2071839]
- can: slcan: add software tx timestamps (Al Stone) [2071839]
- can: janz-ican3: add software tx timestamp (Al Stone) [2071839]
- can: can327: add software tx timestamps (Al Stone) [2071839]
- MAINTAINERS: Add maintainer for the slcan driver (Al Stone) [2071839]
- can: slcan: add support for listen-only mode (Al Stone) [2071839]
- can: slcan: use the generic can_change_mtu() (Al Stone) [2071839]
- can: slcan: change every `slc' occurrence in `slcan' (Al Stone) [2071839]
- can: slcan: remove legacy infrastructure (Al Stone) [2071839]
- can: slcan: remove useless header inclusions (Al Stone) [2071839]
- can: slcan: use KBUILD_MODNAME and define pr_fmt to replace hardcoded names (Al Stone) [2071839]
- can: flexcan: export flexcan_ethtool_ops and remove flexcan_set_ethtool_ops() (Al Stone) [2071839]
- can: c_can: export c_can_ethtool_ops and remove c_can_set_ethtool_ops() (Al Stone) [2071839]
- can: slcan: export slcan_ethtool_ops and remove slcan_set_ethtool_ops() (Al Stone) [2071839]
- can: etas_es58x: remove DRV_VERSION (Al Stone) [2071839]
- can: etas_es58x: replace ES58X_MODULE_NAME with KBUILD_MODNAME (Al Stone) [2071839]
- can: ubs_8dev: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: kvaser_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: gs_ubs: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: esd_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: softing: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: ems_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: can327: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_dump(): fix comment (Al Stone) [2071839]
- can: pch_can: pch_can_error(): initialize errc before using it (Al Stone) [2071839]
- can: rcar_canfd: Add missing of_node_put() in rcar_canfd_probe() (Al Stone) [2071839]
- can: mcp251xfd: fix detection of mcp251863 (Al Stone) [2071839]
- can: add CAN_ERR_CNT flag to notify availability of error counter (Al Stone) [2071839]
- can: usb_8dev: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: kvaser_usb_leaf: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: kvaser_usb_hydra: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: sun4i_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: hi311x: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: slcan: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: sja1000: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: rcar_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: pch_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: peak_usb: include support for a new MCU (Al Stone) [2071839]
- can: peak_usb: correction of an initially misnamed field name (Al Stone) [2071839]
- can: peak_usb: pcan_dump_mem(): mark input prompt and data pointer as const (Al Stone) [2071839]
- can: ctucanfd: Update CTU CAN FD IP core registers to match version 3.x. (Al Stone) [2071839]
- can: c_can: remove wrong comment (Al Stone) [2071839]
- can: slcan: do not sleep with a spin lock held (Al Stone) [2071839]
- can: sja1000: Change the return type as void for SoC specific init (Al Stone) [2071839]
- can: sja1000: Use device_get_match_data to get device data (Al Stone) [2071839]
- can: sja1000: Add Quirk for RZ/N1 SJA1000 CAN controller (Al Stone) [2071839]
- can: slcan: clean up if/else (Al Stone) [2071839]
- can: slcan: convert comparison to NULL into !val (Al Stone) [2071839]
- can: slcan: fix whitespace issues (Al Stone) [2071839]
- can: slcan: slcan_init() convert printk(LEVEL ...) to pr_level() (Al Stone) [2071839]
- can: slcan: convert comments to network style comments (Al Stone) [2071839]
- can: slcan: use scnprintf() as a hardening measure (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix endianness conversion (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): use correct length to read dev_id (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_stop(): add missing hrtimer_cancel() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): update workaround broken CRC on TBC register (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): improve workaround handling for mcp2517fd (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: fix bittiming limits (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: fix CAN clock frequency regression (Al Stone) [2071839]
- can: kvaser_usb: replace run-time checks with struct kvaser_usb_driver_info (Al Stone) [2071839]
- can: m_can: m_can_{read_fifo,echo_tx_event}(): shift timestamp to full 32 bits (Al Stone) [2071839]
- can: m_can: m_can_chip_config(): actually enable internal timestamping (Al Stone) [2071839]
- can: grcan: grcan_probe(): remove extra of_node_get() (Al Stone) [2071839]
- can: gs_usb: gs_usb_open/close(): fix memory leak (Al Stone) [2071839]
- can: rcar_canfd: Fix data transmission failed on R-Car V3U (Al Stone) [2071839]
- Revert "can: xilinx_can: Limit CANFD brp to 2" (Al Stone) [2071839]
- can: slcan: extend the protocol with CAN state info (Al Stone) [2071839]
- can: slcan: extend the protocol with error info (Al Stone) [2071839]
- can: slcan: add ethtool support to reset adapter errors (Al Stone) [2071839]
- can: slcan: move driver into separate sub directory (Al Stone) [2071839]
- can: slcan: send the open/close commands to the adapter (Al Stone) [2071839]
- can: slcan: set bitrate by CAN device driver API (Al Stone) [2071839]
- can: slcan: allow to send commands to the adapter (Al Stone) [2071839]
- can: slcan: use CAN network device driver API (Al Stone) [2071839]
- can: netlink: dump bitrate 0 if can_priv::bittiming.bitrate is -1U (Al Stone) [2071839]
- can: slcan: use the alloc_can_skb() helper (Al Stone) [2071839]
- can: slcan: use netdev helpers to print out messages (Al Stone) [2071839]
- can: slcan: use the BIT() helper (Al Stone) [2071839]
- can: ctucanfd: ctucan_interrupt(): fix typo (Al Stone) [2071839]
- can: can327: CAN/ldisc driver for ELM327 based OBD-II adapters (Al Stone) [2071839]
- docs: networking: device drivers: can: add ctucanfd to index (Al Stone) [2071839]
- docs: networking: device drivers: can: add flexcan (Al Stone) [2071839]
- docs: networking: device drivers: add can sub-folder (Al Stone) [2071839]
- can/esd_usb: Update to copyright, M_AUTHOR and M_DESCRIPTION (Al Stone) [2071839]
- can/esd_usb: Fixed some checkpatch.pl warnings (Al Stone) [2071839]
- can/esd_usb: Rename all terms USB2 to USB (Al Stone) [2071839]
- can/esd_usb2: Rename esd_usb2.c to esd_usb.c (Al Stone) [2071839]
- powerpc/mpc5xxx: Switch mpc5xxx_get_bus_frequency() to use fwnode (Al Stone) [2071839]
- can: netlink: allow configuring of fixed data bit rates without need for do_set_data_bittiming callback (Al Stone) [2071839]
- can: etas_es58x: fix signedness of USB RX and TX pipes (Al Stone) [2071839]
- can: etas_es58x: replace es58x_device::rx_max_packet_size by usb_maxpacket() (Al Stone) [2071839]
- can: skb: drop tx skb if in listen only mode (Al Stone) [2071839]
- can: skb: move can_dropped_invalid_skb() and can_skb_headroom_valid() to skb.c (Al Stone) [2071839]
- net: Kconfig: move the CAN device menu to the "Device Drivers" section (Al Stone) [2071839]
- can: Kconfig: add CONFIG_CAN_RX_OFFLOAD (Al Stone) [2071839]
- can: bittiming: move bittiming calculation functions to calc_bittiming.c (Al Stone) [2071839]
- can: Kconfig: turn menu "CAN Device Drivers" into a menuconfig using CAN_DEV (Al Stone) [2071839]
- can: Kconfig: rename config symbol CAN_DEV into CAN_NETLINK (Al Stone) [2071839]
- can: netlink: allow configuring of fixed bit rates without need for do_set_bittiming callback (Al Stone) [2071839]
- can: m_can: fix typo prescalar -> prescaler (Al Stone) [2071839]
- can: xilinx_can: fix typo prescalar -> prescaler (Al Stone) [2071839]
- can: xilinx_can: add Transmitter Delay Compensation (TDC) feature support (Al Stone) [2071839]
- can: ctucanfd: platform: add missing dependency to HAS_IOMEM (Al Stone) [2071839]
- can: kvaser_usb: silence a GCC 12 -Warray-bounds warning (Al Stone) [2071839]
- can: peak_usb: fix typo in comment (Al Stone) [2071839]
- can: mcp251xfd: silence clang's -Wunaligned-access warning (Al Stone) [2071839]
- can: can-dev: remove obsolete CAN LED support (Al Stone) [2071839]
- can: do not increase tx_bytes statistics for RTR frames (Al Stone) [2071839]
- can: do not increase rx_bytes statistics for RTR frames (Al Stone) [2071839]
- can: do not increase rx statistics when generating a CAN rx error message frame (Al Stone) [2071839]
- can: dev: reorder struct can_priv members for better packing (Al Stone) [2071839]
- can: can-dev: move to netif_napi_add_weight() (Al Stone) [2071839]
- can: slcan: slc_xmit(): use can_dropped_invalid_skb() instead of manual check (Al Stone) [2071839]
- can: ctucanfd: Let users select instead of depend on CAN_CTUCANFD (Al Stone) [2071839]
- can: m_can: remove support for custom bit timing, take #2 (Al Stone) [2071839]
- Revert "can: m_can: pci: use custom bit timings for Elkhart Lake" (Al Stone) [2071839]
- can: ctucanfd: remove PCI module debug parameters (Al Stone) [2071839]
- can: ctucanfd: remove debug statements (Al Stone) [2071839]
- can: ctucanfd: remove inline keyword from local static functions (Al Stone) [2071839]
- can: ctucanfd: ctucan_platform_probe(): remove unnecessary print function dev_err() (Al Stone) [2071839]
- can: ctucanfd: remove unused including <linux/version.h> (Al Stone) [2071839]
- can: grcan: only use the NAPI poll budget for RX (Al Stone) [2071839]
- can: grcan: grcan_probe(): fix broken system id check for errata workaround needs (Al Stone) [2071839]
- can: grcan: use ofdev->dev when allocating DMA memory (Al Stone) [2071839]
- can: grcan: grcan_close(): fix deadlock (Al Stone) [2071839]
- can: ctucanfd: CTU CAN FD open-source IP core - platform/SoC support. (Al Stone) [2071839]
- can: ctucanfd: CTU CAN FD open-source IP core - PCI bus support. (Al Stone) [2071839]
- can: ctucanfd: add support for CTU CAN FD open-source IP core - bus independent part. (Al Stone) [2071839]
- can: mcp251xfd: add support for mcp251863 (Al Stone) [2071839]
- can: xilinx_can: mark bit timing constants as const (Al Stone) [2071839]
- can: flexcan: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: Prepare cleanup of powerpc's asm/prom.h (Al Stone) [2071839]
- can: Fix Links to Technologic Systems web resources (Al Stone) [2071839]
- can: bittiming: can_calc_bittiming(): prefer small bit rate pre-scalers over larger ones (Al Stone) [2071839]
- can: rx-offload: rename can_rx_offload_queue_sorted() -> can_rx_offload_queue_timestamp() (Al Stone) [2071839]
- can: gs_usb: gs_make_candev(): fix memory leak for devices with extended bit timing configuration (Al Stone) [2071839]
- can: mcba_usb: properly check endpoint type (Al Stone) [2071839]
- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb in error path (Al Stone) [2071839]
- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb() in error path (Al Stone) [2071839]
- can: m_can: m_can_tx_handler(): fix use after free of skb (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix return of error value (Al Stone) [2071839]
- can: ucan: fix typos in comments (Al Stone) [2071839]
- can: mcp251xfd: ring: increase number of RX-FIFOs to 3 and increase max TX-FIFO depth to 16 (Al Stone) [2071839]
- can: mcp251xfd: add TX IRQ coalescing ethtool support (Al Stone) [2071839]
- can: mcp251xfd: add TX IRQ coalescing support (Al Stone) [2071839]
- can: mcp251xfd: add RX IRQ coalescing ethtool support (Al Stone) [2071839]
- can: mcp251xfd: add RX IRQ coalescing support (Al Stone) [2071839]
- can: mcp251xfd: ring: add support for runtime configurable RX/TX ring parameters (Al Stone) [2071839]
- can: mcp251xfd: update macros describing ring, FIFO and RAM layout (Al Stone) [2071839]
- can: mcp251xfd: ring: prepare support for runtime configurable RX/TX ring parameters (Al Stone) [2071839]
- can: mcp251xfd: ethtool: add support (Al Stone) [2071839]
- can: mcp251xfd: ram: coalescing support (Al Stone) [2071839]
- can: mcp251xfd: ram: add helper function for runtime ring size calculation (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_ring_init(): use %%d to print free RAM (Al Stone) [2071839]
- can: vxcan: vxcan_xmit(): use kfree_skb() instead of kfree() to free skb (Al Stone) [2071839]
- can: gs_usb: add VID/PID for ABE CAN Debugger devices (Al Stone) [2071839]
- can: gs_usb: add VID/PID for CES CANext FD devices (Al Stone) [2071839]
- can: gs_usb: add extended bt_const feature (Al Stone) [2071839]
- can: gs_usb: activate quirks for CANtact Pro unconditionally (Al Stone) [2071839]
- can: gs_usb: add quirk for CANtact Pro overlapping GS_USB_BREQ value (Al Stone) [2071839]
- can: gs_usb: add usb quirk for NXP LPC546xx controllers (Al Stone) [2071839]
- can: gs_usb: add CAN-FD support (Al Stone) [2071839]
- can: gs_usb: use union and FLEX_ARRAY for data in struct gs_host_frame (Al Stone) [2071839]
- can: gs_usb: support up to 3 channels per device (Al Stone) [2071839]
- can: gs_usb: gs_usb_probe(): introduce udev and make use of it (Al Stone) [2071839]
- can: gs_usb: document the PAD_PKTS_TO_MAX_PKT_SIZE feature (Al Stone) [2071839]
- can: gs_usb: document the USER_ID feature (Al Stone) [2071839]
- can: gs_usb: update GS_CAN_FEATURE_IDENTIFY documentation (Al Stone) [2071839]
- can: gs_usb: add HW timestamp mode bit (Al Stone) [2071839]
- can: gs_usb: gs_make_candev(): call SET_NETDEV_DEV() after handling all bt_const->feature (Al Stone) [2071839]
- can: gs_usb: rewrap usb_control_msg() and usb_fill_bulk_urb() (Al Stone) [2071839]
- can: gs_usb: rewrap error messages (Al Stone) [2071839]
- can: gs_usb: GS_CAN_FLAG_OVERFLOW: make use of BIT() (Al Stone) [2071839]
- can: gs_usb: sort include files alphabetically (Al Stone) [2071839]
- can: gs_usb: fix checkpatch warning (Al Stone) [2071839]
- can: gs_usb: use consistent one space indention (Al Stone) [2071839]
- can: rcar_canfd: Add support for r8a779a0 SoC (Al Stone) [2071839]
- can: etas_es58x: es58x_fd_rx_event_msg(): initialize rx_event_msg before calling es58x_check_msg_len() (Al Stone) [2071839]
- vxcan: enable local echo for sent CAN frames (Al Stone) [2071839]
- vxcan: remove sk reference in peer skb (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_channel_probe(): register the CAN device when fully ready (Al Stone) [2071839]
- can: gs_usb: change active_channels's type from atomic_t to u8 (Al Stone) [2071839]
- can: etas_es58x: change opened_channel_cnt's type from atomic_t to u8 (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_priv: introduce macros specifying the number of supported TEF/RX/TX rings (Al Stone) [2071839]
- can: mcp251xfd: prepare for multiple RX-FIFOs (Al Stone) [2071839]
- can: mcp251xfd: ring: update FIFO setup debug info (Al Stone) [2071839]
- can: mcp251xfd: ring: mcp251xfd_ring_init(): checked RAM usage of ring setup (Al Stone) [2071839]
- can: mcp251xfd: ring: change order of TX and RX FIFOs (Al Stone) [2071839]
- can: mcp251xfd: ring: prepare to change order of TX and RX FIFOs (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_ring_init(): split ring_init into separate functions (Al Stone) [2071839]
- can: mcp251xfd: introduce struct mcp251xfd_tx_ring::nr and ::fifo_nr and make use of it (Al Stone) [2071839]
- can: mcp251xfd: add support for internal PLL (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register(): prepare to activate PLL after softreset (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_clock_init(): prepare for PLL support, wait for OSC ready (Al Stone) [2071839]
- can: mcp251xfd: __mcp251xfd_chip_set_mode(): prepare for PLL support: improve error handling and diagnostics (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wake(): renamed from mcp251xfd_chip_clock_enable() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_timestamp_init(): factor out into separate function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_softreset_check(): wait for OSC ready before accessing chip (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): prepare for PLL support (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): improve chip detection and error handling (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): factor out into separate function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_stop(): convert to a void function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_sleep(): introduce function to bring chip into sleep mode (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_unregister(): simplify runtime PM handling (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): ignore CRC error only if solely OSC register is read (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_reg_invalid(): rename from mcp251xfd_osc_invalid() (Al Stone) [2071839]
- can: etas_es58x: use BITS_PER_TYPE() instead of manual calculation (Al Stone) [2071839]
- can: xilinx_can: Add check for NAPI Poll function (Al Stone) [2071839]
- can: softing: softing_netdev_open(): remove redundant ret variable (Al Stone) [2071839]
- can: c_can: ethtool: use default drvinfo (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_send_cmd(): remove redundant variable actual_len (Al Stone) [2071839]
- can: bittiming: mark function arguments and local variables as const (Al Stone) [2071839]
- can: bittiming: can_validate_bitrate(): simplify bit rate checking (Al Stone) [2071839]
- can: flexcan: mark RX via mailboxes as supported on MCF5441X (Al Stone) [2071839]
- can: tcan4x5x: regmap: fix max register value (Al Stone) [2071839]
- can: m_can: m_can_fifo_{read,write}: don't read or write from/to FIFO if length is 0 (Al Stone) [2071839]
- can: gs_usb: gs_can_start_xmit(): zero-initialize hf->{flags,reserved} (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_channel_probe(): make sure we free CAN network device (Al Stone) [2071839]
- can: xilinx_can: xcan_probe(): check for error irq (Al Stone) [2071839]
- can: softing: softing_startstop(): fix set but not used variable warning (Al Stone) [2071839]
- can: softing_cs: softingcs_probe(): fix memleak on registration failure (Al Stone) [2071839]
- can: flexcan: add ethtool support to get rx/tx ring parameters (Al Stone) [2071839]
- can: flexcan: add ethtool support to change rx-rtr setting during runtime (Al Stone) [2071839]
- can: flexcan: add more quirks to describe RX path capabilities (Al Stone) [2071839]
- can: flexcan: rename RX modes (Al Stone) [2071839]
- can: flexcan: allow to change quirks at runtime (Al Stone) [2071839]
- can: flexcan: move driver into separate sub directory (Al Stone) [2071839]
- can: mcp251xfd: introduce and make use of mcp251xfd_is_fd_mode() (Al Stone) [2071839]
- can: mcp251xfd: move ring init into separate function (Al Stone) [2071839]
- can: mcp251xfd: move chip FIFO init into separate file (Al Stone) [2071839]
- can: mcp251xfd: move TEF handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: move TX handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: move RX handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd.h: sort function prototypes (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_handle_rxovif(): denote RX overflow message to debug + add rate limiting (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): make use of pm_runtime_resume_and_get() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): open_candev() first (Al Stone) [2071839]
- can: mcp251xfd: add missing newline to printed strings (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_tef_obj_read(): fix typo in error message (Al Stone) [2071839]
- can: mcp251xfd: remove double blank lines (Al Stone) [2071839]
- can: janz-ican3: initialize dlc variable (Al Stone) [2071839]
- can: gs_usb: fix use of uninitialized variable, detach device on reception of invalid USB data (Al Stone) [2071839]
- can: netlink: report the CAN controller mode supported flags (Al Stone) [2071839]
- can: dev: add sanity check in can_set_static_ctrlmode() (Al Stone) [2071839]
- can: dev: replace can_priv::ctrlmode_static by can_get_static_ctrlmode() (Al Stone) [2071839]
- can: dev: add can_tdc_get_relative_tdco() helper function (Al Stone) [2071839]
- can: do not copy the payload of RTR frames (Al Stone) [2071839]
- can: kvaser_usb: do not increase tx statistics when sending error message frames (Al Stone) [2071839]
- can: etas_es58x: es58x_init_netdev: populate net_device::dev_port (Al Stone) [2071839]
- can: sja1000: sp_probe(): use platform_get_irq() to get the interrupt (Al Stone) [2071839]
- can: ti_hecc: ti_hecc_probe(): use platform_get_irq() to get the interrupt (Al Stone) [2071839]
- can: kvaser_usb: make use of units.h in assignment of frequency (Al Stone) [2071839]
- can: mcp251x: mcp251x_gpio_setup(): Get rid of duplicate of_node assignment (Al Stone) [2071839]
- can: usb_8dev: remove unused member echo_skb from struct usb_8dev_priv (Al Stone) [2071839]
- can: kvaser_usb: get CAN clock frequency from device (Al Stone) [2071839]
- can: kvaser_pciefd: kvaser_pciefd_rx_error_frame(): increase correct stats->{rx,tx}_errors counter (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): convert to use dev_err_probe() (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): make use of device property API (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): try to get crystal clock rate from property (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): use devm_clk_get_optional() to get the input clock (Al Stone) [2071839]
- can: sun4i_can: add support for R40 CAN controller (Al Stone) [2071839]
- can: bittiming: replace CAN units with the generic ones from linux/units.h (Al Stone) [2071839]
- can: m_can: pci: use custom bit timings for Elkhart Lake (Al Stone) [2071839]
- can: m_can: make custom bittiming fields const (Al Stone) [2071839]
- can: m_can: pci: fix incorrect reference clock rate (Al Stone) [2071839]
- can: m_can: pci: fix iomap_read_fifo() and iomap_write_fifo() (Al Stone) [2071839]
- can: m_can: m_can_read_fifo: fix memory leak in error branch (Al Stone) [2071839]
- can: m_can: Disable and ignore ELO interrupt (Al Stone) [2071839]
- can: sja1000: fix use after free in ems_pcmcia_add_card() (Al Stone) [2071839]
- can: pch_can: pch_can_rx_normal: fix use after free (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_start(): fix error handling for mcp251xfd_chip_rx_int_enable() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_irq(): add missing can_rx_offload_threaded_irq_finish() in case of bus off (Al Stone) [2071839]
- can: peak_usb: exchange the order of information messages (Al Stone) [2071839]
- can: peak_usb: always ask for BERR reporting for PCAN-USB devices (Al Stone) [2071839]
- can: etas_es58x: es58x_rx_err_msg(): fix memory leak in error path (Al Stone) [2071839]
- can: xilinx_can: xcan_remove(): remove redundant netif_napi_del() (Al Stone) [2071839]
- can: xilinx_can: remove repeated word from the kernel-doc (Al Stone) [2071839]
- can: peak_usb: CANFD: store 64-bits hw timestamps (Al Stone) [2071839]
- can: gs_usb: use %%u to print unsigned values (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: Make use of the helper function dev_err_probe() (Al Stone) [2071839]
- can: rcar: drop unneeded ARM dependency (Al Stone) [2071839]
- can: at91/janz-ican3: replace snprintf() in show functions with sysfs_emit() (Al Stone) [2071839]
- can: netlink: add can_priv::do_get_auto_tdcv() to retrieve tdcv from device (Al Stone) [2071839]
- can: netlink: add interface for CAN-FD Transmitter Delay Compensation (TDC) (Al Stone) [2071839]
- can: bittiming: change can_calc_tdco()'s prototype to not directly modify priv (Al Stone) [2071839]
- can: bittiming: change unit of TDC parameters to clock periods (Al Stone) [2071839]
- can: bittiming: allow TDC{V,O} to be zero and add can_tdc_const::tdc{v,o,f}_min (Al Stone) [2071839]
- can: bittiming: fix documentation for struct can_tdc (Al Stone) [2071839]
- can: bittiming: can_fixup_bittiming(): change type of tseg1 and alltseg to unsigned int (Al Stone) [2071839]
- treewide: Replace open-coded flex arrays in unions (Al Stone) [2071839]
- can: peak_usb: pcan_usb_fd_decode_status(): remove unnecessary test on the nullity of a pointer (Al Stone) [2071839]
- can: peak_usb: pcan_usb_fd_decode_status(): fix back to ERROR_ACTIVE state notification (Al Stone) [2071839]
- can: peak_pci: peak_pci_remove(): fix UAF (Al Stone) [2071839]
- can: m_can: fix iomap_read_fifo() and iomap_write_fifo() (Al Stone) [2071839]
- can: rcar_can: fix suspend/resume (Al Stone) [2071839]
- can: flexcan: Use struct_group() to zero struct flexcan_regs regions (Al Stone) [2071839]
- tty: make tty_ldisc_ops::hangup return void (Al Stone) [2071839]
- can: c_can: fix null-ptr-deref on ioctl() (Al Stone) [2071839]
- can: rcar_canfd: add __maybe_unused annotation to silence warning (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: mpc5xxx_can_probe(): remove useless BUG_ON() (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: mpc5xxx_can_probe(): use of_device_get_match_data to simplify code (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_handle_channel_tx(): fix redundant assignment (Al Stone) [2071839]
- can: rcar: Kconfig: Add helper dependency on COMPILE_TEST (Al Stone) [2071839]
- can: c_can: cache frames to operate as a true FIFO (Al Stone) [2071839]
- can: c_can: support tx ring algorithm (Al Stone) [2071839]
- can: c_can: exit c_can_do_tx() early if no frames have been sent (Al Stone) [2071839]
- can: c_can: remove struct c_can_priv::priv field (Al Stone) [2071839]
- can: c_can: rename IF_RX -> IF_NAPI (Al Stone) [2071839]
- can: c_can: c_can_do_tx(): fix typo in comment (Al Stone) [2071839]
- can: m_can: Batch FIFO writes during CAN transmit (Al Stone) [2071839]
- can: m_can: Batch FIFO reads during CAN receive (Al Stone) [2071839]
- can: m_can: Disable IRQs on FIFO bus errors (Al Stone) [2071839]
- can: m_can: fix block comment style (Al Stone) [2071839]
- can: tcan4x5x: cdev_to_priv(): remove stray empty line (Al Stone) [2071839]
- can: rcar_canfd: Add support for RZ/G2L family (Al Stone) [2071839]
- can: mcp251xfd: mark some instances of struct mcp251xfd_priv as const (Al Stone) [2071839]
- can: etas_es58x: clean-up documentation of struct es58x_fd_tx_conf_msg (Al Stone) [2071839]
- can: netlink: allow user to turn off unsupported features (Al Stone) [2071839]
- can: dev: provide optional GPIO based termination support (Al Stone) [2071839]
- can: flexcan: flexcan_clks_enable(): add missing variable initialization (Al Stone) [2071839]
- can: flexcan: update Kconfig to enable coldfire (Al Stone) [2071839]
- can: flexcan: add mcf5441x support (Al Stone) [2071839]
- can: etas_es58x: rewrite the message cast in es58{1,_fd}_tx_can_msg to increase readability (Al Stone) [2071839]
- can: etas_es58x: use sizeof and sizeof_field macros instead of constant values (Al Stone) [2071839]
- can: etas_es58x: add es58x_free_netdevs() to factorize code (Al Stone) [2071839]
- can: etas_es58x: use devm_kzalloc() to allocate device resources (Al Stone) [2071839]
- can: etas_es58x: use error pointer during device probing (Al Stone) [2071839]
- can: etas_es58x: fix three typos in author name and documentation (Al Stone) [2071839]
- can: peak_usb: pcan_usb_decode_error(): upgrade handling of bus state changes (Al Stone) [2071839]
- can: peak_usb: pcan_usb_encode_msg(): add information (Al Stone) [2071839]
- can: peak_usb: PCAN-USB: add support of loopback and one-shot mode (Al Stone) [2071839]
- can: peak_usb: pcan_usb_get_device_id(): read value only in case of success (Al Stone) [2071839]
- can: peak_pci: Add name and FW version of the card in kernel buffer (Al Stone) [2071839]
- can: peak_pci: fix checkpatch warnings (Al Stone) [2071839]
- can: peak_pci: convert comments to network style comments (Al Stone) [2071839]
- net: at91_can: fix the comments style issue (Al Stone) [2071839]
- net: at91_can: remove redundant space (Al Stone) [2071839]
- net: at91_can: add braces {} to all arms of the statement (Al Stone) [2071839]
- net: at91_can: fix the alignment issue (Al Stone) [2071839]
- net: at91_can: use BIT macro (Al Stone) [2071839]
- net: at91_can: fix the code style issue about macro (Al Stone) [2071839]
- net: at91_can: add blank line after declarations (Al Stone) [2071839]
- net: at91_can: remove redundant blank lines (Al Stone) [2071839]
- can: at91_can: use DEVICE_ATTR_RW() helper macro (Al Stone) [2071839]
- can: janz-ican3: use DEVICE_ATTR_RO/RW() helper macro (Al Stone) [2071839]
- can: esd_usb2: use DEVICE_ATTR_RO() helper macro (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): request IRQ as shared (Al Stone) [2071839]
- can: mcp251xfd: Fix header block to clarify independence from OF (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_probe(): try to get crystal clock rate from property (Al Stone) [2071839]
- can: m_can: use devm_platform_ioremap_resource_byname (Al Stone) [2071839]
- can: m_can: Add support for transceiver as phy (Al Stone) [2071839]
- can: netlink: remove redundant check in can_validate() (Al Stone) [2071839]
- can: netlink: clear data_bittiming if FD is turned off (Al Stone) [2071839]
- can: rx-offload: can_rx_offload_threaded_irq_finish(): add new function to be called from threaded interrupt (Al Stone) [2071839]
- can: rx-offload: can_rx_offload_irq_finish(): directly call napi_schedule() (Al Stone) [2071839]
- can: rx-offload: add skb queue for use during ISR (Al Stone) [2071839]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-254.el9]
- arm64: Fix bit-shifting UB in the MIDR_CPU_MODEL() macro (Mark Salter) [2122232]
- arm64: Add AMPERE1 to the Spectre-BHB affected list (Mark Salter) [2122232]
- KVM: arm64: vgic-v3: List M1 Pro/Max as requiring the SEIS workaround (Mark Salter) [2122232]
- arm64: ptrace: Use ARM64_SME to guard the SME register enumerations (Mark Salter) [2122232]
- arm64/signal: Always allocate SVE signal frames on SME only systems (Mark Salter) [2122232]
- arm64/signal: Always accept SVE signal frames on SME only systems (Mark Salter) [2122232]
- arm64/signal: Flush FPSIMD register state when disabling streaming mode (Mark Salter) [2122232]
- arm64/sme: Don't flush SVE register state when handling SME traps (Mark Salter) [2122232]
- arm64/sme: Don't flush SVE register state when allocating SME storage (Mark Salter) [2122232]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Mark Salter) [2122232]
- docs/arm64: elf_hwcaps: unify newlines in HWCAP lists (Mark Salter) [2122232]
- arm64/hwcap: Support FEAT_EBF16 (Mark Salter) [2122232]
- arm64/cpufeature: Store elf_hwcaps as a bitmap rather than unsigned long (Mark Salter) [2122232]
- arm64/hwcap: Document allocation of upper bits of AT_HWCAP (Mark Salter) [2122232]
- arm64: fix oops in concurrently setting insn_emulation (Mark Salter) [2122232]
- arm64: errata: Remove AES hwcap for COMPAT tasks (Mark Salter) [2122232]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2441009 (Mark Salter) [2122232]
- arm64: errata: Add Cortex-A510 to the repeat tlbi list (Mark Salter) [2122232]
- arm64/sysreg: Make BHB clear feature defines match the architecture (Mark Salter) [2122232]
- arm64/sysreg: Align pointer auth enumeration defines with architecture (Mark Salter) [2122232]
- arm64/mte: Standardise GMID field name definitions (Mark Salter) [2122232]
- arm64/sysreg: Standardise naming for DCZID_EL0 field names (Mark Salter) [2122232]
- arm64/sysreg: Standardise naming for CTR_EL0 fields (Mark Salter) [2122232]
- arm64/cache: Restrict which headers are included in __ASSEMBLY__ (Mark Salter) [2122232]
- mm: make minimum slab alignment a runtime property (Mark Salter) [2122232]
- arm64/sysreg: Add SYS_FIELD_GET() helper (Mark Salter) [2122232]
- arm64/sysreg: Allow leading blanks on comments in sysreg file (Mark Salter) [2122232]
- arm64/idreg: Fix tab/space damage (Mark Salter) [2122232]
- arm64/cpuinfo: Remove references to reserved cache type (Mark Salter) [2122232]
- arm64: vdso32: Add DWARF_DEBUG (Mark Salter) [2122232]
- arm64: vdso32: Shuffle .ARM.exidx section above ELF_DETAILS (Mark Salter) [2122232]
- arm64: compat: Move sigreturn32.S to .rodata section (Mark Salter) [2122232]
- arm64: vdso*: place got/plt sections in .rodata (Mark Salter) [2122232]
- arm64: vdso32: add ARM.exidx* sections (Mark Salter) [2122232]
- arm64: compat: Move kuser32.S to .rodata section (Mark Salter) [2122232]
- arm64: vdso32: enable orphan handling for VDSO (Mark Salter) [2122232]
- arm64: vdso32: put ELF related sections in the linker script (Mark Salter) [2122232]
- arm64: vdso: enable orphan handling for VDSO (Mark Salter) [2122232]
- arm64: vdso: put ELF related sections in the linker script (Mark Salter) [2122232]
- arm64/fpsimd: Remove duplicate SYS_SVCR read (Mark Salter) [2122232]
- arm64/signal: Clean up SVE/SME feature checking inconsistency (Mark Salter) [2122232]
- arm64/sme: Expose SMIDR through sysfs (Mark Salter) [2122232]
- arm64/cpufeature: Unexport set_cpu_feature() (Mark Salter) [2122232]
- arm64: Add kasan_hw_tags_enable() prototype to silence sparse (Mark Salter) [2122232]
- arm64/sme: Fix EFI save/restore (Mark Salter) [2122232]
- arm64/fpsimd: Fix typo in comment (Mark Salter) [2122232]
- arm64/sysreg: Fix typo in Enum element regex (Mark Salter) [2122232]
- arm64/sme: Fix SVE/SME typo in ABI documentation (Mark Salter) [2122232]
- arm64/sme: Fix tests for 0b1111 value ID registers (Mark Salter) [2122232]
- arm64: hibernate: Fix syntax errors in comments (Mark Salter) [2122232]
- arm64: Remove the __user annotation for the restore_za_context() argument (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for FAR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for DACR32_EL2 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CSSELR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CPACR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CONTEXTIDR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CLIDR_EL1 (Mark Salter) [2122232]
- arm64/sve: Generate ZCR definitions (Mark Salter) [2122232]
- arm64/sme: Generate defintions for SVCR (Mark Salter) [2122232]
- arm64/sme: Generate SMPRI_EL1 definitions (Mark Salter) [2122232]
- arm64/sme: Automatically generate SMPRIMAP_EL2 definitions (Mark Salter) [2122232]
- arm64/sme: Automatically generate SMIDR_EL1 defines (Mark Salter) [2122232]
- arm64/sme: Automatically generate defines for SMCR (Mark Salter) [2122232]
- arm64/sysreg: Support generation of RAZ fields (Mark Salter) [2122232]
- arm64/sme: Remove _EL0 from name of SVCR - FIXME sysreg.h (Mark Salter) [2122232]
- arm64/sme: Standardise bitfield names for SVCR (Mark Salter) [2122232]
- arm64/sme: Drop SYS_ from SMIDR_EL1 defines (Mark Salter) [2122232]
- arm64/fp: Rename SVE and SME LEN field name to _WIDTH (Mark Salter) [2122232]
- arm64/fp: Make SVE and SME length register definition match architecture (Mark Salter) [2122232]
- arm64/sve: Move sve_free() into SVE code section (Mark Salter) [2122232]
- arm64: Kconfig.platforms: Add comments (Mark Salter) [2122232]
- arm64: Kconfig: Fix indentation and add comments (Mark Salter) [2122232]
- arm64: mm: Make arch_faults_on_old_pte() check for migratability (Mark Salter) [2122232]
- arm64: Declare non global symbols as static (Mark Salter) [2122232]
- arm64: Set ARCH_NR_GPIO to 2048 for ARCH_APPLE (Mark Salter) [2122232]
- arm64: mte: Clean up user tag accessors (Mark Salter) [2122232]
- arm64: cputype: Avoid overflow using MIDR_IMPLEMENTOR_MASK (Mark Salter) [2122232]
- arm64: document the boot requirements for MTE (Mark Salter) [2122232]
- arm64/sve: Make kernel FPU protection RT friendly (Mark Salter) [2122232]
- arm64/sve: Delay freeing memory in fpsimd_flush_thread() (Mark Salter) [2122232]
- arm64/sme: More sensibly define the size for the ZA register set (Mark Salter) [2122232]
- arm64/sme: Fix NULL check after kzalloc (Mark Salter) [2122232]
- arm64/sme: Add ID_AA64SMFR0_EL1 to __read_sysreg_by_encoding() (Mark Salter) [2122232]
- redhat: configs: Add config for ARM64_SME (Mark Salter) [2122232]
- arm64/sme: Provide Kconfig for SME (Mark Salter) [2122232]
- arm64/sme: Save and restore streaming mode over EFI runtime calls (Mark Salter) [2122232]
- arm64/sme: Disable streaming mode and ZA when flushing CPU state (Mark Salter) [2122232]
- arm64/sme: Add ptrace support for ZA (Mark Salter) [2122232]
- arm64/sme: Implement ptrace support for streaming mode SVE registers (Mark Salter) [2122232]
- arm64/sme: Implement ZA signal handling (Mark Salter) [2122232]
- arm64/sme: Implement streaming SVE signal handling (Mark Salter) [2122232]
- arm64/sme: Disable ZA and streaming mode when handling signals (Mark Salter) [2122232]
- arm64/sme: Implement traps and syscall handling for SME (Mark Salter) [2122232]
- arm64/sme: Implement ZA context switching (Mark Salter) [2122232]
- arm64/sme: Implement streaming SVE context switching (Mark Salter) [2122232]
- arm64/sme: Implement SVCR context switching (Mark Salter) [2122232]
- arm64/sme: Implement support for TPIDR2 (Mark Salter) [2122232]
- arm64/sme: Implement vector length configuration prctl()s (Mark Salter) [2122232]
- arm64/sme: Implement sysctl to set the default vector length (Mark Salter) [2122232]
- arm64/sme: Identify supported SME vector lengths at boot (Mark Salter) [2122232]
- arm64/sme: Basic enumeration support (Mark Salter) [2122232]
- arm64/sme: Early CPU setup for SME (Mark Salter) [2122232]
- arm64/sme: Manually encode SME instructions (Mark Salter) [2122232]
- arm64/sme: System register and exception syndrome definitions (Mark Salter) [2122232]
- arm64/sme: Provide ABI documentation for SME (Mark Salter) [2122232]
- arm64/sysreg: fix odd line spacing (Mark Salter) [2122232]
- arm64/sysreg: improve comment for regs without fields (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for SCTLR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for TTBRn_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for ID_AA64ISAR0_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Enable automatic generation of system register definitions (Mark Salter) [2122232]
- arm64: Add sysreg header generation scripting (Mark Salter) [2122232]
- arm64/sysreg: Standardise ID_AA64ISAR0_EL1 macro names (Mark Salter) [2122232]
- arm64: Update name of ID_AA64ISAR0_EL1_ATOMIC to reflect ARM (Mark Salter) [2122232]
- arm64/sysreg: Define bits for previously RES1 fields in SCTLR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Rename SCTLR_EL1_NTWE/TWI to SCTLR_EL1_nTWE/TWI (Mark Salter) [2122232]
- arm64/mte: Make TCF field values and naming more standard (Mark Salter) [2122232]
- arm64/mte: Make TCF0 naming and field values more standard (Mark Salter) [2122232]
- arm64/sysreg: Introduce helpers for access to sysreg fields (Mark Salter) [2122232]
- arm64: Treat ESR_ELx as a 64-bit register (Mark Salter) [2122232]
- arm64: compat: Do not treat syscall number as ESR_ELx for a bad syscall (Mark Salter) [2122232]
- arm64: Make ESR_ELx_xVC_IMM_MASK compatible with assembly (Mark Salter) [2122232]
- arm64: stacktrace: align with common naming (Mark Salter) [2122232]
- arm64: stacktrace: rename stackframe to unwind_state (Mark Salter) [2122232]
- arm64: stacktrace: rename unwinder functions (Mark Salter) [2122232]
- arm64: stacktrace: make struct stackframe private to stacktrace.c (Mark Salter) [2122232]
- arm64: stacktrace: delete PCS comment (Mark Salter) [2122232]
- arm64: stacktrace: remove NULL task check from unwind_frame() (Mark Salter) [2122232]
- arm64: Use WFxT for __delay() when possible (Mark Salter) [2122232]
- arm64: Add wfet()/wfit() helpers (Mark Salter) [2122232]
- arm64: Add HWCAP advertising FEAT_WFXT (Mark Salter) [2122232]
- arm64: Add RV and RN fields for ESR_ELx_WFx_ISS (Mark Salter) [2122232]
- arm64: Expand ESR_ELx_WFx_ISS_TI to match its ARMv8.7 definition (Mark Salter) [2122232]
- arm64: kexec: load from kimage prior to clobbering (Mark Salter) [2122232]
- arm64: paravirt: Use RCU read locks to guard stolen_time (Mark Salter) [2122232]
- arm64, topology: enable use of init_cpu_capacity_cppc() (Mark Salter) [2122232]
- arm64: perf: Consistently make all event numbers as 16-bits (Mark Salter) [2122232]
- arm64: perf: Expose some Armv9 common events under sysfs (Mark Salter) [2122232]
- arm64: mte: Define the number of bytes for storing the tags in a page (Mark Salter) [2122232]
- elf: Introduce the ARM MTE ELF segment type (Mark Salter) [2122232]
- elfcore: Replace CONFIG_{IA64, UML} checks with a new option (Mark Salter) [2122232]
- elfcore: correct reference to CONFIG_UML (Mark Salter) [2122232]
- serial: pl011: Add ACPI SBSA UART match id (Mark Salter) [2122232]
- arm64: Use of_get_cpu_hwid() (Mark Salter) [2122232]
- arm64: Add support of PAuth QARMA3 architected algorithm (Mark Salter) [2122232]
- binfmt_elf: Don't write past end of notes for regset gap (Mark Salter) [2122232]
- coredump/elf: Pass coredump_params into fill_note_info (Mark Salter) [2122232]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-253.el9]
- crypto: testmgr - disallow certain DRBG hash functions in FIPS mode (Vladis Dronov) [2152131]
- rtla: Fix exit status when returning from calls to usage() (John Kacur) [2160394]
- nfsd: don't free files unconditionally in __nfsd_file_cache_purge (Jeffrey Layton) [2160443]
- ice: use GNSS subsystem instead of TTY (Petr Oros) [2111048]
- ice: Add check for kzalloc (Petr Oros) [2111048]
- ice: Fix potential memory leak in ice_gnss_tty_write() (Petr Oros) [2111048]
- ice: add write functionality for GNSS TTY (Petr Oros) [2111048]
- net/ulp: use consistent error code when blocking ULP (Paolo Abeni) [2162758]
- net/ulp: prevent ULP without clone op from entering the LISTEN status (Paolo Abeni) [2162758]
- ipvlan: hold lower dev to avoid possible use-after-free (Davide Caratti) [2162698]
- net: macvlan: Use built-in RCU list checking (Davide Caratti) [2162698]
- net: macvlan: fix memory leaks of macvlan_common_newlink (Davide Caratti) [2162698]
- dmaengine: Fix double increment of client_count in dma_chan_get() (Joel Savitz) [2095651]
- ice: Fix configuring VIRTCHNL_OP_CONFIG_VSI_QUEUES with unbalanced queues (Petr Oros) [2162402]
- ice: virtchnl rss hena support (Petr Oros) [2162402]
- ice: Add additional CSR registers to ETHTOOL_GREGS (Petr Oros) [2162402]
- ice: Add support Flex RXD (Petr Oros) [2162402]
- netfilter: conntrack: reduce timeout when receiving out-of-window fin or rst (Florian Westphal) [2162440]
- netfilter: conntrack: remove unneeded indent level (Florian Westphal) [2162440]
- netfilter: conntrack: ignore overly delayed tcp packets (Florian Westphal) [2162440]
- netfilter: conntrack: prepare tcp_in_window for ternary return value (Florian Westphal) [2162440]
- netfilter: conntrack: work around exceeded receive window (Florian Westphal) [2162440]
- l2tp: prevent lockdep issue in l2tp_tunnel_register() (Guillaume Nault) [2162322]
- l2tp: close all race conditions in l2tp_tunnel_register() (Guillaume Nault) [2162322]
- l2tp: convert l2tp_tunnel_list to idr (Guillaume Nault) [2162322]
- ipv6: raw: Deduct extension header length in rawv6_push_pending_frames (Hangbin Liu) [2162122] {CVE-2023-0394}
- ipv4: Fix incorrect route flushing when table ID 0 is used (Guillaume Nault) [2162116]
- ipv4: Fix incorrect route flushing when source address is deleted (Guillaume Nault) [2162116]
- inet: ping: use hlist_nulls rcu iterator during lookup (Guillaume Nault) [2162116]
- ipv4: Fix route deletion when nexthop info is not specified (Guillaume Nault) [2162116]
- ipv4: Fix error return code in fib_table_insert() (Guillaume Nault) [2162116]
- net: use struct_group to copy ip/ipv6 header addresses (Guillaume Nault) [2162116]
- netfilter: rpfilter/fib: Set ->flowic_uid correctly for user namespaces. (Guillaume Nault) [2162116]
- iwlwifi: remove firmware version limit for AC9560 (Íñigo Huguet) [2129363]
- wifi: iwlwifi: fw: skip PPAG for JF (Íñigo Huguet) [2129363]
- mptcp: fix lockdep false positive (Davide Caratti) [2161699]
- mptcp: fix deadlock in fastopen error path (Davide Caratti) [2161699]
- mptcp: fix sleep in atomic at close time (Davide Caratti) [2161699]
- mptcp: don't orphan ssk in mptcp_close() (Davide Caratti) [2161699]
- mptcp: use proper req destructor for IPv6 (Davide Caratti) [2161699]
- mptcp: dedicated request sock for subflow in v6 (Davide Caratti) [2161699]
- mptcp: remove MPTCP 'ifdef' in TCP SYN cookies (Davide Caratti) [2161699]
- mptcp: netlink: fix some error return code (Davide Caratti) [2161699]
- ACPICA: Fix operand resolution (Mark Langsdorf) [2159836]
- net: mana: Fix race on per-CQ variable napi work_done (Emanuele Giuseppe Esposito) [2153431]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-252.el9]
- vdpa/ifcvf: fix the calculation of queuepair (Cindy Lu) [2158700]
- vdpa_sim: use max_iotlb_entries as a limit in vhost_iotlb_init (Cindy Lu) [2158700]
- vdpa_sim: Use iova_shift() for the size passed to alloc_iova() (Cindy Lu) [2158700]
- vDPA/ifcvf: support userspace to query features and MQ of a management device (Cindy Lu) [2158700]
- vDPA/ifcvf: get_config_size should return a value no greater than dev implementation (Cindy Lu) [2158700]
- vDPA/ifcvf: remove duplicated assignment to pointer cfg (Cindy Lu) [2158700]
- vdpa: ifcvf: Fix spelling mistake in comments (Cindy Lu) [2158700]
- vdpa: ifcvf: set pci driver data in probe (Cindy Lu) [2158700]
- vDPA/ifcvf: fix uninitialized config_vector warning (Cindy Lu) [2158700]
- vDPA/ifcvf: cacheline alignment for ifcvf_hw (Cindy Lu) [2158700]
- vDPA/ifcvf: implement shared IRQ feature (Cindy Lu) [2158700]
- vDPA/ifcvf: implement device MSIX vector allocator (Cindy Lu) [2158700]
- vDPA/ifcvf: make use of virtio pci modern IO helpers in ifcvf (Cindy Lu) [2158700]
- RDMA/mlx5: remove variable i (Cindy Lu) [2158700]
- vdpa/mlx5: Avoid overwriting CVQ iotlb (Cindy Lu) [2158700]
- vdpa/mlx5: Avoid using reslock in event_handler (Cindy Lu) [2158700]
- vdpa/mlx5: Fix wrong mac address deletion (Cindy Lu) [2158700]
- vdpa/mlx5: Return error on vlan ctrl commands if not supported (Cindy Lu) [2158700]
- vdpa/mlx5: Fix rule forwarding VLAN to TIR (Cindy Lu) [2158700]
- vdpa/mlx5: Fix MQ to support non power of two num queues (Cindy Lu) [2158700]
- vdpa/mlx5: Fix possible uninitialized return value (Cindy Lu) [2158700]
- vdpa/mlx5: Support different address spaces for control and data (Cindy Lu) [2158700]
- vdpa/mlx5: Implement susupend virtqueue callback (Cindy Lu) [2158700]
- vdpa/mlx5: Use eth_broadcast_addr() to assign broadcast address (Cindy Lu) [2158700]
- vdpa/mlx5: clean up indenting in handle_ctrl_vlan() (Cindy Lu) [2158700]
- vdpa/mlx5: fix error code for deleting vlan (Cindy Lu) [2158700]
- vdpa/mlx5: Fix syntax errors in comments (Cindy Lu) [2158700]
- vdpa/mlx5: Add RX MAC VLAN filter support (Cindy Lu) [2158700]
- vdpa/mlx5: re-create forwarding rules after mac modified (Cindy Lu) [2158700]
- vdpa/mlx5: Remove flow counter from steering (Cindy Lu) [2158700]
- vdpa/mlx5: Use readers/writers semaphore instead of mutex (Cindy Lu) [2158700]
- net/mlx5: Add support for configuring max device MTU (Cindy Lu) [2158700]
- vdpa/mlx5: Use auxiliary_device driver data helpers (Cindy Lu) [2158700]
- vhost_vdpa: don't setup irq offloading when irq_num < 0 (Cindy Lu) [2158700]
- vhost-vdpa: return -EFAULT on copy_to_user() failure (Cindy Lu) [2158700]
- vhost_vdpa: fix the crash in unmap a large memory (Cindy Lu) [2158700]
- vhost-vdpa: fix an iotlb memory leak (Cindy Lu) [2158700]
- vdpa_sim_net: should not drop the multicast/broadcast packet (Cindy Lu) [2158700]
- vdpasim: fix memory leak when freeing IOTLBs (Cindy Lu) [2158700]
- vdpa: conditionally fill max max queue pair for stats (Cindy Lu) [2158700]
- vdpa/vp_vdpa: fix kfree a wrong pointer in vp_vdpa_remove (Cindy Lu) [2158700]
- vdpa_sim: fix vringh initialization in vdpasim_queue_ready() (Cindy Lu) [2158700]
- vdpa_sim: fix possible memory leak in vdpasim_net_init() and vdpasim_blk_init() (Cindy Lu) [2158700]
- vdpa: merge functionally duplicated dev_features attributes (Cindy Lu) [2158700]
- vDPA: conditionally read MTU and MAC in dev cfg space (Cindy Lu) [2158700]
- vDPA: fix spars cast warning in vdpa_dev_net_mq_config_fill (Cindy Lu) [2158700]
- vDPA: check virtio device features to detect MQ (Cindy Lu) [2158700]
- vDPA: check VIRTIO_NET_F_RSS for max_virtqueue_paris's presence (Cindy Lu) [2158700]
- vDPA: only report driver features if FEATURES_OK is set (Cindy Lu) [2158700]
- vDPA: allow userspace to query features of a vDPA device (Cindy Lu) [2158700]
- vp_vdpa: support feature provisioning (Cindy Lu) [2158700]
- vdpa_sim_net: support feature provisioning (Cindy Lu) [2158700]
- vdpa: device feature provisioning (Cindy Lu) [2158700]
- vdpa/vp_vdpa : add vdpa tool support in vp_vdpa (Cindy Lu) [2158700]
- vhost-vdpa: Call ida_simple_remove() when failed (Cindy Lu) [2158700]
- vDPA: fix 'cast to restricted le16' warnings in vdpa.c (Cindy Lu) [2158700]
- vDPA: !FEATURES_OK should not block querying device config space (Cindy Lu) [2158700]
- vdpa_sim: Implement suspend vdpa op (Cindy Lu) [2158700]
- vhost-vdpa: uAPI to suspend the device (Cindy Lu) [2158700]
- vhost-vdpa: introduce SUSPEND backend feature bit (Cindy Lu) [2158700]
- vdpa: Add suspend operation (Cindy Lu) [2158700]
- vdpa: Use device_iommu_capable() (Cindy Lu) [2158700]
- vdpa: make get_vq_group and set_group_asid optional (Cindy Lu) [2158700]
- vdpa: support exposing the count of vqs to userspace (Cindy Lu) [2158700]
- vdpa: change the type of nvqs to u32 (Cindy Lu) [2158700]
- vdpa: support exposing the config size to userspace (Cindy Lu) [2158700]

* Tue Jan 31 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-251.el9]
- ext4: fix reserved cluster accounting in __es_remove_extent() (Lukas Czerner) [2145193]
- ext4: fix kernel BUG in 'ext4_write_inline_data_end()' (Lukas Czerner) [2145193]
- ext4: fix deadlock due to mbcache entry corruption (Lukas Czerner) [2145193]
- mbcache: Avoid nesting of cache->c_list_lock under bit locks (Lukas Czerner) [2145193]
- mbcache: automatically delete entries from cache on freeing (Lukas Czerner) [2145193]
- mbcache: Remove mb_cache_entry_delete() (Lukas Czerner) [2145193]
- ext4: avoid BUG_ON when creating xattrs (Lukas Czerner) [2145193]
- fs: ext4: initialize fsdata in pagecache_write() (Lukas Czerner) [2145193]
- ext4: fix uninititialized value in 'ext4_evict_inode' (Lukas Czerner) [2145193]
- ext4: fix corruption when online resizing a 1K bigalloc fs (Lukas Czerner) [2145193]
- ext4: fix corrupt backup group descriptors after online resize (Lukas Czerner) [2145193]
- ext4: fix bad checksum after online resize (Lukas Czerner) [2145193]
- ext4: fix off-by-one errors in fast-commit block filling (Lukas Czerner) [2145193]
- ext4: fix unaligned memory access in ext4_fc_reserve_space() (Lukas Czerner) [2145193]
- ext4: add missing validation of fast-commit record lengths (Lukas Czerner) [2145193]
- ext4: fix leaking uninitialized memory in fast-commit journal (Lukas Czerner) [2145193]
- ext4: don't set up encryption key during jbd2 transaction (Lukas Czerner) [2145193]
- ext4: disable fast-commit of encrypted dir operations (Lukas Czerner) [2145193]
- ext4: fix undefined behavior in bit shift for ext4_check_flag_values (Lukas Czerner) [2145193]
- ext4: journal_path mount options should follow links (Lukas Czerner) [2145193]
- ext4: silence the warning when evicting inode with dioread_nolock (Lukas Czerner) [2145193]
- ext4: fix use-after-free in ext4_ext_shift_extents (Lukas Czerner) [2145193]
- ext4: fix warning in 'ext4_da_release_space' (Lukas Czerner) [2145193]
- ext4: fix BUG_ON() when directory entry has invalid rec_len (Lukas Czerner) [2145193]
- ext4: update the backup superblock's at the end of the online resize (Lukas Czerner) [2145193]
- ext4,f2fs: fix readahead of verity data (Lukas Czerner) [2145193]
- ext4: fix potential out of bound read in ext4_fc_replay_scan() (Lukas Czerner) [2145193]
- ext4: factor out ext4_fc_get_tl() (Lukas Czerner) [2145193]
- ext4: introduce EXT4_FC_TAG_BASE_LEN helper (Lukas Czerner) [2145193]
- ext4: factor out ext4_free_ext_path() (Lukas Czerner) [2145193]
- ext4: remove unnecessary drop path references in mext_check_coverage() (Lukas Czerner) [2145193]
- ext4: update 'state->fc_regions_size' after successful memory allocation (Lukas Czerner) [2145193]
- ext4: fix potential memory leak in ext4_fc_record_regions() (Lukas Czerner) [2145193]
- ext4: fix potential memory leak in ext4_fc_record_modified_inode() (Lukas Czerner) [2145193]
- ext4: remove redundant checking in ext4_ioctl_checkpoint (Lukas Czerner) [2145193]
- jbd2: add miss release buffer head in fc_do_one_pass() (Lukas Czerner) [2145193]
- ext4: move DIOREAD_NOLOCK setting to ext4_set_def_opts() (Lukas Czerner) [2145193]
- ext4: remove useless local variable 'blocksize' (Lukas Czerner) [2145193]
- ext4: unify the ext4 super block loading operation (Lukas Czerner) [2145193]
- ext4: factor out ext4_journal_data_mode_check() (Lukas Czerner) [2145193]
- ext4: fix wrong return err in ext4_load_and_init_journal() (Lukas Czerner) [2145193]
- ext4: factor out ext4_load_and_init_journal() (Lukas Czerner) [2145193]
- ext4: factor out ext4_group_desc_init() and ext4_group_desc_free() (Lukas Czerner) [2145193]
- ext4: factor out ext4_geometry_check() (Lukas Czerner) [2145193]
- ext4: factor out ext4_check_feature_compatibility() (Lukas Czerner) [2145193]
- ext4: factor out ext4_init_metadata_csum() (Lukas Czerner) [2145193]
- ext4: factor out ext4_encoding_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_inode_info_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_fast_commit_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_handle_clustersize() (Lukas Czerner) [2145193]
- ext4: factor out ext4_set_def_opts() (Lukas Czerner) [2145193]
- ext4: remove cantfind_ext4 error handler (Lukas Czerner) [2145193]
- ext4: goto right label 'failed_mount3a' (Lukas Czerner) [2145193]
- ext4: adjust fast commit disable judgement order in ext4_fc_track_inode (Lukas Czerner) [2145193]
- ext4: factor out ext4_fc_disabled() (Lukas Czerner) [2145193]
- ext4: fix miss release buffer head in ext4_fc_write_inode (Lukas Czerner) [2145193]
- jbd2: fix potential use-after-free in jbd2_fc_wait_bufs (Lukas Czerner) [2145193]
- jbd2: fix potential buffer head reference count leak (Lukas Czerner) [2145193]
- ext4: fix dir corruption when ext4_dx_add_entry() fails (Lukas Czerner) [2145193]
- ext4: remove ext4_inline_data_fiemap() declaration (Lukas Czerner) [2145193]
- jbd2: wake up journal waiters in FIFO order, not LIFO (Lukas Czerner) [2145193]
- ext4: place buffer head allocation before handle start (Lukas Czerner) [2145193]
- ext4: ext4_read_bh_lock() should submit IO if the buffer isn't uptodate (Lukas Czerner) [2145193]
- ext4: don't increase iversion counter for ea_inodes (Lukas Czerner) [2145193]
- ext4: fix check for block being out of directory size (Lukas Czerner) [2145193]
- jbd2: drop useless return value of submit_bh (Lukas Czerner) [2145193]
- ext4: make ext4_lazyinit_thread freezable (Lukas Czerner) [2145193]
- ext4: fix null-ptr-deref in ext4_write_info (Lukas Czerner) [2145193]
- ext4: don't run ext4lazyinit for read-only filesystems (Lukas Czerner) [2145193]
- ext4: avoid crash when inline data creation follows DIO write (Lukas Czerner) [2145193]
- ext4: minor defrag code improvements (Lukas Czerner) [2145193]
- ext4: continue to expand file system when the target size doesn't reach (Lukas Czerner) [2145193]
- ext4: limit the number of retries after discarding preallocations blocks (Lukas Czerner) [2145193]
- ext4: fix bug in extents parsing when eh_entries == 0 and eh_depth > 0 (Lukas Czerner) [2145193]
- ext4: fixup possible uninitialized variable access in ext4_mb_choose_next_group_cr1() (Lukas Czerner) [2145193]
- ext4: use buckets for cr 1 block scan instead of rbtree (Lukas Czerner) [2145193]
- ext4: use locality group preallocation for small closed files (Lukas Czerner) [2145193]
- ext4: make directory inode spreading reflect flexbg size (Lukas Czerner) [2145193]
- ext4: avoid unnecessary spreading of allocations among groups (Lukas Czerner) [2145193]
- ext4: make mballoc try target group first even with mb_optimize_scan (Lukas Czerner) [2145193]
- ext4: add ioctls to get/set the ext4 superblock uuid (Lukas Czerner) [2145193]
- ext4: avoid resizing to a partial cluster size (Lukas Czerner) [2145193]
- ext4: reduce computation of overhead during resize (Lukas Czerner) [2145193]
- jbd2: fix assertion 'jh->b_frozen_data == NULL' failure when journal aborted (Lukas Czerner) [2145193]
- ext4: block range must be validated before use in ext4_mb_clear_bb() (Lukas Czerner) [2145193]
- ext4: fix race when reusing xattr blocks (Lukas Czerner) [2145193]
- ext4: unindent codeblock in ext4_xattr_block_set() (Lukas Czerner) [2145193]
- ext4: remove EA inode entry from mbcache on inode eviction (Lukas Czerner) [2145193]
- mbcache: add functions to delete entry if unused (Lukas Czerner) [2145193]
- mbcache: don't reclaim used entries (Lukas Czerner) [2145193]
- ext4: reflect mb_optimize_scan value in options file (Lukas Czerner) [2145193]
- ext4: avoid remove directory when directory is corrupted (Lukas Czerner) [2145193]
- ext4: aligned '*' in comments (Lukas Czerner) [2145193]
- ext4: recover csum seed of tmp_inode after migrating to extents (Lukas Czerner) [2145193]
- ext4: fix warning in ext4_iomap_begin as race between bmap and write (Lukas Czerner) [2145193]
- ext4: correct the misjudgment in ext4_iget_extra_inode (Lukas Czerner) [2145193]
- ext4: correct max_inline_xattr_value_size computing (Lukas Czerner) [2145193]
- ext4: fix use-after-free in ext4_xattr_set_entry (Lukas Czerner) [2145193]
- ext4: add EXT4_INODE_HAS_XATTR_SPACE macro in xattr.h (Lukas Czerner) [2145193]
- ext4: fix extent status tree race in writeback error recovery path (Lukas Czerner) [2145193]
- jbd2: fix outstanding credits assert in jbd2_journal_commit_transaction() (Lukas Czerner) [2145193]
- jbd2: unexport jbd2_log_start_commit() (Lukas Czerner) [2145193]
- jbd2: remove unused exports for jbd2 debugging (Lukas Czerner) [2145193]
- jbd2: rename jbd_debug() to jbd2_debug() (Lukas Czerner) [2145193]
- ext4: use ext4_debug() instead of jbd_debug() (Lukas Czerner) [2145193]
- ext4: reuse order and buddy in mb_mark_used when buddy split (Lukas Czerner) [2145193]
- ext4: update the s_overhead_clusters in the backup sb's when resizing (Lukas Czerner) [2145193]
- ext4: update s_overhead_clusters in the superblock during an on-line resize (Lukas Czerner) [2145193]
- ext4: fix a doubled word "need" in a comment (Lukas Czerner) [2145193]
- ext4: correct the judgment of BUG in ext4_mb_normalize_request (Lukas Czerner) [2145193]
- ext4: use kmemdup() to replace kmalloc + memcpy (Lukas Czerner) [2145193]
- ext4: improve write performance with disabled delalloc (Lukas Czerner) [2145193]
- ext4: fix warning when submitting superblock in ext4_commit_super() (Lukas Czerner) [2145193]
- ext4: fix incorrect comment in ext4_bio_write_page() (Lukas Czerner) [2145193]
- ext4: refactor and move ext4_ioctl_get_encryption_pwsalt() (Lukas Czerner) [2145193]
- ext4: cleanup function defs from ext4.h into crypto.c (Lukas Czerner) [2145193]
- ext4: move ext4 crypto code to its own file crypto.c (Lukas Czerner) [2145193]
- fscrypt: remove fscrypt_operations::max_namelen (Lukas Czerner) [2145193]
- fscrypt: document struct fscrypt_operations (Lukas Czerner) [2145193]
- ext4: add unmount filesystem message (Lukas Czerner) [2145193]
- ext4: remove unnecessary conditionals (Lukas Czerner) [2145193]
- ext4: remove unnecessary code in __mb_check_buddy (Lukas Czerner) [2145193]
- ext4: fix spelling errors in comments (Lukas Czerner) [2145193]
- ext4: remove unnecessary type castings (Lukas Czerner) [2145193]
- ext4: get rid of unused DEFAULT_MB_OPTIMIZE_SCAN (Lukas Czerner) [2145193]
- ext4: Use scoped memory APIs in ext4_write_begin() (Lukas Czerner) [2145193]
- ext4: Use scoped memory APIs in ext4_da_write_begin() (Lukas Czerner) [2145193]
- ext4: Use scoped memory API in mext_page_double_lock() (Lukas Czerner) [2145193]
- ext4: Allow GFP_FS allocations in ext4_da_convert_inline_data_to_extent() (Lukas Czerner) [2145193]
- ext4: Use page_symlink() instead of __page_symlink() (Lukas Czerner) [2145193]
- ext4: Convert invalidatepage to invalidate_folio (Lukas Czerner) [2145193]

* Tue Jan 31 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-250.el9]
- mlx5: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- vxlan: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- geneve: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- geneve: fix TOS inheriting for ipv4 (Guillaume Nault) [2161351]
- scsi: storvsc: Fix swiotlb bounce buffer leak in confidential VM (Emanuele Giuseppe Esposito) [2150660]
- vfio: Add an option to get migration data size (Alex Williamson) [2158549]
- vfio/pci: Check the device set open count on reset (Alex Williamson) [2155664]
- vfio: Export the device set open count (Alex Williamson) [2155664]
- vfio: Fix container device registration life cycle (Alex Williamson) [2155664]
- vfio: Split the register_device ops call into functions (Alex Williamson) [2155664]
- tools headers uapi: Sync linux/stat.h with the kernel sources (Lukas Czerner) [2150284]
- ext4: support STATX_DIOALIGN (Lukas Czerner) [2150284]
- xfs: support STATX_DIOALIGN (Lukas Czerner) [2150284]
- vfs: support STATX_DIOALIGN on block devices (Lukas Czerner) [2150284]
- statx: add direct I/O alignment information (Lukas Czerner) [2150284]
- tdx: enable TDX attestation driver (Wander Lairson Costa) [2076749]
- selftests/tdx: Test TDX attestation GetReport support (Wander Lairson Costa) [2076749]
- virt: Add TDX guest driver (Wander Lairson Costa) [2076749]
- x86/tdx: Add a wrapper to get TDREPORT0 from the TDX Module (Wander Lairson Costa) [2076749]
- OPP: Migrate set-supported-hw API to use set-config helpers (Mark Langsdorf) [2122311]
- OPP: Migrate set-regulators API to use set-config helpers (Mark Langsdorf) [2122311]
- OPP: Add dev_pm_opp_set_config() and friends (Mark Langsdorf) [2122311]
- OPP: Make dev_pm_opp_set_regulators() accept NULL terminated list (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Fix module loading (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Staticize struct tegra_cpufreq_soc instances (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Add support for Tegra234 (Mark Langsdorf) [2122311]
- cpufreq: tegra194: add soc data to support multiple soc (Mark Langsdorf) [2122311]
- cpufreq: ACPI: Add Zhaoxin/Centaur turbo boost control interface support (Mark Langsdorf) [2122311]
- drivers: cpufreq: Add missing of_node_put() in qoriq-cpufreq.c (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Fix unused-function warning (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Fix build error without CONFIG_ACPI_CPPC_CPUFREQ_FIE (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Enable dvfs_possible_from_any_cpu (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Register EM based on efficiency class information (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Add per_cpu efficiency_class (Mark Langsdorf) [2122311]
- cpufreq: check only freq_table in __resolve_freq() (Mark Langsdorf) [2122311]
- cpufreq: ondemand: Use cpumask_var_t for on-stack cpu mask (Mark Langsdorf) [2122311]
- cpufreq: Optimize cpufreq_show_cpus() (Mark Langsdorf) [2122311]
- cpufreq: Rearrange locking in cpufreq_remove_dev() (Mark Langsdorf) [2122311]
- cpufreq: Split cpufreq_offline() (Mark Langsdorf) [2122311]
- cpufreq: Reorganize checks in cpufreq_offline() (Mark Langsdorf) [2122311]
- cpufreq: Clear real_cpus mask from remove_cpu_dev_symlink() (Mark Langsdorf) [2122311]
- cpufreq: Avoid unnecessary frequency updates due to mismatch (Mark Langsdorf) [2122311]
- cpufreq: Prepare cleanup of powerpc's asm/prom.h (Mark Langsdorf) [2122311]
- cpufreq: governor: Use kobject release() method to free dbs_data (Mark Langsdorf) [2122311]
- cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support (Mark Langsdorf) [2122311]
- Documentation: power: Add description about new callback for EM registration (Mark Langsdorf) [2122311]
- cpufreq: Add callback to register with energy model (Mark Langsdorf) [2122311]

* Mon Jan 30 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-249.el9]
- DRM: add new config options (Mika Penttilä) [2154295]
- gpu: host1x: Fix a kernel-doc warning (Mika Penttilä) [2154295]
- gpu: host1x: Plug potential memory leak (Mika Penttilä) [2154295]
- gpu/host1x: fence: Make spinlock static (Mika Penttilä) [2154295]
- gpu: host1x: debug: Dump DMASTART and DMAEND register (Mika Penttilä) [2154295]
- gpu: host1x: debug: Dump only relevant parts of CDMA push buffer (Mika Penttilä) [2154295]
- gpu: host1x: debug: Use dma_addr_t more consistently (Mika Penttilä) [2154295]
- gpu: host1x: Use the bitmap API to allocate bitmaps (Mika Penttilä) [2154295]
- gpu: host1x: Generalize host1x_cdma_push_wide() (Mika Penttilä) [2154295]
- gpu: host1x: Initialize syncval in channel_submit() (Mika Penttilä) [2154295]
- gpu: host1x: Register context bus unconditionally (Mika Penttilä) [2154295]
- gpu: host1x: Use RESTART_W to skip timed out jobs on Tegra186+ (Mika Penttilä) [2154295]
- gpu: host1x: Add MLOCK release code on Tegra234 (Mika Penttilä) [2154295]
- gpu: host1x: Rewrite job opcode sequence (Mika Penttilä) [2154295]
- gpu: host1x: Tegra234 device data and headers (Mika Penttilä) [2154295]
- gpu: host1x: Allow reset to be missing (Mika Penttilä) [2154295]
- gpu: host1x: Program interrupt destinations on Tegra234 (Mika Penttilä) [2154295]
- gpu: host1x: Program virtualization tables (Mika Penttilä) [2154295]
- gpu: host1x: Simplify register mapping and add common aperture (Mika Penttilä) [2154295]
- gpu: host1x: Deduplicate hardware headers (Mika Penttilä) [2154295]
- drm/tegra: vic: Use devm_platform_ioremap_resource() (Mika Penttilä) [2154295]
- drm/tegra: Include DMA API header where used (Mika Penttilä) [2154295]
- drm/tegra: Fix vmapping of prime buffers (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix build warning when CONFIG_PM=n (Mika Penttilä) [2154295]
- drm/tegra: vic: Add Tegra234 support (Mika Penttilä) [2154295]
- drm/tegra: Implement stream ID related callbacks on engines (Mika Penttilä) [2154295]
- drm/tegra: Support context isolation (Mika Penttilä) [2154295]
- gpu: host1x: Program context stream ID on submission (Mika Penttilä) [2154295]
- gpu: host1x: Add context device management code (Mika Penttilä) [2154295]
- gpu: host1x: Add context bus (Mika Penttilä) [2154295]
- gpu: host1x: Show all allocated syncpts via debugfs (Mika Penttilä) [2154295]
- gpu: host1x: Do not use mapping cache for job submissions (Mika Penttilä) [2154295]
- gpu: host1x: Fix a memory leak in 'host1x_remove()' (Mika Penttilä) [2154295]
- gpu: host1x: Fix an error handling path in 'host1x_probe()' (Mika Penttilä) [2154295]
- gpu: host1x: Always return syncpoint value when waiting (Mika Penttilä) [2154295]
- gpu: host1x: Fix hang on Tegra186+ (Mika Penttilä) [2154295]
- gpu: host1x: Add back arm_iommu_detach_device() (Mika Penttilä) [2154295]
- gpu: host1x: Add initial runtime PM and OPP support (Mika Penttilä) [2154295]
- gpu: host1x: Add missing DMA API include (Mika Penttilä) [2154295]
- gpu: host1x: select CONFIG_DMA_SHARED_BUFFER (Mika Penttilä) [2154295]
- gpu: host1x: Drop excess kernel-doc entry @key (Mika Penttilä) [2154295]
- drm/tegra: nvdec: Fix TRANSCFG register offset (Mika Penttilä) [2154295]
- drm/tegra: falcon: Set DMACTX field on DMA transactions (Mika Penttilä) [2154295]
- drm/tegra: gem: Do not try to dereference ERR_PTR() (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix unused-function warnings (Mika Penttilä) [2154295]
- drm/tegra: Support YVYU, VYUY and YU24 formats (Mika Penttilä) [2154295]
- drm/tegra: Support semi-planar formats on Tegra114+ (Mika Penttilä) [2154295]
- drm/tegra: Fix planar formats on Tegra186 and later (Mika Penttilä) [2154295]
- drm/tegra: dpaux: Remove unneeded variable (Mika Penttilä) [2154295]
- drm/tegra: Fix reference leak in tegra_dsi_ganged_probe (Mika Penttilä) [2154295]
- drm/tegra: Use dev_err_probe() (Mika Penttilä) [2154295]
- drm/tegra: dpaux: Populate AUX bus (Mika Penttilä) [2154295]
- drm/tegra: Fix cast to restricted __le32 (Mika Penttilä) [2154295]
- drm/tegra: Add support for the nomodeset kernel parameter (Mika Penttilä) [2154295]
- drm/tegra: Add back arm_iommu_detach_device() (Mika Penttilä) [2154295]
- drm/tegra: Consolidate runtime PM management of older UAPI codepath (Mika Penttilä) [2154295]
- drm/tegra: submit: Remove pm_runtime_enabled() checks (Mika Penttilä) [2154295]
- drm/tegra: nvdec: Stop channel on suspend (Mika Penttilä) [2154295]
- drm/tegra: vic: Stop channel on suspend (Mika Penttilä) [2154295]
- drm/tegra: gr3d: Support generic power domain and runtime PM (Mika Penttilä) [2154295]
- drm/tegra: gr2d: Support generic power domain and runtime PM (Mika Penttilä) [2154295]
- gpu: host1x: Add host1x_channel_stop() (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Add OPP support (Mika Penttilä) [2154295]
- drm/tegra: dc: Support OPP and SoC core voltage scaling (Mika Penttilä) [2154295]
- drm/tegra: submit: Add missing pm_runtime_mark_last_busy() (Mika Penttilä) [2154295]
- drm/tegra: vic: Handle tegra_drm_alloc() failure (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix DMA API misuse (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Register audio CODEC on Tegra20 (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Unwind tegra_hdmi_init() errors (Mika Penttilä) [2154295]
- drm/tegra: Mark nvdec PM functions as __maybe_unused (Mika Penttilä) [2154295]
- drm/tegra: Mark nvdec_writel() as inline (Mika Penttilä) [2154295]
- drm/tegra: dc: rgb: Allow changing PLLD rate on Tegra30+ (Mika Penttilä) [2154295]
- drm/tegra: Remove duplicate struct declaration (Mika Penttilä) [2154295]
- drm/tegra: vic: Use autosuspend (Mika Penttilä) [2154295]
- drm/tegra: gr2d: Explicitly control module reset (Mika Penttilä) [2154295]
- drm/tegra: dc: rgb: Move PCLK shifter programming to CRTC (Mika Penttilä) [2154295]
- drm/tegra: Bump VIC/NVDEC clock rates to Fmax (Mika Penttilä) [2154295]
- drm/tegra: Add NVDEC driver (Mika Penttilä) [2154295]
- drm/tegra: Support asynchronous commits for cursor (Mika Penttilä) [2154295]
- drm/tegra: Propagate errors from drm_gem_plane_helper_prepare_fb() (Mika Penttilä) [2154295]
- drm/tegra: Do not reference tegra_plane_funcs directly (Mika Penttilä) [2154295]
- drm/tegra: Implement buffer object cache (Mika Penttilä) [2154295]
- drm/tegra: Implement correct DMA-BUF semantics (Mika Penttilä) [2154295]
- drm/tegra: uapi: Fix wrong mapping end address in case of disabled IOMMU (Mika Penttilä) [2154295]
- drm/tegra: dc: Remove unused variables (Mika Penttilä) [2154295]
- drm/tegra: Use fourcc_mod_is_vendor() helper (Mika Penttilä) [2154295]
- drm/tegra: dc: Extend debug stats with total number of events (Mika Penttilä) [2154295]
- drm/tegra: dc: Support memory bandwidth management (Mika Penttilä) [2154295]
- drm/tegra: Bump driver version (Mika Penttilä) [2154295]
- drm/tegra: Add job firewall (Mika Penttilä) [2154295]
- drm/tegra: Implement job submission part of new UAPI (Mika Penttilä) [2154295]
- gpu: host1x: Add support for syncpoint waits in CDMA pushbuffer (Mika Penttilä) [2154295]
- drm/tegra: Implement syncpoint wait UAPI (Mika Penttilä) [2154295]
- drm/tegra: Implement syncpoint management UAPI (Mika Penttilä) [2154295]
- drm/tegra: Implement new UAPI (Mika Penttilä) [2154295]
- drm/tegra: Allocate per-engine channel in core code (Mika Penttilä) [2154295]
- drm/tegra: Boot VIC during runtime PM resume (Mika Penttilä) [2154295]
- drm/tegra: Extract tegra_gem_lookup() (Mika Penttilä) [2154295]
- gpu: host1x: Add option to skip firewall for a job (Mika Penttilä) [2154295]
- gpu: host1x: Add job release callback (Mika Penttilä) [2154295]
- gpu: host1x: Add DMA fence implementation (Mika Penttilä) [2154295]
- gpu: host1x: Add no-recovery mode (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit fb8d617f8fd6 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commits 720cf96d8fecd da68386d9edb (Mika Penttilä) [2154295]
- drm/tegra: Remove workarounds needed to compile tegra after from DRM backport 99fc716 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit adb9d5a2cc77 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit a2151490cc6c (Mika Penttilä) [2154295]
- drm/tegra: Don't set struct drm_device.irq_enabled (Mika Penttilä) [2154295]
- Initial Orin graphics support (tegra drm and host1x) (Mika Penttilä) [2154295]

* Mon Jan 30 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-248.el9]
- ALSA: pcm: Move rwsem lock inside snd_ctl_elem_read to prevent UAF (Jaroslav Kysela) [2125540] {CVE-2023-0266}
- ALSA: usb-audio: Remove redundant workaround for Roland quirk (Jaroslav Kysela) [2125540]
- ASoC: jz4740-i2s: Handle independent FIFO flush bits (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Apply dual codec fixup for Dell Latitude laptops (Jaroslav Kysela) [2125540]
- ALSA: patch_realtek: Fix Dell Inspiron Plus 16 (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: Static PCM mapping again with AMD HDMI codecs (Jaroslav Kysela) [2125540]
- ALSA: line6: fix stack overflow in line6_midi_transmit (Jaroslav Kysela) [2125540]
- ALSA: line6: correct midi status byte when receiving data from podxt (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: Add HP Device 0x8711 to force connect list (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for Lenovo TianYi510Pro-14IOB (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: add the quirk for KT0206 device (Jaroslav Kysela) [2125540]
- ASoC: rt5670: Remove unbalanced pm_runtime_put() (Jaroslav Kysela) [2125540]
- ASoC: rockchip: spdif: Add missing clk_disable_unprepare() in rk_spdif_runtime_resume() (Jaroslav Kysela) [2125540]
- ASoC: wm8994: Fix potential deadlock (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: fix stream-id config keep-alive for rt suspend (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: set default audio parameters for KAE silent-stream (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: fix i915 silent stream programming flow (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8183: fix refcount leak in mt8183_mt6358_ts3a227_max98357_dev_probe() (Jaroslav Kysela) [2125540]
- ASoC: rockchip: pdm: Add missing clk_disable_unprepare() in rockchip_pdm_runtime_resume() (Jaroslav Kysela) [2125540]
- ASoC: audio-graph-card: fix refcount leak of cpu_ep in __graph_for_each_link() (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8173-rt5650-rt5514: fix refcount leak in mt8173_rt5650_rt5514_dev_probe() (Jaroslav Kysela) [2125540]
- ASoC: Intel: Skylake: Fix driver hang during shutdown (Jaroslav Kysela) [2125540]
- ALSA: hda: add snd_hdac_stop_streams() helper (Jaroslav Kysela) [2125540]
- ASoC: sof_es8336: fix possible use-after-free in sof_es8336_remove() (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Xiaomi Redmi Book Pro 14 2022 into DMI table (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125540]
- ASoC: codecs: rt298: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125540]
- ALSA: mts64: fix possible null-ptr-defer in snd_mts64_interrupt (Jaroslav Kysela) [2125540]
- ALSA: pcm: Set missing stop_operating flag at undoing trigger start (Jaroslav Kysela) [2125540]
- ASoC: pcm512x: Fix PM disable depth imbalance in pcm512x_probe (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8173: Enable IRQ when pdata is ready (Jaroslav Kysela) [2125540]
- ALSA: asihpi: fix missing pci_disable_device() (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mtk-btcvsd: Add checks for write and read of mtk_btcvsd_snd (Jaroslav Kysela) [2125540]
- ASoC: qcom: Add checks for devm_kcalloc (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Lock substream before snd_pcm_stop() (Jaroslav Kysela) [2125540]
- ASoC: pxa: fix null-pointer dereference in filter() (Jaroslav Kysela) [2125540]
- ASoC: codecs: wsa883x: use correct header file (Jaroslav Kysela) [2125540]
- ASoC: codecs: wsa883x: Use proper shutdown GPIO polarity (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Fix potential RX buffer overflow (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Fix DMA mask assignment (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2125540]
- ASoC: ops: Correct bounds check for second channel on SX controls (Jaroslav Kysela) [2125540]
- ASoC: cs42l51: Correct PGA Volume minimum value (Jaroslav Kysela) [2125540]
- ASoC: ops: Check bounds for second channel in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2125540]
- ASoC: fsl_micfil: explicitly clear CHnF flags (Jaroslav Kysela) [2125540]
- ASoC: fsl_micfil: explicitly clear software reset bit (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: More robust component matching for CS35L41 (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm: Add NULL check in BE reparenting (Jaroslav Kysela) [2125540]
- ALSA: seq: Fix function prototype mismatch in snd_seq_expand_var_event (Jaroslav Kysela) [2125540]
- ASoC: rt711-sdca: fix the latency time of clock stop prepare state machine transitions (Jaroslav Kysela) [2125540]
- ASoC: wm8962: Wait for updated value of WM8962_CLOCKING1 register (Jaroslav Kysela) [2125540]
- ASoC: tlv320adc3xxx: Fix build error for implicit function declaration (Jaroslav Kysela) [2125540]
- ASoC: ops: Fix bounds check for _sx controls (Jaroslav Kysela) [2125540]
- ALSA: dice: fix regression for Lexicon I-ONIX FW810S (Jaroslav Kysela) [2125540]
- ASoC: stm32: dfsdm: manage cb buffers cleanup (Jaroslav Kysela) [2125540]
- ASoC: sof_es8336: reduce pop noise on speaker (Jaroslav Kysela) [2125540]
- ASoC: SOF: ipc3-topology: use old pipeline teardown flow with SOF2.1 and older (Jaroslav Kysela) [2125540]
- ASoC: hda: intel-dsp-config: add ES83x6 quirk for IceLake (Jaroslav Kysela) [2125540]
- ASoC: Intel: soc-acpi: add ES83x6 support to IceLake (Jaroslav Kysela) [2125540]
- ASoC: Intel: bytcht_es8316: Add quirk for the Nanote UMPC-01 (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Alienware m17 R5 AMD into DMI table (Jaroslav Kysela) [2125540]
- ASoC: max98373: Add checks for devm_kcalloc (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm: Don't zero TDM masks in __soc_pcm_open() (Jaroslav Kysela) [2125540]
- ASoC: sgtl5000: Reset the CHIP_CLK_CTRL reg on remove (Jaroslav Kysela) [2125540]
- ASoC: hdac_hda: fix hda pcm buffer overflow issue (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: add quirk to fix Hamedal C20 disconnect issue (Jaroslav Kysela) [2125540]
- ASoC: SOF: topology: No need to assign core ID if token parsing failed (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book Pro 360 (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: fix speakers for Samsung Galaxy Book Pro (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Drop snd_BUG_ON() from snd_usbmidi_output_open() (Jaroslav Kysela) [2125540]
- ASoC: soc-utils: Remove __exit for snd_soc_util_exit() (Jaroslav Kysela) [2125540]
- ASoC: rt5677: fix legacy dai naming (Jaroslav Kysela) [2125540]
- ASoC: rt5514: fix legacy dai naming (Jaroslav Kysela) [2125540]
- ASoC: tas2780: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: tas2764: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: tas2770: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: fsl_asrc fsl_esai fsl_sai: allow CONFIG_PM=N (Jaroslav Kysela) [2125540]
- ASoC: core: Fix use-after-free in snd_soc_exit() (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: Fix spelling mistake "Sourc" -> "Source", "Routee" -> "Route" (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Lenovo Thinkbook 14+ 2022 21D0 to quirks table (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Adding Lenovo ThinkBook 14 Gen 4+ ARA and Lenovo ThinkBook 16 Gen 4+ ARA to the Quirks List (Jaroslav Kysela) [2125540]
- ASoC: rt1308-sdw: add the default value of some registers (Jaroslav Kysela) [2125540]
- ASoC: Intel: sof_rt5682: Add quirk for Rex board (Jaroslav Kysela) [2125540]
- ASoC: Intel: sof_sdw: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: fix capture selector naming (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: use right control for Capture Volume (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: fix reported volume for Master ctl (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: add missed Line In power control bit (Jaroslav Kysela) [2125540]
- ASoC: wm8962: Add an event handler for TEMP_HP and TEMP_SPK (Jaroslav Kysela) [2125540]
- ASoC: rt1019: Fix the TDM settings (Jaroslav Kysela) [2125540]
- ASoC: rt5682s: Fix the TDM Tx settings (Jaroslav Kysela) [2125540]
- ASoC: mt6660: Keep the pm_runtime enables before component stuff in mt6660_i2c_probe (Jaroslav Kysela) [2125540]
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe" (Jaroslav Kysela) [2125540]
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe" (Jaroslav Kysela) [2125540]
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe" (Jaroslav Kysela) [2125540]
- ALSA: memalloc: Try dma_alloc_noncontiguous() at first (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add DSD support for Accuphase DAC-60 (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirk entry for M-Audio Micro (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Yet more regression for for the delayed card registration (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add Positivo C6300 model quirk (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125540]
- ALSA: hda: fix potential memleak in 'add_widget_node' (Jaroslav Kysela) [2125540]
- ALSA: hda/ca0132: add quirk for EVGA Z390 DARK (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi - enable runtime pm for more AMD display audio (Jaroslav Kysela) [2125540]
- ALSA: memalloc: Don't fall back for SG-buffer with IOMMU (Jaroslav Kysela) [2125540]
- ALSA: aoa: Fix I2S device accounting (Jaroslav Kysela) [2125540]
- ALSA: aoa: i2sbus: fix possible memory leak in i2sbus_add_dev() (Jaroslav Kysela) [2125540]
- ALSA: ac97: fix possible memory leak in snd_ac97_dev_register() (Jaroslav Kysela) [2125540]
- ASoC: SOF: Intel: pci-tgl: fix ADL-N descriptor (Jaroslav Kysela) [2125540]
- ASoC: SOF: Intel: pci-tgl: use RPL specific firmware definitions (Jaroslav Kysela) [2125540]
- ASoC: Intel: common: add ACPI matching tables for Raptor Lake (Jaroslav Kysela) [2125540]
- ASoC: qcom: lpass-cpu: Mark HDMI TX parity register as volatile (Jaroslav Kysela) [2125540]
- ASoC: codecs: tlv320adc3xxx: Wrap adc3xxx_i2c_remove() in __exit_p() (Jaroslav Kysela) [2125540]
- ASoC: qcom: lpass-cpu: mark HDMI TX registers as volatile (Jaroslav Kysela) [2125540]
- ASoC: codec: tlv320adc3xxx: add GPIOLIB dependency (Jaroslav Kysela) [2125540]
- ALSA: rme9652: use explicitly signed char (Jaroslav Kysela) [2125540]
- ALSA: au88x0: use explicitly signed char (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add another HP ZBook G9 model quirks (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirks for M-Audio Fast Track C400/600 (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125540]
- ALSA: Use del_timer_sync() before freeing timer (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix last interface check for registration (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Lenovo Yoga Slim 7 Pro X to quirks table (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add ASUS UM5302TA into DMI table (Jaroslav Kysela) [2125540]
- ASoC: SOF: add quirk to override topology mclk_id (Jaroslav Kysela) [2125540]
- ASoC: sunxi: sun4i-codec: set debugfs_prefix for CPU DAI component (Jaroslav Kysela) [2125540]
- ASoC: SOF: pci: Change DMI match info to support all Chrome platforms (Jaroslav Kysela) [2125540]
- ALSA: intel-dspconfig: add ES8336 support for AlderLake-PS (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Register card at the last interface (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirk to enable Avid Mbox 3 support (Jaroslav Kysela) [2125540]
- ASoC: mt6660: Fix PM disable depth imbalance in mt6660_i2c_probe (Jaroslav Kysela) [2125540]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2125540]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2125540]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2125540]
- ASoC: stm: Fix PM disable depth imbalance in stm32_i2s_probe (Jaroslav Kysela) [2125540]
- ASoC: stm32: spdifrx: Fix PM disable depth imbalance in stm32_spdifrx_probe (Jaroslav Kysela) [2125540]
- ASoC: stm32: dfsdm: Fix PM disable depth imbalance in stm32_adfsdm_probe (Jaroslav Kysela) [2125540]
- ALSA: dmaengine: increment buffer pointer atomically (Jaroslav Kysela) [2125540]
- ASoC: da7219: Fix an error handling path in da7219_register_dai_clks() (Jaroslav Kysela) [2125540]
- ASoC: codecs: tx-macro: fix kcontrol put (Jaroslav Kysela) [2125540]
- ASoC: eureka-tlv320: Hold reference returned from of_find_xxx API (Jaroslav Kysela) [2125540]
- ASoC: wm_adsp: Handle optional legacy support (Jaroslav Kysela) [2125540]
- ASoC: rsnd: Add check for rsnd_mod_power_on (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm.c: call __soc_pcm_close() in soc_pcm_close() (Jaroslav Kysela) [2125540]
- ASoC: mt6359: fix tests for platform_get_irq() failure (Jaroslav Kysela) [2125540]
- ASoC: wcd934x: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125540]
- ASoC: wcd9335: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add Intel Reference SSID to support headset keys (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS GV601R laptop (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix NULL dererence at error path (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix potential memory leaks (Jaroslav Kysela) [2125540]
- ALSA: rawmidi: Drop register_mutex in snd_rawmidi_free() (Jaroslav Kysela) [2125540]
- ALSA: oss: Fix potential deadlock at unregistration (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for HP Zbook Firefly 14 G9 model (Jaroslav Kysela) [2125540]
- ALSA: hda: Fix position reporting on Poulsbo (Jaroslav Kysela) [2125540]
- ALSA: seq: fix undefined behavior in bit shift for SNDRV_SEQ_FILTER_USE_EVENT (Jaroslav Kysela) [2125540]
- soundwire: dmi-quirks: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2125540]
- soundwire: intel: Initialize clock stop timeout (Jaroslav Kysela) [2125540]
- soundwire: dmi-quirks: add remapping for HP Omen 16-k0005TX (Jaroslav Kysela) [2125540]
- soundwire: qcom: check for outanding writes before doing a read (Jaroslav Kysela) [2125540]
- soundwire: qcom: reinit broadcast completion (Jaroslav Kysela) [2125540]
- soundwire: intel: fix error handling on dai registration issues (Jaroslav Kysela) [2125540]
- soundwire: cadence: Don't overwrite msg->buf during write commands (Jaroslav Kysela) [2125540]

* Fri Jan 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-247.el9]
- powerpc/hv-gpci: Fix hv_gpci event list (Mamatha Inamdar) [2162652]
- powerpc: declare unmodified attribute_group usages const (Mamatha Inamdar) [2162652]
- powerpc/perf: Fix branch_filter support for multiple filters (Steve Best) [2162235]
- s390/kexec: fix ipl report address for kdump (Tobias Huschle) [2161327]
- RHEL: ALSA: enable AMD Pink Sardine DMIC driver (Jaroslav Kysela) [2097071]
- ASoC: amd: ps: Move acp63_dev_data strcture from PCI driver (Jaroslav Kysela) [2097071]
- ASoC: amd: ps: update macros with ps platform naming convention (Jaroslav Kysela) [2097071]
- ASoC: amd: fix ACP version typo mistake (Jaroslav Kysela) [2097071]
- ASoC: amd: fix spelling mistake: "i.e" -> "i.e." (Jaroslav Kysela) [2097071]
- ASoC: amd: enable Pink sardine platform machine driver build. (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine machine driver using dmic (Jaroslav Kysela) [2097071]
- ASoC: amd: create platform device for acp6.2 machine driver (Jaroslav Kysela) [2097071]
- ASoC: amd: enable Pink Sardine acp6.2 drivers build (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm driver pm ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pci driver pm ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm driver dma ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 irq handler (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm platform driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add platform devices for acp6.2 pdm driver and dmic driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 init/de-init functions (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine ACP PCI driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine platform ACP IP register header (Jaroslav Kysela) [2097071]
- arm64: defconfig: Drop ARM_CPUIDLE(generic idle driver) config (Mark Langsdorf) [2122313]
- cpuidle: Add cpu_idle_miss trace event (Mark Langsdorf) [2122313]
- cpuidle: cpuidle-arm: remove arm64 support (Mark Langsdorf) [2122313]
- cpuidle: haltpoll: Add trace points for guest_halt_poll_ns grow/shrink (Mark Langsdorf) [2122313]
- cpuidle: PSCI: Improve support for suspend-to-RAM for PSCI OSI mode (Mark Langsdorf) [2122313]

* Fri Jan 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-246.el9]
- platform/mellanox: Remove redundant 'NULL' check (Mark Langsdorf) [2122315]
- platform/mellanox: Remove unnecessary code (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix locking issue (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix coverity warning (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix error flow and extend verbosity (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Add bit offset for DP VDO (Mark Langsdorf) [2122315]
- platform/chrome: Use tables for values lists of ChromeOS ACPI sysfs ABI (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: fix build warning (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return -EPROTO if empty payload (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return -EAGAIN when retries timed out (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_wait_until_complete() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_xfer_command() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: add "cros_ec_" prefix to send_command() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Register port altmodes (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Rename port altmode array (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Use dev_err_probe on port register fail (Mark Langsdorf) [2122315]
- platform/chrome: wilco_ec: event: Fix typo in comment (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: Always expose last resume result (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Fix spelling mistake "unknwon" -> "unknown" (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return 0 on getting wake mask success (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: check `msg->result` in getting cmd mask (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return 0 on getting cmd mask success (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: don't show MKBP version if unsupported (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: handle empty payload in getting proto info (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_get_proto_info() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: use cros_ec_map_error() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: remove redundant NULL check (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: assign buffer size from protocol info (Mark Langsdorf) [2122315]
- platform/chrome: use macros for passthru indexes (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: support EC PWM backend (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: support OF match (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: separate ACPI backend (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: sort headers alphabetically (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Update size arg types (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Rename cros_ec_command function (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: update cros_ec_check_result() comment (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: factor legacy out from cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: add Kunit tests for cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_spi: drop unneeded BUG_ON() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_i2c: drop BUG_ON() in cros_ec_pkt_xfer_i2c() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop BUG_ON() in cros_ec_get_host_event() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop BUG_ON() in cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: correct cros_ec_prepare_tx() usage (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop unneeded BUG_ON() in prepare_packet() (Mark Langsdorf) [2122315]
- redhat/configs: Enable ChromeOS ACPI driver for Chrome platforms (Mark Langsdorf) [2122315]
- platform/chrome: Add ChromeOS ACPI device driver (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Check for EC driver (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_lpcs: reserve the MEC LPC I/O ports first (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_lpcs: detect the Framework Laptop (Mark Langsdorf) [2122315]
- platform/chrome: Re-introduce cros_ec_cmd_xfer and use it for ioctls (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: append newline to all logs (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: sort header inclusion alphabetically (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: determine `wake_enabled` in cros_ec_suspend() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: remove unused variable `was_wake_device` (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: fix error handling in cros_ec_register() (Mark Langsdorf) [2122315]

* Thu Jan 26 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-245.el9]
- RDMA/bnxt_re: Fix endianness warning for req.pkey (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use bitmap_zalloc() when applicable (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove dynamic pkey table (Kamal Heib) [2142686]
- RDMA/bnxt_re: Scan the whole bitmap when checking if "disabling RCFW with pending cmd-bit" (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove unneeded variable (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove unsupported bnxt_re_modify_ah callback (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use helper function to set GUIDs (Kamal Heib) [2142686]
- RDMA/bnxt_re: Check if the vlan is valid before reporting (Kamal Heib) [2142686]
- RDMA/bnxt_re: Correct FRMR size calculation (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use GFP_KERNEL in non atomic context (Kamal Heib) [2142686]
- RDMA/bnxt_re: Fix FRMR issue with single page MR allocation (Kamal Heib) [2142686]
- RDMA/bnxt_re: Fix query SRQ failure (Kamal Heib) [2142686]
- RDMA/bnxt_re: Suppress unwanted error messages (Kamal Heib) [2142686]
- RDMA/bnxt_re: Support multiple page sizes (Kamal Heib) [2142686]
- RDMA/bnxt_re: Reduce the delay in polling for hwrm command completion (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use separate response buffer for stat_ctx_free (Kamal Heib) [2142686]
- RDMA/bnxt_re: Prefer kcalloc over open coded arithmetic (Kamal Heib) [2142686]
- config: Enable Security Path (Ricardo Robaina) [2161307]
- nvme: fix SRCU protection of nvme_ns_head list (Ewan D. Milne) [2160573]
- PCI/MSI: Move descriptor counting on allocation fail to the legacy code (Myron Stowe) [2151246]
- genirq/msi: Handle PCI/MSI allocation fail in core code (Myron Stowe) [2151246]
- PCI/MSI: Make pci_msi_domain_check_cap() static (Myron Stowe) [2151246]
- PCI/MSI: Move msi_lock to struct pci_dev (Myron Stowe) [2151246]
- PCI/MSI: Sanitize MSI-X table map handling (Myron Stowe) [2151246]
- PCI/MSI: Split out irqdomain code (Myron Stowe) [2151246]
- PCI/MSI: Split out !IRQDOMAIN code (Myron Stowe) [2151246]
- PCI/MSI: Split out CONFIG_PCI_MSI independent part (Myron Stowe) [2151246]
- PCI/MSI: Move code into a separate directory (Myron Stowe) [2151246]
- PCI/MSI: Make msix_update_entries() smarter (Myron Stowe) [2151246]
- PCI/MSI: Cleanup include zoo (Myron Stowe) [2151246]
- PCI/MSI: Make arch_restore_msi_irqs() less horrible. (Myron Stowe) [2151246]
- genirq/msi, treewide: Use a named struct for PCI/MSI attributes (Myron Stowe) [2151246]
- MIPS: Octeon: Use arch_setup_msi_irq() (Myron Stowe) [2151246]
- PCI/sysfs: Use pci_irq_vector() (Myron Stowe) [2151246]
- PCI/MSI: Remove msi_desc_to_pci_sysdata() (Myron Stowe) [2151246]
- PCI/MSI: Make pci_msi_domain_write_msg() static (Myron Stowe) [2151246]
- genirq/msi: Fixup includes (Myron Stowe) [2151246]
- genirq/msi: Remove unused domain callbacks (Myron Stowe) [2151246]
- genirq/msi: Guard sysfs code (Myron Stowe) [2151246]
- PCI/MSI: Fix pci_irq_vector()/pci_irq_get_affinity() (Myron Stowe) [2151246]
- powerpc/4xx: Complete removal of MSI support (Myron Stowe) [2151246]
- powerpc/4xx: Remove MSI support which never worked (Myron Stowe) [2151246]
- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error (Myron Stowe) [2151246]
- PCI/MSI: Mask MSI-X vectors only on success (Myron Stowe) [2151246]
- genirq: Fix kernel-doc warnings in pm.c, msi.c and ipi.c (Myron Stowe) [2151246]
- efi/cper, cxl: Decode CXL Error Log (Lenny Szubowicz) [2143734]
- efi/cper, cxl: Decode CXL Protocol Error Section (Lenny Szubowicz) [2143734]

* Wed Jan 25 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-244.el9]
- gitlab-ci: use CI templates from production branch (Michael Hofmann)
- net/mlx5: fw_reset: Don't try to load device in case PCI isn't working (Petr Oros) [2131117]
- net/mlx5: Fix sync reset event handler error flow (Petr Oros) [2131117]
- net/mlx5: Lag, Fix for loop when checking lag (Petr Oros) [2131117]
- net/mlx5: E-switch, Destroy legacy fdb table when needed (Petr Oros) [2131117]
- net/mlx5: E-switch, Fix duplicate lag creation (Petr Oros) [2131117]
- net/mlx5: Unlock on error in mlx5_sriov_enable() (Petr Oros) [2131117]
- Documentation: devlink: add add devlink-selftests to the table of contents (Petr Oros) [2131117]
- mlxsw: minimal: Fix deadlock in ports creation (Petr Oros) [2131117]
- mlxsw: core: Fix use-after-free calling devl_unlock() in mlxsw_core_bus_device_unregister() (Petr Oros) [2131117]
- net/mlx5: unlock on error path in esw_vfs_changed_event_handler() (Petr Oros) [2131117]
- net/mlx5: E-switch, Set to legacy mode if failed to change switchdev mode (Petr Oros) [2131117]
- net: devlink: add port_init/fini() helpers to allow pre-register/post-unregister functions (Petr Oros) [2131117]
- net: devlink: introduce a flag to indicate devlink port being registered (Petr Oros) [2131117]
- net: devlink: introduce port registered assert helper and use it (Petr Oros) [2131117]
- net: devlink: stub port params cmds for they are unused internally (Petr Oros) [2131117]
- net: devlink: limit flash component name to match version returned by info_get() (Petr Oros) [2131117]
- netdevsim: add version fw.mgmt info info_get() and mark as a component (Petr Oros) [2131117]
- net: devlink: extend info_get() version put to indicate a flash component (Petr Oros) [2131117]
- net: devlink: Fix missing mutex_unlock() call (Petr Oros) [2131117]
- net: devlink: enable parallel ops on netlink interface (Petr Oros) [2131117]
- net: devlink: remove devlink_mutex (Petr Oros) [2131117]
- net: devlink: convert reload command to take implicit devlink->lock (Petr Oros) [2131117]
- net: devlink: introduce "unregistering" mark and use it during devlinks iteration (Petr Oros) [2131117]
- devlink: Hold the instance lock in health callbacks (Petr Oros) [2131117]
- net/mlx5: Lock mlx5 devlink health recovery callback (Petr Oros) [2131117]
- net/mlx4: Lock mlx4 devlink reload callback (Petr Oros) [2131117]
- net/mlx4: Use devl_ API for devlink port register / unregister (Petr Oros) [2131117]
- net/mlx4: Use devl_ API for devlink region create / destroy (Petr Oros) [2131117]
- net/mlx5: Lock mlx5 devlink reload callbacks (Petr Oros) [2131117]
- net/mlx5: Move fw reset unload to mlx5_fw_reset_complete_reload (Petr Oros) [2131117]
- net: devlink: remove region snapshots list dependency on devlink->lock (Petr Oros) [2131117]
- net: devlink: remove region snapshot ID tracking dependency on devlink->lock (Petr Oros) [2131117]
- devlink: introduce framework for selftests (Petr Oros) [2131117]
- net: devlink: remove redundant net_eq() check from sb_pool_get_dumpit() (Petr Oros) [2131117]
- mlxsw: core_linecards: Introduce per line card auxiliary device (Petr Oros) [2131117]
- net: devlink: introduce nested devlink entity for line card (Petr Oros) [2131117]
- net: devlink: move net check into devlinks_xa_for_each_registered_get() (Petr Oros) [2131117]
- net: devlink: make sure that devlink_try_get() works with valid pointer during xarray iteration (Petr Oros) [2131117]
- net: devlink: remove unused locked functions (Petr Oros) [2131117]
- netdevsim: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_region_create/destroy() functions (Petr Oros) [2131117]
- mlxsw: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_dpipe*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_sb*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_resource*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devling_trap*() functions (Petr Oros) [2131117]
- net: devlink: avoid false DEADLOCK warning reported by lockdep (Petr Oros) [2131117]
- net: devlink: fix return statement in devlink_port_new_notify() (Petr Oros) [2131117]
- net: devlink: fix a typo in function name devlink_port_new_notifiy() (Petr Oros) [2131117]
- net: devlink: make devlink_dpipe_headers_register() return void (Petr Oros) [2131117]
- net: devlink: move unlocked function prototypes alongside the locked ones (Petr Oros) [2131117]
- net: devlink: use helpers to work with devlink->lock mutex (Petr Oros) [2131117]
- net: devlink: fix unlocked vs locked functions descriptions (Petr Oros) [2131117]
- devlink: Hold the instance lock in port_new / port_del callbacks (Petr Oros) [2131117]
- net/mlx5: Remove devl_unlock from mlx5_devlink_eswitch_mode_set (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5e_devlink_port_register (Petr Oros) [2131117]
- devlink: Remove unused functions devlink_rate_leaf_create/destroy (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5_esw_devlink_sf_port_register (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5_esw_offloads_devlink_port_register (Petr Oros) [2131117]
- devlink: Remove unused function devlink_rate_nodes_destroy (Petr Oros) [2131117]
- net/mlx5: Use devl_ API for rate nodes destroy (Petr Oros) [2131117]
- net/mlx5: Remove devl_unlock from mlx5_eswtich_mode_callback_enter (Petr Oros) [2131117]
- net/mlx5: E-switch: Change eswitch mode only via devlink command (Petr Oros) [2131117]
- net/mlx5: E-switch, Remove dependency between sriov and eswitch mode (Petr Oros) [2131117]
- net/mlx5: E-switch, Introduce flag to indicate if fdb table is created (Petr Oros) [2131117]
- net/mlx5: E-switch, Introduce flag to indicate if vport acl namespace is created (Petr Oros) [2131117]
- devlink: adopt u64_stats_t (Petr Oros) [2131117]

* Tue Jan 24 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-243.el9]
- powerpc/kprobes: Fix null pointer reference in arch_prepare_kprobe() (Mamatha Inamdar) [2153859]
- drm/amd: Delay removal of the firmware framebuffer (Michel Dänzer) [2155886]
- selftests/bpf: test_stacktrace_build_id: use kprobe/urandom_read (Yauheni Kaliuta) [2161467]
- tracing: Avoid adding tracer option before update_tracer_options (Thomas Huth) [2155737]
- s390/dasd: fix no record found for raw_track_access (Tobias Huschle) [2161269]
- perf tools: Fix empty version number when building outside of a git repo (Michael Petlan) [2155125]
- s390/cio: check the subchannel validity for dev_busid (Tobias Huschle) [2160493]
- s390/cio: add dev_busid sysfs entry for each subchannel (Tobias Huschle) [2160493]
- redhat: ignore rpminspect runpath report on urandom_read selftest binaries (Herton R. Krzesinski) [2155887]
- vhost/vsock: Fix error handling in vhost_vsock_init() (Stefano Garzarella) [2160028]
- net: vmw_vsock: vmci: Check memcpy_from_msg() (Stefano Garzarella) [2160028]
- vsock: fix possible infinite sleep in vsock_connectible_wait_data() (Stefano Garzarella) [2160028]
- vsock: remove the unused 'wait' in vsock_connectible_recvmsg() (Stefano Garzarella) [2160028]
- vhost/vsock: Use kvmalloc/kvfree for larger packets. (Stefano Garzarella) [2160028]
- vsock/vmci: fix repeated words in comments (Stefano Garzarella) [2160028]
- vsock_test: POLLIN + SO_RCVLOWAT test (Stefano Garzarella) [2160028]
- vmci/vsock: check SO_RCVLOWAT before wake up reader (Stefano Garzarella) [2160028]
- virtio/vsock: check SO_RCVLOWAT before wake up reader (Stefano Garzarella) [2160028]
- vsock: add API call for data ready (Stefano Garzarella) [2160028]
- vsock: pass sock_rcvlowat to notify_poll_in as target (Stefano Garzarella) [2160028]
- vmci/vsock: use 'target' in notify_poll_in callback (Stefano Garzarella) [2160028]
- virtio/vsock: use 'target' in notify_poll_in callback (Stefano Garzarella) [2160028]
- hv_sock: disable SO_RCVLOWAT support (Stefano Garzarella) [2160028]
- vsock: SO_RCVLOWAT transport set callback (Stefano Garzarella) [2160028]
- vsock: Set socket state back to SS_UNCONNECTED in vsock_connect_timeout() (Stefano Garzarella) [2160028]
- vsock: Fix memory leak in vsock_connect() (Stefano Garzarella) [2160028]
- dt-bindings: mailbox: qcom-ipcc: Add SM6375 compatible (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: Add NSP1 client (Eric Chanudet) [2123807]
- mailbox: correct kerneldoc (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: simplify the example (Eric Chanudet) [2123807]
- Revert "dt-bindings: mailbox: qcom-ipcc: add missing properties into example" (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: add missing properties into example (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: add missing compatible for SM8450 (Eric Chanudet) [2123807]
- dt-bindings: mailbox: Add more protocol and client ID (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Support interrupt wake up from suspend (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Support more IPCC instance (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Dynamic alloc for channel arrangement (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: Add compatible for SM6350 (Eric Chanudet) [2123807]

* Mon Jan 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-242.el9]
- net: Fix a data-race around gro_normal_batch. (Guillaume Nault) [2160073]
- ratelimit: Fix data-races in ___ratelimit(). (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_notify_on_flag_change. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_reflect_tos. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_nr. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_slack_ns. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_delay_ns. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sk_pacing_rate. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_invalid_ratelimit. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_autocorking. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_min_rtt_wlen. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_min_tso_segs. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_challenge_ack_limit. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_limit_output_bytes. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_no_ssthresh_metrics_save. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_nometrics_save. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_frto. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_adv_win_scale. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_app_win. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_dsack. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_max_reordering. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_abort_on_overflow. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_rfc1337. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_stdurg. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_retrans_collapse. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_slow_start_after_idle. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_thin_linear_timeouts. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_recovery. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_early_retrans. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl knobs related to SYN option. (Guillaume Nault) [2160073]
- ip: Fix data-races around sysctl_ip_prot_sock. (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_multipath_hash_fields. (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_multipath_hash_policy. (Guillaume Nault) [2160073]
- ipv4: Fix a data-race around sysctl_fib_multipath_use_neigh. (Guillaume Nault) [2160073]
- selftests/timens: add a test for vfork+exit (Oleg Nesterov) [2116442]
- fs/exec: switch timens when a task gets a new mm (Oleg Nesterov) [2116442]
- powerpc/pseries/vas: sysfs comments with the correct entries (Mukesh Chaurasiya) [2130348]
- powerpc/pseries/vas: use default_groups in kobj_type (Mukesh Chaurasiya) [2130348]
- powerpc/pseries/vas: Add VAS IRQ primary handler (Mukesh Chaurasiya) [2130348]
- powerpc: Ignore DSI error caused by the copy/paste instruction (Mukesh Chaurasiya) [2130348]
- powerpc/pseries: Move vas_migration_handler early during migration (Mukesh Chaurasiya) [2130348]

* Fri Jan 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-241.el9]
- blk-cgroup: Optimize blkcg_rstat_flush() (Waiman Long) [2077665]
- blk-cgroup: Return -ENOMEM directly in blkcg_css_alloc() error path (Waiman Long) [2077665]
- cgroup/cpuset: Optimize cpuset_attach() on v2 (Waiman Long) [2077665]
- cgroup/cpuset: Skip spread flags update on v2 (Waiman Long) [2077665]
- cgroup: Reorganize css_set_lock and kernfs path processing (Waiman Long) [2077665]
- mm: memcontrol: don't allocate cgroup swap arrays when memcg is disabled (Waiman Long) [2077665]
- cgroup: Make cgroup_get_from_id() prettier (Waiman Long) [2077665]
- cgroup: Fix build failure when CONFIG_SHRINKER_DEBUG (Waiman Long) [2077665]
- cgroup: Homogenize cgroup_get_from_id() return value (Waiman Long) [2077665]
- cgroup: cgroup: Honor caller's cgroup NS when resolving cgroup id (Waiman Long) [2077665]
- cgroup: Honor caller's cgroup NS when resolving path (Waiman Long) [2077665]
- cgroup: Add missing cpus_read_lock() to cgroup_attach_task_all() (Waiman Long) [2077665]
- cgroup: Fix race condition at rebind_subsystems() (Waiman Long) [2077665]
- cgroup: Fix threadgroup_rwsem <-> cpus_read_lock() deadlock (Waiman Long) [2077665]
- mm/memcontrol.c: remove the redundant updating of stats_flush_threshold (Waiman Long) [2077665]
- cgroup: Skip subtree root in cgroup_update_dfl_csses() (Waiman Long) [2077665]
- cgroup: Elide write-locking threadgroup_rwsem when updating csses on an empty subtree (Waiman Long) [2077665]
- mm: memcontrol: introduce mem_cgroup_ino() and mem_cgroup_get_from_ino() (Waiman Long) [2077665]
- cgroup: Use separate src/dst nodes when preloading css_sets for migration (Waiman Long) [2077665]
- cgroup.c: add helper __cset_cgroup_from_root to cleanup duplicated codes (Waiman Long) [2077665]
- cgroup/rstat: check updated_next only for root (Waiman Long) [2077665]
- cgroup: rstat: explicitly put loop variant in while (Waiman Long) [2077665]
- cgroup: return early if it is already on preloaded list (Waiman Long) [2077665]
- cgroup: Trace event cgroup id fields should be u64 (Waiman Long) [2077665]
- cgroup: fix a typo in comment (Waiman Long) [2077665]
- xfrm: Fix oops in __xfrm_state_delete() (Sabrina Dubroca) [2157579]
- rtla: Add License to spec file and sync summary text with upstream (John Kacur) [2153891]
- drm/i915/display: consider DG2_RC_CCS_CC when migrating buffers (Jocelyn Falempe) [2041690]
- drm/i915: allow control over the flags when migrating (Jocelyn Falempe) [2041690]
- drm/i915/display: handle migration for dpt (Jocelyn Falempe) [2041690]
- drm/i915/huc: better define HuC status getparam possible return values. (Jocelyn Falempe) [2041690]
- drm/i915/huc: stall media submission until HuC is loaded (Jocelyn Falempe) [2041690]
- drm/i915/huc: track delayed HuC load with a fence (Jocelyn Falempe) [2041690]
- drm/i915/dg2: setup HuC loading via GSC (Jocelyn Falempe) [2041690]
- drm/i915/pxp: add huc authentication and loading command (Jocelyn Falempe) [2041690]
- drm/i915/pxp: implement function for sending tee stream command (Jocelyn Falempe) [2041690]
- drm/i915/pxp: load the pxp module when we have a gsc-loaded huc (Jocelyn Falempe) [2041690]
- drm/i915/gt: Flush to global observation point before breadcrumb write (Jocelyn Falempe) [2041690]
- drm/i915/guc/slpc: Add SLPC selftest live_slpc_power (Jocelyn Falempe) [2041690]
- drm/i915/guc/slpc: Run SLPC selftests on all tiles (Jocelyn Falempe) [2041690]
- drm/i915: Remove unwanted pointer unpacking (Jocelyn Falempe) [2041690]
- drm/i915/guc: Enable compute scheduling on DG2 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: introduce Wa_22015475538 (Jocelyn Falempe) [2041690]
- drm/i915/uc: Update to latest GuC and use new-format GuC/HuC names (Jocelyn Falempe) [2041690]
- Revert "drm/i915/dg2: extend Wa_1409120013 to DG2" (Jocelyn Falempe) [2041690]
- drm/i915/gsc: allocate extended operational memory in LMEM (Jocelyn Falempe) [2041690]
- drm/i915/gsc: add GSC XeHP SDV platform definition (Jocelyn Falempe) [2041690]
- drm/i915/gsc: add slow_firmware flag to the gsc device definition (Jocelyn Falempe) [2041690]
- drm/i915/gsc: skip irq initialization if using polling (Jocelyn Falempe) [2041690]
- drm/i915/uc: Add patch level version number support (Jocelyn Falempe) [2041690]
- drm/i915/uc: Support for version reduced and multiple firmware files (Jocelyn Falempe) [2041690]
- drm/i915/ttm: Abort suspend on i915_ttm_backup failure (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Incorporate Wa_16014892111 into DRAW_WATERMARK tuning (Jocelyn Falempe) [2041690]
- drm/i915/guc: Record CTB info in error logs (Jocelyn Falempe) [2041690]
- drm/i915/guc: Add GuC <-> kernel time stamp translation information (Jocelyn Falempe) [2041690]
- drm/i915/guc: Don't use pr_err when not necessary (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add support for DC5 state (Jocelyn Falempe) [2041690]
- drm/i915/dmc: Update DG2 DMC firmware to v2.07 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add additional tuning settings (Jocelyn Falempe) [2041690]
- drm/i915/gt: Add dedicated function for non-ctx register tuning settings (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add Wa_1509727124 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Update DG2 to GuC v70.4.1 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add additional HDMI pixel clock frequencies (Jocelyn Falempe) [2041690]
- Revert "drm/i915/dg2: Add preemption changes for Wa_14015141709" (Jocelyn Falempe) [2041690]

* Fri Jan 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-240.el9]
- clk: tegra: Fix Tegra PWM parent clock (Mark Salter) [2135064]
- redhat/configs: Enable CONFIG_SERIAL_TEGRA_TCU (Mark Salter) [2135064]
- firmware: tegra: bpmp: Do not support big-endian (Mark Salter) [2135064]
- firmware: tegra: bpmp: Use iosys-map helpers (Mark Salter) [2135064]
- firmware: tegra: bpmp: Prefer u32 over uint32_t (Mark Salter) [2135064]
- redhat/configs: enable Tegra234 SOC (Mark Salter) [2135064]
- soc/tegra: cbb: Remove redundant dev_err call (Mark Salter) [2135064]
- soc/tegra: cbb: Use DEFINE_SHOW_ATTRIBUTE to simplify tegra_cbb_err (Mark Salter) [2135064]
- soc/tegra: cbb: Check firewall before enabling error reporting (Mark Salter) [2135064]
- soc/tegra: cbb: Add checks for potential out of bound errors (Mark Salter) [2135064]
- soc/tegra: cbb: Update slave maps for Tegra234 (Mark Salter) [2135064]
- soc/tegra: cbb: Use correct master_id mask for CBB NOC in Tegra194 (Mark Salter) [2135064]
- soc/tegra: fuse: Use platform info with SoC revision (Mark Salter) [2135064]
- soc/tegra: pmc: Process wake events during resume (Mark Salter) [2135064]
- soc/tegra: pmc: Fix dual edge triggered wakes (Mark Salter) [2135064]
- soc/tegra: pmc: Add I/O pad table for Tegra234 (Mark Salter) [2135064]
- soc/tegra: fuse: Add nvmem keepout list (Mark Salter) [2135064]
- soc/tegra: fuse: Use SoC specific nvmem cells (Mark Salter) [2135064]
- soc/tegra: pmc: Select IRQ_DOMAIN_HIERARCHY (Mark Salter) [2135064]
- dt-bindings: tegra: pmc: Convert to json-schema (Mark Salter) [2135064]
- dt-bindings: PHY: P2U: Add support for Tegra234 P2U block (Mark Salter) [2135064]
- dt-bindings: phy: Tegra194 P2U convert to YAML (Mark Salter) [2135064]
- dt-bindings: memory: tegra: Update validation for reg and reg-names (Mark Salter) [2135064]
- dt-bindings: arm-smmu: Add compatible for Tegra234 SOC (Mark Salter) [2135064]
- dmaengine: tegra: Fix build error without IOMMU_API (Mark Salter) [2135064]
- redhat: configs: disable tegra186 gpc_dma (Mark Salter) [2135064]
- dmaengine: tegra: Add terminate() for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: Staticize struct tegra_cpufreq_soc instances (Mark Salter) [2135064]
- dmaengine: tegra: Remove unused switch case (Mark Salter) [2135064]
- dmaengine: tegra: Fix uninitialized variable usage (Mark Salter) [2135064]
- dmaengine: tegra: Use platform_get_irq() to get IRQ resource (Mark Salter) [2135064]
- dmaengine: tegra: Remove unused including <linux/version.h> (Mark Salter) [2135064]
- dmaengine: tegra: Add tegra gpcdma driver (Mark Salter) [2135064]
- redhat: configs: Enable Tegra Control Backbone driver (Mark Salter) [2135064]
- arm64: tegra: Add GPCDMA support for Tegra I2C (Mark Salter) [2135064]
- arm64: tegra: Add iommus for HDA on Tegra234 (Mark Salter) [2135064]
- arm64: tegra: Enable HDA node for Jetson AGX Orin (Mark Salter) [2135064]
- arm64: tegra: Add context isolation domains on Tegra234 (Mark Salter) [2135064]
- arm64: tegra: Fixup iommu-map property formatting (Mark Salter) [2135064]
- arm64: dts: tegra: smaug: Add Wi-Fi node (Mark Salter) [2135064]
- arm64: dts: tegra: smaug: Add Bluetooth node (Mark Salter) [2135064]
- soc/tegra: pmc: Check device node status property (Mark Salter) [2135064]
- soc/tegra: pmc: Use devm_clk_get_optional() (Mark Salter) [2135064]
- soc/tegra: fuse: Drop Kconfig dependency on TEGRA20_APB_DMA (Mark Salter) [2135064]
- soc/tegra: pmc: Add USB port wake events for Tegra194 (Mark Salter) [2135064]
- soc/tegra: pmc: Add support for simple wake events (Mark Salter) [2135064]
- soc/tegra: pmc: Remove leading space (Mark Salter) [2135064]
- soc/tegra: fuse: Add missing of_node_put() (Mark Salter) [2135064]
- soc/tegra: fuse: Add missing of_node_put() in tegra_init_fuse() (Mark Salter) [2135064]
- dt-bindings: Add Host1x context stream IDs on Tegra234 (Mark Salter) [2135064]
- soc/tegra: cbb: Add support for Tegra241 (Grace) (Mark Salter) [2135064]
- soc/tegra: cbb: Add driver for Tegra234 CBB 2.0 (Mark Salter) [2135064]
- soc/tegra: cbb: Add CBB 1.0 driver for Tegra194 (Mark Salter) [2135064]
- soc/tegra: Set ERD bit to mask inband errors (Mark Salter) [2135064]
- memory: tegra: Add MGBE memory clients for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: Add support for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: add soc data to support multiple soc (Mark Salter) [2135064]
- memory: tegra: Add MC error logging on Tegra186 onward (Mark Salter) [2135064]
- memory: tegra: Add memory controller channels support (Mark Salter) [2135064]
- memory: tegra: Add APE memory clients for Tegra234 (Mark Salter) [2135064]
- memory: tegra: Add Tegra234 support (Mark Salter) [2135064]
- memory: tegra: mc: simplify platform_get_resource() (Mark Salter) [2135064]
- memory: Update of_memory lpddr2 revision-id binding (Mark Salter) [2135064]
- memory: of: parse max-freq property (Mark Salter) [2135064]
- memory: tegra: Constify struct thermal_cooling_device_ops (Mark Salter) [2135064]
- memory: tegra20-emc: Correct memory device mask (Mark Salter) [2135064]
- memory: tegra30-emc: Print additional memory info (Mark Salter) [2135064]
- memory: tegra20-emc: Add runtime dependency on devfreq governor module (Mark Salter) [2135064]
- memory: tegra20-emc: Support matching timings by LPDDR2 configuration (Mark Salter) [2135064]
- memory: Add LPDDR2-info helpers (Mark Salter) [2135064]
- memory: tegra210-emc: replace DEFINE_SIMPLE_ATTRIBUTE with (Mark Salter) [2135064]
- memory: tegra186-emc: Fix error return code in tegra186_emc_probe() (Mark Salter) [2135064]
- memory: tegra: Make use of the helper function devm_add_action_or_reset() (Mark Salter) [2135064]
- memory: tegra186-emc: Handle errors in BPMP response (Mark Salter) [2135064]
- memory: tegra: Remove interconnect state syncing hack (Mark Salter) [2135064]
- memory: tegra210-emc: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Mark Salter) [2135064]
- memory: tegra30-emc: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Mark Salter) [2135064]
- memory: tegra: make the array list static const, makes object smaller (Mark Salter) [2135064]
- memory: tegra: fix unused-function warning (Mark Salter) [2135064]
- soc/tegra: pmc: Document core domain fields (Mark Salter) [2135064]
- soc/tegra: pmc: Select REGMAP (Mark Salter) [2135064]
- soc/tegra: pmc: Update Tegra234 reset sources (Mark Salter) [2135064]
- soc/tegra: fuse: Add nvmem cell lookup entries for Tegra194 (Mark Salter) [2135064]
- arm64: tegra: Move audio IOMMU properties to ADMAIF node (Mark Salter) [2135064]
- soc/tegra: bpmp: cleanup double word in comment (Mark Salter) [2135064]
- soc/tegra: pmc: Add Tegra234 wake events (Mark Salter) [2135064]
- soc/tegra: fuse: Explicitly cast to/from __iomem (Mark Salter) [2135064]
- soc/tegra: fuse: Update nvmem cell list (Mark Salter) [2135064]
- soc/tegra: pmc: Enable core domain support for Tegra20 and Tegra30 (Mark Salter) [2135064]
- dt-bindings: Document Tegra234 HDA support (Mark Salter) [2135064]
- arm64: tegra: smaug: Remove extra PLL power supplies for XUSB (Mark Salter) [2135064]
- soc/tegra: pmc: Rename core power domain (Mark Salter) [2135064]
- soc/tegra: pmc: Rename 3d power domains (Mark Salter) [2135064]
- soc/tegra: regulators: Prepare for suspend (Mark Salter) [2135064]
- soc/tegra: fuse: Use resource-managed helpers (Mark Salter) [2135064]
- soc/tegra: fuse: Reset hardware (Mark Salter) [2135064]
- soc/tegra: pmc: Add reboot notifier (Mark Salter) [2135064]
- soc/tegra: Don't print error message when OPPs not available (Mark Salter) [2135064]
- soc/tegra: Enable runtime PM during OPP state-syncing (Mark Salter) [2135064]
- soc/tegra: fuse: Fix bitwise vs. logical OR warning (Mark Salter) [2135064]
- soc/tegra: pmc: Use devm_platform_ioremap_resource() (Mark Salter) [2135064]
- soc/tegra: Add Tegra186 ARI driver (Mark Salter) [2135064]
- soc/tegra: Fix an error handling path in tegra_powergate_power_up() (Mark Salter) [2135064]
- soc/tegra: pmc: Expose USB regmap to all SoCs (Mark Salter) [2135064]
- soc/tegra: pmc: Disable PMC state syncing (Mark Salter) [2135064]
- firmware: tegra: bpmp: Use devm_platform_ioremap_resource() (Mark Salter) [2135064]
- soc/tegra: pm: Make stubs usable for compile testing (Mark Salter) [2135064]
- soc/tegra: irq: Add stubs needed for compile testing (Mark Salter) [2135064]
- soc/tegra: fuse: Add stubs needed for compile testing (Mark Salter) [2135064]
- soc/tegra: fuse: Enable fuse clock on suspend for Tegra124 (Mark Salter) [2135064]
- soc/tegra: fuse: Add runtime PM support (Mark Salter) [2135064]
- soc/tegra: fuse: Clear fuse->clk on driver probe failure (Mark Salter) [2135064]
- soc/tegra: pmc: Prevent racing with cpuilde driver (Mark Salter) [2135064]
- soc/tegra: bpmp: Remove unused including <linux/version.h> (Mark Salter) [2135064]

* Thu Jan 19 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-239.el9]
- NFSD: fix use-after-free on source server when doing inter-server copy (Jeffrey Layton) [2138605]
- Revert "SUNRPC: Use RMW bitops in single-threaded hot paths" (Jeffrey Layton) [2138605]
- nfsd: under NFSv4.1, fix double svc_xprt_put on rpc_create failure (Jeffrey Layton) [2138605]
- nfsd: fix handling of cached open files in nfsd4_open codepath (Jeffrey Layton) [2152473]
- nfsd: fix handling of readdir in v4root vs. mount upcall timeout (Jeffrey Layton) [2152996]
- nfsd: shut down the NFSv4 state objects before the filecache (Jeffrey Layton) [2138605]
- nfsd: rework refcounting in filecache (Jeffrey Layton) [2138605]
- nfsd: return error if nfs4_setacl fails (Jeffrey Layton) [2138321]
- NFSD: pass range end to vfs_fsync_range() instead of count (Jeffrey Layton) [2138605]
- NFSD: Add an nfsd_file_fsync tracepoint (Jeffrey Layton) [2138605]
- nfsd: fix up the filecache laundrette scheduling (Jeffrey Layton) [2138605]
- nfsd: reorganize filecache.c (Jeffrey Layton) [2138605]
- nfsd: remove the pages_flushed statistic from filecache (Jeffrey Layton) [2138605]
- NFSD: Fix licensing header in filecache.c (Jeffrey Layton) [2138605]
- NFSD: Use rhashtable for managing nfs4_file objects (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define nfsd_file_cache_stats_fops (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define nfsd_reply_cache_stats_fops (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define export_features_fops and supported_enctypes_fops (Jeffrey Layton) [2138605]
- NFSD: Refactor find_file() (Jeffrey Layton) [2138605]
- NFSD: Clean up find_or_add_file() (Jeffrey Layton) [2138605]
- NFSD: Add a nfsd4_file_hash_remove() helper (Jeffrey Layton) [2138605]
- NFSD: Clean up nfsd4_init_file() (Jeffrey Layton) [2138605]
- NFSD: Update file_hashtbl() helpers (Jeffrey Layton) [2138605]
- NFSD: Use const pointers as parameters to fh_ helpers (Jeffrey Layton) [2138605]
- NFSD: Trace delegation revocations (Jeffrey Layton) [2138605]
- NFSD: Clean up nfs4_preprocess_stateid_op() call sites (Jeffrey Layton) [2138605]
- NFSD: Flesh out a documenting comment for filecache.c (Jeffrey Layton) [2138605]
- NFSD: Add an NFSD_FILE_GC flag to enable nfsd_file garbage collection (Jeffrey Layton) [2138605]
- NFSD: Revert "NFSD: NFSv4 CLOSE should release an nfsd_file immediately" (Jeffrey Layton) [2138605]
- NFSD: Pass the target nfsd_file to nfsd_commit() (Jeffrey Layton) [2138605]
- nfsd: don't call nfsd_file_put from client states seqfile display (Jeffrey Layton) [2138357]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104472]
- ixgbe: stop resetting SYSTIME in ixgbe_ptp_start_cyclecounter (Ken Cox) [2104472]
- ixgbe: Manual AN-37 for troublesome link partners for X550 SFI (Ken Cox) [2104472]
- ixgbe: Don't call kmap() on page allocated with GFP_ATOMIC (Ken Cox) [2104472]
- ixgbe: convert .adjfreq to .adjfine (Ken Cox) [2104472]
- ixgbe: drop unexpected word 'for' in comments (Ken Cox) [2104472]
- ixgbe: remove unexpected word "the" (Ken Cox) [2104472]
- intel: remove unused macros (Ken Cox) [2104472]
- drivers/net/ethernet/intel: fix typos in comments (Ken Cox) [2104472]
- ixgbe: Fix typos in comments (Ken Cox) [2104472]
- drivers, ixgbe: export vf statistics (Ken Cox) [2104472]
- ixgbe: fix unexpected VLAN Rx in promisc mode on VF (Ken Cox) [2104472]
- ixgbe: fix bcast packets Rx on VF after promisc removal (Ken Cox) [2104472]
- ixgbe: add xdp frags support to ndo_xdp_xmit (Ken Cox) [2104472]
- ixgbe: propagate XFRM offload state direction instead of flags (Ken Cox) [2104472]
- ixgbe: Fix module_param allow_unsupported_sfp type (Ken Cox) [2104472]
- ixgbe, xsk: Get rid of redundant 'fallthrough' (Ken Cox) [2104472]
- ixgbe, xsk: Diversify return values from xsk_wakeup call paths (Ken Cox) [2104472]
- ixgbe, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ken Cox) [2104472]
- ixgbe, xsk: Decorate IXGBE_XDP_REDIR with likely() (Ken Cox) [2104472]
- perf test: Fix "all PMU test" to skip parametrized events (Michael Petlan) [2129405]
- aquantia: Do not purge addresses when setting the number of rings (Izabela Bakollari) [2066382]
- intel_idle: Add a new flag to initialize the AMX state (David Arcari) [2117766]
- x86/fpu: Add a helper to prepare AMX state for low-power CPU idle (David Arcari) [2117766]

* Wed Jan 18 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-238.el9]
- net/mlx5: Eswitch, Fix forwarding decision to uplink (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use the proper number of ports (Mohammad Kabat) [2112940]
- net/mlx5: Fix driver use of uninitialized timeout (Mohammad Kabat) [2112940]
- net/mlx5e: Ring the TX doorbell on DMA errors (Mohammad Kabat) [2112940]
- net/mlx5e: Fix capability check for updating vnic env counters (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Use own workqueue instead of mlx5e priv (Mohammad Kabat) [2112940]
- net/mlx5: Lag, correct get the port select mode str (Mohammad Kabat) [2112940]
- net/mlx5e: Fix enabling sriov while tc nic rules are offloaded (Mohammad Kabat) [2112940]
- net/mlx5e: kTLS, Fix build time constant test in RX (Mohammad Kabat) [2112940]
- net/mlx5e: kTLS, Fix build time constant test in TX (Mohammad Kabat) [2112940]
- net/mlx5: Lag, decouple FDB selection and shared FDB (Mohammad Kabat) [2112940]
- net/mlx5: TC, allow offload from uplink to other PF's VF (Mohammad Kabat) [2112940]
- net/mlx5e: Fix matchall police parameters validation (Mohammad Kabat) [2112940]
- mellanox: mlx5: avoid uninitialized variable warning with gcc-12 (Mohammad Kabat) [2112940]
- net/mlx5: E-Switch, pair only capable devices (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Fix cleanup of CT before cleanup of TC ct rules (Mohammad Kabat) [2112940]
- Revert "net/mlx5e: Allow relaxed ordering over VFs" (Mohammad Kabat) [2112940]
- net/mlx5: Fix mlx5_get_next_dev() peer device matching (Mohammad Kabat) [2112940]
- net/mlx5e: Update netdev features after changing XDP state (Mohammad Kabat) [2112940]
- vdpa/mlx5: Add support for reading descriptor statistics (Mohammad Kabat) [2112940]
- RDMA/mlx5: Remove duplicate pointer assignment in mlx5_ib_alloc_implicit_mr() (Mohammad Kabat) [2112940]
- net/mlx5: fix multiple definitions of mlx5_lag_mpesw_init / mlx5_lag_mpesw_cleanup (Mohammad Kabat) [2112940]
- net/mlx5: Support multiport eswitch mode (Mohammad Kabat) [2112940]
- net/mlx5: Remove unused argument (Mohammad Kabat) [2112940]
- net/mlx5: Lag, refactor lag state machine (Mohammad Kabat) [2112940]
- net/mlx5e: Add XDP SQs to uplink representors steering tables (Mohammad Kabat) [2112940]
- net/mlx5e: Correct the calculation of max channels for rep (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Add ct driver counters (Mohammad Kabat) [2112940]
- net/mlx5e: Allow relaxed ordering over VFs (Mohammad Kabat) [2112940]
- net/mlx5e: Support partial GSO for tunnels over vlans (Mohammad Kabat) [2112940]
- net/mlx5e: IPoIB, Improve ethtool rxnfc callback structure in IPoIB (Mohammad Kabat) [2112940]
- net/mlx5e: Allocate virtually contiguous memory for reps structures (Mohammad Kabat) [2112940]
- net/mlx5e: Allocate virtually contiguous memory for VLANs list (Mohammad Kabat) [2112940]
- net/mlx5: Allocate virtually contiguous memory in pci_irq.c (Mohammad Kabat) [2112940]
- net/mlx5: Allocate virtually contiguous memory in vport.c (Mohammad Kabat) [2112940]
- net/mlx5: Inline db alloc API function (Mohammad Kabat) [2112940]
- net/mlx5: Add last command failure syndrome to debugfs (Mohammad Kabat) [2112940]
- net/mlx5: sparse: error: context imbalance in 'mlx5_vf_get_core_dev' (Mohammad Kabat) [2112940]
- net/mlx5: Expose mlx5_sriov_blocking_notifier_register / unregister APIs (Mohammad Kabat) [2112940]
- net/mlx5: Lag, add debugfs to query hardware lag state (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use buckets in hash mode (Mohammad Kabat) [2112940]
- net/mlx5: Lag, refactor dmesg print (Mohammad Kabat) [2112940]
- net/mlx5: Support devices with more than 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use actual number of lag ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use hash when in roce lag on 4 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, support single FDB only on 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, store number of ports inside lag object (Mohammad Kabat) [2112940]
- net/mlx5: Lag, filter non compatible devices (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use lag lock (Mohammad Kabat) [2112940]
- net/mlx5: Lag, move E-Switch prerequisite check into lag code (Mohammad Kabat) [2112940]
- net/mlx5: devcom only supports 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, expose number of lag ports (Mohammad Kabat) [2112940]
- net/mlx5: Increase FW pre-init timeout for health recovery (Mohammad Kabat) [2112940]
- net/mlx5: Add exit route when waiting for FW (Mohammad Kabat) [2112940]
- net/mlx5: Don't perform lookup after already known sec_path (Mohammad Kabat) [2112940]
- net/mlx5: Cleanup XFRM attributes struct (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-supported ICV length (Mohammad Kabat) [2112940]
- net/mlx5: Simplify IPsec capabilities logic (Mohammad Kabat) [2112940]
- net/mlx5: Don't advertise IPsec netdev support for non-IPsec device (Mohammad Kabat) [2112940]
- net/mlx5: Make sure that no dangling IPsec FS pointers exist (Mohammad Kabat) [2112940]
- net/mlx5: Clean IPsec FS add/delete rules (Mohammad Kabat) [2112940]
- net/mlx5: Simplify HW context interfaces by using SA entry (Mohammad Kabat) [2112940]
- net/mlx5: Remove indirections from esp functions (Mohammad Kabat) [2112940]
- net/mlx5: Merge various control path IPsec headers into one file (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless validity check (Mohammad Kabat) [2112940]
- net/mlx5: Store IPsec ESN update work in XFRM state (Mohammad Kabat) [2112940]
- net/mlx5: Reduce useless indirection in IPsec FS add/delete flows (Mohammad Kabat) [2112940]
- net/mlx5: Don't hide fallback to software IPsec in FS code (Mohammad Kabat) [2112940]
- net/mlx5: Check IPsec TX flow steering namespace in advance (Mohammad Kabat) [2112940]
- net/mlx5: Simplify IPsec flow steering init/cleanup functions (Mohammad Kabat) [2112940]
- net/mlx5: fs, an FTE should have no dests when deleted (Mohammad Kabat) [2112940]
- net/mlx5: fs, call the deletion function of the node (Mohammad Kabat) [2112940]
- net/mlx5: fs, delete the FTE when there are no rules attached to it (Mohammad Kabat) [2112940]
- net/mlx5: fs, do proper bookkeeping for forward destinations (Mohammad Kabat) [2112940]
- net/mlx5: fs, add unused destination type (Mohammad Kabat) [2112940]
- net/mlx5: fs, jump to exit point and don't fall through (Mohammad Kabat) [2112940]
- net/mlx5: fs, refactor software deletion rule (Mohammad Kabat) [2112940]
- net/mlx5: fs, split software and IFC flow destination definitions (Mohammad Kabat) [2112940]
- net/mlx5e: TC, set proper dest type (Mohammad Kabat) [2112940]
- net/mlx5e: Remove unused mlx5e_dcbnl_build_rep_netdev function (Mohammad Kabat) [2112940]
- net/mlx5e: Drop error CQE handling from the XSK RX handler (Mohammad Kabat) [2112940]
- net/mlx5: Print initializing field in case of timeout (Mohammad Kabat) [2112940]
- net/mlx5: Delete redundant default assignment of runtime devlink params (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless kfree (Mohammad Kabat) [2112940]
- net/mlx5: use kvfree() for kvzalloc() in mlx5_ct_fs_smfs_matcher_create (Mohammad Kabat) [2112940]
- RDMA/mlx5: Clean UMR QP type flow from mlx5_ib_post_send() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update xlt (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update MR pas (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move creation and free of translation tables to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to rereg pd access (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to revoke MRs (Mohammad Kabat) [2112940]
- RDMA/mlx5: Introduce mlx5_umr_post_send_wait() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Expose wqe posting helpers outside of wr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Simplify get_umr_update_access_mask() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move mkey ctrl segment logic to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move umr checks to umr.h (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move init and cleanup of UMR to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Fix flow steering egress flow (Mohammad Kabat) [2112940]
- mlx5, xsk: Diversify return values from xsk_wakeup call paths (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-implemented IPsec capabilities (Mohammad Kabat) [2112940]
- net/mlx5: Remove ipsec_ops function table (Mohammad Kabat) [2112940]
- net/mlx5: Reduce kconfig complexity while building crypto support (Mohammad Kabat) [2112940]
- net/mlx5: Move IPsec file to relevant directory (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-needed IPsec config (Mohammad Kabat) [2112940]
- net/mlx5: Align flow steering allocation namespace to common style (Mohammad Kabat) [2112940]
- net/mlx5: Unify device IPsec capabilities check (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless IPsec device checks (Mohammad Kabat) [2112940]
- net/mlx5: Remove ipsec vs. ipsec offload file separation (Mohammad Kabat) [2112940]
- RDMA/mlx5: Drop crypto flow steering API (Mohammad Kabat) [2112940]
- RDMA/mlx5: Delete never supported IPsec flow action (Mohammad Kabat) [2112940]
- net/mlx5: Remove FPGA ipsec specific statistics (Mohammad Kabat) [2112940]
- net/mlx5: Remove XFRM no_trailer flag (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-used IDA field from IPsec struct (Mohammad Kabat) [2112940]
- net/mlx5: Delete metadata handling logic (Mohammad Kabat) [2112940]
- net/mlx5_fpga: Drop INNOVA IPsec support (Mohammad Kabat) [2112940]
- net/mlx5: Cleanup kTLS function names and their exposure (Mohammad Kabat) [2112940]
- net/mlx5: Remove tls vs. ktls separation as it is the same (Mohammad Kabat) [2112940]
- net/mlx5: Remove indirection in TLS build (Mohammad Kabat) [2112940]
- net/mlx5: Reliably return TLS device capabilities (Mohammad Kabat) [2112940]
- net/mlx5_fpga: Drop INNOVA TLS support (Mohammad Kabat) [2112940]

* Tue Jan 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-237.el9]
- Revert "stmmac/intel: mark driver as tech preview" (Mark Salter) [2122226]
- stmmac: intel: Simplify intel_eth_pci_remove() (Mark Salter) [2122226]
- net: stmmac: work around sporadic tx issue on link-up (Mark Salter) [2122226]
- stmmac: intel: Add a missing clk_disable_unprepare() call in intel_eth_pci_remove() (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: permit MTU change with interface up (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: generate stmmac dma conf before open (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: move dma conf to dedicated struct (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: first disable all queues and disconnect in release (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: move queue reset to dedicated functions (Mark Salter) [2122226]
- net: phylink: fix SGMII inband autoneg enable (Mark Salter) [2122226]
- stmicro/stmmac: fix repeated words in comments (Mark Salter) [2122226]
- net: phylink: fix NULL pl->pcs dereference during phylink_pcs_poll_start (Mark Salter) [2122226]
- net: phylink: disable PCS polling over major configuration (Mark Salter) [2122226]
- net: phylink: remove pcs_ops member (Mark Salter) [2122226]
- net: pcs: xpcs: depends on PHYLINK in Kconfig (Mark Salter) [2122226]
- net: phylink: add QSGMII support to phylink_mii_c22_pcs_encode_advertisement() (Mark Salter) [2122226]
- net: ethernet: stmmac: remove select QCOM_SOCINFO and make it optional (Mark Salter) [2122226]
- net: stmmac: make mdio register skips PHY scanning for fixed-link (Mark Salter) [2122226]
- stmmac: intel: add phy-mode and fixed-link ACPI _DSD setting support (Mark Salter) [2122226]
- net: pcs: xpcs: add CL37 1000BASE-X AN support (Mark Salter) [2122226]
- stmmac: intel: prepare to support 1000BASE-X phy interface setting (Mark Salter) [2122226]
- net: make xpcs_do_config to accept advertising for pcs-xpcs and sja1105 (Mark Salter) [2122226]
- net: ethernet: stmmac: reset force speed bit for ipq806x (Mark Salter) [2122226]
- net: ethernet: stmmac: add missing sgmii configure for ipq806x (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: fix resource leak in probe (Mark Salter) [2122226]
- net: pcs: xpcs: propagate xpcs_read error to xpcs_get_state_c37_sgmii (Mark Salter) [2122226]
- net: stmmac: remove redunctant disable xPCS EEE call (Mark Salter) [2122226]
- net: stmmac: fix dma queue left shift overflow issue (Mark Salter) [2122226]
- net: stmmac: switch to use interrupt for hw crosstimestamping (Mark Salter) [2122226]
- net: stmmac: fix unbalanced ptp clock issue in suspend/resume flow (Mark Salter) [2122226]
- net: stmmac: fix pm runtime issue in stmmac_dvr_remove() (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: fix clock issue (Mark Salter) [2122226]
- net: stmmac: fix leaks in probe (Mark Salter) [2122226]
- net: stmmac: dwc-qos: Disable split header for Tegra194 (Mark Salter) [2122226]
- stmmac: intel: Fix an error handling path in intel_eth_pci_probe() (Mark Salter) [2122226]
- stmmac: intel: Add RPL-P PCI ID (Mark Salter) [2122226]
- net: stmmac: use dev_err_probe() for reporting mdio bus registration failure (Mark Salter) [2122226]
- net: stmmac: fix out-of-bounds access in a selftest (Mark Salter) [2122226]
- net: stmmac: remove unused get_addr() callback (Mark Salter) [2122226]
- net: pcs: pcs-xpcs: Convert to mdiobus_c45_read (Mark Salter) [2122226]
- net: stmmac: dwmac-imx: comment spelling fix (Mark Salter) [2122226]
- stmmac, xsk: Diversify return values from xsk_wakeup call paths (Mark Salter) [2122226]
- net: stmmac: stmmac_main: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122226]
- net: stmmac: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122226]
- net: stmmac: fix missing pci_disable_device() on error in stmmac_pci_probe() (Mark Salter) [2122226]
- net: stmmac: disable Split Header (SPH) for Intel platforms (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: add missing of_node_put() in sun8i_dwmac_register_mdio_mux() (Mark Salter) [2122226]
- net: ethernet: stmmac: fix write to sgmii_adapter_base (Mark Salter) [2122226]
- net: stmmac: Use readl_poll_timeout_atomic() in atomic state (Mark Salter) [2122226]
- net: ethernet: stmmac: fix altr_tse_pcs function when using a fixed-link (Mark Salter) [2122226]
- stmmac: dwmac-loongson: change loongson_dwmac_driver from global to static (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: Enable RGMII functional clock on resume (Mark Salter) [2122226]
- net: stmmac: clean up impossible condition (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: add support for mt8195 (Mark Salter) [2122226]
- arm64: dts: mt2712: update ethernet device node (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: re-arrange clock setting (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: Reuse more common features (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: add platform level clocks management (Mark Salter) [2122226]
- stmmac: intel: Add ADL-N PCI ID (Mark Salter) [2122226]
- net: stmmac: switch no PTP HW support message to info level (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: Adjust rgmii loopback_en per platform (Mark Salter) [2122226]
- net: stmmac: Add support for SM8150 (Mark Salter) [2122226]
- net: phylink: use %%pe for printing errors (Mark Salter) [2122226]
- stmmac: intel: Enable 2.5Gbps for Intel AlderLake-S (Mark Salter) [2122226]
- net: stmmac: optimize locking around PTP clock reads (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: make clk really gated during rpm suspended (Mark Salter) [2122226]
- net: stmmac/xpcs: convert to pcs_validate() (Mark Salter) [2122226]
- net: convert users of bitmap_foo() to linkmode_foo() (Mark Salter) [2122226]
- net: stmmac: fill in supported_interfaces (Mark Salter) [2122226]
- net: xpcs: add support for retrieving supported interface modes (Mark Salter) [2122226]
- net: stmmac: fix return value of __setup handler (Mark Salter) [2122226]
- net: stmmac: only enable DMA interrupts when ready (Mark Salter) [2122226]
- net: stmmac: ensure PTP time register reads are consistent (Mark Salter) [2122226]
- net: stmmac: dump gmac4 DMA registers correctly (Mark Salter) [2122226]
- net: stmmac: properly handle with runtime pm in stmmac_dvr_remove() (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: No change to ETHER_CLOCK_SEL for unexpected speed request. (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: use return val of readl_poll_timeout() (Mark Salter) [2122226]
- net: stmmac: skip only stmmac_ptp_register when resume from suspend (Mark Salter) [2122226]
- net: stmmac: configure PTP clock source prior to PTP initialization (Mark Salter) [2122226]
- net: stmmac: reduce unnecessary wakeups from eee sw timer (Mark Salter) [2122226]
- net: stmmac: remove unused members in struct stmmac_priv (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix clock configuration for RMII mode (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix bit definitions for ETHER_CLK_SEL (Mark Salter) [2122226]
- net: stmmac: Fix "Unbalanced pm_runtime_enable!" warning (Mark Salter) [2122226]
- net: stmmac: dwmac-oxnas: Add support for OX810SE (Mark Salter) [2122226]
- net: stmmac: add tc flower filter for EtherType matching (Mark Salter) [2122226]
- net: stmmac: bump tc when get underflow error from DMA descriptor (Mark Salter) [2122226]
- net: phylink: tidy up disable bit clearing (Mark Salter) [2122226]
- net: stmmac: Add platform level debug register dump feature (Mark Salter) [2122226]
- stmmac: remove ethtool driver version info (Mark Salter) [2122226]
- net: stmmac: perserve TX and RX coalesce value during XDP setup (Mark Salter) [2122226]
- net: stmmac: Calculate CDC error only once (Mark Salter) [2122226]
- net: phylink: handle NA interface mode in phylink_fwnode_phy_connect() (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: add platform level clocks management (Mark Salter) [2122226]
- net: stmmac: enhance XDP ZC driver level switching performance (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix value of ETHER_CLK_SEL_FREQ_SEL_2P5M (Mark Salter) [2122226]
- net: stmmac: ptp: fix potentially overflowing expression (Mark Salter) [2122226]
- net: stmmac: dwmac-rk: fix oob read in rk_gmac_setup (Mark Salter) [2122226]
- net: stmmac: fix tc flower deletion for VLAN priority Rx steering (Mark Salter) [2122226]
- net: phy: Add the missing blank line in the phylink_suspend comment (Mark Salter) [2122226]
- net: stmmac: Avoid DMA_CHAN_CONTROL write if no Split Header support (Mark Salter) [2122226]
- net: stmmac: Disable Tx queues when reconfiguring the interface (Mark Salter) [2122226]
- net: phylink: Force retrigger in case of latched link-fail indicator (Mark Salter) [2122226]
- net: phylink: Force link down and retrigger resolve on interface change (Mark Salter) [2122226]
- net: stmmac: retain PTP clock time during SIOCSHWTSTAMP ioctls (Mark Salter) [2122226]
- stmmac_pci: Fix underflow size in stmmac_rx (Mark Salter) [2122226]
- net: stmmac: Fix signed/unsigned wreckage (Mark Salter) [2122226]
- net: stmmac: socfpga: add runtime suspend/resume callback for stratix10 platform (Mark Salter) [2122226]
- net: stmmac: allow a tc-taprio base-time of zero (Mark Salter) [2122226]
- ethernet: stmmac: use eth_hw_addr_set() (Mark Salter) [2122226]
- net: stmmac: selftests: Use kcalloc() instead of kzalloc() (Mark Salter) [2122226]
- net: stmmac: fix off-by-one error in sanity check (Mark Salter) [2122226]
- net: stmmac: fix gcc-10 -Wrestrict warning (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Make use of the helper function dev_err_probe() (Mark Salter) [2122226]
- net: stmmac: Fix E2E delay mechanism (Mark Salter) [2122226]
- net: stmmac: add support for dwmac 3.40a (Mark Salter) [2122226]
- dt-bindings: net: snps,dwmac: add dwmac 3.40a IP version (Mark Salter) [2122226]
- net: stmmac: fix get_hw_feature() on old hardware (Mark Salter) [2122226]
- net: pcs: xpcs: Add Pause Mode support for SGMII and 2500BaseX (Mark Salter) [2122226]
- net: stmmac: trigger PCS EEE to turn off on link down (Mark Salter) [2122226]
- net: pcs: xpcs: fix incorrect steps on disable EEE (Mark Salter) [2122226]
- net: pcs: xpcs: fix incorrect CL37 AN sequence (Mark Salter) [2122226]
- net: stmmac: dwmac-rk: Fix ethernet on rk3399 based devices (Mark Salter) [2122226]
- net: stmmac: fix EEE init issue when paired with EEE capable PHYs (Mark Salter) [2122226]
- net: update NXP copyright text (Mark Salter) [2122226]
- net: stmmac: allow CSR clock of 300MHz (Mark Salter) [2122226]
- net: stmmac: platform: fix build warning when with !CONFIG_PM_SLEEP (Mark Salter) [2122226]
- net: stmmac: fix system hang caused by eee_ctrl_timer during suspend/resume (Mark Salter) [2122226]
- net: stmmac: fix MAC not working when system resume back with WoL active (Mark Salter) [2122226]
- stmmac: dwmac-loongson:Fix missing return value (Mark Salter) [2122226]
- net: stmmac: Fix overall budget calculation for rxtx_napi (Mark Salter) [2122226]
- net: stmmac: add ethtool per-queue irq statistic support (Mark Salter) [2122226]
- net: stmmac: add ethtool per-queue statistic framework (Mark Salter) [2122226]
- net: stmmac: fix INTR TBU status affecting irq count statistic (Mark Salter) [2122226]
- net: ethernet: stmmac: Do not use unreachable() in ipq806x_gmac_probe() (Mark Salter) [2122226]

* Mon Jan 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-236.el9]
- Revert "nvme: warn about shared namespaces without CONFIG_NVME_MULTIPATH" (Ewan D. Milne) [2140810]
- vmxnet3: correctly report csum_level for encapsulated packet (Izabela Bakollari) [2158807]
- cpu/hotplug: Set cpuhp target for boot cpu (Phil Auld) [2086305]
- cpu/hotplug: Make target_store() a nop when target == state (Phil Auld) [2086305]
- scsi: target: core: Fix hard lockup when executing a compare-and-write command (Maurizio Lombardi) [2153690]
- ceph: rely on vfs for setgid stripping (Andrey Albershteyn) [2128900]
- fs: move S_ISGID stripping into the vfs_*() helpers (Andrey Albershteyn) [2128898 2128900]
- fs: Add missing umask strip in vfs_tmpfile (Andrey Albershteyn) [2128898 2128900]
- fs: add mode_strip_sgid() helper (Andrey Albershteyn) [2128898 2128900]
- tracing: Add linear buckets to histogram logic (Jerome Marchand) [2143635]
- disable CONFIG_INTEL_MEI_PXP (Jocelyn Falempe) [2147558]
- mei: pxp: support matching with a gfx discrete card (Jocelyn Falempe) [2147558]
- mei: pxp: add command streamer API to the PXP driver (Jocelyn Falempe) [2147558]
- mei: bus: extend bus API to support command streamer API (Jocelyn Falempe) [2147558]
- mei: adjust extended header kdocs (Jocelyn Falempe) [2147558]
- mei: bus: enable sending gsc commands (Jocelyn Falempe) [2147558]
- mei: add support to GSC extended header (Jocelyn Falempe) [2147558]
- mei: debugfs: add pxp mode to devstate in debugfs (Jocelyn Falempe) [2147558]
- mei: drop ready bits check after start (Jocelyn Falempe) [2147558]
- mei: gsc: add transition to PXP mode in resume flow (Jocelyn Falempe) [2147558]
- mei: gsc: setup gsc extended operational memory (Jocelyn Falempe) [2147558]
- mei: mkhi: add memory ready command (Jocelyn Falempe) [2147558]
- mei: bus: export common mkhi definitions into a separate header (Jocelyn Falempe) [2147558]
- mei: extend timeouts on slow devices (Jocelyn Falempe) [2147558]
- mei: gsc: wait for reset thread on stop (Jocelyn Falempe) [2147558]
- mei: gsc: use polling instead of interrupts (Jocelyn Falempe) [2147558]
- mei: add slow_firmware flag to the mei auxiliary device (Jocelyn Falempe) [2147558]
- mei: add kdoc for struct mei_aux_device (Jocelyn Falempe) [2147558]
- mei: me: fix clang -Wformat warning (Jocelyn Falempe) [2147558]
- mei: me: add raptor lake point S DID (Jocelyn Falempe) [2147558]
- mei: hbm: drop capability response on early shutdown (Jocelyn Falempe) [2147558]
- mei: me: set internal pg flag to off on hardware reset (Jocelyn Falempe) [2147558]
- misc/mei: Add NULL check to component match callback functions (Jocelyn Falempe) [2147558]
- drm/display: Move HDCP helpers into display-helper module (Jocelyn Falempe) [2147558]
- mei: avoid iterator usage outside of list_for_each_entry (Jocelyn Falempe) [2147558]
- mei: do not overwrite state on hw start (Jocelyn Falempe) [2147558]
- mei: me: fix reset policy on read error in interrupt (Jocelyn Falempe) [2147558]
- mei: me: avoid link reset on shutdown (Jocelyn Falempe) [2147558]
- mei: me: Use dma_set_mask_and_coherent() and simplify code (Jocelyn Falempe) [2147558]
- mei: hbm: fix client dma reply status (Jocelyn Falempe) [2147558]
- mei: cleanup status before client dma setup call (Jocelyn Falempe) [2147558]
- mei: add POWERING_DOWN into device state print (Jocelyn Falempe) [2147558]
- mei: Remove some dead code (Jocelyn Falempe) [2147558]
- mei: bus: add client dma interface (Jocelyn Falempe) [2147558]
- mei: hbm: drop hbm responses on early shutdown (Jocelyn Falempe) [2147558]
- mei: pxp: export pavp client to me client bus (Jocelyn Falempe) [2147558]
- mei: Remove usage of the deprecated "pci-dma-compat.h" API (Jocelyn Falempe) [2147558]
- mei: constify passed buffers and structures (Jocelyn Falempe) [2147558]

* Fri Jan 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-235.el9]
- x86/topology: Fix duplicated core ID within a package (David Arcari) [2159554]
- x86/topology: Fix multiple packages shown on a single-package system (David Arcari) [2159554]
- hwmon/coretemp: Handle large core ID value (David Arcari) [2159554]
- tools/power turbostat: Add support for RPL-S (David Arcari) [2159756]
- powercap: intel_rapl: Add support for RAPTORLAKE_S (David Arcari) [2159756]
- pNFS/filelayout: Fix coalescing test for single DS (Benjamin Coddington) [2158517]
- sched/core: Use kfree_rcu() in do_set_cpus_allowed() (Waiman Long) [2143847]
- sched/core: Fix use-after-free bug in dup_user_cpus_ptr() (Waiman Long) [2143847]
- KVM: nVMX: Inject #GP, not #UD, if "generic" VMXON CR0/CR4 check fails (Emanuele Giuseppe Esposito) [2155955]
- powerpc: Take in account addition CPU node when building kexec FDT (Mamatha Inamdar) [2149198]
- powerpc: export the CPU node count (Mamatha Inamdar) [2149198]
- crypto: s390/aes - drop redundant xts key check (Vladis Dronov) [2158894]
- crypto: xts - drop xts_check_key() (Vladis Dronov) [2158894]
- net: vrf: determine the dst using the original ifindex for multicast (Antoine Tenart) [2149859]
- net: dropreason: add SKB_DROP_REASON_FRAG_TOO_FAR (Antoine Tenart) [2155181]
- net: dropreason: add SKB_DROP_REASON_FRAG_REASM_TIMEOUT (Antoine Tenart) [2155181]
- net: dropreason: add SKB_DROP_REASON_DUP_FRAG (Antoine Tenart) [2155181]
- net: dropreason: propagate drop_reason to skb_release_data() (Antoine Tenart) [2155181]
- net: dropreason: add SKB_CONSUMED reason (Antoine Tenart) [2155181]
- x86: Remove vendor checks from prefer_mwait_c1_over_halt (David Arcari) [2150068]
- x86: Handle idle=nomwait cmdline properly for x86_idle (David Arcari) [2150068]
- drm/i915: fix TLB invalidation for Gen12 video and compute engines (Wander Lairson Costa) [2148153] {CVE-2022-4139}
- mmc: bcm2835: stop setting chan_config->slave_id (Adrien Thierry) [2139215]
- net: usb: ax88179_178a: Fix packet receiving (Jose Ignacio Tornos Martinez) [2142723] {CVE-2022-2964}
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup (Jose Ignacio Tornos Martinez) [2142723] {CVE-2022-2964}
- vxlan: fix error return code in vxlan_fdb_append (Guillaume Nault) [2142598]
- vxlan_multicast: Move multicast helpers to a separate file (Guillaume Nault) [2142598]
- vxlan_core: add helper vxlan_vni_in_use (Guillaume Nault) [2142598]
- vxlan_core: make multicast helper take rip and ifindex explicitly (Guillaume Nault) [2142598]
- vxlan_core: move some fdb helpers to non-static (Guillaume Nault) [2142598]
- vxlan_core: move common declarations to private header file (Guillaume Nault) [2142598]
- vxlan_core: fix build warnings in vxlan_xmit_one (Guillaume Nault) [2142598]
- vxlan: move to its own directory (Guillaume Nault) [2142598]
- net: vxlan: add macro definition for number of IANA VXLAN-GPE port (Guillaume Nault) [2142598]
- x86/fpu: Fix copy_xstate_to_uabi() to copy init states correctly (Dean Nelson) [2122851]
- x86/fpu: Exclude dynamic states from init_fpstate (Dean Nelson) [2122851]
- x86/fpu: Fix the init_fpstate size check with the actual size (Dean Nelson) [2122851]
- x86/fpu: Configure init_fpstate attributes orderly (Dean Nelson) [2122851]
- x86/fpu/xstate: Fix the ARCH_REQ_XCOMP_PERM implementation (Dean Nelson) [2122851]

* Thu Jan 12 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-234.el9]
- net/mlx5e: xsk: Discard unaligned XSK frames on striding RQ (Artem Savkov) [2137876]
- bpf: Fix panic due to wrong pageattr of im->image (Artem Savkov) [2137876]
- bpf: prevent leak of lsm program after failed attach (Artem Savkov) [2137876]
- selftests/bpf: fix memory leak of lsm_cgroup (Artem Savkov) [2137876]
- skmsg: pass gfp argument to alloc_sk_msg() (Felix Maurer) [2137876]
- tcp: read multiple skbs in tcp_read_skb() (Felix Maurer) [2137876]
- tcp: Use WARN_ON_ONCE() in tcp_read_skb() (Felix Maurer) [2137876]
- tcp: handle pure FIN case correctly (Felix Maurer) [2137876]
- tcp: refactor tcp_read_skb() a bit (Felix Maurer) [2137876]
- tcp: fix tcp_cleanup_rbuf() for tcp_read_skb() (Felix Maurer) [2137876]
- tcp: fix sock skb accounting in tcp_read_skb() (Felix Maurer) [2137876]
- net: Fix suspicious RCU usage in bpf_sk_reuseport_detach() (Felix Maurer) [2137876]
- net: refactor bpf_sk_reuseport_detach() (Felix Maurer) [2137876]
- net: fix refcount bug in sk_psock_get (2) (Felix Maurer) [2137876]
- skmsg: Get rid of unncessary memset() (Felix Maurer) [2137876]
- skmsg: Get rid of skb_clone() (Felix Maurer) [2137876]
- net: Introduce a new proto_ops ->read_skb() (Felix Maurer) [2137876]
- tcp: Introduce tcp_read_skb() (Felix Maurer) [2137876]
- samples/bpf: Fix MAC address swapping in xdp2_kern (Felix Maurer) [2137876]
- samples/bpf: Fix map iteration in xdp1_user (Felix Maurer) [2137876]
- selftests/bpf: fix ct status check in bpf_nf selftests (Felix Maurer) [2137876]
- selftests/xsk: Avoid use-after-free on ctx (Felix Maurer) [2137876]
- xsk: Fix corrupted packets for XDP_SHARED_UMEM (Felix Maurer) [2137876]
- net: bpf: Use the protocol's set_rcvlowat behavior if there is one (Felix Maurer) [2137876]
- netdevsim: Avoid allocation warnings triggered from user space (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to set and change CT status (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to set and change CT timeout (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to allocate and insert CT (Felix Maurer) [2137876]
- net: netfilter: Deduplicate code in bpf_{xdp,skb}_ct_lookup (Felix Maurer) [2137876]
- xsk: Mark napi_id on sendmsg() (Felix Maurer) [2137876]
- samples/bpf: Fix xdp_redirect_map egress devmap prog (Felix Maurer) [2137876]
- selftests, xsk: Rename AF_XDP testing app (Felix Maurer) [2137876]
- net: page_pool: optimize page pool page allocation in NUMA scenario (Felix Maurer) [2137876]
- bpf: Omit superfluous address family check in __bpf_skc_lookup (Felix Maurer) [2137876]
- selftests/xsk: Destroy BPF resources only when ctx refcount drops to 0 (Felix Maurer) [2137876]
- selftests/xsk: Verify correctness of XDP prog attach point (Felix Maurer) [2137876]
- selftests/xsk: Introduce XDP prog load based on existing AF_XDP socket (Felix Maurer) [2137876]
- selftests/xsk: Avoid bpf_link probe for existing xsk (Felix Maurer) [2137876]
- selftests/bpf: Test a BPF CC implementing the unsupported get_info() (Felix Maurer) [2137876]
- selftests/bpf: Test an incomplete BPF CC (Felix Maurer) [2137876]
- selftests/bpf: Test a BPF CC writing sk_pacing_* (Felix Maurer) [2137876]
- bpf: Require only one of cong_avoid() and cong_control() from a TCP CC (Felix Maurer) [2137876]
- bpf: Allow a TCP CC to write sk_pacing_rate and sk_pacing_status (Felix Maurer) [2137876]
- test_bpf: fix incorrect netdev features (Felix Maurer) [2137876]
- samples/bpf: fixup some tools to be able to support xdp multibuffer (Felix Maurer) [2137876]
- bpf: Fix bpf_skc_lookup comment wrt. return type (Felix Maurer) [2137876]
- samples/bpf: Check detach prog exist or not in xdp_fwd (Felix Maurer) [2137876]
- selftests/bpf: Add drv mode testing for xdping (Felix Maurer) [2137876]
- xdp: Directly use ida_alloc()/free() APIs (Felix Maurer) [2137876]
- selftests/bpf: Fix xdp_synproxy compilation failure in 32-bit arch (Artem Savkov) [2137876]
- samples/bpf: Fix sockex3 error: Missing BPF prog type (Artem Savkov) [2137876]
- selftests/bpf: Fix casting error when cross-compiling test_verifier for 32-bit platforms (Artem Savkov) [2137876]
- ftrace/samples: Add missing prototype for my_direct_func (Artem Savkov) [2137876]
- ftrace: Add cleanup to unregister_ftrace_direct_multi (Artem Savkov) [2137876]
- ftrace: Use direct_ops hash in unregister_ftrace_direct (Artem Savkov) [2137876]
- tracing: Reset the function filter after completing trampoline/graph selftest (Artem Savkov) [2137876]
- selftests/bpf: Fix xdp_synproxy build failure if CONFIG_NF_CONNTRACK=m/n (Artem Savkov) [2137876]
- bpf, samples: Remove AF_XDP samples (Artem Savkov) [2137876]
- tools include: add dis-asm-compat.h to handle version differences (Artem Savkov) [2137876]
- perf tools: Rework prologue generation code (Artem Savkov) [2137876]
- bpf/docs: Update README for most recent vmtest.sh (Artem Savkov) [2137876]
- ftrace: Fix recursive locking direct_mutex in ftrace_modify_direct_caller (Artem Savkov) [2137876]
- libbpf: restore memory layout of bpf_object_open_opts (Artem Savkov) [2137876]
- selftests/bpf: Adapt cgroup effective query uapi change (Artem Savkov) [2137876]
- bpftool: Fix wrong cgroup attach flags being assigned to effective progs (Artem Savkov) [2137876]
- bpf, cgroup: Reject prog_attach_flags array when effective query (Artem Savkov) [2137876]
- bpf, tnums: Warn against the usage of tnum_in(tnum_range(), ...) (Artem Savkov) [2137876]
- bpf: Only add BTF IDs for socket security hooks when CONFIG_SECURITY_NETWORK is on (Artem Savkov) [2137876]
- bpf: Don't use tnum_range on array range checking for poke descriptors (Artem Savkov) [2137876]
- selftests/bpf: Add regression test for pruning fix (Artem Savkov) [2137876]
- bpf: Do mark_chain_precision for ARG_CONST_ALLOC_SIZE_OR_ZERO (Artem Savkov) [2137876]
- bpf: Fix a data-race around bpf_jit_limit. (Artem Savkov) [2137876]
- ftrace: Fix build warning for ops_references_rec() not used (Artem Savkov) [2137876]
- bpf, cgroup: Fix kernel BUG in purge_effective_progs (Artem Savkov) [2137876]
- bpf: Restrict bpf_sys_bpf to CAP_PERFMON (Artem Savkov) [2137876]
- bpf: Partially revert flexible-array member replacement (Artem Savkov) [2137876]
- selftests/bpf: Add lru_bug to s390x deny list (Artem Savkov) [2137876]
- bpf: Shut up kern_sys_bpf warning. (Artem Savkov) [2137876]
- selftests/bpf: Ensure sleepable program is rejected by hash map iter (Artem Savkov) [2137876]
- selftests/bpf: Add write tests for sk local storage map iterator (Artem Savkov) [2137876]
- selftests/bpf: Add tests for reading a dangling map iter fd (Artem Savkov) [2137876]
- bpf: Only allow sleepable program for resched-able iterator (Artem Savkov) [2137876]
- bpf: Check the validity of max_rdwr_access for sock local storage map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for sock{map,hash} iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for sock local storage map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for hash map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for array map iterator (Artem Savkov) [2137876]
- bpftool: Complete libbfd feature detection (Artem Savkov) [2137876]
- bpf, arm64: Fix bpf trampoline instruction endianness (Artem Savkov) [2137876]
- selftests/bpf: Add test for prealloc_lru_pop bug (Artem Savkov) [2137876]
- bpf: Don't reinit map value in prealloc_lru_pop (Artem Savkov) [2137876]
- bpf: Allow calling bpf_prog_test kfuncs in tracing programs (Artem Savkov) [2137876]
- bpf, arm64: Allocate program buffer using kvcalloc instead of kcalloc (Artem Savkov) [2137876]
- selftests/bpf: Excercise bpf_obj_get_info_by_fd for bpf2bpf (Artem Savkov) [2137876]
- bpf: Use proper target btf when exporting attach_btf_obj_id (Artem Savkov) [2137876]
- bpf: Cleanup ftrace hash in bpf_trampoline_put (Artem Savkov) [2137876]
- BPF: Fix potential bad pointer dereference in bpf_sys_bpf() (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that BTF_ID does not ABIify a function (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that attaching to functions is not ABI (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that kprobes is not ABI (Artem Savkov) [2137876]
- tools bpftool: Don't display disassembler-four-args feature test (Artem Savkov) [2137876]
- tools bpftool: Fix compilation error with new binutils (Artem Savkov) [2137876]
- tools bpf_jit_disasm: Don't display disassembler-four-args feature test (Artem Savkov) [2137876]
- tools bpf_jit_disasm: Fix compilation error with new binutils (Artem Savkov) [2137876]
- bpf: Remove unneeded semicolon (Artem Savkov) [2137876]
- libbpf: Add bpf_obj_get_opts() (Artem Savkov) [2137876]
- bpf: Fix NULL pointer dereference when registering bpf trampoline (Artem Savkov) [2137876]
- bpf: Fix test_progs -j error with fentry/fexit tests (Artem Savkov) [2137876]
- selftests/bpf: Bump internal send_signal/send_signal_tracepoint timeout (Artem Savkov) [2137876]
- bpftool: Don't try to return value from void function in skeleton (Artem Savkov) [2137876]
- bpftool: Replace sizeof(arr)/sizeof(arr[0]) with ARRAY_SIZE macro (Artem Savkov) [2137876]
- bpf: btf: Fix vsnprintf return value check (Artem Savkov) [2137876]
- libbpf: Support PPC in arch_specific_syscall_pfx (Artem Savkov) [2137876]
- selftests/bpf: Adjust vmtest.sh to use local kernel configuration (Artem Savkov) [2137876]
- selftests/bpf: Copy over libbpf configs (Artem Savkov) [2137876]
- selftests/bpf: Sort configuration (Artem Savkov) [2137876]
- selftests/bpf: Enable config options needed for xdp_synproxy test (Artem Savkov) [2137876]
- selftests/bpf: Attach to socketcall() in test_probe_user (Artem Savkov) [2137876]
- libbpf: Extend BPF_KSYSCALL documentation (Artem Savkov) [2137876]
- bpf, devmap: Compute proper xdp_frame len redirecting frames (Artem Savkov) [2137876]
- bpf: Fix build error in case of !CONFIG_DEBUG_INFO_BTF (Artem Savkov) [2137876]
- bpf: Simplify bpf_prog_pack_[size|mask] (Artem Savkov) [2137876]
- bpf: Support bpf_trampoline on functions with IPMODIFY (e.g. livepatch) (Artem Savkov) [2137876]
- bpf, x64: Allow to use caller address from stack (Artem Savkov) [2137876]
- ftrace: Allow IPMODIFY and DIRECT ops on the same function (Artem Savkov) [2137876]
- ftrace: Add modify_ftrace_direct_multi_nolock (Artem Savkov) [2137876]
- ftrace/direct: Fix lockup in modify_ftrace_direct_multi (Artem Savkov) [2137876]
- ftrace/direct: Do not disable when switching direct callers (Artem Savkov) [2137876]
- ftrace/samples: Add multi direct interface test module (Artem Savkov) [2137876]
- ftrace: Add multi direct modify interface (Artem Savkov) [2137876]
- ftrace: Add multi direct register/unregister interface (Artem Savkov) [2137876]
- ftrace: Add ftrace_add_rec_direct function (Artem Savkov) [2137876]
- tracing: Add trampoline/graph selftest (Artem Savkov) [2137876]
- x86/ftrace: Make function graph use ftrace directly (Artem Savkov) [2137876]
- x86/ftrace: Remove extra orig rax move (Artem Savkov) [2137876]
- bpf/selftests: Fix couldn't retrieve pinned program in xdp veth test (Artem Savkov) [2137876]
- selftests/bpf: Fix test_verifier failed test in unprivileged mode (Artem Savkov) [2137876]
- selftests/bpf: Add negative tests for new nf_conntrack kfuncs (Artem Savkov) [2137876]
- selftests/bpf: Add tests for new nf_conntrack kfuncs (Artem Savkov) [2137876]
- selftests/bpf: Add verifier tests for trusted kfunc args (Artem Savkov) [2137876]
- bpf: Add documentation for kfuncs (Artem Savkov) [2137876]
- bpf: Add support for forcing kfunc args to be trusted (Artem Savkov) [2137876]
- bpf: Switch to new kfunc flags infrastructure (Artem Savkov) [2137876]
- tools/resolve_btfids: Add support for 8-byte BTF sets (Artem Savkov) [2137876]
- bpf: Introduce 8-byte BTF set (Artem Savkov) [2137876]
- bpf, docs: Use SPDX license identifier in bpf_doc.py (Artem Savkov) [2137876]
- bpf, arm64: Fix compile error in dummy_tramp() (Artem Savkov) [2137876]
- bpf: Check attach_func_proto more carefully in check_helper_call (Artem Savkov) [2137876]
- bpf: Fix bpf_trampoline_{,un}link_cgroup_shim ifdef guards (Artem Savkov) [2137876]
- libbpf: fix an snprintf() overflow check (Artem Savkov) [2137876]
- selftests/bpf: fix a test for snprintf() overflow (Artem Savkov) [2137876]
- bpf, docs: document BPF_MAP_TYPE_HASH and variants (Artem Savkov) [2137876]
- selftests/bpf: test eager BPF ringbuf size adjustment logic (Artem Savkov) [2137876]
- bpf: fix bpf_skb_pull_data documentation (Artem Savkov) [2137876]
- libbpf: fallback to tracefs mount point if debugfs is not mounted (Artem Savkov) [2137876]
- selftests/bpf: Mount debugfs in setns_by_fd (Felix Maurer) [2137876]
- selftests/bpf: Make sure zero-len skbs aren't redirectable (Felix Maurer) [2137876]
- bpf: Move skb->len == 0 checks into __bpf_redirect (Felix Maurer) [2137876]
- bpf: make sure skb->len != 0 when redirecting to a tunneling device (Felix Maurer) [2137876]
- bpf: Don't redirect packets with invalid pkt_len (Felix Maurer) [2137876]
- selftests/bpf: validate .bss section bigger than 8MB is possible now (Artem Savkov) [2137876]
- bpf: remove obsolete KMALLOC_MAX_SIZE restriction on array map value size (Artem Savkov) [2137876]
- bpf: make uniform use of array->elem_size everywhere in arraymap.c (Artem Savkov) [2137876]
- bpf: fix potential 32-bit overflow when accessing ARRAY map element (Artem Savkov) [2137876]
- docs/bpf: Update documentation for BTF_KIND_FUNC (Artem Savkov) [2137876]
- bpf: fix lsm_cgroup build errors on esoteric configs (Artem Savkov) [2137876]
- selftests/bpf: use BPF_KSYSCALL and SEC("ksyscall") in selftests (Artem Savkov) [2137876]
- libbpf: add ksyscall/kretsyscall sections support for syscall kprobes (Artem Savkov) [2137876]
- libbpf: improve BPF_KPROBE_SYSCALL macro and rename it to BPF_KSYSCALL (Artem Savkov) [2137876]
- selftests/bpf: add test of __weak unknown virtual __kconfig extern (Artem Savkov) [2137876]
- libbpf: generalize virtual __kconfig externs and use it for USDT (Artem Savkov) [2137876]
- libbpf: perfbuf: Add API to get the ring buffer (Artem Savkov) [2137876]
- bpf: iterators: Build and use lightweight bootstrap version of bpftool (Artem Savkov) [2137876]
- tools: runqslower: Build and use lightweight bootstrap version of bpftool (Artem Savkov) [2137876]
- samples: bpf: Fix cross-compiling error by using bootstrap bpftool (Artem Savkov) [2137876]
- bpf: Fix check against plain integer v 'NULL' (Artem Savkov) [2137876]
- bpf: Fix subprog names in stack traces. (Artem Savkov) [2137876]
- selftests/bpf: Do not attach kprobe_multi bench to bpf_dispatcher_xdp_func (Artem Savkov) [2137876]
- bpf: Add endian modifiers to fix endian warnings (Artem Savkov) [2137876]
- bpf: Warn on non-preallocated case for BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE (Artem Savkov) [2137876]
- selftests/bpf: Return true/false (not 1/0) from bool functions (Artem Savkov) [2137876]
- bpf, arm64: Mark dummy_tramp as global (Artem Savkov) [2137876]
- libbpf: Fix the name of a reused map (Artem Savkov) [2137876]
- samples: bpf: Replace sizeof(arr)/sizeof(arr[0]) with ARRAY_SIZE (Artem Savkov) [2137876]
- bpf: Tidy up verifier check_func_arg() (Artem Savkov) [2137876]
- libbpf: Error out when binary_path is NULL for uprobe and USDT (Artem Savkov) [2137876]
- bpf: Make non-preallocated allocation low priority (Artem Savkov) [2137876]
- bpf: reparent bpf maps on memcg offlining (Artem Savkov) [2137876]
- selftests/bpf: add a ksym iter subtest (Artem Savkov) [2137876]
- bpf: add a ksym BPF iterator (Artem Savkov) [2137876]
- bpf: Fix 'dubious one-bit signed bitfield' warnings (Artem Savkov) [2137876]
- bpf, arm64: Add bpf trampoline for arm64 (Artem Savkov) [2137876]
- bpf, arm64: Implement bpf_arch_text_poke() for arm64 (Artem Savkov) [2137876]
- arm64: Add LDR (literal) instruction (Artem Savkov) [2137876]
- bpf: Remove is_valid_bpf_tramp_flags() (Artem Savkov) [2137876]
- bpf: Correctly propagate errors up from bpf_core_composites_match (Artem Savkov) [2137876]
- libbpf: Disable SEC pragma macro on GCC (Artem Savkov) [2137876]
- bpf: Check attach_func_proto more carefully in check_return_code (Artem Savkov) [2137876]
- selftests/bpf: Add test involving restrict type qualifier (Artem Savkov) [2137876]
- bpftool: Add support for KIND_RESTRICT to gen min_core_btf command (Artem Savkov) [2137876]
- bpf, docs: Remove deprecated xsk libbpf APIs description (Artem Savkov) [2137876]
- selftests/bpf: Add benchmark for local_storage RCU Tasks Trace usage (Artem Savkov) [2137876]
- libbpf: Remove unnecessary usdt_rel_ip assignments (Artem Savkov) [2137876]
- selftests/bpf: Fix few more compiler warnings (Artem Savkov) [2137876]
- selftests/bpf: Add selftests for raw syncookie helpers in TC mode (Artem Savkov) [2137876]
- bpf: Allow the new syncookie helpers to work with SKBs (Artem Savkov) [2137876]
- selftests/bpf: Add selftests for raw syncookie helpers (Artem Savkov) [2137876]
- bpf: Add helpers to issue and check SYN cookies in XDP (Artem Savkov) [2137876]
- bpf: Fix documentation of th_len in bpf_tcp_{gen,check}_syncookie (Artem Savkov) [2137876]
- selftests/bpf: Fix bogus uninitialized variable warning (Artem Savkov) [2137876]
- bpftool: Remove zlib feature test from Makefile (Artem Savkov) [2137876]
- libbpf: Cleanup the legacy uprobe_event on failed add/attach_event() (Artem Savkov) [2137876]
- libbpf: Fix wrong variable used in perf_event_uprobe_open_legacy() (Artem Savkov) [2137876]
- libbpf: Cleanup the legacy kprobe_event on failed add/attach_event() (Artem Savkov) [2137876]
- libbpf: add bpf_core_type_matches() helper macro (Artem Savkov) [2137876]
- selftests/bpf: Add type match test against kernel's task_struct (Artem Savkov) [2137876]
- selftests/bpf: Add nested type to type based tests (Artem Savkov) [2137876]
- selftests/bpf: Add test checking more characteristics (Artem Savkov) [2137876]
- selftests/bpf: Add type-match checks to type-based tests (Artem Savkov) [2137876]
- bpf, libbpf: Add type match support (Artem Savkov) [2137876]
- bpftool: Honor BPF_CORE_TYPE_MATCHES relocation (Artem Savkov) [2137876]
- bpf: Introduce TYPE_MATCH related constants/macros (Artem Savkov) [2137876]
- bpftool: Rename "bpftool feature list" into "... feature list_builtins" (Artem Savkov) [2137876]
- selftests/bpf: Skip lsm_cgroup when we don't have trampolines (Artem Savkov) [2137876]
- bpftool: Show also the name of type BPF_OBJ_LINK (Artem Savkov) [2137876]
- bpftool: Use feature list in bash completion (Artem Savkov) [2137876]
- bpftool: Add feature list (prog/map/link/attach types, helpers) (Artem Savkov) [2137876]
- bpftool: Remove attach_type_name forward declaration (Artem Savkov) [2137876]
- selftests/bpf: lsm_cgroup functional test (Artem Savkov) [2137876]
- bpftool: implement cgroup tree for BPF_LSM_CGROUP (Artem Savkov) [2137876]
- libbpf: implement bpf_prog_query_opts (Artem Savkov) [2137876]
- libbpf: add lsm_cgoup_sock type (Artem Savkov) [2137876]
- tools/bpf: Sync btf_ids.h to tools (Artem Savkov) [2137876]
- bpf: expose bpf_{g,s}etsockopt to lsm cgroup (Artem Savkov) [2137876]
- bpf: implement BPF_PROG_QUERY for BPF_LSM_CGROUP (Artem Savkov) [2137876]
- bpf: minimize number of allocated lsm slots per program (Artem Savkov) [2137876]
- bpf: per-cgroup lsm flavor (Artem Savkov) [2137876]
- bpf: convert cgroup_bpf.progs to hlist (Artem Savkov) [2137876]
- bpf: add bpf_func_t and trampoline helpers (Artem Savkov) [2137876]
- libbpf: fix up few libbpf.map problems (Artem Savkov) [2137876]
- libbpf: enforce strict libbpf 1.0 behaviors (Artem Savkov) [2137876]
- selftests/bpf: remove last tests with legacy BPF map definitions (Artem Savkov) [2137876]
- libbpf: clean up SEC() handling (Artem Savkov) [2137876]
- libbpf: remove internal multi-instance prog support (Artem Savkov) [2137876]
- libbpf: cleanup LIBBPF_DEPRECATED_SINCE supporting macros for v0.x (Artem Savkov) [2137876]
- libbpf: remove multi-instance and custom private data APIs (Artem Savkov) [2137876]
- libbpf: remove most other deprecated high-level APIs (Artem Savkov) [2137876]
- libbpf: remove prog_info_linear APIs (Artem Savkov) [2137876]
- libbpf: clean up perfbuf APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated BTF APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated XDP APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated probing APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated low-level APIs (Artem Savkov) [2137876]
- libbpf: move xsk.{c,h} into selftests/bpf (Artem Savkov) [2137876]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Artem Savkov) [2137876]
- bpf: Fix sockmap calling sleepable function in teardown path (Artem Savkov) [2137876]
- bpf: Merge "types_are_compat" logic into relo_core.c (Artem Savkov) [2137876]
- bpf, docs: Fix the code formatting in instruction-set (Artem Savkov) [2137876]
- selftest/bpf: Test for use-after-free bug fix in inline_bpf_loop (Artem Savkov) [2137876]
- bpf: Fix for use-after-free bug in inline_bpf_loop (Artem Savkov) [2137876]
- bpf: Replace hard-coded 0 with BPF_K in check_alu_op (Artem Savkov) [2137876]
- selftests/bpf: Add benchmark for local_storage get (Artem Savkov) [2137876]
- bpf, arm64: Keep tail call count across bpf2bpf calls (Artem Savkov) [2137876]
- bpf, x64: Add predicate for bpf2bpf with tailcalls support in JIT (Artem Savkov) [2137876]
- selftests/bpf: BPF test_prog selftests for bpf_loop inlining (Artem Savkov) [2137876]
- selftests/bpf: BPF test_verifier selftests for bpf_loop inlining (Artem Savkov) [2137876]
- bpf: Inline calls to bpf_loop when callback is known (Artem Savkov) [2137876]
- selftests/bpf: allow BTF specs and func infos in test_verifier tests (Artem Savkov) [2137876]
- selftests/bpf: specify expected instructions in test_verifier tests (Artem Savkov) [2137876]
- uprobe: gate bpf call behind BPF_EVENTS (Artem Savkov) [2137876]
- bpf: Allow helpers to accept pointers with a fixed size (Artem Savkov) [2137876]
- libbpf: add support for sleepable uprobe programs (Artem Savkov) [2137876]
- selftests/bpf: add tests for sleepable (uk)probes (Artem Savkov) [2137876]
- bpf: implement sleepable uprobes by chaining gps (Artem Savkov) [2137876]
- bpf: allow sleepable uprobe programs to attach (Artem Savkov) [2137876]
- bpf: move bpf_prog to bpf.h (Artem Savkov) [2137876]
- selftests/bpf: Fix test_varlen verification failure with latest llvm (Artem Savkov) [2137876]
- bpf: Fix spelling in bpf_verifier.h (Artem Savkov) [2137876]
- selftest/bpf/benchs: Add bpf_map benchmark (Artem Savkov) [2137876]
- bpf: avoid grabbing spin_locks of all cpus when no free elems (Artem Savkov) [2137876]
- bpf, docs: Fix typo "BFP_ALU" to "BPF_ALU" (Artem Savkov) [2137876]
- bpftool: Fix bootstrapping during a cross compilation (Artem Savkov) [2137876]
- libbpf: Fix a couple of typos (Artem Savkov) [2137876]
- bpf, test_run: Remove unnecessary prog type checks (Artem Savkov) [2137876]
- bpf, sockmap: Fix sk->sk_forward_alloc warn_on in sk_stream_kill_queues (Artem Savkov) [2137876]
- libbpf: Fix determine_ptr_size() guessing (Artem Savkov) [2137876]
- bpf: Fix KASAN use-after-free Read in compute_effective_progs (Artem Savkov) [2137876]
- bpftool: Check for NULL ptr of btf in codegen_asserts (Artem Savkov) [2137876]
- selftests/bpf: Fix test_run logic in fexit_stress.c (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_link_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_link_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_attach_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_attach_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_map_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_map_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_prog_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_prog_type_str (Artem Savkov) [2137876]
- bpf: Correct the comment about insn_to_jit_off (Artem Savkov) [2137876]
- bpf: Unify data extension operation of jited_ksyms and jited_linfo (Artem Savkov) [2137876]

* Wed Jan 11 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-233.el9]
- config: Enable TDX Guest (Wander Lairson Costa) [1955275]
- x86/tdx: mark TDX as a preview (Wander Lairson Costa) [1955275]
- x86/tdx: Panic on bad configs that #VE on "private" memory access (Wander Lairson Costa) [1955275]
- x86/tdx: Prepare for using "INFO" call for a second purpose (Wander Lairson Costa) [1955275]
- x86/tdx: Handle load_unaligned_zeropad() page-cross to a shared page (Wander Lairson Costa) [1955275]
- x86/tdx: Clarify RIP adjustments in #VE handler (Wander Lairson Costa) [1955275]
- swiotlb: merge swiotlb-xen initialization into swiotlb (Wander Lairson Costa) [1955275]
- x86/kaslr: Fix build warning in KASLR code in boot stub (Wander Lairson Costa) [1955275]
- x86/tdx: Fix early #VE handling (Wander Lairson Costa) [1955275]
- x86/tdx: Fix RETs in TDX asm (Wander Lairson Costa) [1955275]
- x86/tdx: Annotate a noreturn function (Wander Lairson Costa) [1955275]
- x86/mm: Fix spacing within memory encryption features message (Wander Lairson Costa) [1955275]
- x86/apic: Do apic driver probe for "nosmp" use case (Wander Lairson Costa) [1955275]
- arm/xen: don't check for xen_initial_domain() in xen_create_contiguous_region (Wander Lairson Costa) [1955275]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Wander Lairson Costa) [1955275]
- x86/Kconfig: Only enable CONFIG_CC_HAS_IBT for clang >= 14.0.0 (Wander Lairson Costa) [1955275]
- selftests/x86/iopl: Adjust to the faked iopl CLI/STI usage (Wander Lairson Costa) [1955275]
- x86/sev-es: Use insn_decode_mmio() for MMIO implementation (Wander Lairson Costa) [1955275]
- x86/insn-eval: Handle insn_get_opcode() failure (Wander Lairson Costa) [1955275]
- Documentation/x86: Document TDX kernel architecture (Wander Lairson Costa) [1955275]
- ACPICA: Avoid cache flush inside virtual machines (Wander Lairson Costa) [1955275]
- x86/tdx/ioapic: Add shared bit for IOAPIC base address (Wander Lairson Costa) [1955275]
- x86/mm: Make DMA memory shared for TD guest (Wander Lairson Costa) [1955275]
- x86/mm/cpa: Add support for TDX shared memory (Wander Lairson Costa) [1955275]
- x86/tdx: Make pages shared in ioremap() (Wander Lairson Costa) [1955275]
- x86/topology: Disable CPU online/offline control for TDX guests (Wander Lairson Costa) [1955275]
- x86/boot: Avoid #VE during boot for TDX platforms (Wander Lairson Costa) [1955275]
- x86/boot: Set CR0.NE early and keep it set during the boot (Wander Lairson Costa) [1955275]
- x86/acpi/x86/boot: Add multiprocessor wake-up support (Wander Lairson Costa) [1955275]
- x86/boot: Add a trampoline for booting APs via firmware handoff (Wander Lairson Costa) [1955275]
- x86/tdx: Wire up KVM hypercalls (Wander Lairson Costa) [1955275]
- x86/tdx: Port I/O: Add early boot support (Wander Lairson Costa) [1955275]
- x86/tdx: Port I/O: Add runtime hypercalls (Wander Lairson Costa) [1955275]
- x86/boot: Port I/O: Add decompression-time support for TDX (Wander Lairson Costa) [1955275]
- x86/boot: Port I/O: Allow to hook up alternative helpers (Wander Lairson Costa) [1955275]
- x86: Consolidate port I/O helpers (Wander Lairson Costa) [1955275]
- x86: Adjust types used in port I/O helpers (Wander Lairson Costa) [1955275]
- x86/tdx: Detect TDX at early kernel decompression time (Wander Lairson Costa) [1955275]
- x86/tdx: Handle in-kernel MMIO (Wander Lairson Costa) [1955275]
- x86/tdx: Handle CPUID via #VE (Wander Lairson Costa) [1955275]
- x86/tdx: Add MSR support for TDX guests (Wander Lairson Costa) [1955275]
- x86/tdx: Add HLT support for TDX guests (Wander Lairson Costa) [1955275]
- x86/traps: Add #VE support for TDX guest (Wander Lairson Costa) [1955275]
- x86/traps: Refactor exc_general_protection() (Wander Lairson Costa) [1955275]
- x86/tdx: Exclude shared bit from __PHYSICAL_MASK (Wander Lairson Costa) [1955275]
- x86/tdx: Extend the confidential computing API to support TDX guests (Wander Lairson Costa) [1955275]
- x86/tdx: Add __tdx_module_call() and __tdx_hypercall() helper functions (Wander Lairson Costa) [1955275]
- x86/tdx: Provide common base for SEAMCALL and TDCALL C wrappers (Wander Lairson Costa) [1955275]
- x86/tdx: Detect running as a TDX guest in early boot (Wander Lairson Costa) [1955275]
- Documentation: Add x86/amd_hsmp driver (Wander Lairson Costa) [1955275]
- x86/insn-eval: Introduce insn_decode_mmio() (Wander Lairson Costa) [1955275]
- x86/insn-eval: Introduce insn_get_modrm_reg_ptr() (Wander Lairson Costa) [1955275]
- x86/iopl: Fake iopl(3) CLI/STI usage (Wander Lairson Costa) [1955275]

* Tue Jan 10 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-232.el9]
- ACPI: x86: s2idle: Stop using AMD specific codepath for Rembrandt+ (David Arcari) [2158310]
- ACPI: x86: s2idle: Force AMD GUID/_REV 2 on HP Elitebook 865 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add another ID to s2idle_dmi_table (David Arcari) [2158310]
- ACPI: x86: s2idle: Fix a NULL pointer dereference (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUSTeK COMPUTER INC. ROG Flow X13 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for Lenovo Slim 7 Pro 14ARH7 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUS ROG Zephyrus G14 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUS TUF Gaming A17 FA707RE (David Arcari) [2158310]
- ACPI: x86: s2idle: Add module parameter to prefer Microsoft GUID (David Arcari) [2158310]
- ACPI: x86: s2idle: If a new AMD _HID is missing assume Rembrandt (David Arcari) [2158310]
- ACPI: x86: s2idle: Move _HID handling for AMD systems into structures (David Arcari) [2158310]
- ACPI: s2idle: Add a new ->check() callback for platform_s2idle_ops (David Arcari) [2158310]
- perf vendor events amd: Add Zen 4 mapping (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 metrics (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 uncore events (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 core events (Michael Petlan) [2148295]
- arm64: kdump: Support crashkernel=X fall back to reserve region above DMA zones (Pingfan Liu) [2112877]
- arm64: kdump: Provide default size when crashkernel=Y,low is not specified (Pingfan Liu) [2112877]
- ice: Implement devlink port split operations (Petr Oros) [2154357]
- ice: Add additional flags to ice_nvm_write_activate (Petr Oros) [2154357]
- ice: Add port option admin queue commands (Petr Oros) [2154357]
- cifs: fix NULL ptr dereference in refresh_mounts() (Ronnie Sahlberg) [2151070]
- s390: fix double free of GS and RI CBs on fork() failure (Brian Foster) [2121449]

* Mon Jan 09 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-231.el9]
- tcp: Fix data-races around sysctl_tcp_fastopen_blackhole_timeout. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_fastopen. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_max_syn_backlog. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_tw_reuse. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_notsent_lowat. (Guillaume Nault) [2149949]
- tcp: Fix data-races around some timeout sysctl knobs. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_reordering. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_migrate_req. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_syn(ack)?_retries. (Guillaume Nault) [2149949]
- tcp: Fix data-races around keepalive sysctl knobs. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_qrv. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_max_msf. (Guillaume Nault) [2149949]
- igmp: Fix a data-race around sysctl_igmp_max_memberships. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_llm_reports. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_probe_interval. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_probe_threshold. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_mtu_probe_floor. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_min_snd_mss. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_base_mss. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_mtu_probing. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_l3mdev_accept. (Guillaume Nault) [2149949]
- tcp/dccp: Fix a data-race around sysctl_tcp_fwmark_accept. (Guillaume Nault) [2149949]
- ip: Fix a data-race around sysctl_fwmark_reflect. (Guillaume Nault) [2149949]
- ip: Fix a data-race around sysctl_ip_autobind_reuse. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_nonlocal_bind. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_fwd_update_priority. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_fwd_use_pmtu. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_no_pmtu_disc. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_default_ttl. (Guillaume Nault) [2149949]
- nexthop: Fix data-races around nexthop_compat_mode. (Guillaume Nault) [2149949]
- ipv4: Fix data-races around sysctl_ip_dynaddr. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_ecn_fallback. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_ecn. (Guillaume Nault) [2149949]
- raw: Fix a data-race around sysctl_raw_l3mdev_accept. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ratemask. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ratelimit. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_errors_use_inbound_ifaddr. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ignore_bogus_error_responses. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_broadcasts. (Guillaume Nault) [2149949]
- icmp: Fix data-races around sysctl_icmp_echo_enable_probe. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_all. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_max_tw_buckets. (Guillaume Nault) [2149949]
- sysctl: Fix data-races in proc_dointvec_ms_jiffies(). (Guillaume Nault) [2149949]
- sysctl: Fix data-races in proc_dou8vec_minmax(). (Guillaume Nault) [2149949]
- ipv4: Fix a data-race around sysctl_fib_sync_mem. (Guillaume Nault) [2149949]
- icmp: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- cipso: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- inetpeer: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_max_orphans. (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec_jiffies(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_doulongvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_douintvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_douintvec(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec(). (Guillaume Nault) [2149949]
- net: sock: tracing: Fix sock_exceed_buf_limit not to dereference stale pointer (Guillaume Nault) [2149949]
- inet: rename INET_MATCH() (Guillaume Nault) [2149949]
- ipv6: add READ_ONCE(sk->sk_bound_dev_if) in INET6_MATCH() (Guillaume Nault) [2149949]
- l2tp: use add READ_ONCE() to fetch sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- inet: add READ_ONCE(sk->sk_bound_dev_if) in inet_csk_bind_conflict() (Guillaume Nault) [2149949]
- dccp: use READ_ONCE() to read sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- net: core: add READ_ONCE/WRITE_ONCE annotations for sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- tcp: sk->sk_bound_dev_if once in inet_request_bound_dev_if() (Guillaume Nault) [2149949]
- net: annotate races around sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- inet: add READ_ONCE(sk->sk_bound_dev_if) in INET_MATCH() (Guillaume Nault) [2149949]

* Fri Jan 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-230.el9]
- x86/cpu: Add several Intel server CPU model numbers (David Arcari) [2158038]
- ip_gre: do not report erspan version on GRE interface (Hangbin Liu) [2150168]
- redhat/configs: enable HP_WATCHDOG for aarch64 (Mark Salter) [2113082]
- watchdog/hpwdt: Enable HP_WATCHDOG for ARM64 systems. (Mark Salter) [2113082]
- watchdog/hpwdt: Include nmi.h only if CONFIG_HPWDT_NMI_DECODING (Mark Salter) [2113082]

* Thu Jan 05 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-229.el9]
- scsi: zfcp: Fix double free of FSF request when qdio send fails (Tobias Huschle) [2155158]
- l2tp: Don't sleep and disable BH under writer-side sk_callback_lock (Guillaume Nault) [2145234] {CVE-2022-4129}
- l2tp: Serialize access to sk_user_data with sk_callback_lock (Guillaume Nault) [2145234] {CVE-2022-4129}
- scsi: target: iscsi: Fix a race condition between login_work and the login thread (Maurizio Lombardi) [2138867]
- RHEL: ALSA: add kunit module soc-utils-test to mod-internal.list (Jaroslav Kysela) [2152183]
- hwmon: (coretemp) Check for null before removing sysfs attrs (Phil Auld) [2101449]
- powerpc/bpf/64: Add instructions for atomic_[cmp]xchg (Mamatha Inamdar) [2113155]
- powerpc/bpf/64: add support for atomic fetch operations (Mamatha Inamdar) [2113155]
- powerpc/bpf/64: add support for BPF_ATOMIC bitwise operations (Mamatha Inamdar) [2113155]
- powerpc64: Set PPC64_ELF_ABI_v[1|2] macros to 1 (Mamatha Inamdar) [2113155]

* Tue Jan 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-228.el9]
- NFS: Allow very small rsize & wsize again (Benjamin Coddington) [2107347]
- NFS: Allow setting rsize / wsize to a multiple of PAGE_SIZE (Benjamin Coddington) [2107347]
- virtio_console: Introduce an ID allocator for virtual console numbers (Cédric Le Goater) [2155154]
- perf/x86/amd/uncore: Fix memory leak for events array (Michael Petlan) [2152144]
- netfs: Fix dodgy maths (Xiubo Li) [2138981]
- netfs: Fix missing xas_retry() calls in xarray iteration (Xiubo Li) [2138981]
- EDAC/mc_sysfs: Increase legacy channel support to 12 (Aristeu Rozanski) [2139862]

* Mon Jan 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-227.el9]
- crypto: pcrypt - Delay write to padata->info (Luis Claudio R. Goncalves) [2154189]
- cpufreq: ACPI: Defer setting boost MSRs (Mark Langsdorf) [2142900]
- SUNRPC: Simplify synopsis of svc_pool_for_cpu() (Luis Claudio R. Goncalves) [2149755]
- SUNRPC: Don't disable preemption while calling svc_pool_for_cpu(). (Luis Claudio R. Goncalves) [2149755]
- kernel/rh_messages.c: gcc12 warning on redundant NULL test (Eric Chanudet) [2142658]
- Bluetooth: L2CAP: fix use-after-free in l2cap_conn_del() (Gopal Tiwari) [2140026]
- Bluetooth: hci_conn: Fix not restoring ISO buffer count on disconnect (Gopal Tiwari) [2140026]
- Bluetooth: hci_conn: Fix CIS connection dst_type handling (Gopal Tiwari) [2140026]
- Bluetooth: avoid hci_dev_test_and_set_flag() in mgmt_init_hdev() (Gopal Tiwari) [2140026]
- Bluetooth: Prevent double register of suspend (Gopal Tiwari) [2140026]
- Bluetooth: use hdev->workqueue when queuing hdev->{cmd,ncmd}_timer works (Gopal Tiwari) [2140026]

* Fri Dec 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-226.el9]
- KVM: s390: pv: don't allow userspace to set the clock under PV (Tobias Huschle) [2154283]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2104470]
- x86/microcode/AMD: Apply the patch early on every logical thread (Waiman Long) [2138389]
- x86/bugs: Enable STIBP for IBPB mitigated RETBleed (Waiman Long) [2138389]
- x86/bugs: Add "unknown" reporting for MMIO Stale Data (Waiman Long) [2138389]
- config: mhi: set CONFIG_MHI_BUS_EP to disabled (Íñigo Huguet) [2136122]
- config: rtw89: set CONFIG_RTW89_8852C to disabled (Íñigo Huguet) [2136122]
- wifi: ath11k: avoid deadlock during regulatory update in ath11k_regd_update() (Íñigo Huguet) [2136122 2139482]
- wifi: mac80211: mlme: Fix double unlock on assoc success handling (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: Fix missing unlock on beacon RX (Íñigo Huguet) [2136122]
- wifi: mac80211: fix memory corruption in minstrel_ht_update_rates() (Íñigo Huguet) [2136122]
- wifi: mac80211: fix regression with non-QoS drivers (Íñigo Huguet) [2136122]
- wifi: mac80211: ensure vif queues are operational after start (Íñigo Huguet) [2136122]
- wifi: mac80211: don't start TX with fq->lock to fix deadlock (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix MCS divisor value (Íñigo Huguet) [2136122]
- wifi: mt76: fix 5 GHz connection regression on mt76x0/mt76x2 (Íñigo Huguet) [2136122]
- wifi: mt76: fix reading current per-tid starting sequence number for aggregation (Íñigo Huguet) [2136122]
- wifi: iwlwifi: Mark IWLMEI as broken (Íñigo Huguet) [2136122]
- wifi: iwlwifi: don't spam logs with NSS>2 messages (Íñigo Huguet) [2136122]
- wifi: use struct_group to copy addresses (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: check length for virtio packets (Íñigo Huguet) [2136122]
- wifi: mac80211: fix locking in auth/assoc timeout (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: release deflink channel in error case (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link warning in RX agg timer expiry (Íñigo Huguet) [2136122]
- wifi: wilc1000: fix DMA on stack objects (Íñigo Huguet) [2136122]
- bus: mhi: host: Fix up null pointer access in mhi_irq_handler (Íñigo Huguet) [2136122]
- net: Use u64_stats_fetch_begin_irq() for stats fetch. (Íñigo Huguet) [2136122]
- wifi: mt76: mt7921e: fix crash in chip reset fail (Íñigo Huguet) [2136122]
- wifi: mac80211: potential NULL dereference in ieee80211_tx_control_port() (Íñigo Huguet) [2136122]
- wifi: cfg80211: debugfs: fix return type in ht40allow_map_read() (Íñigo Huguet) [2136122]
- wifi: mac80211: Don't finalize CSA in IBSS mode if state is disconnected (Íñigo Huguet) [2136122]
- wifi: mac80211: fix possible leak in ieee80211_tx_control_port() (Íñigo Huguet) [2136122]
- wifi: mac80211: always free sta in __sta_info_alloc in case of error (Íñigo Huguet) [2136122]
- wifi: mac80211: Fix UAF in ieee80211_scan_rx() (Íñigo Huguet) [2136122]
- net: qrtr: start MHI channel after endpoit creation (Íñigo Huguet) [2136122]
- wifi: wilc1000: fix spurious inline in wilc_handle_disconnect() (Íñigo Huguet) [2136122]
- wifi: cfg80211: Fix validating BSS pointers in __cfg80211_connect_result (Íñigo Huguet) [2136122]
- wifi: rtw88: check the return value of alloc_workqueue() (Íñigo Huguet) [2136122]
- wifi: rtw89: 8852a: adjust IMR for SER L1 (Íñigo Huguet) [2136122]
- wifi: rtw89: 8852a: update RF radio A/B R56 (Íñigo Huguet) [2136122]
- wifi: brcmfmac: prevent double-free on hardware-reset (Íñigo Huguet) [2136122]
- wifi: brcmfmac: support brcm,ccode-map-trivial DT property (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Replace default (not configured) MAC with a random MAC (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Add brcmf_c_set_cur_etheraddr() helper (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Remove #ifdef guards for PM related functions (Íñigo Huguet) [2136122]
- wifi: brcmfmac: use strreplace() in brcmf_of_probe() (Íñigo Huguet) [2136122]
- wifi: wilc1000: use existing iftype variable to store the interface type (Íñigo Huguet) [2136122]
- wifi: wilc1000: add 'isinit' flag for SDIO bus similar to SPI (Íñigo Huguet) [2136122]
- wifi: wilc1000: cancel the connect operation during interface down (Íñigo Huguet) [2136122]
- wifi: wilc1000: get correct length of string WID from received config packet (Íñigo Huguet) [2136122]
- wifi: wilc1000: set station_info flag only when signal value is valid (Íñigo Huguet) [2136122]
- wifi: wilc1000: set correct value of 'close' variable in failure case (Íñigo Huguet) [2136122]
- wifi: wilc1000: add WID_TX_POWER WID in g_cfg_byte array (Íñigo Huguet) [2136122]
- wifi: rtl8xxxu: Fix the error handling of the probe function (Íñigo Huguet) [2136122]
- wifi: mwifiex: clean up one inconsistent indenting (Íñigo Huguet) [2136122]
- wifi: rtlwifi: Remove duplicate word and Fix typo (Íñigo Huguet) [2136122]
- wifi: mwifiex: Fix comment typo (Íñigo Huguet) [2136122]
- wifi: iwlwifi: mvm: fix clang -Wformat warnings (Íñigo Huguet) [2136122]
- Revert "ath11k: add support for hardware rfkill for QCA6390" (Íñigo Huguet) [2136122]
- wifi: ath11k: Fix register write failure on QCN9074 (Íñigo Huguet) [2136122]
- mac80211: tracing: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link data leak (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix disassoc with MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add macros to loop over active links (Íñigo Huguet) [2136122]
- wifi: mac80211: remove erroneous sband/link validation (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: transmit assoc frame with address translation (Íñigo Huguet) [2136122]
- wifi: mac80211: verify link addresses are different (Íñigo Huguet) [2136122]
- wifi: mac80211: rx: track link in RX data (Íñigo Huguet) [2136122]
- wifi: mac80211: optionally implement MLO multicast TX (Íñigo Huguet) [2136122]
- wifi: mac80211: expand ieee80211_mgmt_tx() for MLO (Íñigo Huguet) [2136122]
- wifi: nl80211: add MLO link ID to the NL80211_CMD_FRAME TX API (Íñigo Huguet) [2136122]
- wifi: mac80211: report link ID to cfg80211 on mgmt RX (Íñigo Huguet) [2136122]
- wifi: cfg80211: report link ID in NL80211_CMD_FRAME (Íñigo Huguet) [2136122]
- wifi: mac80211: add hardware timestamps for RX and TX (Íñigo Huguet) [2136122]
- wifi: cfg80211: add hardware timestamps to frame RX info (Íñigo Huguet) [2136122]
- wifi: cfg80211/nl80211: move rx management data into a struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: add a function for reporting TX status with hardware timestamps (Íñigo Huguet) [2136122]
- wifi: nl80211: add RX and TX timestamp attributes (Íñigo Huguet) [2136122]
- wifi: ieee80211: add helper functions for detecting TM/FTM frames (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: handle links for wmediumd/virtio (Íñigo Huguet) [2136122]
- wifi: mac80211: sta_info: fix link_sta insertion (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix link_sta setup (Íñigo Huguet) [2136122]
- wifi: nl80211/mac80211: clarify link ID in control port TX (Íñigo Huguet) [2136122]
- wifi: mac80211: return error from control port TX for drops (Íñigo Huguet) [2136122]
- wifi: nl80211: require MLD address on link STA add/modify (Íñigo Huguet) [2136122]
- wifi: mac80211: more station handling sanity checks (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link sta hash table handling (Íñigo Huguet) [2136122]
- wifi: mac80211: validate link address doesn't change (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: set sta.mlo to mlo state (Íñigo Huguet) [2136122]
- wifi: mac80211: fast-xmit: handle non-MLO clients (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix address translation for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: fix RX MLD address translation (Íñigo Huguet) [2136122]
- wifi: mac80211: fix NULL pointer deref with non-MLD STA (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix override calculation (Íñigo Huguet) [2136122]
- wifi: mac80211: tx: use AP address in some places for MLO (Íñigo Huguet) [2136122]
- net: add missing includes and forward declarations under net/ (Íñigo Huguet) [2136122]
- wifi: rtl8192se: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: rtlwifi: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: rt2x00: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: brcmsmac: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: brcmfmac: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: mac80211: do not abuse fq.lock in ieee80211_do_stop() (Íñigo Huguet) [2136122]
- wifi: mt7601u: fix clang -Wformat warning (Íñigo Huguet) [2136122]
- wifi: mt7601u: eeprom: fix clang -Wformat warning (Íñigo Huguet) [2136122]
- wifi: ath: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: ath11k: mac: fix long line (Íñigo Huguet) [2136122]
- tracing/iwlwifi: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- tracing/brcm: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- tracing/ath: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: set sta.mlo correctly (Íñigo Huguet) [2136122]
- wifi: mac80211: remove stray printk (Íñigo Huguet) [2136122]
- wifi: mac80211: support MLO authentication/association with one link (Íñigo Huguet) [2136122]
- wifi: mac80211: add API to parse multi-link element (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix TX link selection (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: use MLO link ID for TX (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: do rc update per link (Íñigo Huguet) [2136122]
- wifi: mac80211: do link->MLD address translation on RX (Íñigo Huguet) [2136122]
- wifi: mac80211: select link when transmitting to non-MLO stations (Íñigo Huguet) [2136122]
- wifi: mac80211: fix up link station creation/insertion (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: implement sta_state for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: limit A-MSDU subframes for client too (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor ieee80211_set_associated() (Íñigo Huguet) [2136122]
- wifi: cfg80211: add cfg80211_get_iftype_ext_capa() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: look up beacon elems only if needed (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc link setup (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: remove address arg to ieee80211_mark_sta_auth() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc success handling (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor ieee80211_prep_channel() a bit (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc req element building (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: switch some things back to deflink (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: change flags in ieee80211_determine_chantype() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: shift some code around (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor link station setup (Íñigo Huguet) [2136122]
- wifi: mac80211: move IEEE80211_SDATA_OPERATING_GMODE to link (Íñigo Huguet) [2136122]
- wifi: mac80211: make ieee80211_check_rate_mask() link-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: add multi-link element to AUTH frames (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: clean up supported channels element code (Íñigo Huguet) [2136122]
- wifi: mac80211: release channel context on link stop (Íñigo Huguet) [2136122]
- wifi: mac80211: prohibit DEAUTH_NEED_MGD_TX_PREP in MLO (Íñigo Huguet) [2136122]
- wifi: nl80211: fix some attribute policy entries (Íñigo Huguet) [2136122]
- wifi: nl80211: reject fragmented and non-inheritance elements (Íñigo Huguet) [2136122]
- wifi: nl80211: reject link specific elements on assoc link (Íñigo Huguet) [2136122]
- wifi: cfg80211: set country_elem to NULL (Íñigo Huguet) [2136122]
- wifi: mac80211: remove link_id parameter from link_info_changed() (Íñigo Huguet) [2136122]
- wifi: mac80211: replace link_id with link_conf in switch/(un)assign_vif_chanctx() (Íñigo Huguet) [2136122]
- wifi: nl80211: advertise MLO support (Íñigo Huguet) [2136122]
- wifi: mac80211: Support multi link in ieee80211_recalc_min_chandef() (Íñigo Huguet) [2136122]
- wifi: mac80211: don't check carrier in chanctx code (Íñigo Huguet) [2136122]
- wifi: nl80211: allow link ID in set_wiphy with frequency (Íñigo Huguet) [2136122]
- wifi: mac80211: Allow EAPOL tx from specific link (Íñigo Huguet) [2136122]
- wifi: mac80211: Allow EAPOL frames from link addresses (Íñigo Huguet) [2136122]
- wifi: cfg80211/mac80211: Support control port TX from specific link (Íñigo Huguet) [2136122]
- wifi: nl80211: Support MLD parameters in nl80211_set_station() (Íñigo Huguet) [2136122]
- wifi: nl80211: check MLO support in authenticate (Íñigo Huguet) [2136122]
- wifi: mac80211: add a helper to fragment an element (Íñigo Huguet) [2136122]
- wifi: mac80211: skip rate statistics for MLD STAs (Íñigo Huguet) [2136122]
- wifi: nl80211: set BSS to NULL if IS_ERR() (Íñigo Huguet) [2136122]
- wifi: nl80211: add EML/MLD capabilities to per-iftype capabilities (Íñigo Huguet) [2136122]
- wifi: nl80211: better validate link ID for stations (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link manipulation (Íñigo Huguet) [2136122]
- wifi: mac80211: tighten locking check (Íñigo Huguet) [2136122]
- wifi: cfg80211: clean up links appropriately (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: simplify adding ht/vht/he/eht elements (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor adding custom elements (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor adding rates to assoc request (Íñigo Huguet) [2136122]
- wifi: mac80211: use only channel width in ieee80211_parse_bitrates() (Íñigo Huguet) [2136122]
- wifi: cfg80211: add ieee80211_chanwidth_rate_flags() (Íñigo Huguet) [2136122]
- wifi: mac80211: remove redundant condition (Íñigo Huguet) [2136122]
- wifi: mac80211: don't set link address for station (Íñigo Huguet) [2136122]
- wifi: mac80211: fix multi-BSSID element parsing (Íñigo Huguet) [2136122]
- wifi: mac80211: move tdls_chan_switch_prohibited to link data (Íñigo Huguet) [2136122]
- wifi: mac80211: don't re-parse elems in ieee80211_assoc_success() (Íñigo Huguet) [2136122]
- wifi: mac80211: replace link_id with link_conf in start/stop_ap() (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor elements parsing with parameter struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: extend cfg80211_rx_assoc_resp() for MLO (Íñigo Huguet) [2136122]
- wifi: cfg80211: put cfg80211_rx_assoc_resp() arguments into a struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: adjust assoc comeback for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: unify assoc data event sending (Íñigo Huguet) [2136122]
- wifi: cfg80211: prepare association failure APIs for MLO (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove BSS pointer from cfg80211_disassoc_request (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: use correct link_sta (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: remove sta argument from ieee80211_config_bw (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: use ieee80211_get_link_sband() (Íñigo Huguet) [2136122]
- wifi: mac80211: split IEEE80211_STA_DISABLE_WMM to link data (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: first adjustments for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: do IEEE80211_STA_RESET_SIGNAL_AVE per link (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: track AP (MLD) address separately (Íñigo Huguet) [2136122]
- wifi: mac80211: remove unused bssid variable (Íñigo Huguet) [2136122]
- wifi: mac80211: change QoS settings API to take link into account (Íñigo Huguet) [2136122]
- wifi: mac80211: expect powersave handling in driver for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: move ps setting to vif config (Íñigo Huguet) [2136122]
- wifi: mac80211: provide link ID in link_conf (Íñigo Huguet) [2136122]
- wifi: mac80211: set up/tear down client vif links properly (Íñigo Huguet) [2136122]
- wifi: mac80211: move ieee80211_request_smps_mgd_work (Íñigo Huguet) [2136122]
- wifi: nl80211: acquire wdev mutex for dump_survey (Íñigo Huguet) [2136122]
- wifi: mac80211: fix key lookup (Íñigo Huguet) [2136122]
- wifi: mac80211: separate out connection downgrade flags (Íñigo Huguet) [2136122]
- wifi: mac80211: Align with Draft P802.11be_D2.0 (Íñigo Huguet) [2136122]
- wifi: mac80211: Align with Draft P802.11be_D1.5 (Íñigo Huguet) [2136122]
- wifi: mac80211: skip powersave recalc if driver SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2136122]
- wifi: mac80211: debug: omit link if non-MLO connection (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Ack link addressed frames (Íñigo Huguet) [2136122]
- wifi: cfg80211: drop BSS elements from assoc trace for now (Íñigo Huguet) [2136122]
- wifi: cfg80211: make cfg80211_auth_request::key_idx signed (Íñigo Huguet) [2136122]
- wifi: nl80211: enable setting the link address at new station (Íñigo Huguet) [2136122]
- wifi: mac80211: RCU-ify link/link_conf pointers (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for station APIs (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for channel switch APIs (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex in add/mod/del link station (Íñigo Huguet) [2136122]
- wifi: mac80211: implement callbacks for <add/mod/del>_link_station (Íñigo Huguet) [2136122]
- wifi: cfg80211/mac80211: separate link params from station params (Íñigo Huguet) [2136122]
- wifi: cfg80211: add API to add/modify/remove a link station (Íñigo Huguet) [2136122]
- wifi: mac80211: add an ieee80211_get_link_sband (Íñigo Huguet) [2136122]
- wifi: mac80211: Remove AP SMPS leftovers (Íñigo Huguet) [2136122]
- wifi: cfg80211: Allow MLO TX with link source address (Íñigo Huguet) [2136122]
- wifi: mac80211: Consider MLO links in offchannel logic (Íñigo Huguet) [2136122]
- wifi: mac80211: rx: accept link-addressed frames (Íñigo Huguet) [2136122]
- wifi: mac80211: consistently use sdata_dereference() (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Support link channel matching on rx (Íñigo Huguet) [2136122]
- wifi: mac80211: fix mesh airtime link metric estimating (Íñigo Huguet) [2136122]
- wifi: mac80211: make 4addr null frames using min_rate for WDS (Íñigo Huguet) [2136122]
- wifi: cfg80211: use strscpy to replace strlcpy (Íñigo Huguet) [2136122]
- wifi: mac80211: exclude multicast packets from AQL pending airtime (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: use 32-bit skb cookie (Íñigo Huguet) [2136122]
- mt76: mt7921: Let PCI core handle power state and use pm_sleep_ptr() (Íñigo Huguet) [2136122]
- mediatek: mt76: mac80211: Fix missing of_node_put() in mt76_led_init() (Íñigo Huguet) [2136122]
- mt76: get rid of mt76_wcid_hw routine (Íñigo Huguet) [2136122]
- mt76: convert MT_TX_HW_QUEUE_EXT_PHY to MT_TX_HW_QUEUE_PHY (Íñigo Huguet) [2136122]
- mt76: add phy_idx to mt76_wcid (Íñigo Huguet) [2136122]
- mt76: introduce phys array in mt76_dev structure (Íñigo Huguet) [2136122]
- mt76: add phy_idx in mt76_rx_status (Íñigo Huguet) [2136122]
- mt76: introduce MT_RXQ_BAND2 and MT_RXQ_BAND2_WA in mt76_rxq_id (Íñigo Huguet) [2136122]
- mt76: add len parameter to __mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136122]
- mt76: mt7915 add ht mpdu density (Íñigo Huguet) [2136122]
- mt76: mt7921: reduce the mutex lock scope during reset (Íñigo Huguet) [2136122]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2136122]
- mt76: connac: move tx initialization/cleanup in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: make mt7921_pci_driver static (Íñigo Huguet) [2136122]
- mt76: mt7921: enable HW beacon filter in the initialization stage (Íñigo Huguet) [2136122]
- mt76: mt7921: enable HW beacon filter not depending on PM flag (Íñigo Huguet) [2136122]
- mt76: remove q->qid (Íñigo Huguet) [2136122]
- mt76: do not use skb_set_queue_mapping for internal purposes (Íñigo Huguet) [2136122]
- mt76: pass original queue id from __mt76_tx_queue_skb to the driver (Íñigo Huguet) [2136122]
- mt76: allow receiving frames with invalid CCMP PN via monitor interfaces (Íñigo Huguet) [2136122]
- mt76: mt76x02: improve reliability of the beacon hang check (Íñigo Huguet) [2136122]
- mt76: mt7615: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136122]
- mt76: mt7915: update the maximum size of beacon offload (Íñigo Huguet) [2136122]
- mt76: do not check the ccmp pn for ONLY_MONITOR frame (Íñigo Huguet) [2136122]
- mt76: mt7915: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136122]
- mt76: mt7915: update mpdu density in 6g capability (Íñigo Huguet) [2136122]
- mt76: mt7915: do not copy ieee80211_ops pointer in mt7915_mmio_probe (Íñigo Huguet) [2136122]
- mt76: mt7915: disable UL MU-MIMO for mt7915 (Íñigo Huguet) [2136122]
- mt76: move mt76_connac2_mcu_fill_message in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: move mcu_txd/mcu_rxd structures in shared code (Íñigo Huguet) [2136122]
- mt76: mt7915: rely on mt76_connac_tx_free (Íñigo Huguet) [2136122]
- mt76: connac: move mt7615_txp_skb_unmap in common code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_write_hw_txp in shared code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_tx_complete_skb in shared code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_tx_free in shared code (Íñigo Huguet) [2136122]
- mt76: move mt7615_txp_ptr in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_fw_txp in common module (Íñigo Huguet) [2136122]
- mt76: mt7915: get rid of unnecessary new line in mt7915_mac_write_txwi (Íñigo Huguet) [2136122]
- mt76: mt7921s: remove unnecessary goto in mt7921s_mcu_drv_pmctrl (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_mac_fill_rx_rate in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_reverse_frag0_hdr_trans in mt76-connac module (Íñigo Huguet) [2136122]
- mt76: connac: move HE radiotap parsing in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: fix command timeout in AP stop period (Íñigo Huguet) [2136122]
- mt76: mt7921: not support beacon offload disable command (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_mac_add_txs_skb in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move connac2_mac_write_txwi in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mac connac2 defs in mt76_connac2_mac.h (Íñigo Huguet) [2136122]
- mt76: mt7915: rely on mt76_dev in mt7915_mac_write_txwi signature (Íñigo Huguet) [2136122]
- mt76: mt7921: rely on mt76_dev in mt7921_mac_write_txwi signature (Íñigo Huguet) [2136122]
- mt76: enable the VHT extended NSS BW feature (Íñigo Huguet) [2136122]
- mt76: mt7663: rely on mt76_connac2_fw_trailer (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_load_patch in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_load_ram in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: move fw toggle in mt7921_load_firmware (Íñigo Huguet) [2136122]
- mt76: connac: move shared fw structures in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: get rid of mt7921_mcu_exit (Íñigo Huguet) [2136122]
- mt76: mt7921: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136122]
- mt76: mt7615: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136122]
- mt76: mt7915: add missing bh-disable around tx napi enable/schedule (Íñigo Huguet) [2136122]
- mt76: mt7921: add PATCH_FINISH_REQ cmd response handling (Íñigo Huguet) [2136122]
- mt76: add DBDC rxq handlings into mac_reset_work (Íñigo Huguet) [2136122]
- mt76: mt7915: add more ethtool stats (Íñigo Huguet) [2136122]
- mt76: mt7921: introduce ACPI SAR config in tx power (Íñigo Huguet) [2136122]
- mt76: mt7921: introduce ACPI SAR support (Íñigo Huguet) [2136122]
- mt76: add 6 GHz band support in mt76_sar_freq_ranges (Íñigo Huguet) [2136122]
- mt76: mt7915: fix endian bug in mt7915_rf_regval_set() (Íñigo Huguet) [2136122]
- mt76: mt76x02u: fix possible memory leak in __mt76x02u_mcu_send_msg (Íñigo Huguet) [2136122]
- mt76: mt7915: fix endianness in mt7915_rf_regval_get (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: add back erroneously removed cast (Íñigo Huguet) [2136122]
- wifi: mac80211: fix queue selection for mesh/OCB interfaces (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix race condition in pending packet (Íñigo Huguet) [2136122]
- wifi: mac80211: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2136122]
- wifi: mac80211: fix center freq calculation in ieee80211_chandef_downgrade (Íñigo Huguet) [2136122]
- wifi: nl80211: fix sending link ID info of associated BSS (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix a comment in cfg80211_mlme_mgmt_tx() (Íñigo Huguet) [2136122]
- wifi: nl80211: Fix reading NL80211_ATTR_MLO_LINK_ID in nl80211_pre_doit (Íñigo Huguet) [2136122]
- bus: mhi: ep: Check dev_set_name() return value (Íñigo Huguet) [2136122]
- ath9k: remove unexpected words "the" in comments (Íñigo Huguet) [2136122]
- ath11k: Fix typo in comments (Íñigo Huguet) [2136122]
- wifi: nl80211: retrieve EHT related elements in AP mode (Íñigo Huguet) [2136122]
- wifi: cfg80211: Increase akm_suites array size in cfg80211_crypto_settings (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove chandef check in cfg80211_cac_event() (Íñigo Huguet) [2136122]
- wifi: nl80211: relax wdev mutex check in wdev_chandef() (Íñigo Huguet) [2136122]
- wifi: nl80211: acquire wdev mutex earlier in start_ap (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for tid config (Íñigo Huguet) [2136122]
- wifi: cfg80211: handle IBSS in channel switch (Íñigo Huguet) [2136122]
- wifi: mac80211: properly skip link info driver update (Íñigo Huguet) [2136122]
- wifi: mac80211: only accumulate airtime deficit for active clients (Íñigo Huguet) [2136122]
- wifi: mac80211: add debugfs file to display per-phy AQL pending airtime (Íñigo Huguet) [2136122]
- wifi: mac80211: add a per-PHY AQL limit to improve fairness (Íñigo Huguet) [2136122]
- wifi: mac80211: keep recently active tx queues in scheduling list (Íñigo Huguet) [2136122]
- wifi: mac80211: consider aql_tx_pending when checking airtime deficit (Íñigo Huguet) [2136122]
- wifi: mac80211: make sta airtime deficit field s32 instead of s64 (Íñigo Huguet) [2136122]
- wifi: mac80211: fix a kernel-doc complaint (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove redundant documentation (Íñigo Huguet) [2136122]
- wifi: mac80211: sta_info: fix a missing kernel-doc struct element (Íñigo Huguet) [2136122]
- wifi: mac80211: add a missing comma at kernel-doc markup (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix kernel-doc warnings all over the file (Íñigo Huguet) [2136122]
- wifi: ieee80211: s1g action frames are not robust (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add another Foxconn T99W175 (Íñigo Huguet) [2136122]
- wifi: cfg80211: Allow P2P client interface to indicate port authorization (Íñigo Huguet) [2136122]
- wifi: mac80211: do not wake queues on a vif that is being stopped (Íñigo Huguet) [2136122]
- wifi: mac80211: check skb_shared in ieee80211_8023_xmit() (Íñigo Huguet) [2136122]
- wifi: mac80211: add gfp_t parameter to ieeee80211_obss_color_collision_notify (Íñigo Huguet) [2136122]
- bus: mhi: host: Move IRQ allocation to controller registration phase (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add Cinterion MV31-W with new baseline (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add support for Quectel EM120 FCCL modem (Íñigo Huguet) [2136122]
- wifi: rtw89: disable invalid phy reports for all ICs (Íñigo Huguet) [2136122]
- wifi: rtw89: pci: fix PCI doesn't reclaim TX BD properly (Íñigo Huguet) [2136122]
- wifi: rtw89: fix long RX latency in low power mode (Íñigo Huguet) [2136122]
- wifi: rtw89: drop invalid TX rate report of legacy rate (Íñigo Huguet) [2136122]
- wifi: rtw89: add UNEXP debug mask to keep monitor messages unexpected to happen frequently (Íñigo Huguet) [2136122]
- wifi: rtw89: enable VO TX AMPDU (Íñigo Huguet) [2136122]
- wifi: rtw89: fix potential TX stuck (Íñigo Huguet) [2136122]
- wifi: rtw89: support TDLS (Íñigo Huguet) [2136122]
- wifi: rtw89: allocate BSSID CAM per TDLS peer (Íñigo Huguet) [2136122]
- wifi: rtw89: separate BSSID CAM operations (Íñigo Huguet) [2136122]
- wifi: rtw89: allocate address CAM and MAC ID to TDLS peer (Íñigo Huguet) [2136122]
- cfg80211: Indicate MLO connection info in connect and roam callbacks (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: print the link id (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: support creating MLO-capable radios (Íñigo Huguet) [2136122]
- wifi: nl80211: expose link ID for associated BSSes (Íñigo Huguet) [2136122]
- wifi: nl80211: expose link information for interfaces (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: send a beacon per link (Íñigo Huguet) [2136122]
- wifi: mac80211: set STA deflink addresses (Íñigo Huguet) [2136122]
- wifi: mac80211: maintain link-sta hash table (Íñigo Huguet) [2136122]
- wifi: mac80211: RCU-ify link STA pointers (Íñigo Huguet) [2136122]
- wifi: mac80211: ethtool: use deflink for now (Íñigo Huguet) [2136122]
- wifi: mac80211: move ieee80211_bssid_match() function (Íñigo Huguet) [2136122]
- wifi: mac80211: return a beacon for a specific link (Íñigo Huguet) [2136122]
- wifi: mac80211: pass the link id in start/stop ap (Íñigo Huguet) [2136122]
- wifi: mac80211: use link in start/stop ap (Íñigo Huguet) [2136122]
- wifi: mac80211: implement add/del interface link callbacks (Íñigo Huguet) [2136122]
- wifi: cfg80211: add optional link add/remove callbacks (Íñigo Huguet) [2136122]
- wifi: cfg80211: sort trace.h (Íñigo Huguet) [2136122]
- wifi: mac80211: add sta link addition/removal (Íñigo Huguet) [2136122]
- wifi: mac80211: add MLO link ID to TX frame metadata (Íñigo Huguet) [2136122]
- wifi: mac80211: remove band from TX info in MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add vif link addition/removal (Íñigo Huguet) [2136122]
- wifi: nl80211: support MLO in auth/assoc (Íñigo Huguet) [2136122]
- wifi: mac80211: ignore IEEE80211_CONF_CHANGE_SMPS in chanctx mode (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: split bss_info_changed to vif/link info_changed (Íñigo Huguet) [2136122]
- wifi: cfg80211: simplify cfg80211_mlme_auth() prototype (Íñigo Huguet) [2136122]
- wifi: ieee80211: add definitions for multi-link element (Íñigo Huguet) [2136122]
- wifi: nl80211: refactor BSS lookup in nl80211_associate() (Íñigo Huguet) [2136122]
- wifi: cfg80211: mlme: get BSS entry outside cfg80211_mlme_assoc() (Íñigo Huguet) [2136122]
- wifi: mac80211: tx: simplify chanctx_conf handling (Íñigo Huguet) [2136122]
- wifi: mac80211: status: look up band only where needed (Íñigo Huguet) [2136122]
- wifi: mac80211: sort trace.h file (Íñigo Huguet) [2136122]
- wifi: mac80211: correct link config data in tracing (Íñigo Huguet) [2136122]
- wifi: mac80211: make ieee80211_he_cap_ie_to_sta_he_cap() MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: make some SMPS code MLD-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: HT: make ieee80211_ht_cap_ie_to_sta_ht_cap() MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: add link_id to eht.c code for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add link_id to vht.c code for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some link setup code (Íñigo Huguet) [2136122]
- wifi: mac80211: validate some driver features for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: use IEEE80211_MLD_MAX_NUM_LINKS (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some sta_info link handling (Íñigo Huguet) [2136122]
- wifi: mac80211: remove sta_info_tx_streams() (Íñigo Huguet) [2136122]
- wifi: mac80211: make channel context code MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: pass link ID where already present (Íñigo Huguet) [2136122]
- wifi: mac80211: add per-link configuration pointer (Íñigo Huguet) [2136122]
- wifi: mac80211: split bss_info_changed method (Íñigo Huguet) [2136122]
- wifi: mac80211: reorg some iface data structs for MLD (Íñigo Huguet) [2136122]
- wifi: mac80211: move interface config to new struct (Íñigo Huguet) [2136122]
- wifi: mac80211: move some future per-link data to bss_conf (Íñigo Huguet) [2136122]
- wifi: cfg80211: do some rework towards MLO link APIs (Íñigo Huguet) [2136122]
- wifi: mac80211: reject WEP or pairwise keys with key ID > 3 (Íñigo Huguet) [2136122]
- brcmfmac: Switch to appropriate helper to load EFI variable contents (Íñigo Huguet) [2136122]
- iwlwifi: Switch to proper EFI variable store interface (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Directly use ida_alloc()/free() (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some key code (Íñigo Huguet) [2136122]
- wifi: mac80211: remove cipher scheme support (Íñigo Huguet) [2136122]
- wifi: nl80211: fix typo in comment (Íñigo Huguet) [2136122]
- wifi: virt_wifi: fix typo in comment (Íñigo Huguet) [2136122]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_391.RULE (Íñigo Huguet) [2136122]
- rtw88: 8821c: fix access const table of channel parameters (Íñigo Huguet) [2136122]
- rtw89: add new state to CFO state machine for UL-OFDMA (Íñigo Huguet) [2136122]
- rtw89: 8852c: add trigger frame counter (Íñigo Huguet) [2136122]
- ieee80211: add trigger frame definition (Íñigo Huguet) [2136122]
- ath10k: fix recently introduced checkpatch warning (Íñigo Huguet) [2136122]
- wifi: rtw89: support MULTI_BSSID and correct BSSID mask of H2C (Íñigo Huguet) [2136122]
- wifi: ray_cs: Drop useless status variable in parse_addr() (Íñigo Huguet) [2136122]
- wifi: ray_cs: Utilize strnlen() in parse_addr() (Íñigo Huguet) [2136122]
- wifi: rtw88: use %%*ph to print small buffer (Íñigo Huguet) [2136122]
- ath11k: Fix warnings reported by checkpatch (Íñigo Huguet) [2136122]
- ath11k: Fix LDPC config in set_bitrate_mask hook (Íñigo Huguet) [2136122]
- wifi: mac80211: fix use-after-free in chanctx code (Íñigo Huguet) [2136122]
- ath10k: fix regdomain info of iw reg set/get (Íñigo Huguet) [2136122]
- ath11k: support avg signal in station dump (Íñigo Huguet) [2136122]
- wifi: wilc1000: add IGTK support (Íñigo Huguet) [2136122]
- wifi: wilc1000: add WPA3 SAE support (Íñigo Huguet) [2136122]
- wifi: wilc1000: remove WEP security support (Íñigo Huguet) [2136122]
- wifi: wilc1000: use correct sequence of RESET for chip Power-UP/Down (Íñigo Huguet) [2136122]
- wifi: rtlwifi: fix error codes in rtl_debugfs_set_write_h2c() (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8821c_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8723d_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8822c_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix sparse warning for rtw8822b_hw_spec (Íñigo Huguet) [2136122]
- rtw88: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136122]
- rtw89: sar: adjust and support SAR on 6GHz band (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: re-calibrate RX DCK once thermal changes a lot (Íñigo Huguet) [2136122]
- rtw89: pci: handle hardware watchdog timeout interrupt status (Íñigo Huguet) [2136122]
- rtw89: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136122]
- rtw89: fix channel inconsistency during hw_scan (Íñigo Huguet) [2136122]
- wifi: rtw88: add a work to correct atomic scheduling warning of ::set_tim (Íñigo Huguet) [2136122]
- wifi: iwlwifi: pcie: rename CAUSE macro (Íñigo Huguet) [2136122]
- wifi: brcmfmac: work around a GCC 12 -Warray-bounds warning (Íñigo Huguet) [2136122]
- wifi: iwlwifi: use unsigned to silence a GCC 12 warning (Íñigo Huguet) [2136122]
- wifi: rtlwifi: remove always-true condition pointed out by GCC 12 (Íñigo Huguet) [2136122]
- wifi: ath9k: silence array-bounds warning on GCC 12 (Íñigo Huguet) [2136122]
- ath9k: replace ternary operator with max() (Íñigo Huguet) [2136122]
- ath11k: Init hw_params before setting up AHB resources (Íñigo Huguet) [2136122]
- ath11k: Fix warning on variable 'sar' dereference before check (Íñigo Huguet) [2136122]
- ath10k: fix misreported tx bandwidth for 160Mhz (Íñigo Huguet) [2136122]
- ath10k: add encapsulation offloading support (Íñigo Huguet) [2136122]
- ath10k: turn rawmode into frame_mode (Íñigo Huguet) [2136122]
- ath10k: improve tx status reporting (Íñigo Huguet) [2136122]
- ath10k: do not enforce interrupt trigger type (Íñigo Huguet) [2136122]
- iwlwifi: mei: fix potential NULL-ptr deref (Íñigo Huguet) [2136122]
- iwlwifi: mei: clear the sap data header before sending (Íñigo Huguet) [2136122]
- iwlwifi: mvm: remove vif_count (Íñigo Huguet) [2136122]
- iwlwifi: mvm: always tell the firmware to accept MCAST frames in BSS (Íñigo Huguet) [2136122]
- iwlwifi: mvm: add OTP info in case of init failure (Íñigo Huguet) [2136122]
- iwlwifi: mvm: fix assert 1F04 upon reconfig (Íñigo Huguet) [2136122]
- iwlwifi: mvm: clean up authorized condition (Íñigo Huguet) [2136122]
- iwlwifi: mvm: use NULL instead of ERR_PTR when parsing wowlan status (Íñigo Huguet) [2136122]
- iwlwifi: pcie: simplify MSI-X cause mapping (Íñigo Huguet) [2136122]
- ath11k: update missing MU-MIMO and OFDMA stats (Íñigo Huguet) [2136122]
- rtw89: pci: only mask out INT indicator register for disable interrupt v1 (Íñigo Huguet) [2136122]
- rtw89: convert rtw89_band to nl80211_band precisely (Íñigo Huguet) [2136122]
- rtw89: 8852c: update txpwr tables to HALRF_027_00_052 (Íñigo Huguet) [2136122]
- rtw89: cfo: check mac_id to avoid out-of-bounds (Íñigo Huguet) [2136122]
- rtw89: 8852c: set TX antenna path (Íñigo Huguet) [2136122]
- rtw89: add ieee80211::sta_rc_update ops (Íñigo Huguet) [2136122]
- wireless: Fix Makefile to be in alphabetical order (Íñigo Huguet) [2136122]
- mac80211: refactor freeing the next_beacon (Íñigo Huguet) [2136122]
- cfg80211: fix kernel-doc for cfg80211_beacon_data (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: support ieee80211_rate_status (Íñigo Huguet) [2136122]
- mac80211: extend current rate control tx status API (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: fill all requested rates (Íñigo Huguet) [2136122]
- mac80211: disable BSS color collision detection in case of no free colors (Íñigo Huguet) [2136122]
- nl80211: Parse NL80211_ATTR_HE_BSS_COLOR as a part of nl80211_parse_beacon (Íñigo Huguet) [2136122]
- mac80211: mlme: track assoc_bss/associated separately (Íñigo Huguet) [2136122]
- mac80211: remove useless bssid copy (Íñigo Huguet) [2136122]
- mac80211: remove unused argument to ieee80211_sta_connection_lost() (Íñigo Huguet) [2136122]
- mac80211: mlme: use local SSID copy (Íñigo Huguet) [2136122]
- mac80211: use ifmgd->bssid instead of ifmgd->associated->bssid (Íñigo Huguet) [2136122]
- mac80211: mlme: move in RSSI reporting code (Íñigo Huguet) [2136122]
- mac80211: remove stray multi_sta_back_32bit docs (Íñigo Huguet) [2136122]
- mac80211: fix typo in documentation (Íñigo Huguet) [2136122]
- mac80211: unify CCMP/GCMP AAD construction (Íñigo Huguet) [2136122]
- mt76: mt7921: add ipv6 NS offload support (Íñigo Huguet) [2136122]
- mt76: add gfp to mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136122]
- mt76: mt7915: add more statistics from fw_util debugfs knobs (Íñigo Huguet) [2136122]
- mt76: mt7915: improve error handling for fw_debug knobs (Íñigo Huguet) [2136122]
- mt76: mt7615/mt7915: do reset_work with mt76's work queue (Íñigo Huguet) [2136122]
- mt76: mt7915: add support for 6G in-band discovery (Íñigo Huguet) [2136122]
- mt76: mt7915: add Wireless Ethernet Dispatch support (Íñigo Huguet) [2136122]
- net: ethernet: mtk_eth_soc: add support for Wireless Ethernet Dispatch (WED) (Íñigo Huguet) [2136122]
- mt76: make number of tokens configurable dynamically (Íñigo Huguet) [2136122]
- mt76: add support for overriding the device used for DMA mapping (Íñigo Huguet) [2136122]
- mt76: dma: add wrapper macro for accessing queue registers (Íñigo Huguet) [2136122]
- mt76: mt7915: move MT_INT_MASK_CSR to init.c (Íñigo Huguet) [2136122]
- mt76: mt7915: introduce mt7915_mac_severe_check() (Íñigo Huguet) [2136122]
- mt76: mt7915: rework SER debugfs knob (Íñigo Huguet) [2136122]
- mt76: mt7915: limit minimum twt duration (Íñigo Huguet) [2136122]
- mt76: mt7915: reject duplicated twt flows (Íñigo Huguet) [2136122]
- mt76: mt7915: update mt7986 patch in mt7986_wmac_adie_patch_7976() (Íñigo Huguet) [2136122]
- mt76: connac: use skb_put_data instead of open coding (Íñigo Huguet) [2136122]
- mt76: mt7915: configure soc clocks in mt7986_wmac_init (Íñigo Huguet) [2136122]
- mt76: fix encap offload ethernet type check (Íñigo Huguet) [2136122]
- mt76: mt7915: disable RX_HDR_TRANS_SHORT (Íñigo Huguet) [2136122]
- mt76: mt7603: move spin_lock_bh() to spin_lock() (Íñigo Huguet) [2136122]
- mt76: mt7915: add debugfs knob for RF registers read/write (Íñigo Huguet) [2136122]
- mt76: mt7921: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136122]
- mt76: mt7915: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136122]
- mt76: mt7915: remove SCS feature (Íñigo Huguet) [2136122]
- mt76: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2136122]
- mt76: mt7921: Add AP mode support (Íñigo Huguet) [2136122]
- mt76: mt7915: use 0xff to initialize bitrate_mask in mt7915_init_bitrate_mask (Íñigo Huguet) [2136122]
- mt76: mt7915: always call mt7915_wfsys_reset() during init (Íñigo Huguet) [2136122]
- mt76: mt7921: rely on mt76_dev rxfilter in mt7921_configure_filter (Íñigo Huguet) [2136122]
- mt76: mt7921u: add suspend/resume support (Íñigo Huguet) [2136122]
- mt76: fix MBSS index condition in DBDC mode (Íñigo Huguet) [2136122]
- mt76: fix use-after-free by removing a non-RCU wcid pointer (Íñigo Huguet) [2136122]
- mt76: mt7921: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136122]
- mt76: mt7915: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136122]
- mt76: dma: use kzalloc instead of devm_kzalloc for txwi (Íñigo Huguet) [2136122]
- mt76: reduce tx queue lock hold time (Íñigo Huguet) [2136122]
- mt76: mt7915: rework hardware/phy initialization (Íñigo Huguet) [2136122]
- rtlwifi: Use pr_warn instead of WARN_ONCE (Íñigo Huguet) [2136122]
- rtw89: add debug entry to dump BSSID CAM (Íñigo Huguet) [2136122]
- rtw89: add debug select to dump MAC pages 0x30 to 0x33 (Íñigo Huguet) [2136122]
- rtw89: correct CCA control (Íñigo Huguet) [2136122]
- rtw89: correct setting of RX MPDU length (Íñigo Huguet) [2136122]
- rtw89: 8852c: add settings to decrease the effect of DC (Íñigo Huguet) [2136122]
- brcmfmac: allow setting wlan MAC address using device tree (Íñigo Huguet) [2136122]
- wilc1000: add valid vmm_entry check before fetching from TX queue (Íñigo Huguet) [2136122]
- wilc1000: use 'u64' datatype for cookie variable (Íñigo Huguet) [2136122]
- wilc1000: fix crash observed in AP mode with cfg80211_register_netdevice() (Íñigo Huguet) [2136122]
- wilc1000: use fixed function base register value to access SDIO_FBR_ENABLE_CSA (Íñigo Huguet) [2136122]
- wilc1000: increase firmware version array size (Íñigo Huguet) [2136122]
- ath11k: remove redundant assignment to variables vht_mcs and he_mcs (Íñigo Huguet) [2136122]
- ath11k: Reuse the available memory after firmware reload (Íñigo Huguet) [2136122]
- ath11k: Designating channel frequency when sending management frames (Íñigo Huguet) [2136122]
- ath11k: Implement remain-on-channel support (Íñigo Huguet) [2136122]
- ath11k: Handle keepalive during WoWLAN suspend and resume (Íñigo Huguet) [2136122]
- bus: mhi: host: Add support for Foxconn T99W373 and T99W368 (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: add Telit FN990 (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: add Telit FN980 v1 hardware revision (Íñigo Huguet) [2136122]
- bus: mhi: replace snprintf with sysfs_emit (Íñigo Huguet) [2136122]
- rtw88: adjust adaptivity option to 1 (Íñigo Huguet) [2136122]
- ath11k: Fix RX de-fragmentation issue on WCN6750 (Íñigo Huguet) [2136122]
- ath10k: support bus and device specific API 1 BDF selection (Íñigo Huguet) [2136122]
- ath10k: mac: fix too long lines (Íñigo Huguet) [2136122]
- ath11k: mac: fix too long line (Íñigo Huguet) [2136122]
- mac80211: support disabling EHT mode (Íñigo Huguet) [2136122]
- cfg80211: support disabling EHT mode (Íñigo Huguet) [2136122]
- mac80211: upgrade passive scan to active scan on DFS channels after beacon rx (Íñigo Huguet) [2136122]
- mac80211: tx: delete a redundant if statement in ieee80211_check_fast_xmit() (Íñigo Huguet) [2136122]
- mac80211: consider Order bit to fill CCMP AAD (Íñigo Huguet) [2136122]
- cfg80211: declare MODULE_FIRMWARE for regulatory.db (Íñigo Huguet) [2136122]
- nl80211: rework internal_flags usage (Íñigo Huguet) [2136122]
- nl80211: don't hold RTNL in color change request (Íñigo Huguet) [2136122]
- cfg80211: remove cfg80211_get_chan_state() (Íñigo Huguet) [2136122]
- ath11k: Add support for targets without trustzone (Íñigo Huguet) [2136122]
- rtw89: 8852c: add 8852ce to Makefile and Kconfig (Íñigo Huguet) [2136122]
- rtw89: 8852c: fix warning of FIELD_PREP() mask type (Íñigo Huguet) [2136122]
- rtw89: 8852c: correct register definitions used by 8852c (Íñigo Huguet) [2136122]
- rtw89: correct AID settings of beamformee (Íñigo Huguet) [2136122]
- rtw89: ps: fine tune polling interval while changing low power mode (Íñigo Huguet) [2136122]
- rtw89: 8852c: add basic and remaining chip_info (Íñigo Huguet) [2136122]
- rtw89: 8852c: add chip_ops::bb_ctrl_btc_preagc (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: get calibrated channels to notify firmware (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add DPK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add IQK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RX DCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add TSSI (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add LCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add DACK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RFK tables (Íñigo Huguet) [2136122]
- ath11k: Add support for WCN6750 device (Íñigo Huguet) [2136122]
- ath11k: Datapath changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: HAL changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add QMI changes for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Fetch device information via QMI for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add register access logic for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add HW params for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Move parameters in bus_params to hw_params (Íñigo Huguet) [2136122]
- ath11k: change management tx queue to avoid connection timed out (Íñigo Huguet) [2136122]
- ath11k: fix warning of not found station for bssid in message (Íñigo Huguet) [2136122]
- rtw88: fix hw scan may cause disconnect issue (Íñigo Huguet) [2136122]
- rtw88: fix not disabling beacon filter after disconnection (Íñigo Huguet) [2136122]
- rtw88: add HT MPDU density value for each chip (Íñigo Huguet) [2136122]
- ath11k: Don't use GFP_KERNEL in atomic context (Íñigo Huguet) [2136122]
- ath10k: skip ath10k_halt during suspend for driver state RESTARTING (Íñigo Huguet) [2136122]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2136122]
- ath10k: simplify if-if to if-else (Íñigo Huguet) [2136122]
- ath11k: read country code from SMBIOS for WCN6855/QCA6390 (Íñigo Huguet) [2136122]
- ath11k: disable spectral scan during spectral deinit (Íñigo Huguet) [2136122]
- ath11k: Update WBM idle ring HP after FW mode on (Íñigo Huguet) [2136122]
- ath11k: WMI changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Do not put HW in DBS mode for WCN6750 (Íñigo Huguet) [2136122]
- rtlwifi: btcoex: fix if == else warning (Íñigo Huguet) [2136122]
- rtw88: use the correct bit in the REG_HCI_OPT_CTRL register (Íñigo Huguet) [2136122]
- mwifiex: Add SD8997 SDIO-UART firmware (Íñigo Huguet) [2136122]
- mwifiex: Select firmware based on strapping (Íñigo Huguet) [2136122]
- rtw89: 8852c: add chip_ops related to BTC (Íñigo Huguet) [2136122]
- rtw89: 8852c: fill freq and band of RX status by PPDU report (Íñigo Huguet) [2136122]
- rtw89: 8852c: implement chip_ops::get_thermal (Íñigo Huguet) [2136122]
- rtw89: 8852c: implement chip_ops related to TX power (Íñigo Huguet) [2136122]
- rtw89: 8852c: configure default BB TX/RX path (Íñigo Huguet) [2136122]
- rtw89: add RF H2C to notify firmware (Íñigo Huguet) [2136122]
- rtw89: don't flush hci queues and send h2c if power is off (Íñigo Huguet) [2136122]
- rtw89: pci: allow to process RPP prior to TX BD (Íñigo Huguet) [2136122]
- rtw89: ps: access TX/RX rings via another registers in low power mode (Íñigo Huguet) [2136122]
- rtw89: ser: re-enable interrupt in threadfn if under_recovery (Íñigo Huguet) [2136122]
- rtw89: pci: add a separate interrupt handler for low power mode (Íñigo Huguet) [2136122]
- rtw89: pci: reclaim TX BD only if it really need (Íñigo Huguet) [2136122]
- rtw89: pci: add variant RPWM/CPWM to enter low power mode (Íñigo Huguet) [2136122]
- rtw89: pci: add variant IMR/ISR and configure functions (Íñigo Huguet) [2136122]
- bus: mhi: host: Add support for Cinterion MV32-WA/MV32-WB (Íñigo Huguet) [2136122]
- bus: mhi: host: Optimize and update MMIO register write method (Íñigo Huguet) [2136122]
- bus: mhi: host: Bail on writing register fields if read fails (Íñigo Huguet) [2136122]
- bus: mhi: host: Wait for ready state after reset (Íñigo Huguet) [2136122]
- bus: mhi: host: Add soc_reset sysfs (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Sort mhi_pci_id_table based on the PID (Íñigo Huguet) [2136122]
- bus: mhi: host: Use cached values for calculating the shared write pointer (Íñigo Huguet) [2136122]
- rtw88: pci: 8821c: Disable 21ce completion timeout (Íñigo Huguet) [2136122]
- rtw88: fix uninitialized 'tim_offset' warning (Íñigo Huguet) [2136122]
- rtw89: 8852c: add help function of set channel (Íñigo Huguet) [2136122]
- rtw89: 8852c: add set channel of BB part (Íñigo Huguet) [2136122]
- rtw89: 8852c: set channel of MAC part (Íñigo Huguet) [2136122]
- rtw89: 8852c: add set channel function of RF part (Íñigo Huguet) [2136122]
- rtw89: 8852c: add HFC parameters (Íñigo Huguet) [2136122]
- rtw89: 8852c: add efuse gain offset parser (Íñigo Huguet) [2136122]
- rtw89: 8852c: support bb gain info (Íñigo Huguet) [2136122]
- rtw89: 8852c: add BB initial and reset functions (Íñigo Huguet) [2136122]
- rtw89: 8852c: phy: configure TSSI bandedge (Íñigo Huguet) [2136122]
- rtw89: 8852c: add TX power track tables (Íñigo Huguet) [2136122]
- rtw89: 8852c: add TX power by rate and limit tables (Íñigo Huguet) [2136122]
- rtw89: 8852c: add BB and RF parameters tables (Íñigo Huguet) [2136122]
- ath9k: fix QCA9561 PA bias level (Íñigo Huguet) [2136122]
- ath9k_htc: fix potential out of bounds access with invalid rxstatus->rs_keyix (Íñigo Huguet) [2136122]
- ath11k: Fix build warning without CONFIG_IPV6 (Íñigo Huguet) [2136122]
- ath11k: fix missing unlock on error in ath11k_wow_op_resume() (Íñigo Huguet) [2136122]
- ath11k: Add support for SAR (Íñigo Huguet) [2136122]
- ath11k: add support for extended wmi service bit (Íñigo Huguet) [2136122]
- rtw89: pci: correct return value handling of rtw89_write16_mdio_mask() (Íñigo Huguet) [2136122]
- rtw89: configure security CAM for V1 chip (Íñigo Huguet) [2136122]
- rtw89: add new H2C to configure security CAM via DCTL for V1 chip (Íñigo Huguet) [2136122]
- rtw89: extend H2C of CMAC control info (Íñigo Huguet) [2136122]
- rtlwifi: rtl8192cu: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2136122]
- rtlwifi: Fix spelling mistake "cacluated" -> "calculated" (Íñigo Huguet) [2136122]
- rtw88: 8821ce: Disable PCIe ASPM L1 for 8821CE using chip ID (Íñigo Huguet) [2136122]
- rtw88: 8821ce: add support for device ID 0xb821 (Íñigo Huguet) [2136122]
- rtw88: 8821c: fix debugfs rssi value (Íñigo Huguet) [2136122]
- rtw88: do PHY calibration while starting AP (Íñigo Huguet) [2136122]
- rtw88: 8821c: Enable TX report for management frames (Íñigo Huguet) [2136122]
- rtw88: Add update beacon flow for AP mode (Íñigo Huguet) [2136122]
- rtw88: fix incorrect frequency reported (Íñigo Huguet) [2136122]
- rtw88: add ieee80211:sta_rc_update ops (Íñigo Huguet) [2136122]
- rtw89: rtw89_ser: add const to struct state_ent and event_ent (Íñigo Huguet) [2136122]
- rtw89: 8852c: add 8852c specific BT-coexistence initial function (Íñigo Huguet) [2136122]
- rtw89: Skip useless dig gain and igi related settings for 8852C (Íñigo Huguet) [2136122]
- rtw89: 8852c: disable firmware watchdog if CPU disabled (Íñigo Huguet) [2136122]
- rtw89: reset BA CAM (Íñigo Huguet) [2136122]
- rtw89: change station scheduler setting for hardware TX mode (Íñigo Huguet) [2136122]
- rtw89: ser: configure top ERR IMR for firmware to recover (Íñigo Huguet) [2136122]
- rtw89: ser: configure C-MAC interrupt mask (Íñigo Huguet) [2136122]
- rtw89: ser: configure D-MAC interrupt mask (Íñigo Huguet) [2136122]
- rtw89: ser: fix unannotated fall-through (Íñigo Huguet) [2136122]
- ath9k: Remove unnecessary print function dev_err() (Íñigo Huguet) [2136122]
- ath11k: Fix spelling mistake "reseting" -> "resetting" (Íñigo Huguet) [2136122]
- ath9k: fix ath_get_rate_txpower() to respect the rate list end tag (Íñigo Huguet) [2136122]
- mac80211: prepare sta handling for MLO support (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: fix where rate stats are stored (fixes debugfs output) (Íñigo Huguet) [2136122]
- nl80211: show SSID for P2P_GO interfaces (Íñigo Huguet) [2136122]
- mac80211: introduce BSS color collision detection (Íñigo Huguet) [2136122]
- mac80211: Improve confusing comment around tx_info clearing (Íñigo Huguet) [2136122]
- mac80211: protect ieee80211_assign_beacon with next_beacon check (Íñigo Huguet) [2136122]
- rtl8xxxu: fill up txrate info for gen1 chips (Íñigo Huguet) [2136122]
- rtl8xxxu: feed antenna information for cfg80211 (Íñigo Huguet) [2136122]
- rtlwifi: replace usage of found with dedicated list iterator variable (Íñigo Huguet) [2136122]
- brcmfmac: Avoid keeping power to SDIO card unless WOWL is used (Íñigo Huguet) [2136122]
- mwifiex: add mutex lock for call in mwifiex_dfs_chan_sw_work_queue (Íñigo Huguet) [2136122]
- rtw89: fix misconfiguration on hw_scan channel time (Íñigo Huguet) [2136122]
- rtw89: coex: Add case for scan offload (Íñigo Huguet) [2136122]
- rtw89: packet offload handler to avoid warning (Íñigo Huguet) [2136122]
- rtw89: change idle mode condition during hw_scan (Íñigo Huguet) [2136122]
- rtw89: update ptcl_init (Íñigo Huguet) [2136122]
- rtw89: update TMAC parameters (Íñigo Huguet) [2136122]
- rtw89: initialize NAV control (Íñigo Huguet) [2136122]
- rtw89: update scheduler setting (Íñigo Huguet) [2136122]
- rtw89: 8852c: update security engine setting (Íñigo Huguet) [2136122]
- rtw89: Turn on CR protection of CMAC (Íñigo Huguet) [2136122]
- rtw89: add chip_ops::{enable,disable}_bb_rf to support v1 chip (Íñigo Huguet) [2136122]
- rtw89: update STA scheduler parameters for v1 chip (Íñigo Huguet) [2136122]
- rtw89: extend dmac_pre_init to support 8852C (Íñigo Huguet) [2136122]
- rtw89: pci: add L1 settings (Íñigo Huguet) [2136122]
- rtw89: pci: add deglitch setting (Íñigo Huguet) [2136122]
- rtw89: pci: set address info registers depends on chips (Íñigo Huguet) [2136122]
- rtw89: pci: add LTR setting for v1 chip (Íñigo Huguet) [2136122]
- rtw89: pci: refine pci pre_init function (Íñigo Huguet) [2136122]
- rtw89: pci: add pci attributes to configure operating mode (Íñigo Huguet) [2136122]
- rtw89: pci: add register definition to rtw89_pci_info to generalize pci code (Íñigo Huguet) [2136122]
- ath11k: mhi: remove unnecessary goto from ath11k_mhi_start() (Íñigo Huguet) [2136122]
- ath11k: mhi: add error handling for suspend and resume (Íñigo Huguet) [2136122]
- ath11k: mhi: remove state machine (Íñigo Huguet) [2136122]
- rtw89: handle potential uninitialized variable (Íñigo Huguet) [2136122]
- rtw89: read RX bandwidth from v1 type RX descriptor (Íñigo Huguet) [2136122]
- rtw89: support hardware generate security header (Íñigo Huguet) [2136122]
- rtw89: support variant of fill_txdesc (Íñigo Huguet) [2136122]
- rtw89: pci: support variant of fill_txaddr_info (Íñigo Huguet) [2136122]
- rtw89: add chip_info::h2c_desc_size/fill_txdesc_fwcmd to support new chips (Íñigo Huguet) [2136122]
- rtw89: disabled IGI configuration for unsupported hardware (Íñigo Huguet) [2136122]
- rtw89: packed IGI configuration flow into function for DIG feature (Íñigo Huguet) [2136122]
- rtw89: regd: update mapping table to R59-R32 (Íñigo Huguet) [2136122]
- rtw89: regd: consider 6G band (Íñigo Huguet) [2136122]
- rtw89: 8852a: update txpwr tables to HALRF_027_00_038 (Íñigo Huguet) [2136122]
- rtw89: add UK to regulation type (Íñigo Huguet) [2136122]
- rtw89: reduce export symbol number of mac size and quota (Íñigo Huguet) [2136122]
- rtw89: support FW crash simulation (Íñigo Huguet) [2136122]
- rtw89: reconstruct fw feature (Íñigo Huguet) [2136122]
- rtw89: ser: dump fw backtrace while L2 reset (Íñigo Huguet) [2136122]
- rtw89: ser: dump memory for fw payload engine while L2 reset (Íñigo Huguet) [2136122]
- rtw89: ser: control hci interrupts on/off by state (Íñigo Huguet) [2136122]
- rtw89: mac: correct decision on error status by scenario (Íñigo Huguet) [2136122]
- rtw89: mac: move table of mem base addr to common (Íñigo Huguet) [2136122]
- rtw89: ser: fix CAM leaks occurring in L2 reset (Íñigo Huguet) [2136122]
- rtw88: change idle mode condition during hw_scan (Íñigo Huguet) [2136122]
- iwlwifi: mei: Replace zero-length array with flexible-array member (Íñigo Huguet) [2136122]
- iwlwifi: fw: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2136122]
- ath11k: fix driver initialization failure with WoW unsupported hw (Íñigo Huguet) [2136122]
- ath11k: Remove unnecessary delay in ath11k_core_suspend (Íñigo Huguet) [2136122]
- ath11k: Change max no of active probe SSID and BSSID to fw capability (Íñigo Huguet) [2136122]
- ath11k: Remove core PCI references from PCI common code (Íñigo Huguet) [2136122]
- ath11k: Refactor MSI logic to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Choose MSI config based on HW revision (Íñigo Huguet) [2136122]
- ath11k: Refactor PCI code to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: PCI changes to support WCN6750 (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add uevent support for module autoloading (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for suspending and resuming channels (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for queueing SKBs to the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing channel rings (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for reading from the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing command rings (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for handling SYS_ERR condition (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for handling MHI_RESET (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for powering down the MHI endpoint stack (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for powering up the MHI endpoint stack (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing MHI endpoint interrupts (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for managing MHI state machine (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for sending events to the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for ring management (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for managing MMIO registers (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for creating and destroying MHI EP devices (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for registering MHI endpoint client drivers (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for registering MHI endpoint controllers (Íñigo Huguet) [2136122]
- ath9k: make is2ghz consistent in ar9003_eeprom (Íñigo Huguet) [2136122]
- ath10k: add support for MSDU IDs for USB devices (Íñigo Huguet) [2136122]
- ath11k: add support to search regdb data in board-2.bin for WCN6855 (Íñigo Huguet) [2136122]
- ath11k: store and send country code to firmware after recovery (Íñigo Huguet) [2136122]
- ath9k: add functions to get paprd rate mask (Íñigo Huguet) [2136122]
- ath9k: refactor ar9003_hw_spur_mitigate_ofdm (Íñigo Huguet) [2136122]
- ath9k: fix ar9003_get_eepmisc (Íñigo Huguet) [2136122]
- ath9k: use AR9300_MAX_CHAINS when appropriate (Íñigo Huguet) [2136122]
- ath9k: split set11nRateFlags and set11nChainSel (Íñigo Huguet) [2136122]
- ath9k: make ATH_SREV macros more consistent (Íñigo Huguet) [2136122]
- ath11k: Add peer rhash table support (Íñigo Huguet) [2136122]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2136122]
- ath11k: add fallback board name without variant while searching board-2.bin (Íñigo Huguet) [2136122]
- ath11k: enable PLATFORM_CAP_PCIE_GLOBAL_RESET QMI host capability (Íñigo Huguet) [2136122]
- ath11k: Add hw-restart option to simulate_fw_crash (Íñigo Huguet) [2136122]
- ath11k: add synchronization operation between reconfigure of mac80211 and ath11k_base (Íñigo Huguet) [2136122]
- ath11k: add support for device recovery for QCA6390/WCN6855 (Íñigo Huguet) [2136122]
- ath11k: disable regdb support for QCA6390 (Íñigo Huguet) [2136122]
- ath11k: remove unused ATH11K_BD_IE_BOARD_EXT (Íñigo Huguet) [2136122]
- ath11k: change fw build id format in driver init log (Íñigo Huguet) [2136122]
- ath11k: Refactor the peer delete (Íñigo Huguet) [2136122]
- ath10k: Use of_device_get_match_data() helper (Íñigo Huguet) [2136122]
- ath10k: Trigger sta disconnect on hardware restart (Íñigo Huguet) [2136122]
- ath9k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2136122]
- ath11k: support GTK rekey offload (Íñigo Huguet) [2136122]
- ath11k: support ARP and NS offload (Íñigo Huguet) [2136122]
- ath11k: purge rx pktlog when entering WoW (Íñigo Huguet) [2136122]
- ath11k: implement hardware data filter (Íñigo Huguet) [2136122]
- ath11k: Add WoW net-detect functionality (Íñigo Huguet) [2136122]
- ath11k: Add basic WoW functionalities (Íñigo Huguet) [2136122]

* Fri Dec 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-225.el9]
- net/tunnel: wait until all sk_user_data reader finish before releasing the sock (Hangbin Liu) [2143133]
- drm/ast: Fix drm_fb_memcpy() on rhel9 (Jocelyn Falempe) [2128599]
- drm/ast: Avoid reprogramming primary-plane scanout address (Jocelyn Falempe) [2128599]
- drm/ast: Convert ast to SHMEM (Jocelyn Falempe) [2128599]
- drm/ast: Style cleanups in plane code (Jocelyn Falempe) [2128599]
- drm/ast: Rename struct ast_cursor_plane to struct ast_plane (Jocelyn Falempe) [2128599]
- drm/ast: Remove cursor double buffering (Jocelyn Falempe) [2128599]
- drm/ast: Do not call drm_atomic_add_affected_planes() (Jocelyn Falempe) [2128599]
- drm/ast: Call drm_atomic_helper_check_plane_state() unconditionally (Jocelyn Falempe) [2128599]
- drm/ast: Acquire I/O-register lock in atomic_commit_tail function (Jocelyn Falempe) [2128599]
- drm/ast: Add Atomic gamma lut support for aspeed (Jocelyn Falempe) [2128599]
- drm/ast: make ast_modeset static (Jocelyn Falempe) [2128599]
- drm/ast: Fix video broken in some resolutions on ast2600 (Jocelyn Falempe) [2128599]
- drm/ast: Add resolution support for 1152x864@75 (Jocelyn Falempe) [2128599]
- wifi: brcmfmac: Fix potential buffer overflow in brcmf_fweh_event_worker() (Wander Lairson Costa) [2150965] {CVE-2022-3628}
- lockdown: Fix kexec lockdown bypass with ima policy (Wander Lairson Costa) [2140527] {CVE-2022-21505}
- block: Do not reread partition table on exclusively open device (Ming Lei) [2149790]
- tipc: re-fetch skb cb after tipc_msg_validate (Xin Long) [2140032]
- selftests: net: Fix netdev name mismatch in cleanup (Jonathan Toppins) [2150389]
- Documentation: bonding: correct xmit hash steps (Jonathan Toppins) [2075755 2150389]
- Documentation: bonding: update miimon default to 100 (Jonathan Toppins) [2075140 2150389]
- bonding: uninitialized variable in bond_miimon_inspect() (Jonathan Toppins) [2150389]
- bonding: fix link recovery in mode 2 when updelay is nonzero (Jonathan Toppins) [2150389]
- selftests: bonding: up/down delay w/ slave link flapping (Jonathan Toppins) [2150389]
- bonding (gcc13): synchronize bond_{a,t}lb_xmit() types (Jonathan Toppins) [2150389]
- selftests: net: Fix cross-tree inclusion of scripts (Jonathan Toppins) [2150389]
- treewide: use get_random_u32() when possible (Jonathan Toppins) [2150389]
- net: bonding: Convert to use sysfs_emit()/sysfs_emit_at() APIs (Jonathan Toppins) [2150389]
- selftests/bonding: re-add lladdr target test (Jonathan Toppins) [2150389]
- selftests: bonding: cause oops in bond_rr_gen_slave_id (Jonathan Toppins) [2150389]
- selftests/bonding: add a test for bonding lladdr target (Jonathan Toppins) [2150389]
- net: Add tests for bonding and team address list management (Jonathan Toppins) [2150389]
- net: bonding: Unsync device addresses on ndo_stop (Jonathan Toppins) [2150389]
- net: bonding: Share lacpdu_mcast_addr definition (Jonathan Toppins) [2150389]
- Documentation: bonding: clarify supported modes for tlb_dynamic_lb (Jonathan Toppins) [2150389]
- selftests: include bonding tests into the kselftest infra (Jonathan Toppins) [2150389]
- bonding: fix reference count leak in balance-alb mode (Jonathan Toppins) [2150389]
- net:bonding:support balance-alb interface with vlan to bridge (Jonathan Toppins) [2150389]
- docs: net: bonding: remove mentions of trans_start (Jonathan Toppins) [2150389]
- bonding: cleanup bond_create (Jonathan Toppins) [2150389]
- bonding: netlink error message support for options (Jonathan Toppins) [2150389]
- bonding: Update layer2 and layer2+3 hash formula documentation (Jonathan Toppins) [2150389]
- net: use dev_addr_set() (Jonathan Toppins) [2150389]
- Bluetooth: L2CAP: Fix accepting connection request for invalid SPSM (Gopal Tiwari) [2148402] {CVE-2022-42896}
- xfrm: store and rely on direction to construct offload flags (Sabrina Dubroca) [2139496]
- xfrm: rename xfrm_state_offload struct to allow reuse (Sabrina Dubroca) [2139496]
- xfrm: delete not used number of external headers (Sabrina Dubroca) [2139496]
- lib/irq_poll: Prevent softirq pending leak in irq_poll_cpu_dead() (Prarit Bhargava) [2142946]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-224.el9]
- tls: strp: make sure the TCP skbs do not have overlapping data (Sabrina Dubroca) [2143700]
- selftests: tls: handful of memrnd() and length checks (Sabrina Dubroca) [2143700]
- selftests: tls: add a test for timeo vs lock (Sabrina Dubroca) [2143700]
- selftests: tls: add test for NoPad getsockopt (Sabrina Dubroca) [2143700]
- selftests: tls: add selftest variant for pad (Sabrina Dubroca) [2143700]
- selftests: tls: skip cmsg_to_pipe tests with TLS=n (Sabrina Dubroca) [2143700]
- selftests: tls: test for correct proto_ops (Sabrina Dubroca) [2143700]
- selftests: tls: test splicing decrypted records (Sabrina Dubroca) [2143700]
- selftests: tls: test splicing cmsgs (Sabrina Dubroca) [2143700]
- tls: rx: react to strparser initialization errors (Sabrina Dubroca) [2143700]
- net/tls: Use RCU API to access tls_ctx->netdev (Sabrina Dubroca) [2143700]
- tls: rx: device: don't try to copy too much on detach (Sabrina Dubroca) [2143700]
- tls: rx: device: bound the frag walk (Sabrina Dubroca) [2143700]
- net/tls: Remove redundant workqueue flush before destroy (Sabrina Dubroca) [2143700]
- net/tls: Multi-threaded calls to TX tls_dev_del (Sabrina Dubroca) [2143700]
- net/tls: Perform immediate device ctx cleanup when possible (Sabrina Dubroca) [2143700]
- tls: rx: fix the false positive warning (Sabrina Dubroca) [2143700]
- tls: strp: rename and multithread the workqueue (Sabrina Dubroca) [2143700]
- tls: rx: don't consider sock_rcvtimeo() cumulative (Sabrina Dubroca) [2143700]
- tls: rx: Fix unsigned comparison with less than zero (Sabrina Dubroca) [2143700]
- tls: rx: do not use the standard strparser (Sabrina Dubroca) [2143700]
- tls: rx: device: add input CoW helper (Sabrina Dubroca) [2143700]
- tcp: allow tls to decrypt directly from the tcp rcv queue (Sabrina Dubroca) [2143700]
- tcp: avoid indirect calls to sock_rfree (Sabrina Dubroca) [2143700]
- tls: rx: device: keep the zero copy status with offload (Sabrina Dubroca) [2143700]
- tls: rx: don't free the output in case of zero-copy (Sabrina Dubroca) [2143700]
- redhat/configs: enable CONFIG_DEBUG_NET for debug kernel (Sabrina Dubroca) [2143700]
- net: add CONFIG_DEBUG_NET (Sabrina Dubroca) [2143700]
- net: add include/net/net_debug.h (Sabrina Dubroca) [2143700]
- tls: rx: factor SW handling out of tls_rx_one_record() (Sabrina Dubroca) [2143700]
- tls: rx: wrap recv_pkt accesses in helpers (Sabrina Dubroca) [2143700]
- net/tls: Remove the context from the list in tls_device_down (Sabrina Dubroca) [2143700]
- tls: rx: release the sock lock on locking timeout (Sabrina Dubroca) [2143700]
- tls: rx: decrypt into a fresh skb (Sabrina Dubroca) [2143700]
- tls: rx: async: don't put async zc on the list (Sabrina Dubroca) [2143700]
- tls: rx: async: hold onto the input skb (Sabrina Dubroca) [2143700]
- tls: rx: async: adjust record geometry immediately (Sabrina Dubroca) [2143700]
- tls: rx: return the decrypted skb via darg (Sabrina Dubroca) [2143700]
- tls: rx: read the input skb from ctx->recv_pkt (Sabrina Dubroca) [2143700]
- tls: rx: factor out device darg update (Sabrina Dubroca) [2143700]
- tls: rx: remove the message decrypted tracking (Sabrina Dubroca) [2143700]
- tls: rx: don't keep decrypted skbs on ctx->recv_pkt (Sabrina Dubroca) [2143700]
- tls: rx: don't try to keep the skbs always on the list (Sabrina Dubroca) [2143700]
- tls: rx: allow only one reader at a time (Sabrina Dubroca) [2143700]
- net/tls: Fix race in TLS device down flow (Sabrina Dubroca) [2143700]
- net/tls: Check for errors in tls_device_init (Sabrina Dubroca) [2143700]
- tls: rx: fix the NoPad getsockopt (Sabrina Dubroca) [2143700]
- tls: rx: add counter for NoPad violations (Sabrina Dubroca) [2143700]
- tls: fix spelling of MIB (Sabrina Dubroca) [2143700]
- tls: rx: make tls_wait_data() return an recvmsg retcode (Sabrina Dubroca) [2143700]
- tls: create an internal header (Sabrina Dubroca) [2143700]
- tls: rx: coalesce exit paths in tls_decrypt_sg() (Sabrina Dubroca) [2143700]
- tls: rx: wrap decrypt params in a struct (Sabrina Dubroca) [2143700]
- tls: rx: always allocate max possible aad size for decrypt (Sabrina Dubroca) [2143700]
- strparser: pad sk_skb_cb to avoid straddling cachelines (Sabrina Dubroca) [2143700]
- tls: rx: periodically flush socket backlog (Sabrina Dubroca) [2143700]
- tls: rx: add sockopt for enabling optimistic decrypt with TLS 1.3 (Sabrina Dubroca) [2143700]
- docs: tls: document the TLS_TX_ZEROCOPY_RO (Sabrina Dubroca) [2143700]
- tls: rx: support optimistic decrypt to user buffer with TLS 1.3 (Sabrina Dubroca) [2143700]
- tls: rx: don't include tail size in data_len (Sabrina Dubroca) [2143700]
- Revert "tls: rx: move counting TlsDecryptErrors for sync" (Sabrina Dubroca) [2143700]
- tls: Rename TLS_INFO_ZC_SENDFILE to TLS_INFO_ZC_TX (Sabrina Dubroca) [2143700]
- net: tls: fix messing up lists when bpf enabled (Sabrina Dubroca) [2143700]
- tls: Add opt-in zerocopy mode of sendfile() (Sabrina Dubroca) [2143700]
- tls: Fix context leak on tls_device_down (Sabrina Dubroca) [2143700]
- tls: Skip tls_append_frag on zero copy size (Sabrina Dubroca) [2143700]
- net: tls: fix async vs NIC crypto offload (Sabrina Dubroca) [2143700]
- tls: rx: only copy IV from the packet for TLS 1.2 (Sabrina Dubroca) [2143700]
- tls: rx: use MAX_IV_SIZE for allocations (Sabrina Dubroca) [2143700]
- tls: rx: use async as an in-out argument (Sabrina Dubroca) [2143700]
- tls: rx: return the already-copied data on crypto error (Sabrina Dubroca) [2143700]
- tls: rx: treat process_rx_list() errors as transient (Sabrina Dubroca) [2143700]
- tls: rx: assume crypto always calls our callback (Sabrina Dubroca) [2143700]
- tls: rx: don't handle TLS 1.3 in the async crypto callback (Sabrina Dubroca) [2143700]
- tls: rx: move counting TlsDecryptErrors for sync (Sabrina Dubroca) [2143700]
- tls: rx: reuse leave_on_list label for psock (Sabrina Dubroca) [2143700]
- tls: rx: consistently use unlocked accessors for rx_list (Sabrina Dubroca) [2143700]
- tls: rx: jump out for cases which need to leave skb on list (Sabrina Dubroca) [2143700]
- tls: rx: clear ctx->recv_pkt earlier (Sabrina Dubroca) [2143700]
- tls: rx: inline consuming the skb at the end of the loop (Sabrina Dubroca) [2143700]
- tls: rx: pull most of zc check out of the loop (Sabrina Dubroca) [2143700]
- tls: rx: don't track the async count (Sabrina Dubroca) [2143700]
- tls: rx: don't handle async in tls_sw_advance_skb() (Sabrina Dubroca) [2143700]
- tls: rx: factor out writing ContentType to cmsg (Sabrina Dubroca) [2143700]
- tls: rx: simplify async wait (Sabrina Dubroca) [2143700]
- tls: rx: wrap decryption arguments in a structure (Sabrina Dubroca) [2143700]
- tls: rx: don't report text length from the bowels of decrypt (Sabrina Dubroca) [2143700]
- tls: rx: drop unnecessary arguments from tls_setup_from_iter() (Sabrina Dubroca) [2143700]
- tls: hw: rx: use return value of tls_device_decrypted() to carry status (Sabrina Dubroca) [2143700]
- tls: rx: refactor decrypt_skb_update() (Sabrina Dubroca) [2143700]
- tls: rx: don't issue wake ups when data is decrypted (Sabrina Dubroca) [2143700]
- tls: rx: replace 'back' with 'offset' (Sabrina Dubroca) [2143700]
- tls: rx: use a define for tag length (Sabrina Dubroca) [2143700]
- tls: rx: init decrypted status in tls_read_size() (Sabrina Dubroca) [2143700]
- tls: rx: don't store the decryption status in socket context (Sabrina Dubroca) [2143700]
- tls: rx: don't store the record type in socket context (Sabrina Dubroca) [2143700]
- tls: rx: drop pointless else after goto (Sabrina Dubroca) [2143700]
- tls: rx: jump to a more appropriate label (Sabrina Dubroca) [2143700]
- net/tls: optimize judgement processes in tls_set_device_offload() (Sabrina Dubroca) [2143700]
- net/tls: remove unnecessary jump instructions in do_tls_setsockopt_conf() (Sabrina Dubroca) [2143700]
- net/tls: Provide {__,}tls_driver_ctx() unconditionally (Sabrina Dubroca) [2143700]
- net/tls: simplify the tls_set_sw_offload function (Sabrina Dubroca) [2143700]
- net/tls: getsockopt supports complete algorithm list (Sabrina Dubroca) [2143700]
- net/tls: tls_crypto_context add supported algorithms context (Sabrina Dubroca) [2143700]
- net/tls: support SM4 CCM algorithm (Sabrina Dubroca) [2143700]
- net/tls: support SM4 GCM/CCM algorithm (Sabrina Dubroca) [2143700]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-223.el9]
- pwm: tegra: Ensure the clock rate is not less than needed (d.marlin) [2141743]
- pwm: tegra: Improve required rate calculation (d.marlin) [2141743]
- pwm: tegra: Add runtime PM and OPP support (d.marlin) [2141743]
- pwm: tegra: Optimize period calculation (d.marlin) [2141743]
- hwmon: (pwm-fan) Ensure the fan going on in .probe() (d.marlin) [2141743]
- hwmon: (pwm-fan) Explicitly switch off fan power when setting pwm1_enable to 0 (d.marlin) [2141743]
- hwmon: (pwm-fan) Switch regulator dynamically (d.marlin) [2141743]
- hwmon: (pwm-fan) Use HWMON_CHANNEL_INFO macro (d.marlin) [2141743]
- hwmon: (pwm-fan) split __set_pwm into locked/unlocked functions (d.marlin) [2141743]
- hwmon: (pwm-fan) Add dedicated power switch function (d.marlin) [2141743]
- hwmon: (pwm-fan) Simplify enable/disable check (d.marlin) [2141743]
- hwmon: (pwm-fan) Replace OF specific call to PWM by plain one (d.marlin) [2141743]
- hwmon: (pwm-fan) Refactor fan power on/off (d.marlin) [2141743]
- redhat/configs: consolidate CONFIG_TEST_LIVEPATCH=m (Julia Denham) [2072713]
- redhat/configs: enable CONFIG_TEST_LIVEPATCH=m for s390x (Julia Denham) [2072713]
- redhat/configs: enable s390x CONFIG_EXPOLINE_EXTERN (Julia Denham) [2072713]
- s390/ftrace: implement hotpatching (Julia Denham) [2121735]
- ftrace: Introduce ftrace_need_init_nop() (Julia Denham) [2121735]
- s390/nospec: build expoline.o for modules_prepare target (Julia Denham) [2072713]
- s390/nospec: align and size extern thunks (Julia Denham) [2072713]
- s390/nospec: add an option to use thunk-extern (Julia Denham) [2072713]
- s390/nospec: generate single register thunks if possible (Julia Denham) [2072713]
- s390: remove unused expoline to BC instructions (Julia Denham) [2072713]
- s390/entry: remove unused expoline thunk (Julia Denham) [2072713]
- s390: replace cc-option-yn uses with cc-option (Julia Denham) [2072713]
- net: macsec: Expose MACSEC_SALT_LEN definition to user space (Sabrina Dubroca) [2136170]
- macsec: Fix traffic counters/statistics (Sabrina Dubroca) [2136170]
- net: macsec: fix potential resource leak in macsec_add_rxsa() and macsec_add_txsa() (Sabrina Dubroca) [2136170]
- macsec: always read MACSEC_SA_ATTR_PN as a u64 (Sabrina Dubroca) [2136170]
- macsec: limit replay window size with XPN (Sabrina Dubroca) [2136170]
- macsec: fix error message in macsec_add_rxsa and _txsa (Sabrina Dubroca) [2136170]
- macsec: fix NULL deref in macsec_add_rxsa (Sabrina Dubroca) [2136170]
- iavf: Fix error handling in iavf_init_module() (Stefan Assmann) [2104467]
- iavf: Fix race condition between iavf_shutdown and iavf_remove (Stefan Assmann) [2104467]
- iavf: Do not restart Tx queues after reset task failure (Stefan Assmann) [2104467]
- iavf: Fix a crash during reset task (Stefan Assmann) [2104467]
- iavf: Fix VF driver counting VLAN 0 filters (Stefan Assmann) [2104467]
- iavf: Change information about device removal in dmesg (Stefan Assmann) [2104467]
- iavf: Replace __FUNCTION__ with __func__ (Stefan Assmann) [2104467]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2104467]
- iavf: Fix set max MTU size with port VLAN and jumbo frames (Stefan Assmann) [2104467]
- iavf: Fix bad page state (Stefan Assmann) [2104467]
- iavf: Fix cached head and tail value for iavf_get_tx_pending (Stefan Assmann) [2104467]
- iavf: Detach device during reset task (Stefan Assmann) [2104467]
- iavf: Fix race between iavf_close and iavf_reset_task (Stefan Assmann) [2104467]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2104467]
- iavf: Fix 'tc qdisc show' listing too many queues (Stefan Assmann) [2104467]
- iavf: Fix max_rate limiting (Stefan Assmann) [2104467]
- iavf: Check for duplicate TC flower filter before parsing (Stefan Assmann) [2104467]
- iavf: Fix handling of dummy receive descriptors (Stefan Assmann) [2104467]
- iavf: Disallow changing rx/tx-frames and rx/tx-frames-irq (Stefan Assmann) [2104467]
- intel/iavf:fix repeated words in comments (Stefan Assmann) [2104467]
- intel: remove unused macros (Stefan Assmann) [2104467]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-222.el9]
- Bluetooth: Fix HCIGETDEVINFO regression (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix hci_read_buffer_size_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: hold hdev->lock when cleanup hci_conn (Gopal Tiwari) [2124521]
- Bluetooth: move from strlcpy with unused retval to strscpy (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix checking conn for le_conn_complete_evt (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix not handling shutdown condition (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: fix double mgmt_pending_free() in remove_adv_monitor() (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fix Get Device Flags (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix build errors in some archs (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix suspend performance regression (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix vendor (unknown) opcode status handling (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix not using the correct QoS (Gopal Tiwari) [2124521]
- Bluetooth: don't try to cancel uninitialized works at mgmt_index_removed() (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix iso_sock_getsockopt for BT_DEFER_SETUP (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fixes build warnings with C=1 (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix build warning with C=1 (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix memory corruption (Gopal Tiwari) [2124521]
- Bluetooth: Fix null pointer deref on unexpected status event (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix info leak in iso_sock_getsockopt() (Gopal Tiwari) [2124521]
- Bluetooth: hci_conn: Fix updating ISO QoS PHY (Gopal Tiwari) [2124521]
- Bluetooth: ISO: unlock on error path in iso_sock_setsockopt() (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm regression (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_chan_put (Gopal Tiwari) [2124521]
- Bluetooth: Always set event mask on suspend (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix double free on error path (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Detect if an ACL packet is in fact an ISO packet (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support for ISO packets (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Add broadcast support (Gopal Tiwari) [2124521]
- Bluetooth: Add initial implementation of BIS connections (Gopal Tiwari) [2124521]
- Bluetooth: Add BTPROTO_ISO socket type (Gopal Tiwari) [2124521]
- Bluetooth: Add initial implementation of CIS connections (Gopal Tiwari) [2124521]
- Bluetooth: hci_core: Introduce hci_recv_event_data (Gopal Tiwari) [2124521]
- Bluetooth: Convert delayed discov_off to hci_sync (Gopal Tiwari) [2124521]
- Bluetooth: Remove update_scan hci_request dependancy (Gopal Tiwari) [2124521]
- Bluetooth: Remove dead code from hci_request.c (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Fix typo in comment (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fix holding hci_conn reference while command is queued (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix using hci_conn_abort (Gopal Tiwari) [2124521]
- Bluetooth: Use bt_status to convert from errno (Gopal Tiwari) [2124521]
- Bluetooth: Add bt_status (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Split hci_dev_open_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Refactor remove Adv Monitor (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Refactor add Adv Monitor (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for fake CSR (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for QCA (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Check LMP feature bit instead of quirk (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Correct hci_set_event_mask_page_2_sync() event mask (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new VID/PID 0489/e0e2 for MT7922 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN for MTK (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Increase host baudrate for CYW55572 in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Prevent early baudrate setting in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add DT compatible for CYW55572 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3586 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3587 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0CB8:0xC558 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04C5:0x1675 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04CA:0x4007 (Gopal Tiwari) [2124521]
- Bluetooth: Add default wakeup callback for HCI UART driver (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Don't remove connected devices from accept list (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix not updating privacy_mode (Gopal Tiwari) [2124521]
- Bluetooth: Collect kcov coverage from hci_rx_work (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix resuming scan after suspend resume (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: Add in-band wakeup support (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix refresh cached connection info (Gopal Tiwari) [2124521]
- Bluetooth: HCI: Fix not always setting Scan Response/Advertising Data (Gopal Tiwari) [2124521]
- Bluetooth: eir: Fix using strlen with hdev->{dev_name,short_name} (Gopal Tiwari) [2124521]
- Bluetooth: use memset avoid memory leaks (Gopal Tiwari) [2124521]
- Bluetooth: fix an error code in hci_register_dev() (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add BCM4349B1 variant (Gopal Tiwari) [2124521]
- Bluetooth: Unregister suspend with userchannel (Gopal Tiwari) [2124521]
- Bluetooth: Fix index added after unregister (Gopal Tiwari) [2124521]
- Bluetooth: When HCI work queue is drained, only queue chained work (Gopal Tiwari) [2124521]
- Bluetooth: hci_intel: Add check for platform_driver_register (Gopal Tiwari) [2124521]
- Bluetooth: clear the temporary linkkey in hci_conn_cleanup (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add support for FW loading in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_qca: Return wakeup for qca_wakeup (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support of IMC Networks PID 0x3568 (Gopal Tiwari) [2124521]
- Bluetooth: core: Fix deadlock on hci_power_on_sync. (Gopal Tiwari) [2124521]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_390.RULE (Gopal Tiwari) [2124521]
- bluetooth: don't use bitmaps for random flag accesses (Gopal Tiwari) [2124521]
- Bluetooth: hci_conn: Fix hci_connect_le_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: use hci_skb_event() helper (Gopal Tiwari) [2124521]
- Bluetooth: eir: Add helpers for managing service data (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix attempting to suspend with unfiltered passive scan (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Add conditions for setting HCI_CONN_FLAG_REMOTE_WAKEUP (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: fix the reset takes too long (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: fix use-after-free at btmtksdio_recv_event (Gopal Tiwari) [2124521]
- Bluetooth: btbcm: Add entry for BCM4373A0 UART Bluetooth (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new PID/VID 0489/e0c8 for MT7921 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add 0x0bda:0x8771 Realtek 8761BUV devices (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for QCA (Gopal Tiwari) [2124521]
- Bluetooth: core: Fix missing power_on work cancel on HCI close (Gopal Tiwari) [2124521]
- Bluetooth: btusb: add support for Qualcomm WCN785x (Gopal Tiwari) [2124521]
- Bluetooth: protect le accept and resolv lists with hdev->lock (Gopal Tiwari) [2124521]
- Bluetooth: use hdev lock for accept_list and reject_list in conn req (Gopal Tiwari) [2124521]
- Bluetooth: use hdev lock in activate_scan for hci_is_adv_monitoring (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8852C (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN for QCA (Gopal Tiwari) [2124521]
- Bluetooth: Print broken quirks (Gopal Tiwari) [2124521]
- Bluetooth: HCI: Add HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN quirk (Gopal Tiwari) [2124521]
- Bluetooth: hci_qca: Use del_timer_sync() before freeing (Gopal Tiwari) [2124521]
- Bluetooth: btintel: Constify static struct regmap_bus (Gopal Tiwari) [2124521]
- Bluetooth: Keep MGMT pending queue ordered FIFO (Gopal Tiwari) [2124521]
- Bluetooth: fix dangling sco_conn and use-after-free in sco_sock_timeout (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Fix the incorrect pointer check (Gopal Tiwari) [2124521]
- Bluetooth: btbcm: Support per-board firmware variants (Gopal Tiwari) [2124521]
- Bluetooth: Fix the creation of hdev->name (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Cleanup hci_conn if it cannot be aborted (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix creating hci_conn object on error status (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix checking for invalid handle on error status (Gopal Tiwari) [2124521]
- Bluetooth: ath3k: remove superfluous header files (Gopal Tiwari) [2124521]
- Bluetooth: bcm203x: remove superfluous header files (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add the Asus TF103C to the bcm_broken_irq_dmi_table (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add WBS support (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add .btmtk_get_codec_config_data (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add .get_data_path_id (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Set HCI_QUIRK_VALID_LE_STATES (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: Fix kernel oops in btmtksdio_interrupt (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: fix error handling in mtk_hci_wmt_sync() (Gopal Tiwari) [2124521]
- Bluetooth: call hci_le_conn_failed with hdev lock in hci_le_conn_failed (Gopal Tiwari) [2124521]
- Bluetooth: Send AdvMonitor Dev Found for all matched devices (Gopal Tiwari) [2124521]
- Bluetooth: msft: Clear tracked devices on resume (Gopal Tiwari) [2124521]
- Bluetooth: fix incorrect nonblock bitmask in bt_sock_wait_ready() (Gopal Tiwari) [2124521]
- Bluetooth: Don't assign twice the same value (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8852B (Gopal Tiwari) [2124521]
- Bluetooth: hci_uart: add missing NULL check in h5_enqueue (Gopal Tiwari) [2124521]
- Bluetooth: Fix use after free in hci_send_acl (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Use quirk to skip HCI_FLT_CLEAR_ALL on fake CSR controllers (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Add a new quirk to skip HCI_FLT_CLEAR_ALL (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: fix the conflict between mtk and msft vendor event (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: add .set_bdaddr support (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: rely on BT_MTK module (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add missing Chicony device for Realtek RTL8723BE (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: remove redundant assignment to variable cur_len (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add another Realtek 8761BU (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: add BCM43430A0 & BCM43430A1 (Gopal Tiwari) [2124521]
- Bluetooth: use memset avoid memory leaks (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new PID/VID 13d3/3567 for MT7921 (Gopal Tiwari) [2124521]
- Bluetooth: move adv_instance_cnt read within the device lock (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Add missing locking on hdev in hci_le_ext_adv_term_evt (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Make use of of BIT macro to declare flags (Gopal Tiwari) [2124521]
- Bluetooth: mediatek: fix the conflict between mtk and msft vendor event (Gopal Tiwari) [2124521]
- Bluetooth: make array bt_uuid_any static const (Gopal Tiwari) [2124521]
- Bluetooth: 6lowpan: No need to clear memory twice (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Improve stability for QCA devices (Gopal Tiwari) [2124521]
- Bluetooth: btusb: add support for LG LGSBWAC02 (MT7663BUN) (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support for Intel Madison Peak (MsP2) device (Gopal Tiwari) [2124521]
- Bluetooth: Improve skb handling in mgmt_device_connected() (Gopal Tiwari) [2124521]
- Bluetooth: Fix skb allocation in mgmt_remote_name() & mgmt_device_connected() (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Remove unneeded variable (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: fix undefined return of hci_disconnect_all_sync() (Gopal Tiwari) [2124521]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix queuing commands when HCI_UNREGISTER is set (Gopal Tiwari) [2124521]
- Bluetooth: hci_h5: Add power reset via gpio in h5_btrtl_open (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8822C hci_ver 0x08 (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix HCI_EV_VENDOR max_len (Gopal Tiwari) [2124521]
- Bluetooth: hci_core: Rate limit the logging of invalid SCO handle (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Ignore multiple conn complete events (Gopal Tiwari) [2124521]
- Bluetooth: msft: fix null pointer deref on msft_monitor_device_evt (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: mask out interrupt status (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: run sleep mode by default (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: lower log level in btmtksdio_runtime_[resume|suspend]() (Gopal Tiwari) [2124521]
- Bluetooth: hci_serdev: call init_rwsem() before p->open() (Gopal Tiwari) [2124521]
- Bluetooth: Remove kernel-doc style comment block (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Whitespace fixes for btusb_setup_csr() (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (Gopal Tiwari) [2124521]
- Bluetooth: btintel: Fix WBS setting for Intel legacy ROM products (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Add MGMT Adv Monitor Device Found/Lost events (Gopal Tiwari) [2124521]
- Bluetooth: msft: Handle MSFT Monitor Device Event (Gopal Tiwari) [2124521]
- Bluetooth: fix null ptr deref on hci_sync_conn_complete_evt (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: unlock on error in hci_inquiry_result_with_rssi_evt() (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: clean up inconsistent error message in btmtksdio_mtk_reg_read (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: move struct reg_read_cmd to common file (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: rename btsdio_mtk_reg_read (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix compilation warning (Gopal Tiwari) [2124521]

* Wed Dec 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-221.el9]
- powerpc64: Set PPC64_ELF_ABI_v[1|2] macros to 1 (Yauheni Kaliuta) [2120968 2140077]
- ip_tunnel: Respect tunnel key's "flow_flags" in IP tunnels (Felix Maurer) [2120968]
- redhat/spec: exclude liburandom_read.so from requires (Artem Savkov) [2120968]
- spec: use jsut-built bpftool for vmlinux.h generation (Yauheni Kaliuta) [2120968]
- Revert "build: Fix generating BTF with pahole >=1.24" (Yauheni Kaliuta) [2120968]
- BuildRequires: lld for build with selftests for x86 (Yauheni Kaliuta) [2120968]
- bpf: Fix offset calculation error in __copy_map_value and zero_map_value (Yauheni Kaliuta) [2120968]
- bpf: Add zero_map_value to zero map value with special fields (Yauheni Kaliuta) [2120968]
- bpf: Add copy_map_value_long to copy to remote percpu memory (Yauheni Kaliuta) [2120968]
- libbpf: Fix an unsigned < 0 bug (Yauheni Kaliuta) [2120968]
- libbpf: Don't require full struct enum64 in UAPI headers (Yauheni Kaliuta) [2120968]
- libbpf: Fix sign expansion bug in btf_dump_get_enum_value() (Yauheni Kaliuta) [2120968]
- perf bpf: Remove undefined behavior from bpf_perf_object__next() (Yauheni Kaliuta) [2120968]
- perf build: Fix btf__load_from_kernel_by_id() feature check (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak bpf_map_create() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak btf__raw_data() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak bpf_prog_load() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Fix check for btf__load_from_kernel_by_id() in libbpf (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use consistent build-id type for liburandom_read.so (Yauheni Kaliuta) [2120968]
- docs/bpf: Update documentation for BTF_KIND_ENUM64 support (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add a test for enum64 value relocations (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test BTF_KIND_ENUM64 for deduplication (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add BTF_KIND_ENUM64 unit tests (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test new enum kflag and enum64 API functions (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix selftests failure (Yauheni Kaliuta) [2120968]
- bpftool: Add btf enum64 support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 relocation support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 support for bpf linking (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 sanitization (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 support for btf_dump (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 deduplication support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 parsing and new enum64 public API (Yauheni Kaliuta) [2120968]
- libbpf: Refactor btf__add_enum() for future code sharing (Yauheni Kaliuta) [2120968]
- libbpf: Fix an error in 64bit relocation value computation (Yauheni Kaliuta) [2120968]
- libbpf: Permit 64bit relocation value (Yauheni Kaliuta) [2120968]
- bpf: Add btf enum64 support (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_link_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_attach_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_map_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_prog_type_str (Yauheni Kaliuta) [2120968]
- fprobe: Check rethook_alloc() return in rethook initialization (Yauheni Kaliuta) [2120968]
- tracing/fprobe: Fix to check whether fprobe is registered correctly (Yauheni Kaliuta) [2120968]
- bpf, sockmap: Fix the sk->sk_forward_alloc warning of sk_stream_kill_queues (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix error failure of case test_xdp_adjust_tail_grow (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix error usage of ASSERT_OK in xdp_adjust_tail.c (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix memory leak caused by not destroying skeleton (Yauheni Kaliuta) [2120968]
- libbpf: Fix memory leak in parse_usdt_arg() (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix memory leak in kprobe_multi_test (Yauheni Kaliuta) [2120968]
- ftrace: Still disable enabled records marked as disabled (Yauheni Kaliuta) [2120968]
- ftrace: Add FTRACE_MCOUNT_MAX_OFFSET to avoid adding weak function (Yauheni Kaliuta) [2130850]
- xdp: Fix spurious packet loss in generic XDP TX path (Felix Maurer) [2120968]
- net: Use this_cpu_inc() to increment net->core_stats (Felix Maurer) [2130850]
- net: disable preemption in dev_core_stats_XXX_inc() helpers (Felix Maurer) [2130850]
- net: add per-cpu storage and net->core_stats (Felix Maurer) [2130850]
- selftests/bpf/test_progs: rhskip with subtest granularity (Artem Savkov) [2130850]
- selftests/bpf: Don't assign outer source IP to host (Felix Maurer) [2120968]
- bpf: Set flow flag to allow any source IP in bpf_tunnel_key (Felix Maurer) [2120968]
- geneve: Use ip_tunnel_key flow flags in route lookups (Felix Maurer) [2120968]
- vxlan: Use ip_tunnel_key flow flags in route lookups (Felix Maurer) [2120968]
- ip_tunnels: Add new flow flags field to ip_tunnel_key (Felix Maurer) [2120968]
- xsk: Clear page contiguity bit when unmapping pool (Felix Maurer) [2120968]
- net: page_pool: add page allocation stats for two fast page allocate path (Felix Maurer) [2120968]
- selftests: xsk: make stat tests not spin on getsockopt (Felix Maurer) [2120968]
- selftests: xsk: make the stats tests normal tests (Felix Maurer) [2120968]
- selftests: xsk: introduce validation functions (Felix Maurer) [2120968]
- selftests: xsk: cleanup veth pair at ctrl-c (Felix Maurer) [2120968]
- selftests: xsk: add timeout to tests (Felix Maurer) [2120968]
- selftests: xsk: fix reporting of failed tests (Felix Maurer) [2120968]
- selftests: xsk: run all tests for busy-poll (Felix Maurer) [2120968]
- selftests: xsk: do not send zero-length packets (Felix Maurer) [2120968]
- selftests: xsk: cleanup bash scripts (Felix Maurer) [2120968]
- selftests/bpf: Add test for skb_load_bytes (Felix Maurer) [2120968]
- net: Change skb_ensure_writable()'s write_len param to unsigned int type (Felix Maurer) [2120968]
- xsk: Drop ternary operator from xskq_cons_has_entries (Felix Maurer) [2120968]
- xsk: Diversify return codes in xsk_rcv_check() (Felix Maurer) [2120968]
- xsk: Improve xdp_do_redirect() error codes (Felix Maurer) [2120968]
- net: page_pool: introduce ethtool stats (Felix Maurer) [2120968]
- bpf: Add verifier check for BPF_PTR_POISON retval and arg (Yauheni Kaliuta) [2120968]
- bpf: Fix non-static bpf_func_proto struct definitions (Yauheni Kaliuta) [2120968]
- bpf: Fix ref_obj_id for dynptr data slices in verifier (Yauheni Kaliuta) [2120968]
- bpf: Cleanup check_refcount_ok (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add liburandom_read.so to TEST_GEN_FILES (Yauheni Kaliuta) [2120968]
- btf: Export bpf_dynptr definition (Yauheni Kaliuta) [2120968]
- bpf: Gate dynptr API behind CAP_BPF (Yauheni Kaliuta) [2120968]
- bpf: Fix resetting logic for unreferenced kptrs (Yauheni Kaliuta) [2120968]
- libbpf: Fix str_has_sfx()'s return value (Yauheni Kaliuta) [2120968]
- libbpf: make RINGBUF map size adjustments more eagerly (Yauheni Kaliuta) [2120968]
- bpf: Add flags arg to bpf_dynptr_read and bpf_dynptr_write APIs (Yauheni Kaliuta) [2120968]
- bpf: Make sure mac_header was set before using it (Yauheni Kaliuta) [2120968]
- bpf, selftests: Add verifier test case for jmp32's jeq/jne (Yauheni Kaliuta) [2120968]
- bpf, selftests: Add verifier test case for imm=0,umin=0,umax=1 scalar (Yauheni Kaliuta) [2120968]
- bpf: Fix insufficient bounds propagation from adjust_scalar_min_max_vals (Yauheni Kaliuta) [2120968]
- bpf: Fix incorrect verifier simulation around jmp32's jeq/jne (Yauheni Kaliuta) [2120968]
- bpftool: Probe for memcg-based accounting before bumping rlimit (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test sockmap update when socket has ULP (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix kprobe_multi bench test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Don't force lld on non-x86 architectures (Yauheni Kaliuta) [2120968]
- libbpf: Fix internal USDT address translation logic for shared libraries (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test tail call counting with bpf2bpf and data on stack (Yauheni Kaliuta) [2120968]
- bpf, x86: Fix tail call count offset calculation on bpf2bpf call (Yauheni Kaliuta) [2120968]
- bpf: Limit maximum modifier chain length in btf_check_type_tags (Yauheni Kaliuta) [2120968]
- bpftool: Do not check return value from libbpf_set_strict_mode() (Yauheni Kaliuta) [2120968]
- Revert "bpftool: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK" (Yauheni Kaliuta) [2120968]
- libbpf: Fix uprobe symbol file offset calculation logic (Yauheni Kaliuta) [2120968]
- MAINTAINERS: Add a maintainer for bpftool (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add selftest for calling global functions from freplace (Yauheni Kaliuta) [2120968]
- bpf: Fix calling global functions from BPF_PROG_TYPE_EXT programs (Yauheni Kaliuta) [2120968]
- bpf, arm64: Clear prog->jited_len along prog->jited (Yauheni Kaliuta) [2120968]
- libbpf: Fix is_pow_of_2 (Yauheni Kaliuta) [2120968]
- sample: bpf: xdp_router_ipv4: Allow the kernel to send arp requests (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix stacktrace_build_id with missing kprobe/urandom_read (Yauheni Kaliuta) [2120968]
- bpf: Fix probe read error in ___bpf_prog_run() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Dynptr tests (Yauheni Kaliuta) [2120968]
- bpf: Add dynptr data slices (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_dynptr_read and bpf_dynptr_write (Yauheni Kaliuta) [2120968]
- bpf: Dynptr support for ring buffers (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_dynptr_from_mem for local dynptrs (Yauheni Kaliuta) [2120968]
- bpf: Add verifier support for dynptrs (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix btf_dump/btf_dump due to recent clang change (Yauheni Kaliuta) [2120968]
- s390/bpf: Fix typo in comment (Yauheni Kaliuta) [2120968]
- libbpf: Fix typo in comment (Yauheni Kaliuta) [2120968]
- bpf: Suppress 'passing zero to PTR_ERR' warning (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix spelling mistake: "unpriviliged" -> "unprivileged" (Yauheni Kaliuta) [2120968]
- selftests/bpf: add tests verifying unprivileged bpf behaviour (Yauheni Kaliuta) [2120968]
- bpf: refine kernel.unprivileged_bpf_disabled behaviour (Yauheni Kaliuta) [2120968]
- bpf: Allow kfunc in tracing and syscall programs. (Yauheni Kaliuta) [2120968]
- selftests/bpf: Remove filtered subtests from output (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix subtest number formatting in test_progs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add missing trampoline program type to trampoline_count test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify first of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify ca_name of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify token of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test bpf_skc_to_mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add MPTCP test base (Yauheni Kaliuta) [2120968]
- selftests/bpf: Enable CONFIG_IKCONFIG_PROC in config (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_skc_to_mptcp_sock_proto (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix some bugs in map_lookup_percpu_elem testcase (Yauheni Kaliuta) [2120968]
- blob_to_mnt(): kern_unmount() is needed to undo kern_mount() (Yauheni Kaliuta) [2120968]
- libbpf: remove bpf_create_map*() APIs (Yauheni Kaliuta) [2120968]
- libbpf: start 1.0 development cycle (Yauheni Kaliuta) [2120968]
- libbpf: fix up global symbol counting logic (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add missed ima_setup.sh in Makefile (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix building bpf selftests statically (Yauheni Kaliuta) [2120968]
- libbpf: fix memory leak in attach_tp for target-less tracepoint program (Yauheni Kaliuta) [2120968]
- bpftool: Use sysfs vmlinux when dumping BTF by ID (Yauheni Kaliuta) [2120968]
- bpf: Add MEM_UNINIT as a bpf_type_flag (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix usdt_400 test case (Yauheni Kaliuta) [2120968]
- selftests/bpf: Convert some selftests to high-level BPF map APIs (Yauheni Kaliuta) [2120968]
- libbpf: Add safer high-level wrappers for map operations (Yauheni Kaliuta) [2120968]
- selftests/bpf: Check combination of jit blinding and pointers to bpf subprogs. (Yauheni Kaliuta) [2120968]
- bpf: Fix combination of jit blinding and pointers to bpf subprogs. (Yauheni Kaliuta) [2120968]
- bpf: Fix potential array overflow in bpf_trampoline_get_progs() (Yauheni Kaliuta) [2120968]
- selftests/bpf: make fexit_stress test run in serial mode (Yauheni Kaliuta) [2120968]
- selftests/bpf: add test case for bpf_map_lookup_percpu_elem (Yauheni Kaliuta) [2120968]
- bpf: add bpf_map_lookup_percpu_elem for percpu map (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for kptr_ref refcounting (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add negative C tests for kptrs (Yauheni Kaliuta) [2120968]
- bpf: Prepare prog_test_struct kfuncs for runtime tests (Yauheni Kaliuta) [2120968]
- bpf: Fix sparse warning for bpf_kptr_xchg_proto (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix a few clang compilation errors (Yauheni Kaliuta) [2120968]
- selftests/bpf: Enable CONFIG_FPROBE for self tests (Yauheni Kaliuta) [2120968]
- selftest/bpf: The test cases of BPF cookie for fentry/fexit/fmod_ret/lsm. (Yauheni Kaliuta) [2120968]
- libbpf: Assign cookies to links in libbpf. (Yauheni Kaliuta) [2120968]
- bpf, x86: Attach a cookie to fentry/fexit/fmod_ret/lsm. (Yauheni Kaliuta) [2120968]
- libbpf: Add bpf_program__set_insns function (Yauheni Kaliuta) [2120968]
- libbpf: Clean up ringbuf size adjustment implementation (Yauheni Kaliuta) [2120968]
- bpf, x86: Create bpf_tramp_run_ctx on the caller thread's stack (Yauheni Kaliuta) [2120968]
- bpf, x86: Generate trampolines from bpf_tramp_links (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add attach bench test (Yauheni Kaliuta) [2120968]
- fprobe: Resolve symbols with ftrace_lookup_symbols (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add bpf link iter test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use ASSERT_* instead of CHECK (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix result check for test_bpf_hash_map (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_link iterator (Yauheni Kaliuta) [2120968]
- selftests/bpf: Replace bpf_trace_printk in tunnel kernel code (Yauheni Kaliuta) [2120968]
- selftests/bpf: Move vxlan tunnel testcases to test_progs (Yauheni Kaliuta) [2120968]
- bpf: Add source ip in "struct bpf_tunnel_key" (Yauheni Kaliuta) [2120968]
- bpftool: bpf_link_get_from_fd support for LSM programs in lskel (Yauheni Kaliuta) [2120968]
- selftests/bpf: Handle batch operations for map-in-map bpf-maps (Yauheni Kaliuta) [2120968]
- bpf: Extend batch operations for map-in-map bpf-maps (Yauheni Kaliuta) [2120968]
- bpf: Print some info if disable bpf_jit_enable failed (Yauheni Kaliuta) [2120968]
- bpf: Remove unused parameter from find_kfunc_desc_btf() (Yauheni Kaliuta) [2120968]
- bpftool: Declare generator name (Yauheni Kaliuta) [2120968]
- bpftool: Output message if no helpers found in feature probing (Yauheni Kaliuta) [2120968]
- bpftool: Adjust for error codes from libbpf probes (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test libbpf's ringbuf size fix up logic (Yauheni Kaliuta) [2120968]
- libbpf: Automatically fix up BPF_MAP_TYPE_RINGBUF size, if necessary (Yauheni Kaliuta) [2120968]
- libbpf: Provide barrier() and barrier_var() in bpf_helpers.h (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add bpf_core_field_offset() tests (Yauheni Kaliuta) [2120968]
- libbpf: Complete field-based CO-RE helpers with field offset helper (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use both syntaxes for field-based CO-RE helpers (Yauheni Kaliuta) [2120968]
- libbpf: Improve usability of field-based CO-RE helpers (Yauheni Kaliuta) [2120968]
- libbpf: Make __kptr and __kptr_ref unconditionally use btf_type_tag() attr (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix two memory leaks in prog_tests (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test bpf_map__set_autocreate() and related log fixup logic (Yauheni Kaliuta) [2120968]
- libbpf: Allow to opt-out from creating BPF maps (Yauheni Kaliuta) [2120968]
- libbpf: Use libbpf_mem_ensure() when allocating new map (Yauheni Kaliuta) [2120968]
- libbpf: Append "..." in fixed up log if CO-RE spec is truncated (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use target-less SEC() definitions in various tests (Yauheni Kaliuta) [2120968]
- libbpf: Support target-less SEC() definitions for BTF-backed programs (Yauheni Kaliuta) [2120968]
- libbpf: Allow "incomplete" basic tracing SEC() definitions (Yauheni Kaliuta) [2120968]
- bpf, sockmap: Call skb_linearize only when required in sk_psock_skb_ingress_enqueue (Yauheni Kaliuta) [2120968]
- bpf, docs: Fix typo "respetively" to "respectively" (Yauheni Kaliuta) [2120968]
- bpf, docs: BPF_FROM_BE exists as alias for BPF_TO_BE (Yauheni Kaliuta) [2120968]
- bpf, docs: Remove duplicated word "instructions" (Yauheni Kaliuta) [2120968]
- samples/bpf: Detach xdp prog when program exits unexpectedly in xdp_rxq_info_user (Yauheni Kaliuta) [2120968]
- bpf/selftests: Add granular subtest output for prog_test (Yauheni Kaliuta) [2120968]
- x86/speculation: Add missing prototype for unpriv_ebpf_notify() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add libbpf's log fixup logic selftests (Yauheni Kaliuta) [2120968]
- libbpf: Fix up verifier log for unguarded failed CO-RE relos (Yauheni Kaliuta) [2120968]
- libbpf: Simplify bpf_core_parse_spec() signature (Yauheni Kaliuta) [2120968]
- libbpf: Refactor CO-RE relo human description formatting routine (Yauheni Kaliuta) [2120968]
- libbpf: Record subprog-resolved CO-RE relocations unconditionally (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add CO-RE relos and SEC("?...") to linked_funcs selftests (Yauheni Kaliuta) [2120968]
- libbpf: Avoid joining .BTF.ext data with BPF programs by section name (Yauheni Kaliuta) [2120968]
- libbpf: Fix logic for finding matching program for CO-RE relocation (Yauheni Kaliuta) [2120968]
- libbpf: Drop unhelpful "program too large" guess (Yauheni Kaliuta) [2120968]
- libbpf: Fix anonymous type check in CO-RE logic (Yauheni Kaliuta) [2120968]
- bpf: Compute map_btf_id during build time (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add test for strict BTF type check (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add verifier tests for kptr (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add C tests for kptr (Yauheni Kaliuta) [2120968]
- libbpf: Add kptr type tag macros to bpf_helpers.h (Yauheni Kaliuta) [2120968]
- bpf: Make BTF type match stricter for release arguments (Yauheni Kaliuta) [2120968]
- bpf: Teach verifier about kptr_get kfunc helpers (Yauheni Kaliuta) [2120968]
- bpf: Wire up freeing of referenced kptr (Yauheni Kaliuta) [2120968]
- bpf: Populate pairs of btf_id and destructor kfunc in btf (Yauheni Kaliuta) [2120968]
- bpf: Adapt copy_map_value for multiple offset case (Yauheni Kaliuta) [2120968]
- bpf: Prevent escaping of kptr loaded from maps (Yauheni Kaliuta) [2120968]
- bpf: Allow storing referenced kptr in map (Yauheni Kaliuta) [2120968]
- bpf: Tag argument to be released in bpf_func_proto (Yauheni Kaliuta) [2120968]
- bpf: Allow storing unreferenced kptr in map (Yauheni Kaliuta) [2120968]
- bpf: Use bpf_prog_run_array_cg_flags everywhere (Yauheni Kaliuta) [2120968]
- bpftool, musl compat: Replace sys/fcntl.h by fcntl.h (Yauheni Kaliuta) [2120968]
- bpftool, musl compat: Replace nftw with FTW_ACTIONRETVAL (Yauheni Kaliuta) [2120968]
- libbpf: Remove unnecessary type cast (Yauheni Kaliuta) [2120968]
- selftests/bpf: Switch fexit_stress to bpf_link_create() API (Yauheni Kaliuta) [2120968]
- libbpf: Teach bpf_link_create() to fallback to bpf_raw_tracepoint_open() (Yauheni Kaliuta) [2120968]
- bpf: Allow attach TRACING programs through LINK_CREATE command (Yauheni Kaliuta) [2120968]
- perf tools: Move libbpf init in libbpf_init function (Yauheni Kaliuta) [2120968]
- libbpf: Improve libbpf API documentation link position (Yauheni Kaliuta) [2120968]
- libbpf: Remove redundant non-null checks on obj_elf (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix map tests errno checks (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix prog_tests uprobe_autoattach compilation error (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix attach tests retcode checks (Yauheni Kaliuta) [2120968]
- bpf: Move check_ptr_off_reg before check_map_access (Yauheni Kaliuta) [2120968]
- bpf: Make btf_find_field more generic (Yauheni Kaliuta) [2120968]
- libbpf: Add documentation to API functions (Yauheni Kaliuta) [2120968]
- libbpf: Update API functions usage to check error (Yauheni Kaliuta) [2120968]
- libbpf: Add error returns to two API functions (Yauheni Kaliuta) [2120968]
- samples/bpf: Reduce the sampling interval in xdp1_user (Yauheni Kaliuta) [2120968]
- bpf: Enlarge offset check value to INT_MAX in bpf_skb_{load,store}_bytes (Yauheni Kaliuta) [2120968]
- libbpf: Support riscv USDT argument parsing logic (Yauheni Kaliuta) [2120968]
- libbpf: Fix usdt_cookie being cast to 32 bits (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for type tag order validation (Yauheni Kaliuta) [2120968]
- bpf: Ensure type tags precede modifiers in BTF (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use non-autoloaded programs in few tests (Yauheni Kaliuta) [2120968]
- libbpf: Support opting out from autoloading BPF programs declaratively (Yauheni Kaliuta) [2120968]
- selftests/bpf: Workaround a verifier issue for test exhandler (Yauheni Kaliuta) [2120968]
- bpf: Move rcu lock management out of BPF_PROG_RUN routines (Yauheni Kaliuta) [2120968]
- selftests/bpf: Refactor prog_tests logging and test execution (Yauheni Kaliuta) [2120968]
- bpf: Remove unnecessary type castings (Yauheni Kaliuta) [2120968]
- bpf: Move BPF sysctls from kernel/sysctl.c to BPF core (Yauheni Kaliuta) [2120968]
- page_pool: Add recycle stats to page_pool_put_page_bulk (Yauheni Kaliuta) [2120968]
- libbpf: Usdt aarch64 arg parsing support (Yauheni Kaliuta) [2120968]
- bpf: Remove redundant assignment to meta.seq in __task_seq_show() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Drop duplicate max/min definitions (Yauheni Kaliuta) [2120968]
- tools/runqslower: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- bpftool: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- samples/bpf: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- libbpf: Fix a bug with checking bpf_probe_read_kernel() support in old kernels (Yauheni Kaliuta) [2120968]
- selftests/bpf: Improve by-name subtest selection logic in prog_tests (Yauheni Kaliuta) [2120968]
- libbpf: Allow WEAK and GLOBAL bindings during BTF fixup (Yauheni Kaliuta) [2120968]
- libbpf: Use strlcpy() in path resolution fallback logic (Yauheni Kaliuta) [2120968]
- libbpf: Add s390-specific USDT arg spec parsing logic (Yauheni Kaliuta) [2120968]
- bpf: Fix excessive memory allocation in stack_map_alloc() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix return value checks in perf_event_stackmap test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add CO-RE relos into linked_funcs selftests (Yauheni Kaliuta) [2120968]
- libbpf: Use weak hidden modifier for USDT BPF-side API functions (Yauheni Kaliuta) [2120968]
- libbpf: Don't error out on CO-RE relos for overriden weak subprogs (Yauheni Kaliuta) [2120968]
- samples, bpf: Move routes monitor in xdp_router_ipv4 in a dedicated thread (Yauheni Kaliuta) [2120968]
- libbpf: Make BPF-side of USDT support work on big-endian machines (Yauheni Kaliuta) [2120968]
- libbpf: Minor style improvements in USDT code (Yauheni Kaliuta) [2120968]
- libbpf: Potential NULL dereference in usdt_manager_attach_usdt() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Uprobe tests should verify param/return values (Yauheni Kaliuta) [2120968]
- libbpf: Improve string parsing for uprobe auto-attach (Yauheni Kaliuta) [2120968]
- libbpf: Improve library identification for uprobe binary path resolution (Yauheni Kaliuta) [2120968]
- libbpf: Fix use #ifdef instead of #if to avoid compiler warning (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test for writes to map key from BPF helpers (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test passing rdonly mem to global func (Yauheni Kaliuta) [2120968]
- bpf: Reject writes for PTR_TO_MAP_KEY in check_helper_mem_access (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use bpf_num_possible_cpus() in per-cpu map allocations (Yauheni Kaliuta) [2120968]
- libbpf: Fix spelling mistake "libaries" -> "libraries" (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix issues in parse_num_list() (Yauheni Kaliuta) [2120968]
- net: netfilter: Reports ct direction in CT lookup helpers for XDP and TC-BPF (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix file descriptor leak in load_kallsyms() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add urandom_read shared lib and USDTs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add basic USDT selftests (Yauheni Kaliuta) [2120968]
- libbpf: Add x86-specific USDT arg spec parsing logic (Yauheni Kaliuta) [2120968]
- libbpf: Wire up spec management and other arch-independent USDT logic (Yauheni Kaliuta) [2120968]
- libbpf: Add USDT notes parsing and resolution logic (Yauheni Kaliuta) [2120968]
- libbpf: Wire up USDT API and bpf_link integration (Yauheni Kaliuta) [2120968]
- libbpf: Add BPF-side of USDT support (Yauheni Kaliuta) [2120968]
- bpf, arm64: Sign return address for JITed code (Yauheni Kaliuta) [2120968]
- libbpf: Support Debian in resolve_full_path() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Define SYS_NANOSLEEP_KPROBE_NAME for aarch64 (Yauheni Kaliuta) [2120968]
- bpftool: Handle libbpf_probe_prog_type errors (Yauheni Kaliuta) [2120968]
- bpftool: Add missing link types (Yauheni Kaliuta) [2120968]
- bpftool: Add syscall prog type (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix parsing of prog types in UAPI hdr for bpftool sync (Yauheni Kaliuta) [2120968]
- samples: bpf: Fix linking xdp_router_ipv4 after migration (Yauheni Kaliuta) [2120968]
- sample: bpf: syscall_tp_user: Print result of verify_map (Yauheni Kaliuta) [2120968]
- libbpf: Don't return -EINVAL if hdr_len < offsetofend(core_relo_len) (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for uprobe auto-attach via skeleton (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for u[ret]probe attach by name (Yauheni Kaliuta) [2120968]
- libbpf: Add auto-attach for uprobes based on section name (Yauheni Kaliuta) [2120968]
- libbpf: Support function name-based attach uprobes (Yauheni Kaliuta) [2120968]
- libbpf: auto-resolve programs/libraries when necessary for uprobes (Yauheni Kaliuta) [2120968]
- samples: bpf: Convert xdp_router_ipv4 to XDP samples helper (Yauheni Kaliuta) [2120968]
- bpf: Correct the comment for BTF kind bitfield (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix cd_flavor_subdir() of test_progs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Return true/false (not 1/0) from bool functions (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix vfs_link kprobe definition (Yauheni Kaliuta) [2120968]
- bpf: Replace usage of supported with dedicated list iterator variable (Yauheni Kaliuta) [2120968]
- bpf: Remove redundant assignment to smap->map.value_size (Yauheni Kaliuta) [2120968]
- selftests/bpf: Remove unused variable from bpf_sk_assign test (Yauheni Kaliuta) [2120968]
- bpf: Use swap() instead of open coding it (Yauheni Kaliuta) [2120968]
- bpf, tests: Add load store test case for tail call (Yauheni Kaliuta) [2120968]
- bpf, tests: Add tests for BPF_LDX/BPF_STX with different offsets (Yauheni Kaliuta) [2120968]
- bpf, arm64: Adjust the offset of str/ldr(immediate) to positive number (Yauheni Kaliuta) [2120968]
- bpf, arm64: Optimize BPF store/load using arm64 str/ldr(immediate offset) (Yauheni Kaliuta) [2120968]
- arm64, insn: Add ldr/str with immediate offset (Yauheni Kaliuta) [2120968]

* Wed Dec 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-220.el9]
- firmware_loader: Fix memory leak in firmware upload (Mark Langsdorf) [2122318]
- firmware_loader: Fix use-after-free during unregister (Mark Langsdorf) [2122318]
- firmware_loader: Replace kmap() with kmap_local_page() (Mark Langsdorf) [2122318]
- firmware_loader: describe 'module' parameter of firmware_upload_register() (Mark Langsdorf) [2122318]
- firmware_loader: Move definitions from sysfs_upload.h to sysfs.h (Mark Langsdorf) [2122318]
- firmware_loader: Add sysfs nodes to monitor fw_upload (Mark Langsdorf) [2122318]
- redhat/configs: enable CONFIG_FW_UPLOAD (Mark Langsdorf) [2122318]
- firmware_loader: Add firmware-upload support (Mark Langsdorf) [2122318]
- firmware_loader: Split sysfs support from fallback (Mark Langsdorf) [2122318]
- PM / devfreq: Fix kernel warning with cpufreq passive register fail (Mark Langsdorf) [2122318]
- PM / devfreq: Fix cpufreq passive unregister erroring on PROBE_DEFER (Mark Langsdorf) [2122318]
- PM / devfreq: Mute warning on governor PROBE_DEFER (Mark Langsdorf) [2122318]
- PM / devfreq: Fix kernel panic with cpu based scaling to passive gov (Mark Langsdorf) [2122318]
- of: base: Avoid console probe delay when fw_devlink.strict=1 (Mark Langsdorf) [2122318]
- driver core: Set default deferred_probe_timeout back to 0. (Mark Langsdorf) [2122318]
- PM / devfreq: passive: revert an editing accident in SPDX-License line (Mark Langsdorf) [2122318]
- drm/rockchip: Detach from ARM DMA domain in attach_device (Mark Langsdorf) [2122318]
- serial: 8250: Fix PM usage_count for console handover (Mark Langsdorf) [2122318]
- arch_topology: Make cluster topology span at least SMT CPUs (Mark Langsdorf) [2122318]
- driver core: fix driver_set_override() issue with empty strings (Mark Langsdorf) [2122318]
- arch_topology: Silence early cacheinfo errors when non-existent (Mark Langsdorf) [2122318]
- driver core: Don't probe devices after bus_type.match() probe deferral (Mark Langsdorf) [2122318]
- regmap: spi: Reserve space for register address/padding (Mark Langsdorf) [2122318]
- arch_topology: Fix cache attributes detection in the CPU hotplug path (Mark Langsdorf) [2122318]
- cacheinfo: Use atomic allocation for percpu cache attributes (Mark Langsdorf) [2122318]
- regmap: permit to set reg_update_bits with bulk implementation (Mark Langsdorf) [2122318]
- PM: domains: Ensure genpd_debugfs_dir exists before remove (Mark Langsdorf) [2122318]
- PM: runtime: Extend support for wakeirq for force_suspend|resume (Mark Langsdorf) [2122318]
- regmap: add WARN_ONCE when invalid mask is provided to regmap_field_init() (Mark Langsdorf) [2122318]
- PM: wakeup: Unify device_init_wakeup() for PM_SLEEP and !PM_SLEEP (Mark Langsdorf) [2122318]
- regmap-irq: Fix bug in regmap_irq_get_irq_reg_linear() (Mark Langsdorf) [2122318]
- arch_topology: Warn that topology for nested clusters is not supported (Mark Langsdorf) [2122318]
- arch_topology: Add support for parsing sockets in /cpu-map (Mark Langsdorf) [2122318]
- arch_topology: Set cluster identifier in each core/thread from /cpu-map (Mark Langsdorf) [2122318]
- arch_topology: Limit span of cpu_clustergroup_mask() (Mark Langsdorf) [2122318]
- arch_topology: Don't set cluster identifier as physical package identifier (Mark Langsdorf) [2122318]
- arch_topology: Avoid parsing through all the CPUs once a outlier CPU is found (Mark Langsdorf) [2122318]
- arch_topology: Check for non-negative value rather than -1 for IDs validity (Mark Langsdorf) [2122318]
- arch_topology: Set thread sibling cpumask only within the cluster (Mark Langsdorf) [2122318]
- arch_topology: Drop LLC identifier stash from the CPU topology (Mark Langsdorf) [2122318]
- arch_topology: Use the last level cache information from the cacheinfo (Mark Langsdorf) [2122318]
- arch_topology: Add support to parse and detect cache attributes (Mark Langsdorf) [2122318]
- cacheinfo: Align checks in cache_shared_cpu_map_{setup,remove} for readability (Mark Langsdorf) [2122318]
- cacheinfo: Use cache identifiers to check if the caches are shared if available (Mark Langsdorf) [2122318]
- cacheinfo: Allow early detection and population of cache attributes (Mark Langsdorf) [2122318]
- cacheinfo: Add support to check if last level cache(LLC) is valid or shared (Mark Langsdorf) [2122318]
- cacheinfo: Move cache_leaves_are_shared out of CONFIG_OF (Mark Langsdorf) [2122318]
- cacheinfo: Add helper to access any cache index for a given CPU (Mark Langsdorf) [2122318]
- cacheinfo: Use of_cpu_device_node_get instead cpu_dev->of_node (Mark Langsdorf) [2122318]
- arm64: topology: Remove redundant setting of llc_id in CPU topology (Mark Langsdorf) [2122318]
- PM: runtime: Fix supplier device management during consumer probe (Mark Langsdorf) [2122318]
- PM: runtime: Redefine pm_runtime_release_supplier() (Mark Langsdorf) [2122318]
- regmap: cache: Add extra parameter check in regcache_init (Mark Langsdorf) [2122318]
- regmap-irq: Deprecate the not_fixed_stride flag (Mark Langsdorf) [2122318]
- regmap-irq: Add get_irq_reg() callback (Mark Langsdorf) [2122318]
- regmap-irq: Fix inverted handling of unmask registers (Mark Langsdorf) [2122318]
- regmap-irq: Deprecate type registers and virtual registers (Mark Langsdorf) [2122318]
- regmap-irq: Introduce config registers for irq types (Mark Langsdorf) [2122318]
- regmap-irq: Refactor checks for status bulk read support (Mark Langsdorf) [2122318]
- regmap-irq: Remove mask_writeonly and regmap_irq_update_bits() (Mark Langsdorf) [2122318]
- regmap-irq: Remove inappropriate uses of regmap_irq_update_bits() (Mark Langsdorf) [2122318]
- regmap-irq: Remove an unnecessary restriction on type_in_mask (Mark Langsdorf) [2122318]
- regmap-irq: Cleanup sizeof(...) use in memory allocation (Mark Langsdorf) [2122318]
- regmap-irq: Remove unused type_reg_stride field (Mark Langsdorf) [2122318]
- regmap-irq: Convert bool bitfields to unsigned int (Mark Langsdorf) [2122318]
- driver core: fw_devlink: Allow firmware to mark devices as best effort (Mark Langsdorf) [2122318]
- driver core: fix potential deadlock in __driver_attach (Mark Langsdorf) [2122318]
- devtmpfs: fix the dangling pointer of global devtmpfsd thread (Mark Langsdorf) [2122318]
- regmap: Don't warn about cache only mode for devices with no cache (Mark Langsdorf) [2122318]
- MAINTAINERS: Add new IOMMU development mailing list (Mark Langsdorf) [2122318]
- regmap-irq: Fix offset/index mismatch in read_sub_irq_data() (Mark Langsdorf) [2122318]
- regmap-irq: Fix a bug in regmap_irq_enable() for type_in_mask chips (Mark Langsdorf) [2122318]
- regmap: Wire up regmap_config provided bulk write in missed functions (Mark Langsdorf) [2122318]
- regmap: Make regmap_noinc_read() return -ENOTSUPP if map->read isn't set (Mark Langsdorf) [2122318]
- regmap: Re-introduce bulk read support check in regmap_bulk_read() (Mark Langsdorf) [2122318]
- init: Initialize noop_backing_dev_info early (Mark Langsdorf) [2122318]
- regmap: provide regmap_field helpers for simple bit operations (Mark Langsdorf) [2122318]
- driver core: Introduce device_find_any_child() helper (Mark Langsdorf) [2122318]
- driver core: Add wait_for_init_devices_probe helper function (Mark Langsdorf) [2122318]
- pinctrl: devicetree: Delete usage of driver_deferred_probe_check_state() (Mark Langsdorf) [2122318]
- regmap: cache: Fix syntax errors in comments (Mark Langsdorf) [2122318]
- firmware_loader: enable XZ by default if compressed support is enabled (Mark Langsdorf) [2122318]
- driver core: Fix wait_for_device_probe() & deferred_probe_timeout interaction (Mark Langsdorf) [2122318]
- PM: domains: Trust domain-idle-states from DT to be correct by genpd (Mark Langsdorf) [2122318]
- PM: domains: Measure power-on/off latencies in genpd based on a governor (Mark Langsdorf) [2122318]
- PM: domains: Allocate governor data dynamically based on a genpd governor (Mark Langsdorf) [2122318]
- PM: domains: Clean up some code in pm_genpd_init() and genpd_remove() (Mark Langsdorf) [2122318]
- PM: domains: Fix initialization of genpd's next_wakeup (Mark Langsdorf) [2122318]
- PM: domains: Fixup QoS latency measurements for IRQ safe devices in genpd (Mark Langsdorf) [2122318]
- PM: domains: Measure suspend/resume latencies in genpd based on governor (Mark Langsdorf) [2122318]
- PM: domains: Move the next_wakeup variable into the struct gpd_timing_data (Mark Langsdorf) [2122318]
- PM: domains: Allocate gpd_timing_data dynamically based on governor (Mark Langsdorf) [2122318]
- PM: domains: Skip another warning in irq_safe_dev_in_sleep_domain() (Mark Langsdorf) [2122318]
- PM: domains: Rename irq_safe_dev_in_no_sleep_domain() in genpd (Mark Langsdorf) [2122318]
- PM: domains: Don't check PM_QOS_FLAG_NO_POWER_OFF in genpd (Mark Langsdorf) [2122318]
- PM: domains: Drop redundant code for genpd always-on governor (Mark Langsdorf) [2122318]
- PM: domains: Add GENPD_FLAG_RPM_ALWAYS_ON for the always-on governor (Mark Langsdorf) [2122318]
- PM: wakeup: expose pm_wakeup_pending to modules (Mark Langsdorf) [2122318]
- driver core: fix deadlock in __device_attach (Mark Langsdorf) [2122318]
- driver core: Extend deferred probe timeout on driver registration (Mark Langsdorf) [2122318]
- driver: base: fix UAF when driver_attach failed (Mark Langsdorf) [2122318]
- driver core: location: Add "back" as a possible output for panel (Mark Langsdorf) [2122318]
- driver core: location: Free struct acpi_pld_info *pld (Mark Langsdorf) [2122318]
- driver core: Add "*" wildcard support to driver_async_probe cmdline param (Mark Langsdorf) [2122318]
- PM / devfreq: passive: Keep cpufreq_policy for possible cpus (Mark Langsdorf) [2122318]
- PM / devfreq: passive: Reduce duplicate code when passive_devfreq case (Mark Langsdorf) [2122318]
- PM / devfreq: Add cpu based scaling support to passive governor (Mark Langsdorf) [2122318]
- PM / devfreq: Export devfreq_get_freq_range symbol within devfreq (Mark Langsdorf) [2122318]
- iommu/arm-smmu: Force identity domains for legacy binding (Mark Langsdorf) [2122318]
- regmap: Add missing map->bus check (Mark Langsdorf) [2122318]
- driver core: location: Check for allocations failure (Mark Langsdorf) [2122318]
- arch_topology: Trace the update thermal pressure (Mark Langsdorf) [2122318]
- regmap: Add bulk read/write callbacks into regmap_config (Mark Langsdorf) [2122318]
- drivers/base/memory: fix an unlikely reference counting issue in __add_memory_block() (Mark Langsdorf) [2122318]
- driver core: Add sysfs support for physical location of a device (Mark Langsdorf) [2122318]
- platform: finally disallow IRQ0 in platform_get_irq() and its ilk (Mark Langsdorf) [2122318]
- drivers/base/node.c: fix compaction sysfs file leak (Mark Langsdorf) [2122318]
- driver core: Prevent overriding async driver of a device before it probe (Mark Langsdorf) [2122318]
- Documentation: dd: Use ReST lists for return values of driver_deferred_probe_check_state() (Mark Langsdorf) [2122318]
- regmap: cache: set max_register with reg_stride (Mark Langsdorf) [2122318]
- firmware_loader: Check fw_state_is_done in loading_store (Mark Langsdorf) [2122318]
- firmware_loader: Clear data and size in fw_free_paged_buf (Mark Langsdorf) [2122318]
- driver: platform: Add helper for safer setting of driver_override (Mark Langsdorf) [2122318]
- PM: domains: Move genpd's time-accounting to ktime_get_mono_fast_ns() (Mark Langsdorf) [2122318]
- redhat/configs: Enable XZ and ZSTD compress firmware loading (Mark Langsdorf) [2122318]
- firmware: Add the support for ZSTD-compressed firmware files (Mark Langsdorf) [2122318]
- PM: runtime: Allow to call __pm_runtime_set_status() from atomic context (Mark Langsdorf) [2122318]
- PM: runtime: Avoid device usage count underflows (Mark Langsdorf) [2122318]
- PM: domains: Extend dev_pm_domain_detach() doc (Mark Langsdorf) [2122318]
- regmap: Constify static regmap_bus structs (Mark Langsdorf) [2122318]

* Tue Dec 20 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-219.el9]
- i2c: ismt: Fix an out-of-bounds bug in ismt_access() (David Arcari) [2119067] {CVE-2022-2873}
- redhat/configs: Enable CONFIG_CRYPTO_CURVE25519 (Prarit Bhargava) [2030750]
- x86/fpu: Drop fpregs lock before inheriting FPU permissions (Valentin Schneider) [2153181]
- vmxnet3: use correct intrConf reference when using extended queues (Izabela Bakollari) [2150922]
- vmxnet3: correctly report encapsulated LRO packet (Izabela Bakollari) [2150922]
- net: move from strlcpy with unused retval to strscpy (Izabela Bakollari) [2150922]
- vmxnet3: Implement ethtool's get_channels command (Izabela Bakollari) [2150922]
- vmxnet3: Record queue number to incoming packets (Izabela Bakollari) [2150922]
- powerpc/rtas: Allow ibm,platform-dump RTAS call with null buffer address (Mamatha Inamdar) [2095499]
- kernfs: remove redundant kernfs_rwsem declaration. (Luis Claudio R. Goncalves) [2152737]
- kernfs: fix potential NULL dereference in __kernfs_remove (Luis Claudio R. Goncalves) [2152737]
- kernfs: fix NULL dereferencing in kernfs_remove (Luis Claudio R. Goncalves) [2152737]
- kernfs: prevent early freeing of root node (Luis Claudio R. Goncalves) [2152737]
- kernfs: switch global kernfs_rwsem lock to per-fs lock (Luis Claudio R. Goncalves) [2152737]
- tracing: Use a copy of the va_list for __assign_vstr() (Íñigo Huguet) [2143357]
- tracing/events: Add __vstring() and __assign_vstr() helper macros (Íñigo Huguet) [2143357]
- kunit/memcpy: Avoid pathological compile-time string size (Josef Oskera) [2139493]
- mips: boot/compressed: use __NO_FORTIFY (Josef Oskera) [2139493]
- fortify: Fix __compiletime_strlen() under UBSAN_BOUNDS_LOCAL (Josef Oskera) [2139493]
- string: Introduce strtomem() and strtomem_pad() (Josef Oskera) [2139493]
- fortify: Provide a memcpy trap door for sharp corners (Josef Oskera) [2139493]
- fortify: Add Clang support (Josef Oskera) [2139493]
- fortify: Make sure strlen() may still be used as a constant expression (Josef Oskera) [2139493]
- fortify: Use __diagnose_as() for better diagnostic coverage (Josef Oskera) [2139493]
- fortify: Make pointer arguments const (Josef Oskera) [2139493]
- Compiler Attributes: Add __diagnose_as for Clang (Josef Oskera) [2139493]
- Compiler Attributes: Add __overloadable for Clang (Josef Oskera) [2139493]
- fortify: Update compile-time tests for Clang 14 (Josef Oskera) [2139493]
- fortify: Replace open-coded __gnu_inline attribute (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memset() at compile-time (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memmove() at compile-time (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memcpy() at compile-time (Josef Oskera) [2139493]
- Compiler Attributes: Add __pass_object_size for Clang (Josef Oskera) [2139493]
- lib/string_helpers: Introduce kasprintf_strarray() (Josef Oskera) [2139493]
- string: uninline memcpy_and_pad (Josef Oskera) [2139493]
- fortify: strlen: Avoid shadowing previous locals (Josef Oskera) [2139493]
- fortify: Add compile-time FORTIFY_SOURCE tests (Josef Oskera) [2139493]
- fortify: Allow strlen() and strnlen() to pass compile-time known lengths (Josef Oskera) [2139493]
- fortify: Prepare to improve strnlen() and strlen() warnings (Josef Oskera) [2139493]
- fortify: Fix dropped strcpy() compile-time write overflow check (Josef Oskera) [2139493]
- fortify: Explicitly disable Clang support (Josef Oskera) [2139493]
- fortify: Move remaining fortify helpers into fortify-string.h (Josef Oskera) [2139493]
- lib/string: Move helper functions out of string.c (Josef Oskera) [2139493]
- Redo missing uapi/linux/stddef.h: Add include guards (Patrick Talbert) [2132632]

* Mon Dec 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-218.el9]
- arm64: tegra: Mark BPMP channels as no-memory-wc (Al Stone) [2129151]
- dt-bindings: misc: Convert Tegra MISC to json-schema (Al Stone) [2129151]
- dt-bindings: sram: Document NVIDIA Tegra SYSRAM (Al Stone) [2129151]
- misc: sram: Add compatible string for Tegra234 SYSRAM (Al Stone) [2129151]
- dt-bindings: sram: Allow numbers in sram region node name (Al Stone) [2129151]
- dt-bindings: sram: Document qcom,rpm-msg-ram (Al Stone) [2129151]
- misc: sram: Only map reserved areas in Tegra SYSRAM (Al Stone) [2129151]
- wireguard: Kconfig: select CRYPTO_CHACHA_S390 (John B. Wyatt IV) [2134831]
- crypto: s390 - do not depend on CRYPTO_HW for SIMD implementations (John B. Wyatt IV) [2134831]
- HID: hyperv: fix possible memory leak in mousevsc_probe() (Mohammed Gamal) [2139469]
- HID: hyperv: Correctly access fields declared as __le16 (Mohammed Gamal) [2139469]
- md/raid1: stop mdx_raid1 thread when raid1 array run failed (Nigel Croxon) [2141362 2143273]
- md/raid5: use bdev_write_cache instead of open coding it (Nigel Croxon) [2143273]
- md: fix a crash in mempool_free (Nigel Croxon) [2143261 2143273]
- md/raid0, raid10: Don't set discard sectors for request queue (Nigel Croxon) [2128207 2135609 2143273]
- md/bitmap: Fix bitmap chunk size overflow issues (Nigel Croxon) [2143273]
- md: introduce md_ro_state (Nigel Croxon) [2143273]
- md: factor out __md_set_array_info() (Nigel Croxon) [2143273]
- lib/raid6: drop RAID6_USE_EMPTY_ZERO_PAGE (Nigel Croxon) [2143273]
- raid5-cache: use try_cmpxchg in r5l_wake_reclaim (Nigel Croxon) [2143273]
- drivers/md/md-bitmap: check the return value of md_bitmap_get_counter() (Nigel Croxon) [2143273]

* Fri Dec 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-217.el9]
- igc: Correct the launchtime offset (Corinna Vinschen) [2104471]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2104471]
- igc: Remove IGC_MDIC_INT_EN definition (Corinna Vinschen) [2104471]
- igc: add xdp frags support to ndo_xdp_xmit (Corinna Vinschen) [2104471]
- igc: Remove forced_speed_duplex value (Corinna Vinschen) [2104471]
- igc: Remove MSI-X PBA Clear register (Corinna Vinschen) [2104471]
- igc: Lift TAPRIO schedule restriction (Corinna Vinschen) [2104471]
- PCI: vmd: Fix secondary bus reset for Intel bridges (Myron Stowe) [2136299]
- PCI: vmd: Disable MSI remapping after suspend (Myron Stowe) [2136299]
- KVM: s390: vsie: Fix the initialization of the epoch extension (epdx) field (Thomas Huth) [2140899]
- scsi: qla2xxx: Fix crash when I/O abort times out (Nilesh Javali) [2115892]
- redhat/configs: Change the amd-pstate to builtin (David Arcari) [2150425]
- Documentation: amd-pstate: add driver working mode introduction (David Arcari) [2150425]
- cpufreq: amd-pstate: add amd-pstate driver parameter for mode selection (David Arcari) [2150425]
- cpufreq: amd-pstate: change amd-pstate driver to be built-in type (David Arcari) [2150425]
- cpufreq: amd-pstate: cpufreq: amd-pstate: reset MSR_AMD_PERF_CTL register at init (David Arcari) [2150425]
- Documentation: amd-pstate: Add unit test introduction (David Arcari) [2150425]
- cpufreq: amd-pstate: Expose struct amd_cpudata (David Arcari) [2150425]
- cpufreq: amd-pstate: Fix initial highest_perf value (David Arcari) [2150425]
- cpufreq: amd-pstate: update pstate frequency transition delay time (David Arcari) [2150425]
- cpufreq: amd_pstate: map desired perf into pstate scope for powersave governor (David Arcari) [2150425]
- cpufreq: amd_pstate: fix wrong lowest perf fetch (David Arcari) [2150425]
- cpufreq: amd-pstate: fix white-space (David Arcari) [2150425]
- cpufreq: amd-pstate: simplify cpudata pointer assignment (David Arcari) [2150425]
- ACPI: CPPC: Add ACPI disabled check to acpi_cpc_valid() (David Arcari) [2150425]
- cpufreq: amd-pstate: Add resume and suspend callbacks (David Arcari) [2150425]
- Documentation: amd-pstate: grammar and sentence structure updates (David Arcari) [2150425]
- Documentation: amd-pstate: add tracer tool introduction (David Arcari) [2150425]
- MAINTAINERS: Add AMD P-State driver maintainer entry (David Arcari) [2150425]
- Documentation: amd-pstate: Add AMD P-State driver introduction (David Arcari) [2150425]
- arm64: dts: imx93-pinfunc: drop execution permission (Steve Best) [2144998]
- dt-bindings: i2c: i2c-imx-lpi2c: add i.MX93 (Steve Best) [2140034]
- dt-bindings: i2c: i2c-imx-lpi2c: add dmas property (Steve Best) [2140034]
- dt-bindings: i2c: i2c-imx-lpi2c: add ipg clk (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Add imx8ulp compatible string (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Add i.MX8DXL compatible match (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Fix i.MX 8QM compatible matching (Steve Best) [2140034]
- dt-bindings: mfd: syscon: Add i.MX93 blk ctrl system registers (Steve Best) [2140034]
- dt-bindings: soc: add i.MX93 SRC (Steve Best) [2140034]
- hwmon: Handle failure to register sensor with thermal zone correctly (d.marlin) [2122394]
- openvswitch: add nf_ct_is_confirmed check before assigning the helper (Antoine Tenart) [2134560]
- net: openvswitch: allow conntrack in non-initial user namespace (Antoine Tenart) [2134560]
- net: openvswitch: allow metering in non-initial user namespace (Antoine Tenart) [2134560]
- openvswitch: Change the return type for vport_ops.send function hook to int (Antoine Tenart) [2134560]
- net: openvswitch: fix repeated words in comments (Antoine Tenart) [2134560]
- openvswitch: add OVS_DP_ATTR_PER_CPU_PIDS to get requests (Antoine Tenart) [2134560]
- openvswitch: allow specifying ifindex of new interfaces (Antoine Tenart) [2134560]
- openvswitch: move from strlcpy with unused retval to strscpy (Antoine Tenart) [2134560]
- openvswitch: Fix overreporting of drops in dropwatch (Antoine Tenart) [2134560]
- openvswitch: Fix double reporting of drops in dropwatch (Antoine Tenart) [2134560]
- openvswitch: fix memory leak at failed datapath creation (Antoine Tenart) [2134560]

* Fri Dec 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-216.el9]
- mailbox: imx: fix RST channel support (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: clear pending interrupts (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support RST channel (Al Stone) [2122400 2129154 2139961]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_30.RULE (part 2) (Al Stone) [2122400 2129154 2139961]
- mailbox: forward the hrtimer if not queued and under a lock (Al Stone) [2122400 2129154 2139961]
- mailbox: pcc: Fix an invalid-load caught by the address sanitizer (Al Stone) [2122400 2129154 2139961]
- mailbox: correct kerneldoc (Al Stone) [2122400 2129154 2139961]
- mailbox:imx: using pm_runtime_resume_and_get (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Add 128-bit shared mailbox support (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Add tegra_hsp_sm_ops (Al Stone) [2122400 2129154 2139961]
- mailbox: remove an unneeded NULL check on list iterator (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: remove redundant initializer (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support i.MX93 S401 MU (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support dual interrupts (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: extend irq to an array (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: add i.MX8 SECO MU support (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: introduce rxdb callback (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: enlarge timeout while reading/writing messages to SCFW (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: fix crash in resume on i.mx8ulp (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: fix wakeup failure from freeze mode (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Flush whole channel (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: Fix an IS_ERR() vs NULL bug (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support i.MX8ULP S4 MU (Al Stone) [2122400 2129154 2139961]
- mailbox: platform-mhu: Make use of the helper function devm_platform_ioremap_resource() (Al Stone) [2122400 2129154 2139961]
- arm64: tegra: Add MGBE nodes on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Add regulators required for PCIe (Al Stone) [2122303]
- arm64: tegra: Fix up compatible for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Enable MGBE on Jetson AGX Orin Developer Kit (Al Stone) [2122303]
- arm64: tegra: Add P2U and PCIe controller nodes to Tegra234 DT (Al Stone) [2122303]
- arm64: tegra: Enable PCIe slots in P3737-0000 board (Al Stone) [2122303]
- dt-bindings: net: Add Tegra234 MGBE (Al Stone) [2122303]
- dt-bindings: arm: tegra: Add NVIDIA Tegra234 CBB 2.0 binding (Al Stone) [2122303]
- dt-bindings: Document Tegra CCPLEX Cluster (Al Stone) [2122303]
- dt-bindings: fuse: tegra: Document Tegra234 FUSE (Al Stone) [2122303]
- dt-bindings: mmc: tegra: Document Tegra234 SDHCI (Al Stone) [2122303]
- dt-bindings: fuse: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: rtc: tegra: Document Tegra234 RTC (Al Stone) [2122303]
- dt-bindings: rtc: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: mmc: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: tegra: Document Jetson AGX Orin (and devkit) (Al Stone) [2122303]
- dt-bindings: tegra: Describe recent developer kits consistently (Al Stone) [2122303]
- dt-bindings: arm: cpus: Add ARM Cortex-A78 (Al Stone) [2122303]
- dt-bindings: tegra: Document NVIDIA Jetson TX2 NX developer kit (Al Stone) [2122303]
- arm64: tegra: Update compatible for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Add Host1x context stream IDs on Tegra186+ (Al Stone) [2122303]
- arm64: tegra: Fix SDMMC1 CD on P2888 (Al Stone) [2122303]
- arm64: tegra: Add Host1x and VIC on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Enable OPE on various platforms (Al Stone) [2122303]
- arm64: tegra: Add node for CBB 1.0 on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Mark BPMP channels as no-memory-wc (Al Stone) [2122303]
- arm64: tegra: Add Tegra234 GPCDMA device tree node (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Adjust whitespace around '=' (Al Stone) [2122303]
- arm64: tegra: Add OPE device on Tegra210 and later (Al Stone) [2122303]
- arm64: tegra: Add node for CBB 2.0 on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Align gpio-keys node names with dtschema (Al Stone) [2122303]
- dt-bindings: Add headers for Host1x and VIC on Tegra234 (Al Stone) [2122303]
- dt-bindings: Add Tegra234 MGBE clocks and resets (Al Stone) [2122303]
- dt-bindings: memory: Add Tegra234 MGBE memory clients (Al Stone) [2122303]
- dt-bindings: power: Add Tegra234 MGBE power domains (Al Stone) [2122303]
- dt-bindings: Add headers for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Add missing DFLL reset on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Add memory controller channels (Al Stone) [2122303]
- arm64: tegra: Enable ASRC on various platforms (Al Stone) [2122303]
- arm64: tegra: Add ASRC device on Tegra186 and later (Al Stone) [2122303]
- arm64: tegra: Update PWM fan node name (Al Stone) [2122303]
- arm64: tegra: Add node for Tegra234 CCPLEX cluster (Al Stone) [2122303]
- arm64: tegra: Update SDMMC1/3 clock source for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Drop arm,armv8-pmuv3 compatible string (Al Stone) [2122303]
- arm64: tegra: Enable UART instance on 40-pin header (Al Stone) [2122303]
- arm64: tegra: Enable Jetson Xavier NX USB device mode (Al Stone) [2122303]
- arm64: tegra: Enable device-tree overlay support (Al Stone) [2122303]
- arm64: tegra: Add GPCDMA node for tegra186 and tegra194 (Al Stone) [2122303]
- arm64: tegra: Disable ISO SMMU for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Remove non existent Tegra194 reset (Al Stone) [2122303]
- arm64: tegra: Add host1x hotflush reset on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Add EMC general interrupt on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Sort Tegra210 XUSB clocks correctly (Al Stone) [2122303]
- arm64: tegra: Drop unit-address for audio card graph endpoints (Al Stone) [2122303]
- arm64: tegra: Fix Tegra194 HSP compatible string (Al Stone) [2122303]
- arm64: tegra: Remove undocumented Tegra194 PCIe "core_m" clock (Al Stone) [2122303]
- arm64: tegra: Update SDMMC4 speeds for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add dma-coherent for Tegra194 VIC (Al Stone) [2122303]
- arm64: tegra: jetson-nano: Remove extra PLL power supplies for PCIe and XUSB (Al Stone) [2122303]
- arm64: tegra: Rename TCU node to "serial" (Al Stone) [2122303]
- arm64: tegra: Rename GPIO hog nodes to match schema (Al Stone) [2122303]
- arm64: tegra: Use JEDEC vendor prefix for SPI NOR flash chips (Al Stone) [2122303]
- arm64: tegra: Rename Ethernet PHY nodes (Al Stone) [2122303]
- arm64: tegra: Fix Tegra186 compatible string list (Al Stone) [2122303]
- arm64: tegra: jetson-tx1: Remove extra PLL power supplies for PCIe and XUSB (Al Stone) [2122303]
- arm64: tegra: Drop unsupported nvidia,lpdr property (Al Stone) [2122303]
- arm64: tegra: Adjust length of CCPLEX cluster MMIO region (Al Stone) [2122303]
- arm64: tegra: Add missing TSEC properties on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Drop unused properties for Tegra194 PCIe (Al Stone) [2122303]
- arm64: tegra: Remove unsupported regulator properties (Al Stone) [2122303]
- arm64: tegra: Add support to enumerate SD in UHS mode (Al Stone) [2122303]
- arm64: tegra: Rename thermal zones nodes (Al Stone) [2122303]
- arm64: tegra: Sort Tegra132 XUSB clocks correctly (Al Stone) [2122303]
- arm64: tegra: Add NVENC and NVJPG nodes for Tegra186 and Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add OPP tables on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Add ISO SMMU controller for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add native timer support on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Fix compatible string for Tegra132 timer (Al Stone) [2122303]
- arm64: tegra: Drop unused AHCI clocks on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Fix Tegra132 I2C compatible string list (Al Stone) [2122303]
- arm64: tegra: Remove unsupported properties on Norrin (Al Stone) [2122303]
- arm64: tegra: Rename top-level clocks (Al Stone) [2122303]
- arm64: tegra: Rename power-monitor input nodes (Al Stone) [2122303]
- arm64: tegra: Fix unit-addresses on Norrin (Al Stone) [2122303]
- arm64: tegra: Rename top-level regulators (Al Stone) [2122303]
- arm64: tegra: Fix pcie-ep DT nodes (Al Stone) [2122303]
- arm64: tegra: Remove useless usb-ehci compatible string (Al Stone) [2122303]
- arm64: tegra: Extend APE audio support on Jetson platforms (Al Stone) [2122303]
- arm64: tegra: Add few AHUB devices for Tegra210 and later (Al Stone) [2122303]
- arm64: tegra: Remove unused backlight-boot-off property (Al Stone) [2122303]
- arm64: tegra: Add NVDEC to Tegra186/194 device trees (Al Stone) [2122303]
- arm64: tegra: Add new USB PHY properties on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Update HDA card name on Jetson TX2 NX (Al Stone) [2122303]
- arm64: tegra: Audio graph sound card for Jetson TX2 NX (Al Stone) [2122303]
- arm64: tegra: Add additional GPIO interrupt entries on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Fix compatible string for Tegra132 CPUs (Al Stone) [2122303]
- arm64: tegra: Add missing interconnects property for USB on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Add NVIDIA Jetson TX2 NX Developer Kit support (Al Stone) [2122303]
- arm64: tegra: Add PWM nodes on Tegra186 (Al Stone) [2122303]
- arm64: tegra194: p2888: Correct interrupt trigger type of temperature sensor (Al Stone) [2122303]
- arm64: tegra: Fix Tegra194 PCIe EP compatible string (Al Stone) [2122303]

* Thu Dec 15 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-215.el9]
- scsi: storvsc: Fix handling of srb_status and capacity change events (Mohammed Gamal) [2149711]
- redhat/Makefile: Drop message about BUILDID deprecation (Veronika Kabatova)
- pinctrl: amd: Don't save/restore interrupt status and wake status bits (David Arcari) [2130060]
- clocksource/drivers/hyperv: add data structure for reference TSC MSR (Mohammed Gamal) [2139455]
- x86/hyperv: Restore VP assist page after cpu offlining/onlining (Mohammed Gamal) [2139455]
- x86/hyperv: fix invalid writes to MSRs during root partition kexec (Mohammed Gamal) [2139455]
- x86/hyperv: Remove BUG_ON() for kmap_local_page() (Mohammed Gamal) [2139455]
- x86/hyperv: Disable hardlockup detector by default in Hyper-V guests (Mohammed Gamal) [2139455]
- x86/hyperv: fix for unwanted manipulation of sched_clock when TSC marked unstable (Mohammed Gamal) [2139455]
- x86/hyperv: Update 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139455]
- x86/hyperv: Fix 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139455]
- x86/hyperv: Replace kmap() with kmap_local_page() (Mohammed Gamal) [2139455]
- hyperv: simplify and rename generate_guest_id (Mohammed Gamal) [2139455]
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Fix the definition of vector in hv_compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Take a const cpumask in hv_compose_msi_req_get_cpu() (Mohammed Gamal) [2139460]
- PCI: hv: Fix synchronization between channel callback and hv_pci_bus_exit() (Mohammed Gamal) [2139460]
- PCI: hv: Add validation for untrusted Hyper-V values (Mohammed Gamal) [2139460]
- PCI: hv: Fix interrupt mapping for multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Fix synchronization between channel callback and hv_compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Use vmbus_requestor to generate transaction IDs for VMbus hardening (Mohammed Gamal) [2139460]
- PCI: hv: Fix multi-MSI to allow more than one MSI vector (Mohammed Gamal) [2139460]
- Drivers: hv: vmbus: fix possible memory leak in vmbus_device_register() (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: fix double free in the error path of vmbus_add_channel_work() (Mohammed Gamal) [2139472]
- Drivers: hv: fix repeated words in comments (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Split memcpy of flex-array (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Don't wait for the ACPI device upon initialization (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Use PCI_VENDOR_ID_MICROSOFT for better discoverability (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Fix kernel-doc (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Mohammed Gamal) [2139472]
- Drivers: hv: Never allocate anything besides framebuffer from framebuffer memory region (Mohammed Gamal) [2139472]
- Drivers: hv: Always reserve framebuffer region for Gen1 VMs (Mohammed Gamal) [2139472]
- Drivers: hv: remove duplicate word in a comment (Mohammed Gamal) [2139472]
- Drivers: hv: Create debugfs file with hyper-v balloon usage information (Mohammed Gamal) [2139472]
- Drivers: hv: vm_bus: Handle vmbus rescind calls after vmbus is suspended (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Release cpu lock in error case (Mohammed Gamal) [2139472]
- Drivers: hv: Fix syntax errors in comments (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Don't assign VMbus channel interrupts to isolated CPUs (Mohammed Gamal) [2139472]
- tcp: Fix build break when CONFIG_IPV6=n (Jamie Bainbridge) [2143850]
- tcp: annotate data-race around queue->synflood_warned (Jamie Bainbridge) [2143850]
- tcp: Add listening address to SYN flood message (Jamie Bainbridge) [2143850]
- tcp: Fix data-races around sysctl_tcp_syncookies. (Jamie Bainbridge) [2143850]
- redhat/configs: enable CONFIG_GNSS for RHEL (Michal Schmidt) [2136119]
- gnss: replace ida_simple API (Michal Schmidt) [2136119]

* Wed Dec 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-214.el9]
- sfc: move unmaintained message to sfc_siena (Íñigo Huguet) [2112206 2139802]
- sfc/siena: add entries for new CONFIG_SFC_SIENA* configs (Íñigo Huguet) [2112206 2139802]
- sfc: Fix an error handling path in efx_pci_probe() (Íñigo Huguet) [2112206]
- sfc: support PTP over Ethernet (Íñigo Huguet) [2112206 2139802]
- sfc: support PTP over IPv6/UDP (Íñigo Huguet) [2112206 2139802]
- sfc: allow more flexible way of adding filters for PTP (Íñigo Huguet) [2112206 2139802]
- sfc: correct filter_table_remove method for EF10 PFs (Íñigo Huguet) [2112206]
- sfc/siena: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2112206]
- sfc/siena: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2112206]
- sfc: implement ethtool get/set RX ring size for EF100 reps (Íñigo Huguet) [2112206]
- sfc: use a dynamic m-port for representor RX and set it promisc (Íñigo Huguet) [2112206]
- sfc: move table locking into filter_table_{probe,remove} methods (Íñigo Huguet) [2112206]
- sfc: insert default MAE rules to connect VFs to representors (Íñigo Huguet) [2112206]
- sfc: receive packets from EF100 VFs into representors (Íñigo Huguet) [2112206]
- sfc: check ef100 RX packets are from the wire (Íñigo Huguet) [2112206]
- sfc: determine wire m-port at EF100 PF probe time (Íñigo Huguet) [2112206]
- sfc: ef100 representor RX top half (Íñigo Huguet) [2112206]
- sfc: ef100 representor RX NAPI poll (Íñigo Huguet) [2112206]
- sfc: plumb ef100 representor stats (Íñigo Huguet) [2112206]
- sfc: disable softirqs for ptp TX (Íñigo Huguet) [2112206]
- sfc/siena: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc: attach/detach EF100 representors along with their owning PF (Íñigo Huguet) [2112206]
- sfc: hook up ef100 representor TX (Íñigo Huguet) [2112206]
- sfc: support passing a representor to the EF100 TX path (Íñigo Huguet) [2112206]
- sfc: determine representee m-port for EF100 representors (Íñigo Huguet) [2112206]
- sfc: phys port/switch identification for ef100 reps (Íñigo Huguet) [2112206]
- sfc: add basic ethtool ops to ef100 reps (Íñigo Huguet) [2112206]
- sfc: add skeleton ef100 VF representors (Íñigo Huguet) [2112206]
- sfc: detect ef100 MAE admin privilege/capability at probe time (Íñigo Huguet) [2112206]
- sfc: update EF100 register descriptions (Íñigo Huguet) [2112206]
- sfc: update MCDI protocol headers (Íñigo Huguet) [2112206]
- sfc/siena: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2112206]
- sfc: Separate netdev probe/remove from PCI probe/remove (Íñigo Huguet) [2112206]
- sfc: replace function name in string with __func__ (Íñigo Huguet) [2112206]
- sfc: Unsplit literal string. (Íñigo Huguet) [2112206]
- sfc: Move EF100 efx_nic_type structs to the end of the file (Íñigo Huguet) [2112206]
- sfc: Separate efx_nic memory from net_device memory (Íñigo Huguet) [2112206]
- sfc: Encapsulate access to netdev_priv() (Íñigo Huguet) [2112206]
- sfc: Change BUG_ON to WARN_ON and recovery code. (Íñigo Huguet) [2112206]
- sfc: Remove netdev init from efx_init_struct (Íñigo Huguet) [2112206]
- sfc: Add a PROBED state for EF100 VDPA use. (Íñigo Huguet) [2112206]
- sfc: Split STATE_READY in to STATE_NET_DOWN and STATE_NET_UP. (Íñigo Huguet) [2112206]
- sfc: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc: siena: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc/siena: Fix typo in comment (Íñigo Huguet) [2112206]
- sfc: Fix typo in comment (Íñigo Huguet) [2112206]
- sfc/siena: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2112206]
- sfc/siena: fix considering that all channels have TX queues (Íñigo Huguet) [2112206]
- sfc/siena: Remove duplicate check on segments (Íñigo Huguet) [2112206]
- sfc: siena: Have a unique wrapper ifndef for efx channels header (Íñigo Huguet) [2112206]
- eth: sfc: remove remnants of the out-of-tree napi_weight module param (Íñigo Huguet) [2112206]
- sfc: siena: Fix Kconfig dependencies (Íñigo Huguet) [2112206]
- sfc/siena: Reinstate SRIOV init/fini function calls (Íñigo Huguet) [2112206]
- sfc/siena: Make PTP and reset support specific for Siena (Íñigo Huguet) [2112206]
- sfc/siena: Make MCDI logging support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make HWMON support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make SRIOV support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make MTD support specific for Siena (Íñigo Huguet) [2112206]
- sfc: Add a basic Siena module (Íñigo Huguet) [2112206]
- sfc/siena: Inline functions in sriov.h to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in nic_common.h to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in mcdi headers to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename peripheral functions to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename RX/TX functions to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in efx headers to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Remove build references to missing functionality (Íñigo Huguet) [2112206]
- sfc: Copy shared files needed for Siena (part 2) (Íñigo Huguet) [2112206]
- sfc: Copy shared files needed for Siena (part 1) (Íñigo Huguet) [2112206]
- sfc: Move Siena specific files (Íñigo Huguet) [2112206]
- sfc: Copy a subset of mcdi_pcol.h to siena (Íñigo Huguet) [2112206]
- sfc: Disable Siena support (Íñigo Huguet) [2112206]
- sfc: add EF100 VF support via a write to sriov_numvfs (Íñigo Huguet) [2112206]
- sfc: Remove global definition of efx_reset_type_names (Íñigo Huguet) [2112206]
- sfc: Remove duplicate definition of efx_xmit_done (Íñigo Huguet) [2112206]
- sfc: efx_default_channel_type APIs can be static (Íñigo Huguet) [2112206]
- sfc: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2112206]
- sfc: ef10: Fix assigning negative value to unsigned variable (Íñigo Huguet) [2112206]
- sfc: use hardware tx timestamps for more than PTP (Íñigo Huguet) [2112206 2139802]
- drm/vc4: hdmi: Fix build error for implicit function declaration (Adrien Thierry) [2138240]
- drm/vc4: Use pm_runtime_resume_and_get to fix pm_runtime_get_sync() usage (Adrien Thierry) [2138240]
- drm/vc4: Fix build error when CONFIG_DRM_VC4=y && CONFIG_RASPBERRYPI_FIRMWARE=m (Adrien Thierry) [2138240]
- drm/vc4: Make use of the helper component_compare_dev (Adrien Thierry) [2138240]
- drm/vc4: Use drm_mode_copy() (Adrien Thierry) [2138240]
- drm/vc4: crtc: Fix runtime_pm reference counting (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Unregister codec device on unbind (Adrien Thierry) [2138240]
- drm/vc4: Use of_device_get_match_data() (Adrien Thierry) [2138240]
- drm/vc4: crtc: Fix redundant variable assignment (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Allow DBLCLK modes even if horz timing is odd. (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Don't try disabling SCDC on Pi0-3. (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Ensure we don't use 2711 HPD registers on Pi0-3 (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Simplify the connector state retrieval (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Change CSC callback prototype (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Define colorspace matrices (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Replace CSC_CTL hardcoded value by defines (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Move XBAR setup to csc_setup (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Use full range helper in csc functions (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Add full range RGB helper (Adrien Thierry) [2138240]
- drm/edid: Rename drm_hdmi_avi_infoframe_colorspace to _colorimetry (Adrien Thierry) [2138240]
- drm/vc4: Fix deadlock on DSI device attach error (Adrien Thierry) [2138240]
- drm/vc4: remove redundant assignment of variable size (Adrien Thierry) [2138240]
- drm/vc4: Notify the firmware when DRM is in charge (Adrien Thierry) [2138240]
- drm/vc4: Remove conflicting framebuffers before callind bind_all (Adrien Thierry) [2138240]
- drm/vc4: Support nomodeset (Adrien Thierry) [2138240]
- firmware: raspberrypi: Add RPI_FIRMWARE_NOTIFY_DISPLAY_DONE (Adrien Thierry) [2138240]
- drm/vc4: plane: Add support for YUV color encodings and ranges (Adrien Thierry) [2138240]
- drm/vc4: plane: Add support for DRM_FORMAT_P030 (Adrien Thierry) [2138240]
- drm/vc4: kms: Wait for the commit before increasing our clock rate (Adrien Thierry) [2138240]
- drm: Remove CONFIG_DRM_KMS_CMA_HELPER option (Adrien Thierry) [2138240]
- drm/cma-helper: Pass GEM CMA object in public interfaces (Adrien Thierry) [2138240]
- drm/cma-helper: Export dedicated wrappers for GEM object functions (Adrien Thierry) [2138240]
- drm/vc4: kms: Fix previous HVS commit wait (Adrien Thierry) [2138240]
- drm/vc4: kms: Don't duplicate pending commit (Adrien Thierry) [2138240]
- drm/vc4: kms: Clear the HVS FIFO commit pointer once done (Adrien Thierry) [2138240]
- drm/vc4: kms: Add missing drm_crtc_commit_put (Adrien Thierry) [2138240]
- drm/vc4: kms: Fix return code check (Adrien Thierry) [2138240]
- drm/vc4: fix error code in vc4_create_object() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Introduce a scdc_enabled flag (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Introduce an output_enabled flag (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Check the device state in prepare() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Prevent access to crtc->state outside of KMS (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Use a mutex to prevent concurrent framework access (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Add a spinlock to protect register access (Adrien Thierry) [2138240]
- drm/vc4: crtc: Copy assigned channel to the CRTC (Adrien Thierry) [2138240]
- drm/vc4: Fix non-blocking commit getting stuck forever (Adrien Thierry) [2138240]
- drm/vc4: crtc: Drop feed_txp from state (Adrien Thierry) [2138240]
- drm/vc4: Increase the core clock based on HVS load (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Enable the scrambler on reconnection (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Raise the maximum clock rate (Adrien Thierry) [2138240]
- drm/vc4: Leverage the load tracker on the BCM2711 (Adrien Thierry) [2138240]
- drm/vc4: crtc: Add some logging (Adrien Thierry) [2138240]
- drm/vc4: crtc: Rework the encoder retrieval code (again) (Adrien Thierry) [2138240]
- drm/vc4: crtc: Add encoder to vc4_crtc_config_pv prototype (Adrien Thierry) [2138240]
- drm/vc4: Make vc4_crtc_get_encoder public (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Fix HPD GPIO detection (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove the DDC probing for status detection (Adrien Thierry) [2138240]
- drm/vc4: crtc: Make sure the HDMI controller is powered when disabling (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Warn if we access the controller while disabled (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the device is powered with CEC (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Split the CEC disable / enable functions in two (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Rework the pre_crtc_configure error handling (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the controller is powered up during bind (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the controller is powered in detect (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Move the HSM clock enable to runtime_pm (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set a default HSM rate (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove unused struct (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Actually check for the connector status in hotplug (Adrien Thierry) [2138240]
- Revert "drm/vc4: hdmi: Remove drm_encoder->crtc usage" (Adrien Thierry) [2138240]
- Revert drm/vc4 hdmi runtime PM changes (Adrien Thierry) [2138240]
- drm/vc4: dsi: Switch to devm_drm_of_get_bridge (Adrien Thierry) [2138240]
- drm/vc4: dpi: Switch to devm_drm_of_get_bridge (Adrien Thierry) [2138240]
- drm/vc4: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: make vc4_hdmi_codec_pdata static (Adrien Thierry) [2138240]
- drm/vc4: Convert to Linux IRQ interfaces (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove unused struct (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove redundant variables (Adrien Thierry) [2138240]
- drm/bridge: Centralize error message when bridge attach fails (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove drm_encoder->crtc usage (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Only call into DRM framework if registered (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Drop devm interrupt handler for hotplug interrupts (Adrien Thierry) [2138240]
- drm: vc4: Fix pixel-wrap issue with DVP teardown (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Limit noise when deferring snd card registration (Adrien Thierry) [2138240]
- drm/aperture: Pass DRM driver structure instead of driver name (Adrien Thierry) [2138240]
- drm/vc4: Don't set struct drm_device.irq_enabled (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Register HDMI codec (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove firmware logic for MAI threshold setting (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set VC4_HDMI_MAI_CONFIG_FORMAT_REVERSE (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set HDMI_MAI_FMT (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set HD_CTL_WHOLSMP and HD_CTL_CHALIGN_SET (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Rely on interrupts to handle hotplug (Adrien Thierry) [2138240]

* Wed Dec 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-213.el9]
- redhat: configs: disable vDPA on all archs except x86_64 (Laurent Vivier) [2140885]
- pipe: Fix missing lock in pipe_resize_ring() (Ian Kent) [2141632] {CVE-2022-2959}
- NFSD: Protect against send buffer overflow in NFSv3 READ (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READ (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv3 READDIR (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READDIR (Scott Mayhew) [2141770] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_encode's buflen calculation (Scott Mayhew) [2141770] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_decode's end-of-buffer calculation (Scott Mayhew) [2141770] {CVE-2022-43945}
- block: change request end_io handler to pass back a return value (Eric Chanudet) [2139205]
- block: Change the return type of blk_mq_map_queues() into void (Eric Chanudet) [2139205]
- block: simplify disk shutdown (Eric Chanudet) [2139205]
- scsi: ufs: Split the drivers/scsi/ufs directory (Eric Chanudet) [2139205]
- blk-mq: remove the done argument to blk_execute_rq_nowait (Eric Chanudet) [2139205]
- i40e: Fix error handling in i40e_init_module() (Stefan Assmann) [2104466]
- i40e: Add appropriate error message logged for incorrect duplex setting (Stefan Assmann) [2104466]
- i40e: Add i40e_napi_poll tracepoint (Stefan Assmann) [2104466]
- i40e: Record number of RXes cleaned during NAPI (Stefan Assmann) [2104466]
- i40e: Record number TXes cleaned during NAPI (Stefan Assmann) [2104466]
- i40e: Store the irq number in i40e_q_vector (Stefan Assmann) [2104466]
- ptp: introduce helpers to adjust by scaled parts per million (Stefan Assmann) [2104466]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2104466]
- i40e: Fix flow-type by setting GL_HASH_INSET registers (Stefan Assmann) [2104466]
- i40e: Fix VF hang when reset is triggered on another VF (Stefan Assmann) [2104466]
- i40e: Fix ethtool rx-flow-hash setting for X722 (Stefan Assmann) [2104466]
- i40e: Fix DMA mappings leak (Stefan Assmann) [2104466]
- i40e: add description and modify interrupts configuration procedure (Stefan Assmann) [2104466]
- i40e: Add basic support for I710 devices (Stefan Assmann) [2104466]
- i40e: Fix set max_tx_rate when it is lower than 1 Mbps (Stefan Assmann) [2104466]
- i40e: Fix VF set max MTU size (Stefan Assmann) [2104466]
- i40e: Fix ADQ rate limiting for PF (Stefan Assmann) [2104466]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2104466]
- i40e: Fix incorrect address type for IPv6 flow rules (Stefan Assmann) [2104466]
- i40e: Fix to stop tx_timeout recovery if GLOBR fails (Stefan Assmann) [2104466]
- i40e: convert .adjfreq to .adjfine (Stefan Assmann) [2104466]
- i40e: use mul_u64_u64_div_u64 for PTP frequency calculation (Stefan Assmann) [2104466]
- i40e: Fix interface init with MSI interrupts (no MSI-X) (Stefan Assmann) [2104466]
- i40e: Refactor tc mqprio checks (Stefan Assmann) [2104466]
- i40e: Fix erroneous adapter reinitialization during recovery process (Stefan Assmann) [2104466]
- i40e: Fix VF's MAC Address change on VM (Stefan Assmann) [2104466]
- i40e: Fix dropped jumbo frames statistics (Stefan Assmann) [2104466]
- intel/i40e:fix repeated words in comments (Stefan Assmann) [2104466]
- intel: remove unused macros (Stefan Assmann) [2104466]
- i40e: read the XDP program once per NAPI (Stefan Assmann) [2104466]
- intel/i40e: delete if NULL check before dev_kfree_skb (Stefan Assmann) [2104466]
- i40e: Remove unnecessary synchronize_irq() before free_irq() (Stefan Assmann) [2104466]
- i40e: Add support for ethtool -s <interface> speed <speed in Mb> (Stefan Assmann) [2104466]
- i40e: Add VF VLAN pruning (Stefan Assmann) [2104466]
- ethernet: constify references to netdev->dev_addr in drivers (Stefan Assmann) [2104466]

* Tue Dec 13 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-212.el9]
- udp: track the forward memory release threshold in an hot cacheline (Paolo Abeni) [2133057]
- net: introduce and use custom sockopt socket flag (Paolo Abeni) [2133057]
- bpf: Change bpf_setsockopt(SOL_SOCKET) to reuse sk_setsockopt() (Paolo Abeni) [2133057]
- net: Add sk_setsockopt() to take the sk ptr instead of the sock ptr (Paolo Abeni) [2133057]
- net: skb: introduce and use a single page frag cache (Paolo Abeni) [2133057]
- net: add napi_get_frags_check() helper (Paolo Abeni) [2133057]
- libceph: clean up ceph_osdc_start_request prototype (Xiubo Li) [2120166]
- rbd: replace usage of found with dedicated list iterator variable (Xiubo Li) [2120166]
- libceph: fix ceph_pagelist_reserve() comment typo (Xiubo Li) [2120166]
- ceph: don't truncate file in atomic_open (Xiubo Li) [2120166]
- ceph: make f_bsize always equal to f_frsize (Xiubo Li) [2120166]
- libceph: print fsid and epoch with osd id (Xiubo Li) [2120166]
- libceph: check pointer before assigned to "c->rules[]" (Xiubo Li) [2120166]
- ceph: update the auth cap when the async create req is forwarded (Xiubo Li) [2120166]
- ceph: make change_auth_cap_ses a global symbol (Xiubo Li) [2120166]
- ceph: fix incorrect old_size length in ceph_mds_request_args (Xiubo Li) [2120166]
- ceph: convert to generic_file_llseek (Xiubo Li) [2120166]
- ceph: fix the incorrect comment for the ceph_mds_caps struct (Xiubo Li) [2120166]
- ceph: don't leak snap_rwsem in handle_cap_grant (Xiubo Li) [2120166]
- ceph: prevent a client from exceeding the MDS maximum xattr size (Xiubo Li) [2120166]
- ceph: choose auth MDS for getxattr with the Xs caps (Xiubo Li) [2120166]
- ceph: add session already open notify support (Xiubo Li) [2120166]
- ceph: wait for the first reply of inflight async unlink (Xiubo Li) [2120166]
- fs/dcache: export d_same_name() helper (Xiubo Li) [2120166]
- ceph: remove useless CEPHFS_FEATURES_CLIENT_REQUIRED (Xiubo Li) [2120166]
- ceph: use correct index when encoding client supported features (Xiubo Li) [2120166]
- ceph: switch TASK_INTERRUPTIBLE to TASK_KILLABLE (Xiubo Li) [2120166]
- ceph: remove redundant variable ino (Xiubo Li) [2120166]
- ceph: try to queue a writeback if revoking fails (Xiubo Li) [2120166]
- ceph: fix statfs for subdir mounts (Xiubo Li) [2120166]
- ceph: try to choose the auth MDS if possible for getattr (Xiubo Li) [2120166]
- ceph: disable updating the atime since cephfs won't maintain it (Xiubo Li) [2120166]
- ceph: flush the mdlog for filesystem sync (Xiubo Li) [2120166]
- ceph: rename unsafe_request_wait() (Xiubo Li) [2120166]
- libceph: use swap() macro instead of taking tmp variable (Xiubo Li) [2120166]
- ceph: fix statx AT_STATX_DONT_SYNC vs AT_STATX_FORCE_SYNC check (Xiubo Li) [2120166]
- ceph: use dedicated list iterator variable (Xiubo Li) [2120166]
- ceph: update the dlease for the hashed dentry when removing (Xiubo Li) [2120166]
- ceph: stop retrying the request when exceeding 256 times (Xiubo Li) [2120166]
- ceph: stop forwarding the request when exceeding 256 times (Xiubo Li) [2120166]
- ceph: remove unused CEPH_MDS_LEASE_RELEASE related code (Xiubo Li) [2120166]
- ceph: allow ceph.dir.rctime xattr to be updatable (Xiubo Li) [2120166]
- powercap: RAPL: Add Power Limit4 support for Alder Lake-N and Raptor Lake-P (David Arcari) [2106144]
- powercap: intel_rapl: remove redundant store to value after multiply (David Arcari) [2106144]
- powercap: RAPL: Add Power Limit4 support for RaptorLake (David Arcari) [2106144]
- powercap: intel_rapl: support new layout of Psys PowerLimit Register on SPR (David Arcari) [2106144]
- powercap: Add Power Limit4 support for Alder Lake SoC (David Arcari) [2106144]
- Revert "Merge: Backport Aspeed conversion to shmem" (Herton R. Krzesinski)

* Mon Dec 12 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-211.el9]
- RDMA/core: Fix null-ptr-deref in ib_core_cleanup() (Kamal Heib) [2120668]
- IB/hfi1: Correctly move list in sc_disable() (Kamal Heib) [2120668]
- RDMA/cma: Use output interface for net_dev check (Kamal Heib) [2120668]
- RDMA/usnic: fix set-but-not-unused variable 'flags' warning (Kamal Heib) [2120668]
- IB/rdmavt: Add __init/__exit annotations to module init/exit funcs (Kamal Heib) [2120668]
- IB: Set IOVA/LENGTH on IB_MR in core/uverbs layers (Kamal Heib) [2120668]
- RDMA/cm: Use SLID in the work completion as the DLID in responder side (Kamal Heib) [2120668]
- RDMA/siw: Fix QP destroy to wait for all references dropped. (Kamal Heib) [2120668]
- RDMA/srp: Fix srp_abort() (Kamal Heib) [2120668]
- RDMA/irdma: Validate udata inlen and outlen (Kamal Heib) [2120668]
- RDMA/irdma: Align AE id codes to correct flush code and event (Kamal Heib) [2120668]
- vgacon: Propagate console boot parameters before calling `vc_resize' (Mohammed Gamal) [2141944]
- cifs: fix uninitialized pointer in error case in dfs_cache_get_tgt_share (Ronnie Sahlberg) [2145009]
- cifs: skip trailing separators of prefix paths (Ronnie Sahlberg) [2145009]
- cifs: use new enum for ses_status (Ronnie Sahlberg) [2145009]
- cifs: fix minor compile warning (Ronnie Sahlberg) [2145009]
- cifs: return ENOENT for DFS lookup_cache_entry() (Ronnie Sahlberg) [2145009]
- cifs: use correct lock type in cifs_reconnect() (Ronnie Sahlberg) [2145009]
- cifs: force new session setup and tcon for dfs (Ronnie Sahlberg) [2145009]
- smb3: cleanup and clarify status of tree connections (Ronnie Sahlberg) [2145009]
- cifs: remove repeated state change in dfs tree connect (Ronnie Sahlberg) [2145009]
- cifs: skip extra NULL byte in filenames (Ronnie Sahlberg) [2145009]
- cifs: don't call cifs_dfs_query_info_nonascii_quirk() if nodfs was set (Ronnie Sahlberg) [2145009]
- cifs: quirk for STATUS_OBJECT_NAME_INVALID returned for non-ASCII dfs refs (Ronnie Sahlberg) [2145009]
- cifs: alloc_path_with_tree_prefix: do not append sep. if the path is empty (Ronnie Sahlberg) [2145009]
- Enable the Tegra186 timer (Al Stone) [2129130]
- clocksource/drivers/timer-tegra186: Add support for Tegra234 SoC (Al Stone) [2129130]
- clocksource: Add Tegra186 timers support (Al Stone) [2129130]
- hv_netvsc: Fix race between VF offering and VF association message from host (Mohammed Gamal) [2139466]
- clocksource: hyper-v: unexport __init-annotated hv_init_clocksource() (Mohammed Gamal) [2139464]
- net: mana: Add rmb after checking owner bits (Mohammed Gamal) [2139461]
- net: mana: Add support of XDP_REDIRECT action (Mohammed Gamal) [2139461]
- net: mana: Add the Linux MANA PF driver (Mohammed Gamal) [2139461]
- drm/ast: Avoid reprogramming primary-plane scanout address (Jocelyn Falempe) [2128599]
- drm/ast: Convert ast to SHMEM (Jocelyn Falempe) [2128599]
- drm/ast: Style cleanups in plane code (Jocelyn Falempe) [2128599]
- drm/ast: Rename struct ast_cursor_plane to struct ast_plane (Jocelyn Falempe) [2128599]
- drm/ast: Remove cursor double buffering (Jocelyn Falempe) [2128599]
- drm/ast: Do not call drm_atomic_add_affected_planes() (Jocelyn Falempe) [2128599]
- drm/ast: Call drm_atomic_helper_check_plane_state() unconditionally (Jocelyn Falempe) [2128599]
- drm/ast: Acquire I/O-register lock in atomic_commit_tail function (Jocelyn Falempe) [2128599]
- drm/ast: Add Atomic gamma lut support for aspeed (Jocelyn Falempe) [2128599]
- drm/ast: make ast_modeset static (Jocelyn Falempe) [2128599]
- drm/ast: Fix video broken in some resolutions on ast2600 (Jocelyn Falempe) [2128599]
- drm/ast: Add resolution support for 1152x864@75 (Jocelyn Falempe) [2128599]
- misc: rtsx: rts522a rts5228 rts5261 support Runtime PM (Mark Pearson) [2120778]
- misc: rtsx: conditionally build rtsx_pm_power_saving() (Mark Pearson) [2120778]
- misc: rtsx: Quiesce rts5249 on system suspend (Mark Pearson) [2120778]
- misc: rtsx: Cleanup power management ops (Mark Pearson) [2120778]
- misc: rtsx: Rework runtime power management flow (Mark Pearson) [2120778]

* Fri Dec 09 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-210.el9]
- NFSD: Mark exports of NFS as unsupported (Benjamin Coddington) [2150887]
- bonding: get correct NA dest address (Jonathan Toppins) [2112748]
- bonding: fix ICMPv6 header handling when receiving IPv6 messages (Jonathan Toppins) [2112748]
- mmc: cqhci: Provide helper for resetting both SDHCI and CQHCI (Steve Best) [2122404]
- mmc: sdhci-tegra: Fix SDHCI_RESET_ALL for CQHCI (Steve Best) [2122404]
- mmc: sdhci-tegra: Use actual clock rate for SW tuning correction (Steve Best) [2122404]
- mmc: sdhci-tegra: Use of_device_get_match_data() helper (Steve Best) [2122404]
- mmc: sdhci-tegra: Enable wake on SD card event (Steve Best) [2122404]
- mmc: sdhci-tegra: Add runtime PM and OPP support (Steve Best) [2122404]
- mmc: sdhci-tegra: Fix switch to HS400ES mode (Steve Best) [2122404]
- Enable LinuxRV in Config (Alessandro Carminati) [2129758]
- rv/dot2c: Make automaton definition static (Alessandro Carminati) [2129758]
- rv/monitor: Add __init/__exit annotations to module init/exit funcs (Alessandro Carminati) [2129758]
- rv/dot2K: add 'static' qualifier for local variable (Alessandro Carminati) [2129758]
- rv/monitors: add 'static' qualifier for local symbols (Alessandro Carminati) [2129758]
- rv/reactor: add __init/__exit annotations to module init/exit funcs (Alessandro Carminati) [2129758]
- rv: Unlock on error path in rv_unregister_reactor() (Alessandro Carminati) [2129758]
- MAINTAINERS: Add Runtime Verification (RV) entry (Alessandro Carminati) [2129758]
- rv/monitors: Make monitor's automata definition static (Alessandro Carminati) [2129758]
- rv/reactor: Add the panic reactor (Alessandro Carminati) [2129758]
- rv/reactor: Add the printk reactor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wwnr monitor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wip monitor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wip monitor skeleton created by dot2k (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automata instrumentation documentation (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automata monitor synthesis documentation (Alessandro Carminati) [2129758]
- tools/rv: Add dot2k (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automaton documentation (Alessandro Carminati) [2129758]
- tools/rv: Add dot2c (Alessandro Carminati) [2129758]
- Documentation/rv: Add a basic documentation (Alessandro Carminati) [2129758]
- rv/include: Add instrumentation helper functions (Alessandro Carminati) [2129758]
- rv/include: Add deterministic automata monitor definition via C macros (Alessandro Carminati) [2129758]
- rv/include: Add helper functions for deterministic automata (Alessandro Carminati) [2129758]
- rv: Add runtime reactors interface (Alessandro Carminati) [2129758]
- rv: Add Runtime Verification (RV) interface (Alessandro Carminati) [2129758]
- tracing: make tracer_init_tracefs initcall asynchronous (Alessandro Carminati) [2129758]
- fs: dlm: fix race in lowcomms (Alexander Aring) [2110543]
- EDAC/ghes: Set the DIMM label unconditionally (Aristeu Rozanski) [2109713]

* Thu Dec 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-209.el9]
- RHEL: ALSA: update configuration (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-mtl: fix firmware name (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Correct pin configs for ASUS G533Z (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: remove ALC289_FIXUP_DUAL_SPK for Dell 5530 (Jaroslav Kysela) [2125537]
- ALSA: ac97: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: ca0106: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: control: add snd_ctl_rename() (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix build error unused-function (Jaroslav Kysela) [2125537]
- ACPI: utils: Add api to read _SUB from ACPI (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: use regmap_read_poll_timeout_atomic to poll I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: use regmap_read_poll_timeout to poll I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: wcd-mbhc-v2: remove useless initialization (Jaroslav Kysela) [2125537]
- ALSA: aoa: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- sound:spi: remove reference to AVR32 in Atmel AT73C213 DAC driver (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: xilinx: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: xilinx: Suppress second error message about reset failure in .remove() (Jaroslav Kysela) [2125537]
- ASoC: ux500: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ux500: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ux500: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: ux500: mop500: Check before clk_put() not needed (Jaroslav Kysela) [2125537]
- ASoC: ux500: Remove some leftover from the "Replace GPLv2 boilerplate/reference with SPDX" rules (Jaroslav Kysela) [2125537]
- ASoC: ti: osk5912: Make it CCF clk API compatible (Jaroslav Kysela) [2125537]
- ASoC: ti: omap-mcbsp: duplicate sysfs error (Jaroslav Kysela) [2125537]
- ASoC: ti: j721e-evm: Fix refcount leak in j721e_soc_probe_* (Jaroslav Kysela) [2125537]
- ASoC: ti: davinci-mcasp: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: ti: davinci-mcasp: Add dma-type for bcdma (Jaroslav Kysela) [2125537]
- ASoC: ti: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ti: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ti: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: tegra: Fix clock DAI format on Tegra210 (Jaroslav Kysela) [2125537]
- ASoC: tegra: AHUB routes for OPE module (Jaroslav Kysela) [2125537]
- ASoC: tegra: AHUB routes for ASRC module (Jaroslav Kysela) [2125537]
- ASoC: tegra: delete a semicolon (Jaroslav Kysela) [2125537]
- ASoC: tegra: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: tegra: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Drop write-only driver data member (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Make helper functions return void (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Get rid of global pointer for driver data (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Remove unused function tegra20_das_read (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Fold header file into only user (Jaroslav Kysela) [2125537]
- ASoC: tegra20_ac97: Fix missing error code in tegra20_ac97_platform_probe() (Jaroslav Kysela) [2125537]
- ASoC: tegra: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: tegra: Fix MBDRC bypass mode check (Jaroslav Kysela) [2125537]
- ASoC: tegra: Add Tegra210 based OPE driver (Jaroslav Kysela) [2125537]
- ASoC: tegra186_asrc: mark runtime-pm functions as __maybe_unused (Jaroslav Kysela) [2125537]
- ASoC: tegra: Add Tegra186 based ASRC driver (Jaroslav Kysela) [2125537]
- ASoC: sun8i-codec: Partial revert to fix clock specifiers (Jaroslav Kysela) [2125537]
- ASoC: sun50i-codec-analog: Add support for internal bias (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sunxi: sun4i-i2s: update kernel-doc (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Use {regmap/regmap_field}_{set/clear}_bits helpers (Jaroslav Kysela) [2125537]
- ASoC: stm32: sai: Remove useless define (Jaroslav Kysela) [2125537]
- ASoC: stm: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: stm: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: stm32: dfsdm: fix typo in comment (Jaroslav Kysela) [2125537]
- ASoC: stm32: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sti-uniperf: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: report error on stream not opened (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: SOF: Kconfig: Make IPC_FLOOD_TEST depend on SND_SOC_SOF (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care default case on rsnd_ssiu_busif_err_status_clear() (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_probe() error path (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Release the DMA channels in rz_ssi_probe() error path (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Propagate error codes returned from platform_get_irq_byname() (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Drop SSIFSR_TDC and SSIFSR_RDC macros (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care default case on rsnd_ssiu_busif_err_irq_ctrl() (Jaroslav Kysela) [2125537]
- ASoC: rsnd: ssiu: add missing .quit callback for gen2 (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care return value from rsnd_node_fixed_index() (Jaroslav Kysela) [2125537]
- ASoC: rsnd: Emit useful error messages in .remove() (Jaroslav Kysela) [2125537]
- ASoC: sh: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sh: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sh: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: rsnd: use inclusive language for DAIFMT mask (Jaroslav Kysela) [2125537]
- ASoC: sh: Make SND_SOC_RZ depend on ARCH_RZG2L (Jaroslav Kysela) [2125537]
- ASoC: samsung: Enable compile test (Jaroslav Kysela) [2125537]
- ASoC: samsung: spdif: remove unnecessary check of mem_res (Jaroslav Kysela) [2125537]
- ASoC: samsung: snow: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c24xx-i2s: Drop unneeded gpio.h include (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c24xx-i2s: Fix typo in DAIFMT handling (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c-i2s-v2: Allow build for unsupported hardware (Jaroslav Kysela) [2125537]
- ASoC: samsung: change gpiod_speaker_power and rx1950_audio from global to static variables (Jaroslav Kysela) [2125537]
- ASoC: samsung: change neo1973_audio from a global to static (Jaroslav Kysela) [2125537]
- ASoC: samsung: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: samsung: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: samsung: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: samsung: h1940_uda1380: include proepr GPIO consumer header (Jaroslav Kysela) [2125537]
- ASoC: samsung: Constify snd_soc_dapm_{route,widget} structs (Jaroslav Kysela) [2125537]
- ASoC: samsung: Fix error handling in aries_audio_probe (Jaroslav Kysela) [2125537]
- ASoC: samsung: Fix refcount leak in aries_audio_probe (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s_tdm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: dt-bindings: Add bindings for WCD9335 DAIs (Jaroslav Kysela) [2125537]
- MAINTAINERS: add ASoC Qualcomm codecs (Jaroslav Kysela) [2125537]
- ASoC: rockchip: pdm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix NULL pointer dereference when pinctrl is not found (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix error code when fail to read I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: rockchip-i2s: Undo BCLK pinctrl changes (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix NULL pointer dereference when pinctrl is not found (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: rockchip: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: qcom: sm8250: add missing module owner (Jaroslav Kysela) [2125537]
- ASoC: qcom: Add driver support for audioreach solution (Jaroslav Kysela) [2125537]
- ASoC: qcom: SC7280: Update machine driver startup, shutdown callbacks (Jaroslav Kysela) [2125537]
- ASoC: qcom: Use MCLK as RT5682I-VS sysclk source (Jaroslav Kysela) [2125537]
- ASoC: qcom: Add driver support for ALC5682I-VS (Jaroslav Kysela) [2125537]
- ASoC: q6asm: use kcalloc() instead of kzalloc() (Jaroslav Kysela) [2125537]
- ASoC: qdsp6: q6apm-dai: unprepare stream if its already prepared (Jaroslav Kysela) [2125537]
- ASoC: qcom: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: q6adm: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: qcom: lpass: Fix apq8016 compat string to match yaml (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Fix refcount leak in mxs_saif_probe (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: qdsp6: fix potential memory leak in q6apm_get_audioreach_graph() (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: remove spurious space (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: Fix an off-by-one in q6adm_alloc_copp() (Jaroslav Kysela) [2125537]
- ASoC: qcom: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: qcom: lpass-platform: Update memremap flag to MEMREMAP_WC (Jaroslav Kysela) [2125537]
- ASoC: qcom: Fix missing of_node_put() in asoc_qcom_lpass_cpu_platform_probe() (Jaroslav Kysela) [2125537]
- ASoC: qcom: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: pxa: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: pxa: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: pxa: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: meson: remove useless initialization (Jaroslav Kysela) [2125537]
- ASoC: meson: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: meson: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: meson: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: meson: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: remove unnecessary NULL check (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195-mt6359: Properly register sound card for SOF (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: Fix build warning without CONFIG_OF (Jaroslav Kysela) [2125537]
- ASoC: mediatek: simplify the return expression of mtk_dai_pcm_prepare() (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8173-rt5650: Fix refcount leak in mt8173_rt5650_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8173: Fix refcount leak in mt8173_rt5650_rt5676_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: remove unnecessary check of clk_disable_unprepare (Jaroslav Kysela) [2125537]
- ASoC: mt6797-mt6351: Fix refcount leak in mt6797_mt6351_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Fix missing of_node_put in mt2701_wm8960_machine_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: support rt1015p_rt5682s (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: refactor for I2S8/I2S9 DAI links of headset (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: refactor for I2S3 DAI link of speaker (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: fix Kconfig dependency (Jaroslav Kysela) [2125537]
- ASoC: img-spdif-in: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: extract SOF common code (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: fix DMIC record noise (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: remove unnecessary judgments (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: set the correct string to strncmp() (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add machine driver with mt6366, rt1019 and rt5682s (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add machine driver with mt6366, da7219 and max98357 (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add mt8186-mt6366 common driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Remove condition with no effect (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Fix mutex double unlock in GPIO request (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Use new direct clock defines (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Fix a handful of spelling mistakes (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add misc driver and register definitions (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support gpio control in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support audio clock control in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support tdm in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support src in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support pcm in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support i2s in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support hw gain in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support hostless in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support adda in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support audsys clock control (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Remove unused 'mem' resource (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Refactor DMA channel setup (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2c: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: js4740-i2s: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Remove Open Firmware dependency (Jaroslav Kysela) [2125537]
- ASoC: img-spdif-out: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: img-parallel-out: using pm_runtime_resume_and_get (Jaroslav Kysela) [2125537]
- ASoC: img: img-i2s-out: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img-i2s-in: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: img: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: fsl: pcm030-audio-fabric: use platform_device_unregsiter() (Jaroslav Kysela) [2125537]
- ASoC: fsl: Fix refcount leak in imx_sgtl5000_probe (Jaroslav Kysela) [2125537]
- ASoC: imx-hdmi: remove useless null check before call of_node_put() (Jaroslav Kysela) [2125537]
- ASoC: imx-card: Fix refcount issue with of_node_put (Jaroslav Kysela) [2125537]
- ASoC: imx-card: use snd_pcm_format_t type for asrc_format (Jaroslav Kysela) [2125537]
- ASoC: imx-audmux: Silence a clang warning (Jaroslav Kysela) [2125537]
- ASoC: imx-card: Fix DSD/PDM mclk frequency (Jaroslav Kysela) [2125537]
- ASoC: imx-audmux: remove unnecessary check of clk_disable_unprepare/clk_prepare_enable (Jaroslav Kysela) [2125537]
- ASoC: fsl_xcvr:Fix unbalanced pm_runtime_enable in fsl_xcvr_probe (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Drop usage of __clk_get_name() (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Don't use plain integer as NULL pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Add function to handle PLL clock source (Jaroslav Kysela) [2125537]
- ASoC: fsl_ssi: Add support multi fifo script (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: Add support for i.MX93 platform (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: Fix supported clock DAI format (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: simplify the code with adding fsl_mqs_soc_data (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: fix the naming style for mask definition (Jaroslav Kysela) [2125537]
- ASoC: fsl: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: fsl_aud2htx: Add error handler for pm_runtime_enable (Jaroslav Kysela) [2125537]
- ASoC: fsl_easrc: use snd_pcm_format_t type for sample_format (Jaroslav Kysela) [2125537]
- ASoC: fsl_aud2htx: register platform component before registering cpu dai (Jaroslav Kysela) [2125537]
- ASoC: fsl: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Fix FSL_SAI_xDR/xFR definition (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add DSD bit format support (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: enable dual fifo for ASRC P2P (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: Use dmaengine_terminate_async() (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc: force cast the asrc_format type (Jaroslav Kysela) [2125537]
- ASoC: fsl-asoc-card: force cast the asrc_format type (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: fix incorrect mclk number in error message (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Don't use plain integer as NULL pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for PLL switch at runtime (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Configure dataline/FIFO information from dts property (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Make res a member of struct fsl_sai (Jaroslav Kysela) [2125537]
- ASoc: fsl_sai: Add pinctrl operation for PDM and DSD (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for more sample rates (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add PDM daifmt support (Jaroslav Kysela) [2125537]
- ASoC: fsl: fsl_sai: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Enable MCTL_MCLK_EN bit for master mode (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: add error message in case of missing imx-pcm-dma support (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: use local device pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: fsl: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8MN (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8ULP (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8M Plus (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8MM (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add support for PLL switch at runtime (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: change micfil default settings (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: fold fsl_set_clock_params() into its only user (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop only once used defines (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop unused include (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: rework quality setting (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: simplify clock setting (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop get_pdm_clk() (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use define for OSR default value (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: add multi fifo support (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop unused variables (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop error messages from failed register accesses (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use clear/set bits (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use GENMASK to define register bit fields (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: do not define SHIFT/MASK for single bits (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop fsl_micfil_set_mclk_rate() (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop unused register read (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop unnecessary register read (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop support for undocumented property (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Remove debug message (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add support for i.MX8MPlus (Jaroslav Kysela) [2125537]
- ASoC: fsl_spdif: Add support for PLL switch at runtime. (Jaroslav Kysela) [2125537]
- ASoC: dwc: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: dwc: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: dwc: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: handle timeouts in resume path (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: fix warning using-module-alias-sdw.cocci (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: add missing break statement (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: add control, dapm widgets and map (Jaroslav Kysela) [2125537]
- ASoC: wcd938x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wcd938x: Fix event generation for some controls (Jaroslav Kysela) [2125537]
- ASoC: wcd934x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: tlv320adcx140: Fix tx_mask check (Jaroslav Kysela) [2125537]
- ASoC: tlv320adcx140: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320adc3xxx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320adc3xxx: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: codecs: tfa989x: Add support for tfa9890 (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: rk817: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: nau8822: Don't reconfigure PLL to the same values (Jaroslav Kysela) [2125537]
- ASoC: madera: Fix event generation for rate controls (Jaroslav Kysela) [2125537]
- ASoC: madera: Fix event generation for OUT1 demux (Jaroslav Kysela) [2125537]
- ASoC: codecs: lpass: Fix passing zero to 'PTR_ERR' (Jaroslav Kysela) [2125537]
- ASoC: codecs: Fix error handling in power domain init and exit handlers (Jaroslav Kysela) [2125537]
- ASoC: codecs: va-macro: use fsgen as clock (Jaroslav Kysela) [2125537]
- ASoC: lm49453: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: codecs: da7210: add check for i2c_add_driver (Jaroslav Kysela) [2125537]
- ASoC: cs47l92: Fix event generation for OUT1 demux (Jaroslav Kysela) [2125537]
- ASoC: cs4234: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Make cs35l45_remove() return void (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Remove incorrect comment (Jaroslav Kysela) [2125537]
- ASoC: cros_ec_codec: Fix refcount leak in cros_ec_codec_platform_probe (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2125537]
- ASoC: cros_ec_codec: Add endianness flag in i2s_rx_component_driver (Jaroslav Kysela) [2125537]
- ASoC: add tas2780 driver (Jaroslav Kysela) [2125537]
- ASoC: codecs: add wsa883x amplifier support (Jaroslav Kysela) [2125537]
- ASoC: rt1016: enable building (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: add and remove black line around MODULE_DEVICE_TABLE() (Jaroslav Kysela) [2125537]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_30.RULE (part 2) (Jaroslav Kysela) [2125537]
- ASoC: bcm: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: bcm: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sam9g20_wm8731: Simplify some error message (Jaroslav Kysela) [2125537]
- ASoC: sam9g20_wm8731: Use dev_err_probe() for snd_soc_register_card() (Jaroslav Kysela) [2125537]
- ASoC: bcm: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: au1x: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: au1x: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: au1x: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: atmel: Fix error handling in at91samg20ek probe() (Jaroslav Kysela) [2125537]
- ASoC: atmel: Don't squash error codes from atmel_ssc_set_audio() (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: return directly ret (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: Fix clang -Wbitfield-constant-conversion (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: remove references to mchp_i2s_caps (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdifrx: disable end of block interrupt on failures (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdifrx: use single tab indent for structure (Jaroslav Kysela) [2125537]
- ASoC: atmel: mchp-pdmc: remove space in front of mchp_pdmc_dt_init() (Jaroslav Kysela) [2125537]
- ASoC: atmel: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: atmel: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: atmel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: atmel-pdmic: Remove endianness flag on pdmic component (Jaroslav Kysela) [2125537]
- ASoC: atmel-classd: Remove endianness flag on class d component (Jaroslav Kysela) [2125537]
- ASoC: adi: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: Makefile: Fix simultaneous build of KUNIT tests (Jaroslav Kysela) [2125537]
- ALSA: ac97: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ASoC: madera: Replace kernel.h with the necessary inclusions (Jaroslav Kysela) [2125537]
- ASoC: dt-bindings: cs35l45: Cirrus Logic CS35L45 Smart Amp (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: typo in argument definition (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Enable BOOST (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Make exports namespaced (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Add driver for Cirrus Logic CS35L45 Smart Amp (Jaroslav Kysela) [2125537]
- ASoC: doc: Capitalize RESET line name (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Add kunit test for snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Add helper to calculate BCLK from TDM info (Jaroslav Kysela) [2125537]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Use only dynamic PCM device allocation (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Free the ida when IPC fails in sof_ipc4_widget_setup() (Jaroslav Kysela) [2125537]
- ASoC: test-component: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ssm4567: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: rk3328: fix disabling mclk on pclk probe failure (Jaroslav Kysela) [2125537]
- ASoC: pcm3060: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: remove redundant test (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Add comment for the endianness flag (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa881x: handle timeouts in resume path (Jaroslav Kysela) [2125537]
- ASoC: wsa881x: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Fix event generation for wm_adsp_fw_put() (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Minor clean and redundant code removal (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Compressed stream DSP memory structs should be __packed (Jaroslav Kysela) [2125537]
- ASoC: wm8998: Fix event generation for input mux (Jaroslav Kysela) [2125537]
- ASoC: wm8962: Fix suspend while playing music (Jaroslav Kysela) [2125537]
- ASoC: codecs: wm8962: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: wm8960: Add ACPI support (Jaroslav Kysela) [2125537]
- ASoC: wm8940: add devicetree support (Jaroslav Kysela) [2125537]
- ASoC: wm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: wm8903: Fix the error handling of wm8903_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: wm8731: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: wm5102: Fix event generation for output compensation (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Use int array instead of bitmask for TX mixers (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Use DT bindings instead of local DAI definitions (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Fix spurious event generation (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Remove RX channel from old list before adding it to a new one (Jaroslav Kysela) [2125537]
- ASoC: codecs: wcd9335: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: remove redundant tests (Jaroslav Kysela) [2125537]
- ASoC: uda1380: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: twl4030: Drop legacy, non DT boot support (Jaroslav Kysela) [2125537]
- ASoC: tscs*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: ts3a227e: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tpa6130: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tlv320dac3x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic33: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: codec: tlv320aic32x4: fix mono playback via I2S (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic32x4: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic31xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic26: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic23: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Return zero in remove callback (Jaroslav Kysela) [2125537]
- ASoC: tda7419: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Fix the error handling of tas6424_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas5720: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas571x: Fix the error handling of tas571x_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: tas5086: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas2552: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Reinit regcache on reset (Jaroslav Kysela) [2125537]
- ASoC: tas2562: Propagate the error in tas2562_dac_event() (Jaroslav Kysela) [2125537]
- ASoC: tas2562: Fix mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Allow mono streams (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Fix handling of mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Allow mono streams (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Set correct FSYNC polarity (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tas2552: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta350: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta350: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: sta*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: sta32x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta32x: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: ssm2602: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: ssm2518: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: Fix noise on shutdown/remove (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Fix 3byte read, valule offset typo (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Use pm_runtime and regcache to optimize 'pwdnn' logic (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt715-sdca: remove useless assignment of ops (Jaroslav Kysela) [2125537]
- ASoC: rt5682s: Separate the regulator consumer controls (Jaroslav Kysela) [2125537]
- ASoC: rt5645: Fix the error handling of rt5645_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the issue of the abnormal JD2 status (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the JD voltage dropping issue (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the wrong state of JD1 and JD2 (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Add the MICBIAS1 to the dapm routing (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Fix jack detection (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Fix NULL jack in interrupt (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt286: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt274: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt274: Always init jack_detect_work (Jaroslav Kysela) [2125537]
- ASoC: rt1308-sdw: add the default value of register 0xc320 (Jaroslav Kysela) [2125537]
- ASoC: rk3328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: pcm1789: Make pcm1789_common_exit() return void (Jaroslav Kysela) [2125537]
- ASoC: pcm186x: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: pcm186x: simplify the return expression of pcm186x_power_off() (Jaroslav Kysela) [2125537]
- ASoC: pcm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: nau8825: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8825: Declare 2 channels for DAI of capture stream (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Fix semaphore is released unexpectedly (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Fix semaphore unbalance at error paths (Jaroslav Kysela) [2125537]
- ASoC: nau8822: Disable internal PLL if freq_out is zero (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Don't unconditionally free interrupt (Jaroslav Kysela) [2125537]
- ASoC: nau8821: add new widget to control system clock (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Add headset button detection (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt6366: support for mt6366 codec (Jaroslav Kysela) [2125537]
- ASoC: nau8540: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: mt6660: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: mt6359: Fix refcount leak bug (Jaroslav Kysela) [2125537]
- ASoC: codecs: msm8916-wcd-digital: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125537]
- ASoC: ml26124: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: max98390: use linux/gpio/consumer.h to fix build (Jaroslav Kysela) [2125537]
- ASoC: max98390: Add reset gpio control (Jaroslav Kysela) [2125537]
- ASoC: codecs: soundwire: call pm_runtime_resume() in component probe (Jaroslav Kysela) [2125537]
- ASoC: max98373: Removing 0x203E from the volatile reg (Jaroslav Kysela) [2125537]
- ASoC: max98090: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: max98090: Fix event generation for custom controls (Jaroslav Kysela) [2125537]
- ASoC: codecs: max98088: Clean up some inconsistent indenting (Jaroslav Kysela) [2125537]
- ASoC: max980*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: lm4857: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: da732x: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: da7219: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: max9*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: lm49xxx: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: hdmi-codec: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: es83*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: codes: Add support for ES8316 producer mode (Jaroslav Kysela) [2125537]
- ASoC: dmic: Add support for DSD data format (Jaroslav Kysela) [2125537]
- ASoC: da[79]*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: da7219: cancel AAD related work earlier for jack removal (Jaroslav Kysela) [2125537]
- ASoC: da7219: Fix pole orientation detection on certain headsets (Jaroslav Kysela) [2125537]
- ASoC: da7218: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: cs4349: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs42l56: Fix the error handling of cs42l56_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: cs42l51: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: Only report button state if there was a button interrupt (Jaroslav Kysela) [2125537]
- ASoC: cs4270: update kernel-doc (Jaroslav Kysela) [2125537]
- ASoC: cs4270: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add support for CLSA3541 ACPI device ID (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Enable Internal Boost in shared lib (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Do not print error when waking from hibernation (Jaroslav Kysela) [2125537]
- ASoC: cs35l36: Fix the error handling of cs35l36_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: cs*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: arizona: Update arizona_aif_cfg_changed to use RX_BCLK_RATE (Jaroslav Kysela) [2125537]
- ASoC: alc56*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: ak4613: cares Simple-Audio-Card case for TDM (Jaroslav Kysela) [2125537]
- ASoC: ak4613: add TDM256 support (Jaroslav Kysela) [2125537]
- ASoC: ak4613: rename constraint to constraint_rates (Jaroslav Kysela) [2125537]
- ASoC: ak4613: priv has ctrl1 instead of iface (Jaroslav Kysela) [2125537]
- ASoC: ak4613: return error if it was setup as clock provider (Jaroslav Kysela) [2125537]
- ASoC: ak4613: tidyup ak4613_interface (Jaroslav Kysela) [2125537]
- ASoC: ak4613: add missing mutex_lock() (Jaroslav Kysela) [2125537]
- ASoC: ak4642: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: ak*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: ak4*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: adau1761: Add ADAU1761-as-ADAU1361 compatibility mode (Jaroslav Kysela) [2125537]
- ASoC: ada*, ssm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: ab8500: Remove some leftover from the "Replace GPLv2 boilerplate/reference with SPDX" rules (Jaroslav Kysela) [2125537]
- ASoC: ad1*, ada*, ssm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: test-component: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: rename asoc_simple_init_dai_link_params() to asoc_simple_init_for_codec2codec() (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils.c: care Codec2Codec vs DPCM:BE (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils.c: ignore Codec2Codec setting if it already have (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: Make asoc_simple_clean_reference() return void (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2: indicate "Experimental stage" warning only when successed (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2: Add of_node_put() in fail path (Jaroslav Kysela) [2125537]
- ASoc: audio-graph-card2: Fix refcount leak bug in __graph_get_type() (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: remove pre-alloced Codec2Codec space (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: make Codec2Codec settings optional (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: use of_property_read_u32() for rate (Jaroslav Kysela) [2125537]
- ASoC: audio_graph_card2: Fix port numbers in example (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2-custom-sample.dtsi: add verbose explanation (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card: Add of_node_put() in fail path (Jaroslav Kysela) [2125537]
- ASoC: test-component: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_ssp_amp: remove 'set-but-not-used' warning (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: avoid oops in error handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: sof_sdw: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: Drop redundant enum constant (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_ssp_amp: enable capture stream from cs35l41 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: allow HDaudio/HDMI disable (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add quirk for HP Omen 16-k0005TX (Jaroslav Kysela) [2125537]
- ASoC: intel: sof_sdw: add RT711 SDCA card for MTL platform (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_pcm512x: remove unnecessary init (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_nau8825: Move quirk check to the front in late probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AFF (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AF0 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Perform quirk check first in card late probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Add support for mtl_mx98357_rt5682 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: fix out-of-bounds array access (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: rename RTL1019 compatible driver to rt1019p (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_nau8825: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_da7219_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ALSA: x86: intel_hdmi_audio: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ALSA: x86: intel_hdmi_audio: enable pm_runtime and set autosuspend delay (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: uniphier: simplify the return expression of uniphier_aio_compr_set_params() (Jaroslav Kysela) [2125537]
- ASoC: spear: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-topology: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: test DMA buffer first in hw_params (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-ipc: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dsp: report error on power-up/down (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: Drop misleading comment regarding dma_data (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: fix sof_es8336 probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: remove hard-coded SSP selection (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: reset the num_links during probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: add support for HDMI_In capture (Jaroslav Kysela) [2125537]
- ASoC: Intel: common: fix typo for tplg naming (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Add support for adl_rt1019_rt5682s (Jaroslav Kysela) [2125537]
- ASoC: Intel: soc-acpi: add table for HP Omen 16-k0005TX (Jaroslav Kysela) [2125537]
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in ADL match table (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: ignore GpioInt when looking for speaker/headset GPIO lines (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: Fix GPIO quirks set via module option (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_da7219_max98373: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: add adl_mx98360a_cs4242 board config (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: support BT offload audio (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: skl_nau88l25_ssm4567: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: skl_nau88l25_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_rt5663_rt5514_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_rt5663_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: hda: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: glk_rt5682_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: cml_rt1011_rt5682: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: Use temporary variable for struct device (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: reset acpi_chan_package (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Reorganize jack detect handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: bxt_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Improve hw_params() debug-ability (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Improve probe() function quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Update file comments (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Update code indentation (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Reword driver name (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Reword prefixes of all driver members (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename haswell source file to hsw_rt5640 (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst_ipc: remove redundant test (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Remove FE DAI ops (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve codec_init() quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve hw_params() debug-ability (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve probe() function quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Update file comments (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Update code indentation (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Reword driver name (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Reword prefixes of all driver members (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename broadwell source file to bdw_rt286 (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt286: Reorganize jack detect handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: broadwell: Make broadwell_disable_jack() return void (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt5677: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt5650: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst_ipc: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst: remove useless initialization (Jaroslav Kysela) [2125537]
- ASoC: intel: atom: Remove superfluous flush_scheduled_work() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: controls: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: Intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: Intel: skylake: skl-pcm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Skylake: remove redundant re-assignments to pointer array (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: bdw: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: byt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: cnl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: Do snd_hdac_ext_stream_decouple() only once (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: add sanity check on SSP index reported by NHLT (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: only fixup topology name if not set already (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: don't set fw_filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: enable dmic handling with 2 or fewer SoundWire links (Jaroslav Kysela) [2125537]
- ASoC: SOF: compress: Prevent current kernel running with older FW (Jaroslav Kysela) [2125537]
- ASoC: SOF: Copy compress parameters into extended data (Jaroslav Kysela) [2125537]
- ASoC: SOF: compress: Dynamically allocate pcm params struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: atom: don't keep a temporary string in fixup_tplg_name (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add trigger callback into sdw_callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Correct the ROM/FW state reporting code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: MTL: remove redundant snd_sof_dsp_read() call (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: mtl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: mtl: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Introduce skip_imr_boot flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: disable IMR boot when resuming from ACPI S4 and S5 states (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: IPC4: enable IMR boot (Jaroslav Kysela) [2125537]
- ASoC: SOC: Intel: introduce cl_init callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Do not (wrongly) assume positive return value in IMR path (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Revisit IMR boot sequence (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: Print out the non matching ext_man magic number (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-topology: Fix clang -Wformat warning (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove warning on ABI checks (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Fix error code in sof_ipc4_volume_put() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-pcm: set pcm rate to dai setting (Jaroslav Kysela) [2125537]
- ASoC: SOF: reduce default verbosity of IPC logs (Jaroslav Kysela) [2125537]
- Revert "RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default" (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: fix alh_group_ida max value (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: fix wrong use of sizeof in sof_ipc4_widget_setup_comp_src() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: set domain bit based on dp domain type (Jaroslav Kysela) [2125537]
- ASoC: SOF: add ipc4 SRC module support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: move ida allocate/free to widget_setup/free (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: free memories allocated in sof_ipc4_get_audio_fmt (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: check dai->private in ipc_free() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: add SoundWire/ALH aggregation support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Compile and runtime IPC version selection (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Align mt8186 clock names with dt-bindings (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Fix error code in probe (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Revise mt8195 boot flow (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: fix mt8195 StatvectorSel wrong setting (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: use pm_resume_and_get() on component probe (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: fix copy in sof_msg_inject_ipc4_dfs_write() (Jaroslav Kysela) [2125537]
- ASoC: sof: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-probes: Only load the driver if IPC3 is used (Jaroslav Kysela) [2125537]
- ASoC: SOF: probes: rename assign/free callbacks as startup/shutdown (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add cont_update_posn to platform parameters (Jaroslav Kysela) [2125537]
- ASoC: SOF: pm: add definitions for S4 and S5 states (Jaroslav Kysela) [2125537]
- ASoC: SOF: pm: add explicit behavior for ACPI S1 and S2 (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: Clarify the IPC timeout handling path (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: remove unused variable (Jaroslav Kysela) [2125537]
- ASoC: SOF: Switch to IPC generic firmware tracing (Jaroslav Kysela) [2125537]
- ALSA: aloop: Fix random zeros in capture data when using jiffies timer (Jaroslav Kysela) [2125537]
- ALSA: Add generic serial MIDI driver using serial bus API (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Use lookup table to create modules (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Update AVS_FW_INIT_TIMEOUT_US declaration (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Lower UNLOAD_MULTIPLE_MODULES IPC timeout (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Replace hardcodes with SD_CTL_STREAM_RESET (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Recognize FW_CFG_RESERVED (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Use helper function to set up DMA (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Set max DMA segment size (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Block IPC channel on suspend (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Shield LARGE_CONFIG_GETs against zero payload_size (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Copy only as many RX bytes as necessary (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Relax DSP core transition timings (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Assign I2S gateway when parsing topology (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix i2s_test card name initialization (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: correct config reference for I2S test board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix parsing UUIDs in topology (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add da7219 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add max98373 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add max98357a machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add ssm4567 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add nau8825 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt5682 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt298 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt286 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt274 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add I2S-test machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add DMIC machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix build error on arc, m68k and sparc (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: APL-based platforms support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: SKL-based platforms support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Power management (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Machine board registration (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Replace link_mask usage with i2s_link_mask (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Event tracing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: D0ix power state support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Prepare for firmware tracing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Register HDAudio ext-bus operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add HDAudio machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: PCI driver implementation (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Coredump and recovery flow (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Drop direct ACPI dependency (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Depend on SND_INTEL_DSP_CONFIG (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Enable AVS driver only on x86 platforms (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: HDA PCM BE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: non-HDA PCM BE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Generic PCM FE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Generic soc component driver (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Account for libraries when booting basefw (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Configure modules according to their type (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Prepare modules before bindings them (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Arm paths after creating them (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Path state management (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Path creation and freeing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Declare path and its components (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Support link_mask formatted string (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add topology loading operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse path and path templates tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse pipeline and module tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse pplcfg and binding tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse module-extension tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add topology parsing infrastructure (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add MeteorLake machines (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Declare vendor tokens (Jaroslav Kysela) [2125537]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK_AON bit (Jaroslav Kysela) [2125537]
- uapi: sof: abi: Bump SOF ABI for ext_data_length (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add two new structures for topology manifest data (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: introduce cont_update_posn in sof_ipc_stream_params struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: bump SOF_ABI_MINOR (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add header for IPC4 manifest (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: add code to parse config params for ACPDMIC dai (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add topology tokens for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: hdac_hda: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: max98504: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: adau1372: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6351: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6358: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6359: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6660: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: pcm3060: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt700: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt715: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt715-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt1308-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt1316-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wsa881x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: sdw-mockup: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: lochnagar: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: lochnagar: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: tfa*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tfa9879: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cs*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wm9090: Remove redundant endianness flag (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor out the I2C and SPI bus code into separate modules (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor our MCLK and mutex initialisation (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Move regulator request into wm8731_init() (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor component init out of bus code (Jaroslav Kysela) [2125537]
- Revert "ASoC: wm8731: Disable the regulator when probing fails" (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Update to modern DAI terminology (Jaroslav Kysela) [2125537]
- ASoC: wm2000: fix missing clk_disable_unprepare() on error in wm2000_anc_transition() (Jaroslav Kysela) [2125537]
- ASoC: wm2000: Remove redundant endianness flag (Jaroslav Kysela) [2125537]
- ASoC: wm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix amp gain register offset & default (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Correct playback volume range (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix and extend FSYNC polarity handling (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Add post reset delays (Jaroslav Kysela) [2125537]
- ASoC: tas*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tas*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix TDM mode BSEL settings (Jaroslav Kysela) [2125537]
- ASoC: max*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: max98396: Implement DSP speaker monitor (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix register access for PCM format settings (Jaroslav Kysela) [2125537]
- ASoC: max98396: Improve some error prints (Jaroslav Kysela) [2125537]
- ASoC: max98396: add voltage regulators (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix build error for implicit function declaration (Jaroslav Kysela) [2125537]
- ASoC: max98396: add amplifier driver (Jaroslav Kysela) [2125537]
- ASoC: rt*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: rt1019: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: fsl: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: pistachio: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: samsung: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tegra: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: test-component: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: uniphier: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ad*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ak*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: alc*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: da*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: es*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: msm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: nau*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: pcm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: spdif: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ssm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sta*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: twl*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: uda*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: 88pm860x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ab8500: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ac97: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ads117x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: bd28623: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: bt-sco: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cpcap: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cq93vc: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cx20442: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: dmic: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: gtm601: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: hdac_hdmi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: hdmi-codec: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ics43432: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: inno_rk3036: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: isabelle: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: jz4740: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: lm49453: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: mc13783: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ml26124: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: si476x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: stac9766: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sti-sas: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tscs42xx: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wl1273: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: zl38060: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Remove non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: Move snd_soc_component_is_codec to be local (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: core: Add new SOC_DOUBLE_SX_TLV macro (Jaroslav Kysela) [2125537]
- ASoC: Remove unused hw_write_t type (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Add SOC_SINGLE_S_EXT_TLV macro (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Introduce SOC_DOUBLE_R_S_EXT_TLV() macro (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Add SOC_SINGLE_S_TLV() macro (Jaroslav Kysela) [2125537]
- ALSA: hda: Skip event processing for unregistered codecs (Jaroslav Kysela) [2125537]
- ASoC: codecs: Add HD-Audio codec driver (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: Move CS42L42 register descriptions to general include (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Read System Name from ACPI _SUB to identify firmware (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add common cs35l41 enter hibernate function (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41 exit hibernate function into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs_dsp config struct into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41 fs errata into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41_set_cspl_mbox_cmd to shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Support external boost (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Add support for MeteorLake (MTL) (Jaroslav Kysela) [2125537]
- treewide: Replace zero-length arrays with flexible-array members (Jaroslav Kysela) [2125537]
- ASoC: SOF: add definitions for different IPC types (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: enhance debug messages (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: add sdw blob (Jaroslav Kysela) [2125537]
- AsoC: SOF: ipc4-topology: Add dai_get_clk op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for SSP/DMIC DAI's (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a new IPC op for parsing topology manifest (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: init NHLT for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add ops_free (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: set the BE DAI ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-pcm: Expose sof_ipc4_set_pipeline_state() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add the dai_config op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add route_setup/route_free ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add widget_setup/widget_free ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Add pcm ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add control IO ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add control_setup op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing mixer widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing and preparing pga widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add prepare op for DAI type widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add prepare op for AIF type widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing DAI_IN/DAI_OUT widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing AIF_IN/AIF_OUT widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Introduce topology ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Return from dtrace_read if there is no new data available (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Add helper function to update the sdev->host_offset (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Introduce SOF_DTRACE_INITIALIZING state (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: implement pm ctx_save callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Switch to use the generic pm_ops.set_core_state (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add initial header file for ipc4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof_ipc_pm_ops: Add support for DSP core power management (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195: Import namespace SND_SOC_SOF_MTK_COMMON (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 suspend check dsp idle (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 modify dram type as non-cache (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add shared_size for mediatek common chip information (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: revise mt8195 clock sequence (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Add SOF pm ops callback for Renoir (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Fix reversed if statement (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Propagate write errors correctly (Jaroslav Kysela) [2125537]
- ASoC: SOF: Fix potential NULL pointer dereference (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-ipc-flood-test: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: remove duplicate include in mt8195.c (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8195 debug dump (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mediatek common debug dump (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Move dtrace related variables local from sof_dev (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce opaque storage of private data for firmware tracing (Jaroslav Kysela) [2125537]
- ASoC: SOF: Modify the host trace_init parameter list to include dmab (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Move host ops wrappers from generic header to private (Jaroslav Kysela) [2125537]
- ASoC: SOF: Clone the trace code to ipc3-dtrace as fw_tracing implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: Rename dtrace_is_supported flag to fw_trace_is_supported (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce IPC independent ops for firmware tracing support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Cap the rmaining to count in IPC4 mode (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 ipc support (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add ipc support for mt8195 (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: HDA: Set up sof_ipc4_fw_data for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Add FW loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add IPC4 private header (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: HDA: Set IPC4-specific DSP ops for CaVS platforms (Jaroslav Kysela) [2125537]
- ASoC: SOF: trace: The dtrace is only available with SOF_IPC (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: IPC flood test can only work with SOF_IPC (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Add support for IPC4 messages (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Separate the message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add support IPC4 message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add API to get the ipc_type (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-probes: Query the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Query the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add API to get the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: Add support for mandatory message handling functionality (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add rx_data pointer to snd_sof_ipc_msg struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Remove the ipc3-ops.h header file (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: fix missing pci_release_regions() on error in sof_pci_probe() (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Call optional query_fw_configuration on first boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Remove snd_sof_parse_module_memcpy() as it is not used (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: bdw/byt/pci-tng: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: imx: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: renoir: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Switch to use the fw_loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add check for fw_loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: Implement firmware parsing and loading (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce IPC dependent ops for firmware handling, loading (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a prepare op to IPC topology widget ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: clarify use of widget complete flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Skip parsing DAI link tokens if not needed (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: remove unnecessary function declaration (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add two new fields to struct snd_sof_widget (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a route_free op in struct sof_ipc_tplg_ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: expose a couple of functions (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: Move the call to snd_sof_pcm_platform_hw_params() (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: Set up widgets from source to sink (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: reset route status before freeing widget (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a new op to set up volume table (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Fix allyesconfig build error (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 change ipc timeout as 1 second (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-ipc-msg-injector: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: control: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8186 (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 dsp clock support (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 sof fw loader and dsp ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 hardware support (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Remove the old fw_ready related code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: imx: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Do not check for the fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Add local implementation for handling fw_ready message (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: protect hw_params against successive calls (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add helper for link DMA cleanups (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: reset dma_data and release stream (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: improve suspend case (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: move code to deal with hda dai/dailink suspend (Jaroslav Kysela) [2125537]
- ASOC: SOF: Intel: hda-dai: add hda_dai_hw_free_ipc() helper (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: flag errors on pipeline teardown (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: regroup dai and link DMA operations (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: split link DMA and dai operations (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: use snd_soc_dai_get_widget() helper (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: simplify hda_dai_widget_update() prototype (Jaroslav Kysela) [2125537]
- ASOC: SOF: Intel: hda-dai: consistent naming for HDA DAI and HDA link DMA (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Add IPC-specific dai ops for IPC3 (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove incorrect clearing of prepared flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: simplify NHLT handling (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Check w->sname validity once in sof_connect_dai_widget() (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: remove useless assignment (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-tgl: add RPL-P support (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-tgl: add ADL-PS support (Jaroslav Kysela) [2125537]
- ASOC: SOF: pci: add ipc_type override for Intel IPC4 tests (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: don't use the community key on APL Chromebooks (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Use dedicated MBOX for ACP and PSP communication (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Add psp_mbox_ready() and psp_send_cmd() callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Kconfig: Make SND_SOC_SOF_HDA_PROBES tristate (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add IP identifier (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: expose some codeloader functions (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Define rom_status_reg in sof_intel_dsp_desc (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: define check_ipc_irq op (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: use BIT() macros for consistency (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: move HDA_CL_STREAM_FORMAT definition to header (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: use common ops across platforms (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove const qualifier for 'struct snd_sof_dsp_ops' (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: preserve topology filename override in nocodec mode (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: add parameter to override topology filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: add parameter to override firmware filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: add IPC-dependent file names (Jaroslav Kysela) [2125537]
- ASoC: SOF: add default IPC capability and file paths (Jaroslav Kysela) [2125537]
- ASoC: SOF: add path indirection to each IPC type (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Check the bar size before remapping (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Move the ipc_set_get_comp_data() local to ipc3-control (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: Use the widget_kcontrol_setup ops for kcontrol set up (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add widget_kcontrol_setup control ops for IPC3 (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Switch over to use the rx_msg ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Switch over to use the tx_msg and set_get_data ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use the get_reply ops in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add check for mandatory IPC message handling ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Separate the ops checks by functions/topics (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement rx_msg IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the get_reply IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the set_get_data IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Use sof_ipc3_tx_msg() internally for message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the tx_msg IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add high level IPC IO callback definitions to ipc_ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add helper function to prepare and send an IPC message (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 add shutdown callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: OF: Add shutdown callback for SOF OF device (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Avoid open coded arithmetic in memory allocation (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: use new sound control LED layer (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove redundant return statements (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove header from struct snd_sof_ipc_msg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Drop 'header' parameter from tx_message() API (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use msg->reply_data directly in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125537]
- ASoC: SOF: disable dma trace in s0ix (Jaroslav Kysela) [2125537]
- ASoC: SOF: extend the interface to stop DMA trace (Jaroslav Kysela) [2125537]
- ASoC: SOF: Drop support for mapped control data (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use ipc->max_payload_size for message/reply size checking (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add max_payload_size field in struct snd_sof_ipc (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove dmab and dmab_bdl from snd_sof_dev struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-loader: Use local snd_dma_buffer (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: add missing platform_device_unregister() in acp_pci_probe() (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Fix initialization of ext_intr_stat1 in i2s_irq_handler() (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Use non-legacy DAI naming for cs35l41 (Jaroslav Kysela) [2125537]
- ASoC: amd: enable RPL Platform acp drivers build (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform pci driver pm-ops (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform init/de-init functions (Jaroslav Kysela) [2125537]
- ASoC: amd: add ACP PCI driver for RPL platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform acp header file (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add error handling cases (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Modify const resource struct variable to generic (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Drop superfluous mmap callback (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Modify local variables name to generic (Jaroslav Kysela) [2125537]
- ASoC: amd: yc: Decrease level of error message (Jaroslav Kysela) [2125537]
- ASoC: amd: yc: add new YC platform varaint support (Jaroslav Kysela) [2125537]
- ASoC: amd: fix Jadeite kconfig warning and build errors (Jaroslav Kysela) [2125537]
- ASoC: amd: Fix error pointer dereference (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add legacy audio driver support for Rembrandt platform (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: ACP code generic to support newer platforms (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Remove rt1019_1 codec conf from machine driver (Jaroslav Kysela) [2125537]
- ASoC: amd: Remove duplicated include in acp-es8336.c (Jaroslav Kysela) [2125537]
- ASoC: amd: fix for variable set but not used warning (Jaroslav Kysela) [2125537]
- ASoC: amd: drop machine driver remove function (Jaroslav Kysela) [2125537]
- ASoC: amd: remove unused header file inclusion (Jaroslav Kysela) [2125537]
- ASoC: amd: acp-es8336: use static variables (Jaroslav Kysela) [2125537]
- ASoC: amd: fix ACPI dependency compile errors and warnings (Jaroslav Kysela) [2125537]
- ASoC: amd: enable machine driver build for Jadeite platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add Machine driver for Jadeite platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add I2S MICSP instance support (Jaroslav Kysela) [2125537]
- ASoC: amd: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Fix error handling in .remove() (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: fix typo in comment (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add support for rt5682s and rt1019 card with hs instance (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add support for nau8825 and max98360 card (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver. (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Remove duplicate include files (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add pm ops callback in machine driver (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: topology: Drop superfluous check of CONFIG_SND_CTL_VALIDATION (Jaroslav Kysela) [2125537]
- ASoC: topology: Rename soc_tplg_init_kcontrol() function (Jaroslav Kysela) [2125537]
- ASoC: topology: Correct error message (Jaroslav Kysela) [2125537]
- ASoC: topology: Rename SOC_TPLG_PASS_MIXER to _CONTROL (Jaroslav Kysela) [2125537]
- ASoC: topology: Return bool instead of int (Jaroslav Kysela) [2125537]
- ASoC: topology: Remove unnecessary looping (Jaroslav Kysela) [2125537]
- ASoC: topology: Use for loop instead of while (Jaroslav Kysela) [2125537]
- ASoC: topology: KUnit: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: topology: KUnit: Followup prototype change of snd_soc_unregister_card() (Jaroslav Kysela) [2125537]
- ASoC: DPCM: Don't pick up BE without substream (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: demote warnings on non-atomic BE connection (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: fix BE transition for TRIGGER_START (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: improve BE transition for TRIGGER_START (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: improve BE transition for PAUSE_RELEASE (Jaroslav Kysela) [2125537]
- ASoC: ops: Fix integer detection for when max possible values > 1 (Jaroslav Kysela) [2125537]
- ASoC: ops: Fix boolean/integer detection for simple controls (Jaroslav Kysela) [2125537]
- ASoC: ops: Don't modify the driver's plaform_max when reading state (Jaroslav Kysela) [2125537]
- ASoC: ops: Remove unneeded delay.h inclusion (Jaroslav Kysela) [2125537]
- ASoC: ops: Clarify snd_soc_info_volsw_sx() (Jaroslav Kysela) [2125537]
- ASoC: soc-generic-dmaengine-pcm: Use default config when none is given (Jaroslav Kysela) [2125537]
- ASoC: dapm: Move stereo autodisable check (Jaroslav Kysela) [2125537]
- ASoC: soc-dai: Remove set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: soc-core.c: share code for snd_soc_of_get_dai_link_cpus/codecs() (Jaroslav Kysela) [2125537]
- ASoC: soc-core.c: fixup snd_soc_of_get_dai_link_cpus() (Jaroslav Kysela) [2125537]
- ASoC: core: Switch core to new DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: core: Make snd_soc_unregister_card() return void (Jaroslav Kysela) [2125537]
- ASoC: core: Always send the CPU DAI a direct clock specifier (Jaroslav Kysela) [2125537]
- ASoC: core: Add set_fmt_new callback that directly specifies provider (Jaroslav Kysela) [2125537]
- ASoC: core: Pass legacy_dai_naming flag directly (Jaroslav Kysela) [2125537]
- ASoC: core: Correct spelling fliped -> flipped (Jaroslav Kysela) [2125537]
- ASoC: soc-core: remove always-false path (Jaroslav Kysela) [2125537]
- ASoC: Introduce snd_soc_of_get_dai_link_cpus (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Update handling to component delays (Jaroslav Kysela) [2125537]
- ASoC: Introduce 'fixup_controls' card method (Jaroslav Kysela) [2125537]
- ASoC: soc-card: Create jack kcontrol without pins (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: Make sure of_device_id table are NULL terminated (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: add machine support for max98390 and rt5682 (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: rename card controls (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: merge machine driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: revise mt8195-mt6359-rt1019-rt5682.c (Jaroslav Kysela) [2125537]
- ALSA: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125537]
- Revert "ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations" (Jaroslav Kysela) [2125537]
- ALSA: hda: beep: Simplify keep-power-at-enable behavior (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Don't skip notification handling during PM operation (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Limit the maximal count of PCM devices to 8 (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: ELD procfs - print the codec NIDs (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Simplify the pcm_idx condition in hdmi_pcm_setup_pin() (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Fix the converter allocation for the silent stream (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: change type for the 'assigned' variable (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: Move structs out of #define block (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add a quirk for HP OMEN 16 (8902) mute LED (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Fix the converter reuse for the silent stream (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for ASUS GA503R laptop (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add pincfg for ASUS G533Z HP jack (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add pincfg for ASUS G513 HP jack (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Re-arrange quirk table entries (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5530 laptop (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5570 laptop (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix Nvidia dp infoframe (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Huawei WRT-WX9 (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: set depop delay for tegra (Jaroslav Kysela) [2125537]
- ALSA: hda: add Intel 5 Series / 3400 PCI DID (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix hang at HD-audio codec unbinding due to refcount saturation (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Fix out of bounds access in snd_emu10k1_pcm_channel_alloc() (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: Align BDL entry to 4KB boundary (Jaroslav Kysela) [2125537]
- ALSA: hda/sigmatel: Fix unused variable warning for beep power change (Jaroslav Kysela) [2125537]
- ALSA: hda/sigmatel: Keep power up while beep is enabled (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add speaker AMP init for Samsung laptops with ALC298 (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU, NS70PU (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support new Dolphin Variants (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga7 14IAL7 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Clarify support for CSC3551 without _DSD Properties (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirks for ASUS Zenbooks using CS35L41 (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix crash due to jack poll in suspend (Jaroslav Kysela) [2125537]
- ALSA: hda/cirrus - support for iMac 12,1 model (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 (8786) mute LED (Jaroslav Kysela) [2125537]
- ALSA: hda/conexant: Add quirk for LENOVO 20149 Notebook model (Jaroslav Kysela) [2125537]
- ALSA: ice1712: remove redundant assignment to new (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for another Asus K42JZ model (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-eb0xxx (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Clevo NV45PZ (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga9 14IAP7 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support CLSA0101 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Use the CS35L41 HDA internal define (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable speaker and mute LEDs for HP laptops (Jaroslav Kysela) [2125537]
- ALSA: asihpi: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: asihpi: Fix typo in comments (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Fix typo in comments (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add module parameter to control firmware load (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Firmware switching and reloading (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add defaulted values into dsp bypass config sequence (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add fw id strings (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Read Speaker Calibration data from UEFI variables (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Hibernation during Suspend (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Speaker ID for laptops (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support multiple load paths for firmware (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support reading subsystem id from ACPI (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Save Subsystem ID inside CS35L41 Driver (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add initial DSP support and firmware loading (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Save codec object inside component struct (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add apis to write the controls directly (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add Library to support CS_DSP ALSA controls (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Consolidate selections under SND_HDA_SCODEC_CS35L41 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Drop wrong use of ACPI_PTR() (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Don't dereference fwnode handle (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Improve dev_err_probe() messaging (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix comments wrt serial-multi-instantiate reference (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix put_device() inconsistency in error path (Jaroslav Kysela) [2125537]
- ALSA: hda: Make device usage_count consistent across subsequent probing (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix null-ptr-deref when i915 fails and hdmi is denylisted (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: change cs8409_fixups v.pins initializers to static (Jaroslav Kysela) [2125537]
- ASoC: doc: Update dead links (Jaroslav Kysela) [2125537]
- ALSA: hda/via: Delete does not require return (Jaroslav Kysela) [2125537]
- ALSA: ctxfi: fix typo in comment (Jaroslav Kysela) [2125537]
- ALSA: cs5535audio: fix typo in comment (Jaroslav Kysela) [2125537]
- ALSA: lola: Bounds check loop iterator against streams array size (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Amp Name based on channel and index (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Enable GPIO2 Interrupt for CLSA0100 laptops (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Support for Interrupts (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Remove Set Channel Map api from binding (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Set Speaker Position for CLSA0100 Laptop (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix error in spi cs35l41 hda driver name (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Warlock (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Cyborg (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support new Odin Variants (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support manual mode detection for CS42L42 (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Use general cs42l42 include in cs8409 hda driver (Jaroslav Kysela) [2125537]
- ALSA: hdsp: remove redundant assignment to pointer kctl (Jaroslav Kysela) [2125537]
- ALSA: hda/conexant: add a new hda codec SN6140 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Move external boost handling to lib for ASoC use (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Handle all external boost setups the same way (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Reorganize log for playback actions (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Remove cs35l41_hda_reg_sequence struct (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Move boost config to initialization code (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Mute the device before shutdown (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Put the device into safe mode for external boost (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Boost type flag (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Always configure the DAI (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix I2S params comments (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Move cs35l41_gpio_config to shared lib (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Check hw_config before using it (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Unify hardware configuration (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: Enable Jack poll for tegra (Jaroslav Kysela) [2125537]
- ALSA: hda: Jack detection poll in suspend state (Jaroslav Kysela) [2125537]
- ALSA: echoaudio: remove redundant assignment to variable i (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Stop using iommu_present() (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-dsp-config: add missing RaptorLake PCI IDs (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2125537]
- ALSA: hda: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: hda: Remove unused macro definition (Jaroslav Kysela) [2125537]
- ALSA: hda: Reset all SIE bits in INTCTL (Jaroslav Kysela) [2125537]
- tracing: ALSA: hda: Remove string manipulation out of the fast path (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-dspcfg: use SOF for UpExtreme and UpExtreme11 boards (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Properly refcounting clock rate (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Clear fixed clock rate at closing EP (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Fix an out-of-bounds bug in __snd_usb_parse_audio_interface() (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Register card again for iface over delayed_register option (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Inform the delayed registration more properly (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add quirk for LH Labs Geek Out HD Audio 1V5 (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: make read-only array marker static const (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: More comprehensive mixer map for ASUS ROG Zenith II (Jaroslav Kysela) [2125537]
- ALSA: scarlett2: Add Focusrite Clarett+ 8Pre support (Jaroslav Kysela) [2125537]
- ALSA: line6: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: hiface: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: usb/6fire: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add quirk for Behringer UMC202HD (Jaroslav Kysela) [2125537]
- ALSA: bcd2000: Fix a UAF bug on the error path of probing (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Use atomic_try_cmpxchg in ep_state_update (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add endianness annotations (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Turn off 'manual mode' on Dell dock (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Support jack detection on Dell dock (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: US16x08: Move overflow check before array access (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add mixer mapping for Gigabyte B450/550 Mobos (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Fix wrong kfree issue in snd_usb_endpoint_free_all (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Refcount multiple accesses on the single clock (Jaroslav Kysela) [2125537]
- firmware: cs_dsp: Add memory chunk helpers (Jaroslav Kysela) [2125537]
- firmware: cs_dsp: Add pre_stop callback (Jaroslav Kysela) [2125537]
- regmap: Constify static regmap_bus structs (Jaroslav Kysela) [2125537]
- soundwire: peripheral: remove useless ops pointer (Jaroslav Kysela) [2125537]
- soundwire: intel: use pm_runtime_resume() on component probe (Jaroslav Kysela) [2125537]
- soundwire: qcom: fix device status array range (Jaroslav Kysela) [2125537]
- soundwire: qcom: remove duplicate reset control get (Jaroslav Kysela) [2125537]
- soundwire: Intel: add trigger callback (Jaroslav Kysela) [2125537]
- soundwire: qcom: Enable software clock gating requirement flag (Jaroslav Kysela) [2125537]
- soundwire: qcom: Check device status before reading devid (Jaroslav Kysela) [2125537]
- soundwire: qcom: Add flag for software clock gating check (Jaroslav Kysela) [2125537]
- soundwire: revisit driver bind/unbind and callbacks (Jaroslav Kysela) [2125537]
- soundwire: bus_type: fix remove and shutdown support (Jaroslav Kysela) [2125537]
- soundwire: intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: qcom: soundwire: Add support for controlling audio CGCR from HLOS (Jaroslav Kysela) [2125537]
- soundwire: qcom: adjust autoenumeration timeout (Jaroslav Kysela) [2125537]
- soundwire: qcom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: intel: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: cadence: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: bus: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: qcom: return error when pm_runtime_get_sync fails (Jaroslav Kysela) [2125537]
- soundwire: bus: pm_runtime_request_resume on peripheral attachment (Jaroslav Kysela) [2125537]
- soundwire: intel: disable WAKEEN in pm_runtime resume (Jaroslav Kysela) [2125537]
- soundwire: cadence: recheck device0 attachment after status change (Jaroslav Kysela) [2125537]
- soundwire: qcom: Add compatible name for v1.6.0 (Jaroslav Kysela) [2125537]
- soundwire: stream: Fix error return code in do_bank_switch() (Jaroslav Kysela) [2125537]
- soundwire: qcom: fix an error message in swrm_wait_for_frame_gen_enabled() (Jaroslav Kysela) [2125537]
- soundwire: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125537]
- ALSA: Add snd_pcm_direction_name() helper (Jaroslav Kysela) [2125537]
- ALSA: core: Fix double-free at snd_card_new() (Jaroslav Kysela) [2125537]
- ALSA: hda: Once again fix regression of page allocations with IOMMU (Jaroslav Kysela) [2125537]
- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC (Jaroslav Kysela) [2125537]
- ALSA: control: Re-order bounds checking in get_ctl_id_hash() (Jaroslav Kysela) [2125537]
- ALSA: control: Fix an out-of-bounds bug in get_ctl_id_hash() (Jaroslav Kysela) [2125537]
- ALSA: seq: Fix data-race at module auto-loading (Jaroslav Kysela) [2125537]
- ALSA: seq: oss: Fix data-race for max_midi_devs access (Jaroslav Kysela) [2125537]
- ALSA: memalloc: Revive x86-specific WC page allocations again (Jaroslav Kysela) [2125537]
- ALSA: info: Fix llseek return value when using callback (Jaroslav Kysela) [2125537]
- ALSA: pcm: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: core: Replace scnprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: control-led: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: control: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: pcm: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: timer: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: core: Add async signal helpers (Jaroslav Kysela) [2125537]
- ALSA: core: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: memalloc: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: control: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: compress: Fix kernel doc warnings (Jaroslav Kysela) [2125537]
- ALSA: dmaengine: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: pcm: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: compress: Enable kernel doc markers for some functions (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Take buffer refcount while draining output (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Check stream state at exported functions (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Take open_mutex around parameter changes (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Move lock to snd_rawmidi_substream (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Make internal functions local static (Jaroslav Kysela) [2125537]
- ALSA: control: Add input validation (Jaroslav Kysela) [2125537]
- ALSA: control: Drop superfluous ifdef CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125537]
- ALSA: control: Rename CONFIG_SND_CTL_VALIDATION to CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125537]
- ALSA: control: Use xarray for faster lookups (Jaroslav Kysela) [2125537]
- ALSA: seq: replace ternary operator with max() (Jaroslav Kysela) [2125537]

* Wed Dec 07 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-208.el9]
- selftests/livepatch: better synchronize test_klp_callbacks_busy (Julia Denham) [2121205]
- livepatch: Reorder to use before freeing a pointer (Julia Denham) [2121205]
- livepatch: Skip livepatch tests if ftrace cannot be configured (Julia Denham) [2121205]
- livepatch: Don't block removal of patches that are safe to unload (Julia Denham) [2121205]
- enable CONFIG_CRYPTO_DH_RFC7919_GROUPS (Chris Leech) [2143836]
- crypto: add __init/__exit annotations to init/exit funcs (Chris Leech) [2143836]
- crypto: dh - Remove the unused function dh_safe_prime_dh_alg() (Chris Leech) [2143836]
- crypto: dh - calculate Q from P for the full public key verification (Chris Leech) [2143836]
- crypto: dh - allow for passing NULL to the ffdheXYZ(dh)s' ->set_secret() (Chris Leech) [2143836]
- crypto: testmgr - add keygen tests for ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - implement private key generation primitive for ffdheXYZ(dh) (Chris Leech) [2143836]
- crypto: testmgr - add known answer tests for ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - implement ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - introduce common code for built-in safe-prime group support (Chris Leech) [2143836]
- crypto: dh - split out deserialization code from crypto_dh_decode() (Chris Leech) [2143836]
- crypto: dh - remove struct dh's ->q member (Chris Leech) [2143836]
- crypto: kpp - provide support for KPP spawns (Chris Leech) [2143836]
- crypto: kpp - provide support for KPP template instances (Chris Leech) [2143836]
- scsi: storvsc: remove an extraneous "to" in a comment (Cathy Avery) [2143335]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Cathy Avery) [2143335]
- scsi: storvsc: Drop DID_TARGET_FAILURE use (Cathy Avery) [2143335]
- scsi: storvsc: Remove WQ_MEM_RECLAIM from storvsc_error_wq (Cathy Avery) [2143335]
- scsi: storvsc: Correct reporting of Hyper-V I/O size limits (Cathy Avery) [2143335]
- scsi: storvsc: Removing Pre Win8 related logic (Cathy Avery) [2143335]
- scsi: storvsc: Fix typo in comment (Cathy Avery) [2143335]
- scsi: storvsc: Remove support for Hyper-V 2008 and 2008R2/Win7 (Cathy Avery) [2143335]

* Tue Dec 06 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-207.el9]
- HID: intel-ish-hid: ipc: Add Meteor Lake PCI device ID (Tony Camuso) [2131760]
- hid: intel-ish-hid: ishtp: Fix ishtp client sending disordered message (Tony Camuso) [2131760]
- HID: ishtp-hid-clientHID: ishtp-hid-client: Fix comment typo (Tony Camuso) [2131760]
- ID: intel-ish-hid: hid-client: drop unexpected word "the" in the comments (Tony Camuso) [2131760]
- HID: intel-ish-hid: ipc: use time_before to replace "jiffies < a" (Tony Camuso) [2131760]
- HID: intel-ish-hid: ipc: add ADL and RPL device id (Tony Camuso) [2131760]
- fs: allow cross-vfsmount reflink/dedupe (Andrey Albershteyn) [2088133]
- EDAC/skx_common: Make output format similar (Aristeu Rozanski) [2124913]
- EDAC/skx_common: Use driver decoder first (Aristeu Rozanski) [2124913]
- redhat/configs: Change the amd-pstate driver from builtin to loadable (David Arcari) [2143793]
- KVM: selftests: Enable rseq_test for all architectures (Gavin Shan) [2107034]
- selftests/rseq: check if libc rseq support is registered (Gavin Shan) [2107034]
- selftests/rseq: Change type of rseq_offset to ptrdiff_t (Gavin Shan) [2107034]
- selftests/rseq: x86-32: use %%gs segment selector for accessing rseq thread area (Gavin Shan) [2107034]
- selftests/rseq: x86-64: use %%fs segment selector for accessing rseq thread area (Gavin Shan) [2107034]
- selftests/rseq: Fix: work-around asm goto compiler bugs (Gavin Shan) [2107034]
- selftests/rseq: Remove arm/mips asm goto compiler work-around (Gavin Shan) [2107034]
- selftests/rseq: Fix warnings about #if checks of undefined tokens (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32 offsets by using long rather than off_t (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32 missing instruction selection "u" and "x" for load/store (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32: wrong rseq_cs 32-bit field pointer on big endian (Gavin Shan) [2107034]
- selftests/rseq: Uplift rseq selftests for compatibility with glibc-2.35 (Gavin Shan) [2107034]
- selftests/rseq: Introduce thread pointer getters (Gavin Shan) [2107034]
- selftests/rseq: Introduce rseq_get_abi() helper (Gavin Shan) [2107034]
- selftests/rseq: Remove volatile from __rseq_abi (Gavin Shan) [2107034]
- selftests/rseq: Remove useless assignment to cpu variable (Gavin Shan) [2107034]
- selftests/rseq: introduce own copy of rseq uapi header (Gavin Shan) [2107034]
- selftests/rseq: remove ARRAY_SIZE define from individual tests (Gavin Shan) [2107034]
- net: Remove unused inline function sk_nulls_node_init() (Guillaume Nault) [2143237]
- ping: convert to RCU lookups, get rid of rwlock (Guillaume Nault) [2143237]
- mm: migrate: fix THP's mapcount on isolation (Gavin Shan) [2142505]
- dm-log-writes: set dma_alignment limit in io_hints (Ming Lei) [2142432]
- dm-integrity: set dma_alignment limit in io_hints (Ming Lei) [2142432]
- block: make blk_set_default_limits() private (Ming Lei) [2142432]
- dm-crypt: provide dma_alignment limit in io_hints (Ming Lei) [2142432]
- block: make dma_alignment a stacking queue_limit (Ming Lei) [2142432]
- blk-cgroup: properly pin the parent in blkcg_css_online (Ming Lei) [2142432]
- block: sed-opal: kmalloc the cmd/resp buffers (Ming Lei) [2142432]
- block, bfq: fix null pointer dereference in bfq_bio_bfqg() (Ming Lei) [2142432]
- block: blk_add_rq_to_plug(): clear stale 'last' after flush (Ming Lei) [2142432]
- blk-mq: Fix kmemleak in blk_mq_init_allocated_queue (Ming Lei) [2142432]
- block: Fix possible memory leak for rq_wb on add_disk failure (Ming Lei) [2142432]
- fuse: lock inode unconditionally in fuse_fallocate() (Miklos Szeredi) [2112621]
- fuse: add file_modified() to fallocate (Miklos Szeredi) [2112621]
- sgx: use ->f_mapping... (Vladis Dronov) [2130211]
- x86/sgx: Improve comments for sgx_encl_lookup/alloc_backing() (Vladis Dronov) [2130211]
- x86/sgx: Handle VA page allocation failure for EAUG on PF. (Vladis Dronov) [2130211]
- x86/sgx: Do not fail on incomplete sanitization on premature stop of ksgxd (Vladis Dronov) [2130211]
- selftests/sgx: Ignore OpenSSL 3.0 deprecated functions warning (Vladis Dronov) [2130211]
- x86/sgx: Set active memcg prior to shmem allocation (Vladis Dronov) [2130211]
- x86/sgx: Drop 'page_index' from sgx_backing (Vladis Dronov) [2130211]
- selftests/sgx: Page removal stress test (Vladis Dronov) [2130211]
- selftests/sgx: Test reclaiming of untouched page (Vladis Dronov) [2130211]
- selftests/sgx: Test invalid access to removed enclave page (Vladis Dronov) [2130211]
- selftests/sgx: Test faulty enclave behavior (Vladis Dronov) [2130211]
- selftests/sgx: Test complete changing of page type flow (Vladis Dronov) [2130211]
- selftests/sgx: Introduce TCS initialization enclave operation (Vladis Dronov) [2130211]
- selftests/sgx: Introduce dynamic entry point (Vladis Dronov) [2130211]
- selftests/sgx: Test two different SGX2 EAUG flows (Vladis Dronov) [2130211]
- selftests/sgx: Add test for TCS page permission changes (Vladis Dronov) [2130211]
- selftests/sgx: Add test for EPCM permission changes (Vladis Dronov) [2130211]
- Documentation/x86: Introduce enclave runtime management section (Vladis Dronov) [2130211]
- x86/sgx: Free up EPC pages directly to support large page ranges (Vladis Dronov) [2130211]
- x86/sgx: Support complete page removal (Vladis Dronov) [2130211]
- x86/sgx: Support modifying SGX page type (Vladis Dronov) [2130211]
- x86/sgx: Tighten accessible memory range after enclave initialization (Vladis Dronov) [2130211]
- x86/sgx: Support adding of pages to an initialized enclave (Vladis Dronov) [2130211]
- x86/sgx: Support restricting of enclave page permissions (Vladis Dronov) [2130211]
- x86/sgx: Support VA page allocation without reclaiming (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_page_alloc() (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_{grow,shrink}() (Vladis Dronov) [2130211]
- x86/sgx: Keep record of SGX page type (Vladis Dronov) [2130211]
- x86/sgx: Create utility to validate user provided offset and length (Vladis Dronov) [2130211]
- x86/sgx: Make sgx_ipi_cb() available internally (Vladis Dronov) [2130211]
- x86/sgx: Move PTE zap code to new sgx_zap_enclave_ptes() (Vladis Dronov) [2130211]
- x86/sgx: Rename sgx_encl_ewb_cpumask() as sgx_encl_cpumask() (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_ewb_cpumask() (Vladis Dronov) [2130211]
- x86/sgx: Support loading enclave page without VMA permissions check (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EAUG function (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EMODT function (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EMODPR function (Vladis Dronov) [2130211]
- x86/sgx: Add short descriptions to ENCLS wrappers (Vladis Dronov) [2130211]
- x86/sgx: Ensure no data in PCMD page after truncate (Vladis Dronov) [2130211]
- x86/sgx: Fix race between reclaimer and page fault handler (Vladis Dronov) [2130211]
- x86/sgx: Obtain backing storage page with enclave mutex held (Vladis Dronov) [2130211]
- x86/sgx: Mark PCMD page as dirty when modifying contents (Vladis Dronov) [2130211]
- x86/sgx: Disconnect backing page references from dirty status (Vladis Dronov) [2130211]

* Mon Dec 05 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-206.el9]
- dt-bindings: gpio: gpio-vf610: Add imx93 compatible string (Steve Best) [2143601]
- dt-bindings: gpio: gpio-vf610: Add imx8ulp compatible string (Steve Best) [2143601]
- ice: xsk: drop power of 2 ring size restriction for AF_XDP (Petr Oros) [2104468]
- ice: xsk: change batched Tx descriptor cleaning (Petr Oros) [2104468]
- ice: Fix interface being down after reset with link-down-on-close flag on (Petr Oros) [2104468]
- ice: config netdev tc before setting queues number (Petr Oros) [2104468]
- ice: Fix ice_xdp_xmit() when XDP TX queue number is not sufficient (Petr Oros) [2104468]
- ice: Don't double unplug aux on peer initiated reset (Petr Oros) [2104468]
- ice: use bitmap_free instead of devm_kfree (Petr Oros) [2104468]
- ice: Fix DMA mappings leak (Petr Oros) [2104468]
- ice: xsk: use Rx ring's XDP ring when picking NAPI context (Petr Oros) [2104468]
- ice: xsk: prohibit usage of non-balanced queue id (Petr Oros) [2104468]
- ice: Fix call trace with null VSI during VF reset (Petr Oros) [2104468]
- ice: Fix VSI rebuild WARN_ON check for VF (Petr Oros) [2104468]
- net/ice: fix initializing the bitmap in the switch code (Petr Oros) [2104468]
- net: ice: fix error NETIF_F_HW_VLAN_CTAG_FILTER check in ice_vsi_sync_fltr() (Petr Oros) [2104468]
- ice: implement adjfine with mul_u64_u64_div_u64 (Petr Oros) [2104468]
- ice: allow toggling loopback mode via ndo_set_features callback (Petr Oros) [2104468]
- ice: compress branches in ice_set_features() (Petr Oros) [2104468]
- ice: Add support for PPPoE hardware offload (Petr Oros) [2104468]
- ice: add i2c write command (Petr Oros) [2104468]
- ice: Remove pci_aer_clear_nonfatal_status() call (Petr Oros) [2104468]
- ice: Add EXTTS feature to the feature bitmap (Petr Oros) [2104468]
- ice: Remove unnecessary NULL check before dev_put (Petr Oros) [2104468]
- ice: use eth_broadcast_addr() to set broadcast address (Petr Oros) [2104468]
- ice: switch: dynamically add VLAN headers to dummy packets (Petr Oros) [2104468]
- ice: Add support for VLAN TPID filters in switchdev (Petr Oros) [2104468]
- ice: Add support for double VLAN in switchdev (Petr Oros) [2104468]
- intel/ice:fix repeated words in comments (Petr Oros) [2104468]
- drivers/net/ethernet/intel: fix typos in comments (Petr Oros) [2104468]
- ice: Use correct order for the parameters of devm_kcalloc() (Petr Oros) [2104468]
- ice: remove u16 arithmetic in ice_gnss (Petr Oros) [2104468]
- ice: remove VLAN representor specific ops (Petr Oros) [2104468]
- ice: don't set VF VLAN caps in switchdev (Petr Oros) [2104468]
- Merge DRM changes from upstream v6.0..v6.0.8 (Karol Herbst) [2115876]
- firmware: sysfb: Add sysfb_disable() helper function (Karol Herbst) [2115876]
- firmware: sysfb: Make sysfb_create_simplefb() return a pdev pointer (Karol Herbst) [2115876]
- Revert "dma-buf: remove useless FMODE_LSEEK flag" (Karol Herbst) [2115876]
- Revert "mm: shrinkers: provide shrinkers with names" (Karol Herbst) [2115876]
- Revert "drm/amdkfd: add SPM support for SVM" (Karol Herbst) [2115876]
- Merge DRM changes from upstream v5.19..v6.0 (Karol Herbst) [2115876]
- agp/intel: Rename intel-gtt symbols (Karol Herbst) [2115876]
- dma-buf: fix use of DMA_BUF_SET_NAME_{A,B} in userspace (Karol Herbst) [2115876]
- Revert "i915: Call aops write_begin() and write_end() directly" (Karol Herbst) [2115876]
- Merge DRM changes from upstream v5.18..v5.19 (Karol Herbst) [2115876]
- drm/i915/rpl-p: Add PCI IDs (Karol Herbst) [2115876]
- mei: gsc: retrieve the firmware version (Karol Herbst) [2115876]
- mei: gsc: add runtime pm handlers (Karol Herbst) [2115876]
- mei: gsc: setup char driver alive in spite of firmware handshake failure (Karol Herbst) [2115876]
- mei: add support for graphics system controller (gsc) devices (Karol Herbst) [2115876]
- drm/i915/gsc: add gsc as a mei auxiliary device (Karol Herbst) [2115876]
- drm/i915: Prepare for multiple GTs (Karol Herbst) [2115876]
- drm/i915/gt: add gt_is_root() helper (Karol Herbst) [2115876]
- drm/i915: Rename INTEL_REGION_LMEM with INTEL_REGION_LMEM_0 (Karol Herbst) [2115876]
- drm/i915: fixup the initial fb base on DGFX (Karol Herbst) [2115876]
- drm/i915: add i915_gem_object_create_region_at() (Karol Herbst) [2115876]
- drm/i915: Report steering details in debugfs (Karol Herbst) [2115876]
- DRM: add new options (Karol Herbst) [2115876]
- spec: Update bpftool versioning scheme (Viktor Malik) [2139374]
- ptp: introduce helpers to adjust by scaled parts per million (Izabela Bakollari) [2141641]
- ptp: add missing documentation for parameters (Izabela Bakollari) [2141641]
- dt-bindings: serial: fsl-lpuart: Add imx93 compatible string (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Remove i.MX8QM from enum (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Drop i.MX8QXP backwards compatibility (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Add i.MX8DXL compatible (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Fix i.MX 8QM compatible matching (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: add i.MXRT1050 compatible (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Add imx8ulp compatible string (Steve Best) [2143617]

* Fri Dec 02 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-205.el9]
- gpio: vf610: fix compilation error (Steve Best) [2137977]
- gpio: vf610: drop the SOC_VF610 dependency for GPIO_VF610 (Steve Best) [2137977]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- sound: usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- net: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- media: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- Input: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- HID: usbhid: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- dt-bindings: mailbox: imx-mu: add RST channel (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX93 S4 MU support (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX93 MU (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX8 SECO MU support (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX8ULP S400 MU support (Steve Best) [2137972]
- mm, slab: remove duplicate kernel-doc comment for ksize() (Michal Schmidt) [2143368]
- slab: Introduce kmalloc_size_roundup() (Michal Schmidt) [2143368]
- redhat/configs: turn off IMX93 CCM Clock Driver (Steve Best) [2137971]
- dt-bindings: clock: imx93-clock: add more MU/SAI clocks (Steve Best) [2137971]
- clk: imx93: drop of_match_ptr (Steve Best) [2137971]
- clk: imx93: add SAI IPG clk (Steve Best) [2137971]
- clk: imx93: add MU1/2 clock (Steve Best) [2137971]
- clk: imx93: switch to use new clk gate API (Steve Best) [2137971]
- clk: imx93: Correct the edma1's parent clock (Steve Best) [2137971]
- clk: imx93: correct nic_media parent (Steve Best) [2137971]
- clk: imx93: use adc_root as the parent clock of adc1 (Steve Best) [2137971]
- clk: imx: Select MXC_CLK for i.MX93 clock driver (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: Add more freq config for video pll (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: correct rdiv (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: Return rate in rate table properly in ->recalc_rate() (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: fix mfd value (Steve Best) [2137971]
- clk: imx: clk-composite-93: check white_list (Steve Best) [2137971]
- clk: imx: clk-composite-93: check slice busy (Steve Best) [2137971]
- clk: imx: add i.MX93 clk (Steve Best) [2137971]
- clk: imx: support fracn gppll (Steve Best) [2137971]
- clk: imx: add i.MX93 composite clk (Steve Best) [2137971]
- s390/block/dcssblk: add error handling support for add_disk() (Ming Lei) [2136402]
- s390/block/scm_blk: add error handling support for add_disk() (Ming Lei) [2136402]
- s390/block/dasd_genhd: add error handling support for add_disk() (Ming Lei) [2136402]
- platform/x86/intel/pmt: Sapphire Rapids PMT errata fix (David Arcari) [2144690]
- iavf: remove INITIAL_MAC_SET to allow gARP to work properly (Ivan Vecera) [2119698]
- iavf: Fix change VF's mac address (Ivan Vecera) [2119698]
- iavf: Add waiting for response from PF in set mac (Ivan Vecera) [2119698]
- scsi: smartpqi: Change version to 2.1.20-035 (Don Brace) [2116978]
- scsi: smartpqi: Initialize feature section info (Don Brace) [2116978]
- scsi: smartpqi: Add controller cache flush during rmmod (Don Brace) [2116978]
- scsi: smartpqi: Correct device removal for multi-actuator devices (Don Brace) [2116978]
- scsi: smartpqi: Change sysfs raid_level attribute to N/A for controllers (Don Brace) [2116978]
- scsi: smartpqi: Correct max LUN number (Don Brace) [2116978]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [2116978]
- scsi: smartpqi: Convert to host_tagset (Don Brace) [2116978]
- scsi: smartpqi: Stop using the SCSI pointer (Don Brace) [2116978]
- scsi: smartpqi: Call scsi_done() directly (Don Brace) [2116978]
- smartpqi: Change request pointer to scsi_cmd_to_rq (Don Brace) [2116978]
- scsi: smartpqi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Don Brace) [2116978]

* Wed Nov 30 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-204.el9]
- Documentation/admin-guide: Document nomodeset kernel parameter (Karol Herbst) [2143841]
- drm: Move nomodeset kernel parameter to the DRM subsystem (Karol Herbst) [2143841]
- Add rtla subpackage (John Kacur) [2075216]
- dt-bindings: mmc: PL18x stop relying on order of dma-names (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add i.MX8DXL compatible string (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Update compatible fallbacks (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add imx93 compatible string (Steve Best) [2137969]
- dt-bindings: mmc: Add missing properties used in examples (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: add i.MXRT compatible string (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add imx8ulp compatible string (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: change the pinctrl-names rule (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: add a new compatible string (Steve Best) [2137969]
- MAINTAINERS: Update Kishon's email address in PCI endpoint subsystem (Myron Stowe) [2135902]
- MAINTAINERS: Add Vignesh Raghavendra as maintainer of TI DRA7XX/J721E PCI driver (Myron Stowe) [2135902]
- MAINTAINERS: Add Mahesh J Salgaonkar as EEH maintainer (Myron Stowe) [2135902]
- MAINTAINERS: Add Manivannan Sadhasivam as PCI Endpoint reviewer (Myron Stowe) [2135902]
- PCI/P2PDMA: Use for_each_pci_dev() helper (Myron Stowe) [2135902]
- PCI: mt7621: Use PCI_CONF1_EXT_ADDRESS() macro (Myron Stowe) [2135902]
- PCI: ftpci100: Use PCI_CONF1_ADDRESS() macro (Myron Stowe) [2135902]
- PCI: Add standard PCI Config Address macros (Myron Stowe) [2135902]
- PCI: qcom-ep: Check platform_get_resource_byname() return value (Myron Stowe) [2135902]
- PCI: qcom-ep: Add support for SM8450 SoC (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Add support for SM8450 SoC (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Define clocks per platform (Myron Stowe) [2135902]
- PCI: qcom-ep: Make PERST separation optional (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Make PERST separation optional (Myron Stowe) [2135902]
- PCI: qcom-ep: Disable Master AXI Clock when there is no PCIe traffic (Myron Stowe) [2135902]
- PCI: qcom-ep: Gate Master AXI clock to MHI bus during L1SS (Myron Stowe) [2135902]
- PCI: qcom-ep: Expose link transition counts via debugfs (Myron Stowe) [2135902]
- PCI: qcom-ep: Disable IRQs during driver remove (Myron Stowe) [2135902]
- PCI: qcom-ep: Make use of the cached dev pointer (Myron Stowe) [2135902]
- PCI: qcom-ep: Rely on the clocks supplied by devicetree (Myron Stowe) [2135902]
- PCI: qcom-ep: Add kernel-doc for qcom_pcie_ep structure (Myron Stowe) [2135902]
- PCI: qcom: Rename host-init error label (Myron Stowe) [2135902]
- PCI: qcom: Drop unused post_deinit callback (Myron Stowe) [2135902]
- PCI: qcom-ep: Add MODULE_DEVICE_TABLE (Myron Stowe) [2135902]
- PCI: qcom: Sort device-id table (Myron Stowe) [2135902]
- PCI: qcom: Clean up IP configurations (Myron Stowe) [2135902]
- PCI: qcom: Make all optional clocks optional (Myron Stowe) [2135902]
- PCI: qcom: Add support for SA8540P (Myron Stowe) [2135902]
- PCI: qcom: Add support for SC8280XP (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Add SA8540P to binding (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Add SC8280XP to binding (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Enumerate platforms with single msi interrupt (Myron Stowe) [2135902]
- PCI: mvebu: Fix endianness when accessing PCI emul bridge members (Myron Stowe) [2135902]
- PCI: mediatek-gen3: Change driver name to mtk-pcie-gen3 (Myron Stowe) [2135902]
- phy: freescale: imx8m-pcie: Fix the wrong order of phy_init() and phy_power_on() (Myron Stowe) [2135902]
- PCI: imx6: Add i.MX8MP PCIe support (Myron Stowe) [2135902]
- PCI: dwc: Replace of_gpio_named_count() by gpiod_count() (Myron Stowe) [2135902]
- PCI: dwc: Drop dependency on ZONE_DMA32 (Myron Stowe) [2135902]
- dt-bindings: pci: QCOM Add missing sc7280 aggre0, aggre1 clocks (Myron Stowe) [2135902]
- dt-bindings: PCI: microchip,pcie-host: fix missing dma-ranges (Myron Stowe) [2135902]
- dt-bindings: PCI: microchip,pcie-host: fix missing clocks properties (Myron Stowe) [2135902]
- dt-bindings: PCI: mediatek-gen3: Add support for MT8188 and MT8195 (Myron Stowe) [2135902]
- PCI: pci-bridge-emul: Set position of PCI capabilities to real HW value (Myron Stowe) [2135902]
- PCI: aardvark: Add support for PCI Bridge Subsystem Vendor ID on emulated bridge (Myron Stowe) [2135902]
- PCI: Sanitise firmware BAR assignments behind a PCI-PCI bridge (Myron Stowe) [2135902]
- PCI: Fix typo in pci_scan_child_bus_extend() (Myron Stowe) [2135902]
- PCI: Fix whitespace and indentation (Myron Stowe) [2135902]
- PCI: Move pci_assign_unassigned_root_bus_resources() (Myron Stowe) [2135902]
- PCI: Pass available buses even if the bridge is already configured (Myron Stowe) [2135902]
- PCI: Fix used_buses calculation in pci_scan_child_bus_extend() (Myron Stowe) [2135902]
- PCI: Expose PCIe Resizable BAR support via sysfs (Myron Stowe) [2135902]
- PCI/PM: Reduce D3hot delay with usleep_range() (Myron Stowe) [2135902]
- PCI/PM: Simplify pci_pm_suspend_noirq() (Myron Stowe) [2135902]
- PCI/PM: Always disable PTM for all devices during suspend (Myron Stowe) [2135902]
- PCI/PTM: Consolidate PTM interface declarations (Myron Stowe) [2135902]
- PCI/PTM: Reorder functions in logical order (Myron Stowe) [2135902]
- PCI/PTM: Preserve RsvdP bits in PTM Control register (Myron Stowe) [2135902]
- PCI/PTM: Move pci_ptm_info() body into its only caller (Myron Stowe) [2135902]
- PCI/PTM: Add pci_suspend_ptm() and pci_resume_ptm() (Myron Stowe) [2135902]
- PCI/PTM: Separate configuration and enable (Myron Stowe) [2135902]
- PCI/PTM: Add pci_upstream_ptm() helper (Myron Stowe) [2135902]
- PCI/PTM: Cache PTM Capability offset (Myron Stowe) [2135902]
- PCI/DPC: Quirk PIO log size for certain Intel Root Ports (Myron Stowe) [2135902]
- PCI/ASPM: Correct LTR_L1.2_THRESHOLD computation (Myron Stowe) [2135902]
- PCI/ASPM: Ignore L1 PM Substates if device lacks capability (Myron Stowe) [2135902]
- PCI/ASPM: Factor out L1 PM Substates configuration (Myron Stowe) [2135902]
- PCI/ASPM: Save L1 PM Substates Capability for suspend/resume (Myron Stowe) [2135902]
- PCI/ASPM: Refactor L1 PM Substates Control Register programming (Myron Stowe) [2135902]
- drm: Implement DRM aperture helpers under video/ (Myron Stowe) [2135902]
- MAINTAINERS: Broaden scope of simpledrm entry (Myron Stowe) [2135902]
- MAINTAINERS: Add simpledrm driver co-maintainer (Myron Stowe) [2135902]
- PCI: qcom: Remove ddrss_sf_tbu clock from SC8180X (Myron Stowe) [2135902]
- ARM: 9100/1: MAINTAINERS: mark all linux-arm-kernel@infradead list as moderated (Myron Stowe) [2135902]
- PM: core: Remove static qualifier in DEFINE_SIMPLE_DEV_PM_OPS macro (Íñigo Huguet) [2147541]
- x86/ftrace: remove return_to_handler SYM_FUNC_END macro (Joe Lawrence) [2144901]
- dt-bindings: pinctrl: imx93: Add pinctrl binding (Steve Best) [2137921]
- pinctrl: imx93: Add MODULE_DEVICE_TABLE() (Steve Best) [2137921]
- ACPI: NUMA: Add CXL CFMWS 'nodes' to the possible nodes set (John W. Linville) [2107254]
- tools/testing/cxl: Fix decoder default state (John W. Linville) [2107254]
- cxl/mbox: Use __le32 in get,set_lsa mailbox structures (John W. Linville) [2107254]
- cxl: Fix cleanup of port devices on failure to probe driver. (John W. Linville) [2107254]
- cxl/mem: Drop mem_enabled check from wait_for_media() (John W. Linville) [2107254]
- cxl/pci: Make cxl_dvsec_ranges() failure not fatal to cxl_pci (John W. Linville) [2107254]
- rehdat/configs:  set missing options relevant to CXL update (John W. Linville) [2107254]
- cxl/pci: Drop shadowed variable (John W. Linville) [2107254]
- cxl/core/port: Fix NULL but dereferenced coccicheck error (John W. Linville) [2107254]
- cxl/port: Hold port reference until decoder release (John W. Linville) [2107254]
- cxl/port: Fix endpoint refcount leak (John W. Linville) [2107254]
- cxl/core: Fix cxl_device_lock() class detection (John W. Linville) [2107254]
- cxl/core/port: Fix unregister_port() lock assertion (John W. Linville) [2107254]
- cxl/regs: Fix size of CXL Capability Header Register (John W. Linville) [2107254]
- cxl/core/port: Handle invalid decoders (John W. Linville) [2107254]
- cxl/core/port: Fix / relax decoder target enumeration (John W. Linville) [2107254]
- tools/testing/cxl: Add a physical_node link (John W. Linville) [2107254]
- tools/testing/cxl: Enumerate mock decoders (John W. Linville) [2107254]
- tools/testing/cxl: Mock one level of switches (John W. Linville) [2107254]
- tools/testing/cxl: Fix root port to host bridge assignment (John W. Linville) [2107254]
- tools/testing/cxl: Mock dvsec_ranges() (John W. Linville) [2107254]
- cxl/core/port: Add endpoint decoders (John W. Linville) [2107254]
- cxl/core: Move target_list out of base decoder attributes (John W. Linville) [2107254]
- cxl/mem: Add the cxl_mem driver (John W. Linville) [2107254]
- cxl/core/port: Add switch port enumeration (John W. Linville) [2107254]
- cxl/memdev: Add numa_node attribute (John W. Linville) [2107254]
- cxl/pci: Emit device serial number (John W. Linville) [2107254]
- cxl/pci: Implement wait for media active (John W. Linville) [2107254]
- cxl/pci: Retrieve CXL DVSEC memory info (John W. Linville) [2107254]
- cxl/pci: Cache device DVSEC offset (John W. Linville) [2107254]
- cxl/pci: Store component register base in cxlds (John W. Linville) [2107254]
- cxl/core/port: Remove @host argument for dport + decoder enumeration (John W. Linville) [2107254]
- cxl/port: Add a driver for 'struct cxl_port' objects (John W. Linville) [2107254]
- cxl/core: Emit modalias for CXL devices (John W. Linville) [2107254]
- cxl/core/hdm: Add CXL standard decoder enumeration to the core (John W. Linville) [2107254]
- cxl/core: Generalize dport enumeration in the core (John W. Linville) [2107254]
- cxl/pci: Rename pci.h to cxlpci.h (John W. Linville) [2107254]
- cxl/port: Up-level cxl_add_dport() locking requirements to the caller (John W. Linville) [2107254]
- cxl/pmem: Introduce a find_cxl_root() helper (John W. Linville) [2107254]
- cxl/port: Introduce cxl_port_to_pci_bus() (John W. Linville) [2107254]
- cxl/core/port: Use dedicated lock for decoder target list (John W. Linville) [2107254]
- cxl: Prove CXL locking (John W. Linville) [2107254]
- cxl/core: Track port depth (John W. Linville) [2107254]
- cxl/core/port: Make passthrough decoder init implicit (John W. Linville) [2107254]
- cxl/core: Fix cxl_probe_component_regs() error message (John W. Linville) [2107254]
- cxl/core/port: Clarify decoder creation (John W. Linville) [2107254]
- cxl/core: Convert decoder range to resource (John W. Linville) [2107254]
- cxl/decoder: Hide physical address information from non-root (John W. Linville) [2107254]
- cxl/core/port: Rename bus.c to port.c (John W. Linville) [2107254]
- cxl: Introduce module_cxl_driver (John W. Linville) [2107254]
- cxl/acpi: Map component registers for Root Ports (John W. Linville) [2107254]
- cxl/pci: Add new DVSEC definitions (John W. Linville) [2107254]
- cxl: Flesh out register names (John W. Linville) [2107254]
- cxl/pci: Defer mailbox status checks to command timeouts (John W. Linville) [2107254]
- cxl/pci: Implement Interface Ready Timeout (John W. Linville) [2107254]
- cxl: Rename CXL_MEM to CXL_PCI (John W. Linville) [2107254]
- ACPI: NUMA: Add a node and memblk for each CFMWS not in SRAT (John W. Linville) [2107254]
- cxl/test: Mock acpi_table_parse_cedt() (John W. Linville) [2107254]
- cxl/acpi: Convert CFMWS parsing to ACPI sub-table helpers (John W. Linville) [2107254]
- cxl/pci: Use pci core's DVSEC functionality (John W. Linville) [2107254]
- cxl/core: Replace unions with struct_group() (John W. Linville) [2107254]
- PCI: Add pci_find_dvsec_capability to find designated VSEC (John W. Linville) [2107254]
- net: remove noblock parameter from skb_recv_datagram() (Íñigo Huguet) [2143360]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104465]
- e1000e: convert .adjfreq to .adjfine (Ken Cox) [2104465]
- e1000e: remove unnecessary range check in e1000e_phc_adjfreq (Ken Cox) [2104465]
- Revert "e1000e: Fix possible HW unit hang after an s0ix exit" (Ken Cox) [2104465]
- e1000e: Enable GPT clock before sending message to CSME (Ken Cox) [2104465]
- intel/e1000e:fix repeated words in comments (Ken Cox) [2104465]
- intel: remove unused macros (Ken Cox) [2104465]
- e1000e: Remove useless DMA-32 fallback configuration (Ken Cox) [2104465]

* Tue Nov 29 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-203.el9]
- udp: Update reuse->has_conns under reuseport_lock. (Xin Long) [2135958]
- udp: Remove redundant __udp_sysctl_init() call from udp_init(). (Xin Long) [2135958]
- udp: Fix a data-race around sysctl_udp_l3mdev_accept. (Xin Long) [2135958]
- udplite: remove udplite_csum_outgoing() (Xin Long) [2135958]
- udp: remove inner_udp_hdr() (Xin Long) [2135958]
- net: udp: fix alignment problem in udp4_seq_show() (Xin Long) [2135958]
- x86/insn: Add AVX512-FP16 instructions to the x86 instruction decoder (Michael Petlan) [2140492]
- x86/insn: Add misc instructions to x86 instruction decoder (Michael Petlan) [2140492]
- x86/insn: Add AMX instructions to the x86 instruction decoder (Michael Petlan) [2140492]
- powerpc/64/kdump: Limit kdump base to 512MB (Mamatha Inamdar) [2127026]
- net: wrap the wireless pointers in struct net_device in an ifdef (Íñigo Huguet) [2143376]
- s390/pci: add missing EX_TABLE entries to __pcistg_mio_inuser()/__pcilg_mio_inuser() (Tobias Huschle) [2141962]
- s390/futex: add missing EX_TABLE entry to __futex_atomic_op() (Tobias Huschle) [2141962]
- s390/uaccess: add missing EX_TABLE entries to __clear_user() (Tobias Huschle) [2141962]
- s390/boot: add secure boot trailer (Tobias Huschle) [2141966]
- intel_idle: Add AlderLake-N support (David Arcari) [2144693]
- ipv6: Use ipv6_only_sock() helper in condition. (Ivan Vecera) [2144847]
- ipv6: Remove __ipv6_only_sock(). (Ivan Vecera) [2144847]
- powerpc/fadump: print start of preserved area (Mamatha Inamdar) [2108291]
- powerpc/fadump: align destination address to pagesize (Mamatha Inamdar) [2108291]
- powerpc/fadump: fix PT_LOAD segment for boot memory area (Mamatha Inamdar) [2108291]
- ethtool: add header/data split indication (Josef Oskera) [2141648]
- thermal/core: Add missing EXPORT_SYMBOL_GPL (Al Stone) [2071849]
- thermal: Drop obsolete dependency on COMPILE_TEST (Al Stone) [2071849]
- thermal: sysfs: Fix cooling_device_stats_setup() error code path (Al Stone) [2071849]
- thermal/of: Initialize trip points separately (Al Stone) [2071849]
- thermal/of: Use thermal trips stored in the thermal zone (Al Stone) [2071849]
- thermal/core: Add thermal_trip in thermal_zone (Al Stone) [2071849]
- thermal/core: Rename 'trips' to 'num_trips' (Al Stone) [2071849]
- thermal/core: Move thermal_set_delay_jiffies to static (Al Stone) [2071849]
- thermal/core: Remove unneeded EXPORT_SYMBOLS (Al Stone) [2071849]
- thermal/of: Move thermal_trip structure to thermal.h (Al Stone) [2071849]
- thermal/of: Remove the device node pointer for thermal_trip (Al Stone) [2071849]
- thermal/of: Replace device node match with device node search (Al Stone) [2071849]
- thermal/core: Remove duplicate information when an error occurs (Al Stone) [2071849]
- thermal/core: Avoid calling ->get_trip_temp() unnecessarily (Al Stone) [2071849]
- thermal/core: Remove DROP_FULL and RAISE_FULL (Al Stone) [2071849]
- thermal/core: Use clamp() helper in the stepwise governor (Al Stone) [2071849]
- thermal/drivers/tegra: Remove get_trend function (Al Stone) [2071849]
- drivers/thermal/devfreq_cooling: Extend the devfreq_cooling_device with ops (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling: Update outdated comments (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling : Refactor thermal_power_cpu_get_power tracing (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling: Use private callback ops for each cooling device (Al Stone) [2071849]
- PM: EM: convert power field to micro-Watts precision and align drivers (Al Stone) [2071849]
- PM: EM: Use the new .get_cost() callback while registering EM (Al Stone) [2071849]
- PM: EM: Decrement policy counter (Al Stone) [2071849]
- PM: EM: Mark inefficiencies in CPUFreq (Al Stone) [2071849]
- PM: EM: Remove old debugfs files and print all 'flags' (Al Stone) [2071849]
- thermal: Directly use ida_alloc()/free() (Al Stone) [2071849]
- thermal/drivers/thermal_hwmon: Use hwmon_device_register_for_thermal() (Al Stone) [2071849]
- hwmon: Introduce hwmon_device_register_for_thermal (Al Stone) [2071849]
- thermal: k3_j72xx_bandgap: Add the bandgap driver support (Al Stone) [2071849]
- thermal/drivers/imx_sc_thermal: Fix refcount leak in imx_sc_thermal_probe (Al Stone) [2071849]
- thermal/core: Fix memory leak in __thermal_cooling_device_register() (Al Stone) [2071849]
- thermal: thermal_of: fix typo on __thermal_bind_params (Al Stone) [2071849]
- thermal/drivers/thermal_of: Add change_mode ops support for thermal_of sensor (Al Stone) [2071849]
- thermal/governor: Remove deprecated information (Al Stone) [2071849]
- thermal: devfreq_cooling: use local ops instead of global ops (Al Stone) [2071849]
- thermal: cooling: Check Energy Model type in cpufreq_cooling and devfreq_cooling (Al Stone) [2071849]
- thermal: tegra-bpmp: Handle errors in BPMP response (Al Stone) [2071849]
- thermal: core: Fix TZ_GET_TRIP NULL pointer dereference (Al Stone) [2071849]
- thermal/drivers/imx8mm: Enable ADC when enabling monitor (Al Stone) [2071849]
- thermal/drivers: Add TSU driver for RZ/G2L (Al Stone) [2071849]
- thermal/drivers/imx: Implement runtime PM support (Al Stone) [2071849]
- thermal: core: Reset previous low and high trip during thermal zone init (Al Stone) [2071849]
- thermal: Replace pr_warn() with pr_warn_once() in user_space_bind() (Al Stone) [2071849]
- thermal: Fix NULL pointer dereferences in of_thermal_ functions (Al Stone) [2071849]
- thermal/core: Make the userspace governor deprecated (Al Stone) [2071849]
- thermal/core: fix a UAF bug in __thermal_cooling_device_register() (Al Stone) [2071849]
- thermal/core: Fix null pointer dereference in thermal_release() (Al Stone) [2071849]
- thermal/drivers/netlink: Add the temperature when crossing a trip point (Al Stone) [2071849]
- thermal/drivers/thermal_mmio: Constify static struct thermal_mmio_ops (Al Stone) [2071849]
- thermal/drivers/devfreq_cooling: use HZ macros (Al Stone) [2071849]
- thermal/drivers/tegra-soctherm: Silence message about clamped temperature (Al Stone) [2071849]
- thermal: Spelling s/scallbacks/callbacks/ (Al Stone) [2071849]
- thermal/core: Fix thermal_cooling_device_register() prototype (Al Stone) [2071849]
- thermal/drivers/tegra: Correct compile-testing of drivers (Al Stone) [2071849]
- thermal/drivers/tegra: Add driver for Tegra30 thermal sensor (Al Stone) [2071849]
- Revert "powerpc/rtas: Implement reentrant rtas call" (Mamatha Inamdar) [2129156]
- arm64: dts: imx93: correct gpio-ranges (Steve Best) [2137947]
- arm64: dts: imx93: correct s4mu interrupt names (Steve Best) [2137947]
- arm64: dts: imx93: add mediamix blk ctrl node (Steve Best) [2137947]
- arm64: dts: imx93: add src node (Steve Best) [2137947]
- arm64: dts: imx93: add lpspi nodes (Steve Best) [2137947]
- arm64: dts: imx93: add lpi2c nodes (Steve Best) [2137947]
- arm64: dts: imx93: add a55 pmu (Steve Best) [2137947]
- arm64: dts: imx93: add blk ctrl node (Steve Best) [2137947]
- arm64: dts: imx93: add s4 mu node (Steve Best) [2137947]
- arm64: dts: imx93: add gpio clk (Steve Best) [2137947]
- arm64: dts: imx93: correct SDHC clk entry (Steve Best) [2137947]
- arm64: defconfig: enable i.MX93 clk & pinctrl (Steve Best) [2137947]
- dt-bindings: arm: fsl: add imx93 11x11 evk board (Steve Best) [2137947]
- arm64: dts: freescale: add i.MX93 11x11 EVK basic support (Steve Best) [2137947]
- arm64: dts: freescale: Add i.MX93 dtsi support (Steve Best) [2137947]
- powerpc: Don't select HAVE_IRQ_EXIT_ON_IRQ_STACK (Mamatha Inamdar) [2129351]

* Mon Nov 28 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-202.el9]
- build: Fix generating BTF with pahole >=1.24 (Viktor Malik) [2148429]
- selftests: spectrum-2: tc_flower_scale: Dynamically set scale target (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a RIF counter scale test (Ivan Vecera) [2140704]
- selftests: mlxsw: tc_flower_scale: Add a traffic test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Pass target count to cleanup (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Allow skipping a test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Introduce traffic tests (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Update scale target after test setup (Ivan Vecera) [2140704]
- selftests: mirror_gre_bridge_1q_lag: Enslave port to bridge before other configurations (Ivan Vecera) [2140704]
- mlxsw: Add a resource describing number of RIFs (Ivan Vecera) [2140704]
- mlxsw: Keep track of number of allocated RIFs (Ivan Vecera) [2140704]
- mlxsw: Trap ARP packets at layer 3 instead of layer 2 (Ivan Vecera) [2140704]
- mlxsw: Revert "Prepare for XM implementation - LPM trees" (Ivan Vecera) [2140704]
- mlxsw: Revert "Prepare for XM implementation - prefix insertion and removal" (Ivan Vecera) [2140704]
- mlxsw: Revert "Introduce initial XM router support" (Ivan Vecera) [2140704]
- selftests: mlxsw: Add QOS test for maximum use of descriptors (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix IPv4 nexthop gateway indication (Ivan Vecera) [2140704]
- selftests: forwarding: fix learning_test when h1 supports IFF_UNICAST_FLT (Ivan Vecera) [2140704]
- selftests: forwarding: fix flood_unicast_test when h2 supports IFF_UNICAST_FLT (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix rollback in tunnel next hop init (Ivan Vecera) [2140704]
- mlxsw: spectrum_cnt: Reorder counter pools (Ivan Vecera) [2140704]
- mlxsw: Avoid warning during ip6gre device removal (Ivan Vecera) [2140704]
- selftests: forwarding: Add a tunnel-based test for L3 HW stats (Ivan Vecera) [2140704]
- selftests: lib: Add a generic helper for obtaining HW stats (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Take router lock in router notifier handler (Ivan Vecera) [2140704]
- mlxsw: spectrum: Update a comment (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of tunnel events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of router events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of HW stats events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of VRF events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add a dedicated notifier block (Ivan Vecera) [2140704]
- mlxsw: spectrum: Tolerate enslaving of various devices to VRF (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Only query neighbour activity when necessary (Ivan Vecera) [2140704]
- mlxsw: spectrum_switchdev: Only query FDB notifications when necessary (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl: Do not report activity for multicast routes (Ivan Vecera) [2140704]
- mlxsw: Treat LLDP packets as control (Ivan Vecera) [2140704]
- mlxsw: spectrum_dcb: Do not warn about priority changes (Ivan Vecera) [2140704]
- selftests: router.sh: Add a diagram (Ivan Vecera) [2140704]
- selftests: router_vid_1: Add a diagram, fix coding style (Ivan Vecera) [2140704]
- selftests: mlxsw: bail_on_lldpad before installing the cleanup trap (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test for soaking up a burst of traffic (Ivan Vecera) [2140704]
- selftests: forwarding: lib: Add start_traffic_pktsize() helpers (Ivan Vecera) [2140704]
- mlxsw: Configure descriptor buffers (Ivan Vecera) [2140704]
- mlxsw: reg: Add "desc" field to SBPR (Ivan Vecera) [2140704]
- selftests: mirror_gre_bridge_1q: Avoid changing PVID while interface is operational (Ivan Vecera) [2140704]
- Revert "Merge branch 'mlxsw-line-card-model'" (Ivan Vecera) [2140704]
- selftests: mlxsw: Check device info on activated line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Expose device FW version over device info (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MDDQ device_info by FW version fields (Ivan Vecera) [2140704]
- selftests: mlxsw: Check line card info on provisioned line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Expose HW revision and INI version (Ivan Vecera) [2140704]
- selftests: mlxsw: Check devices on provisioned line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Probe provisioned line cards for devices and attach them (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MDDQ by device_info (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Fix size of array element during ini_files allocation (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_flooding_ipv6: Prevent flooding of unwanted packets (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_flooding: Prevent flooding of unwanted packets (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_env: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_env: Split module power mode setting to a separate function (Ivan Vecera) [2140704]
- mlxsw: core: Add bus argument to environment init API (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Introduce ops for linecards status change tracking (Ivan Vecera) [2140704]
- selftests: mlxsw: Introduce devlink line card provision/unprovision/activation tests (Ivan Vecera) [2140704]
- mlxsw: spectrum: Add port to linecard mapping (Ivan Vecera) [2140704]
- mlxsw: core: Extend driver ops by remove selected ports op (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Implement line card activation process (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Add line card objects and implement provisioning (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management Binary Code Transfer Register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management DownStream Device Control Register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management DownStream Device Query Register (Ivan Vecera) [2140704]
- mlxsw: spectrum: Introduce port mapping change event processing (Ivan Vecera) [2140704]
- mlxsw: Narrow the critical section of devl_lock during ports creation/removal (Ivan Vecera) [2140704]
- mlxsw: reg: Add Ports Mapping Event Configuration Register (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allocate port mapping array of structs instead of pointers (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allow lane to start from non-zero index (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Use common define for thermal zone name length (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Use exact name of cooling devices for binding (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Add line card id prefix to line card thermal zone name (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Extend internal structures to support multi thermal areas (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Introduce slot parameter in hwmon interfaces (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Extend internal structures to support multi hwmon objects (Ivan Vecera) [2140704]
- mlxsw: core: Move port module events enablement to a separate function (Ivan Vecera) [2140704]
- mlxsw: core: Extend port module data structures for line cards (Ivan Vecera) [2140704]
- mlxsw: core: Extend interfaces for cable info access with slot argument (Ivan Vecera) [2140704]
- mlxsw: reg: Add new field to Management General Peripheral Information Register (Ivan Vecera) [2140704]
- mlxsw: core_env: Pass slot index during PMAOS register write call (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MGPIR register with new slot fields (Ivan Vecera) [2140704]
- mlxsw: reg: Extend PMMP register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MCION register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MCIA register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MTBR register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MTMP register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: i2c: Fix initialization error flow (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: simplify list unwinding (Ivan Vecera) [2140704]
- selftests: mlxsw: hw_stats_l3: Add a new test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Fix return value (Ivan Vecera) [2140704]
- selftests: mlxsw: tc_police_scale: Make test more robust (Ivan Vecera) [2140704]
- mlxsw: Add support for IFLA_OFFLOAD_XSTATS_L3_STATS (Ivan Vecera) [2140704]
- mlxsw: Extract classification of router-related events to a helper (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Drop mlxsw_sp arg from counter alloc/free functions (Ivan Vecera) [2140704]
- mlxsw: reg: Fix packing of router interface counters (Ivan Vecera) [2140704]
- mlxsw: core: Add support for OSFP transceiver modules (Ivan Vecera) [2140704]
- mlxsw: Remove resource query check (Ivan Vecera) [2140704]
- mlxsw: core: Unify method of trap support validation (Ivan Vecera) [2140704]
- mlxsw: spectrum: Remove SP{1,2,3} defines for FW minor and subminor (Ivan Vecera) [2140704]
- mlxsw: core: Remove unnecessary asserts (Ivan Vecera) [2140704]
- mlxsw: reg: Add "mgpir_" prefix to MGPIR fields comments (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Remove obsolete API for query resource (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Rename labels according to naming convention (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Fix variable names for hwmon attributes (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Avoid creation of virtual hwmon objects by thermal module (Ivan Vecera) [2140704]
- mlxsw: spectrum_span: Ignore VLAN entries not used by the bridge in mirroring (Ivan Vecera) [2140704]
- mlxsw: core: Prevent trap group setting if driver does not support EMAD (Ivan Vecera) [2140704]
- mlxsw: spectrum: remove guards against !BRIDGE_VLAN_INFO_BRENTRY (Ivan Vecera) [2140704]
- mlxsw: Support FLOW_ACTION_MANGLE for SIP and DIP IPv6 addresses (Ivan Vecera) [2140704]
- mlxsw: Support FLOW_ACTION_MANGLE for SIP and DIP IPv4 addresses (Ivan Vecera) [2140704]
- mlxsw: core_acl_flex_actions: Add SIP_DIP_ACTION (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl: Allocate default actions for internal TCAM regions (Ivan Vecera) [2140704]
- mlxsw: spectrum: Guard against invalid local ports (Ivan Vecera) [2140704]
- mlxsw: core: Consolidate trap groups to a single event group (Ivan Vecera) [2140704]
- mlxsw: core: Move functions to register/unregister array of traps to core.c (Ivan Vecera) [2140704]
- mlxsw: core: Move basic trap group initialization from spectrum.c (Ivan Vecera) [2140704]
- mlxsw: core: Move basic_trap_groups_set() call out of EMAD init code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Set basic trap groups from an array (Ivan Vecera) [2140704]
- mlxsw: spectrum_kvdl: Use struct_size() helper in kzalloc() (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid module reset on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid power mode set and get on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid getting module EEPROM on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Query and store port module's type during initialization (Ivan Vecera) [2140704]
- mlxsw: reg: Add Port Module Type Mapping register (Ivan Vecera) [2140704]
- mlxsw: spectrum_ethtool: Add support for two new link modes (Ivan Vecera) [2140704]
- mlxsw: Add netdev argument to mlxsw_env_get_module_info() (Ivan Vecera) [2140704]
- mlxsw: core_env: Do not pass number of modules as argument (Ivan Vecera) [2140704]
- mlxsw: spectrum_ethtool: Remove redundant variable (Ivan Vecera) [2140704]
- mlxsw: spectrum: Extend to support Spectrum-4 ASIC (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Add support for Spectrum-4 calculation (Ivan Vecera) [2140704]
- mlxsw: Add operations structure for bloom filter calculation (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Rename Spectrum-2 specific objects for future use (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Make mlxsw_sp_acl_bf_key_encode() more flexible (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Reorder functions to make the code more aesthetic (Ivan Vecera) [2140704]
- mlxsw: Introduce flex key elements for Spectrum-4 (Ivan Vecera) [2140704]
- mlxsw: Rename virtual router flex key element (Ivan Vecera) [2140704]
- mlxsw: pci: Avoid flow control for EMAD packets (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_vxlan: Fix 'decap_error' case (Ivan Vecera) [2140704]
- selftests: mlxsw: Add test for VxLAN related traps for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: spectrum-2: Add a test for VxLAN flooding with IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: spectrum: Add a test for VxLAN flooding with IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: Add VxLAN FDB veto test for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_fdb_veto: Make the test more flexible for future use (Ivan Vecera) [2140704]
- selftests: mlxsw: Add VxLAN configuration test for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan: Make the test more flexible for future use (Ivan Vecera) [2140704]
- mlxsw: spectrum_flower: Make vlan_id limitation more specific (Ivan Vecera) [2140704]
- mlxsw: core: Extend devlink health reporter with new events and parameters (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MFDE register with new events and parameters (Ivan Vecera) [2140704]
- mlxsw: core: Convert a series of if statements to switch case (Ivan Vecera) [2140704]
- mlxsw: Fix naming convention of MFDE fields (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan: Remove IPv6 test case (Ivan Vecera) [2140704]
- mlxsw: Add support for VxLAN with IPv6 underlay (Ivan Vecera) [2140704]
- mlxsw: spectrum_nve: Keep track of IPv6 addresses used by FDB entries (Ivan Vecera) [2140704]
- mlxsw: reg: Add a function to fill IPv6 unicast FDB entries (Ivan Vecera) [2140704]
- mlxsw: Split handling of FDB tunnel entries between address families (Ivan Vecera) [2140704]
- mlxsw: spectrum_nve_vxlan: Make VxLAN flags check per address family (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Use common hash table for IPv6 address mapping (Ivan Vecera) [2140704]
- mlxsw: spectrum: Add hash table for IPv6 address mapping (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test case for MAC profiles consolidation (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Consolidate MAC profiles when possible (Ivan Vecera) [2140704]
- mlxsw: Use Switch Multicast ID Register Version 2 (Ivan Vecera) [2140704]
- mlxsw: Use Switch Flooding Table Register Version 2 (Ivan Vecera) [2140704]
- mlxsw: Add support for more than 256 ports in SBSR register (Ivan Vecera) [2140704]
- mlxsw: Use u16 for local_port field instead of u8 (Ivan Vecera) [2140704]
- mlxsw: reg: Adjust PPCNT register to support local port 255 (Ivan Vecera) [2140704]
- mlxsw: reg: Increase 'port_num' field in PMTDB register (Ivan Vecera) [2140704]
- mlxsw: reg: Align existing registers to use extended local_port field (Ivan Vecera) [2140704]
- mlxsw: item: Add support for local_port field in a split form (Ivan Vecera) [2140704]
- mlxsw: reg: Remove unused functions (Ivan Vecera) [2140704]
- mlxsw: spectrum: Bump minimum FW version to xx.2010.1006 (Ivan Vecera) [2140704]
- mlxsw: spectrum: Protect driver from buggy firmware (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allow driver to load with old firmware versions (Ivan Vecera) [2140704]
- mlxsw: pci: Add shutdown method in PCI driver (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Remove deadcode in mlxsw_sp_rif_mac_profile_find (Ivan Vecera) [2140704]
- mlxsw: constify address in mlxsw_sp_port_dev_addr_set (Ivan Vecera) [2140704]
- selftests: mlxsw: Test port shaper (Ivan Vecera) [2140704]
- selftests: mlxsw: Test offloadability of root TBF (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Offload root TBF as port shaper (Ivan Vecera) [2140704]
- selftests: mlxsw: Remove deprecated test cases (Ivan Vecera) [2140704]
- selftests: Add an occupancy test for RIF MAC profiles (Ivan Vecera) [2140704]
- selftests: mlxsw: Add forwarding test for RIF MAC profiles (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a scale test for RIF MAC profiles (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Expose RIF MAC profiles to devlink resource (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add RIF MAC profiles support (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Propagate extack further (Ivan Vecera) [2140704]
- mlxsw: resources: Add resource identifier for RIF MAC profiles (Ivan Vecera) [2140704]
- mlxsw: reg: Add MAC profile ID field to RITR register (Ivan Vecera) [2140704]
- mlxsw: pci: Recycle received packet upon allocation failure (Ivan Vecera) [2140704]
- mlxsw: spectrum: Use 'bitmap_zalloc()' when applicable (Ivan Vecera) [2140704]
- selftests: mlxsw: Reduce test run time (Ivan Vecera) [2140704]
- selftests: mlxsw: Use permanent neighbours instead of reachable ones (Ivan Vecera) [2140704]
- selftests: mlxsw: Add helpers for skipping selftests (Ivan Vecera) [2140704]
- ethernet: mlxsw: use eth_hw_addr_gen() (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test for un/offloadable qdisc trees (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Make RED, TBF offloads classful (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Validate qdisc topology (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Clean stats recursively when priomap changes (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Unify graft validation (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Destroy children in mlxsw_sp_qdisc_destroy() (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Extract two helpers for handling future FIFOs (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Query tclass / priomap instead of caching it (Ivan Vecera) [2140704]
- selftests: mlxsw: RED: Test per-TC ECN counters (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Introduce per-TC ECN counters (Ivan Vecera) [2140704]
- mlxsw: reg: Add ecn_marked_tc to Per-TC Congestion Counters (Ivan Vecera) [2140704]
- mlxsw: reg: Rename MLXSW_REG_PPCNT_TC_CONG_TC to _CNT (Ivan Vecera) [2140704]
- mlxsw: reg: Fix a typo in a group heading (Ivan Vecera) [2140704]
- mlxsw: thermal: Fix out-of-bounds memory accesses (Ivan Vecera) [2140704]
- selftests: mlxsw: RED: Add selftests for the mark qevent (Ivan Vecera) [2140704]
- selftests: mlxsw: sch_red_core: Drop two unused variables (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Offload RED qevent mark (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Track permissible actions per binding (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Distinguish between ingress and egress triggers (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Pass extack to mlxsw_sp_qevent_entry_configure() (Ivan Vecera) [2140704]
- mlxsw: item: Annotate item helpers with '__maybe_unused' (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Send a full-length key (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Remove code duplication (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Align topology drawing correctly (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip6: Add test case for IPv6 decap_error (Ivan Vecera) [2140704]
- mlxsw: Add support for transceiver module extended state (Ivan Vecera) [2140704]
- mlxsw: Add ability to control transceiver modules' power mode (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management Cable IO and Notifications register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Port Module Memory Map Properties register (Ivan Vecera) [2140704]
- mlxsw: spectrum_buffers: silence uninitialized warning (Ivan Vecera) [2140704]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ivan Vecera) [2140704]
- mlxsw: Add support for IP-in-IP with IPv6 underlay for Spectrum-2 and above (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Increase parsing depth for IPv6 decapsulation (Ivan Vecera) [2140704]
- mlxsw: Add IPV6_ADDRESS kvdl entry type (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Add mlxsw_sp_ipip_gre6_ops (Ivan Vecera) [2140704]
- mlxsw: Create separate ipip_ops_arr for different ASICs (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for ritr_loopback_ipip6_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for ratr_ipip6_entry_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for rtdp_ipip6_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add Router IP version Six Register (Ivan Vecera) [2140704]
- mlxsw: Take tunnel's type into account when searching underlay device (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Create common function for mlxsw_sp_ipip_ol_netdev_change_gre() (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix arguments alignment (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Pass IP tunnel parameters by reference and as 'const' (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Create common function for fib_entry_type_unset() code (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Start using new trap adjacency entry (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add trap adjacency entry upon first nexthop group (Ivan Vecera) [2140704]
- mlxsw: Add support for transceiver modules reset (Ivan Vecera) [2140704]
- mlxsw: Make PMAOS pack function more generic (Ivan Vecera) [2140704]
- mlxsw: reg: Add fields to PMAOS register (Ivan Vecera) [2140704]
- mlxsw: Track per-module port status (Ivan Vecera) [2140704]
- mlxsw: spectrum: Do not return an error in mlxsw_sp_port_module_unmap() (Ivan Vecera) [2140704]
- mlxsw: spectrum: Do not return an error in ndo_stop() (Ivan Vecera) [2140704]
- mlxsw: core_env: Convert 'module_info_lock' to a mutex (Ivan Vecera) [2140704]
- mlxsw: core_env: Defer handling of module temperature warning events (Ivan Vecera) [2140704]
- mlxsw: core: Remove mlxsw_core_is_initialized() (Ivan Vecera) [2140704]
- mlxsw: core: Initialize switch driver last (Ivan Vecera) [2140704]
- net: switchdev: Simplify 'mlxsw_sp_mc_write_mdb_entry()' (Ivan Vecera) [2140704]
- platform/mellanox: nvsw-sn2201: fix error code in nvsw_sn2201_create_static_devices() (Ivan Vecera) [2140704]
- platform/mellanox: Add static in struct declaration. (Ivan Vecera) [2140704]
- i2c: mlxcpld: Add callback to notify probing completion (Ivan Vecera) [2140704]
- i2c: mlxcpld: Fix register setting for 400KHz frequency (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- Documentation/ABI: mlxreg-io: Fix contact info (Ivan Vecera) [2140704]
- platform/mellanox: mlxreg-io: Add locking for io operations (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add COME board revision register (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for new system XH3000 (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Introduce support for COMe NVSwitch management module for Vulcan chassis (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for systems equipped with two ASICs (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add cosmetic changes for alignment (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Make activation of some drivers conditional (Ivan Vecera) [2140704]
- platform/mellanox: Spelling s/platfom/platform/ (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- redhat: Enable support for SN2201 system (Ivan Vecera) [2140704]
- platform/mellanox: Add support for new SN2201 system (Ivan Vecera) [2140704]
- platform_data/mlxreg: Add field for notification callback (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Use pwm attribute for setting fan speed low limit (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for new system SGN2410 (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add BIOS attributes for CoffeeLake COMEx based systems (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Extend FAN and LED configuration to support new MQM97xx systems (Ivan Vecera) [2140704]
- watchdog: mlx-wdt: Use regmap_write_bits() (Ivan Vecera) [2140704]
- docs: ABI: fix documentation warning in sysfs-driver-mlxreg-io (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for multiply cooling devices (Ivan Vecera) [2140704]
- Documentation/ABI: Add new line card attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Configure notifier callbacks for modular system (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add initial support for new modular system (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Support distinctive names per different cooling devices (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Modify PWM connectivity validation (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Fix out of bounds read on array fan->pwm (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend driver to support multiply cooling devices (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend driver to support multiply PWM (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend the maximum number of tachometers (Ivan Vecera) [2140704]
- i2c: mlxcpld: Allow flexible polling time setting for I2C transactions (Ivan Vecera) [2140704]
- i2c: mlxcpld: Reduce polling time for performance improvement (Ivan Vecera) [2140704]
- i2c: mlxcpld: Modify register setting for 400KHz frequency (Ivan Vecera) [2140704]
- i2c: mlxcpld: Fix criteria for frequency setting (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Return non-zero value when fan current state is enforced from sysfs (Ivan Vecera) [2140704]
- percpu_ref_init(): clean ->percpu_count_ref on failure (Ian Kent) [2089125]
- ata: libata-core: Print timeout value when internal command times (Ewan D. Milne) [2132143]
- ata: libata-core: fix sloppy parameter type in ata_exec_internal[_sg]() (Ewan D. Milne) [2132143]
- ata: libata-core: make ata_exec_internal_sg() *static* (Ewan D. Milne) [2132143]
- ice: Fix crash by keep old cfg when update TCs more than queues (Petr Oros) [2131953]
- ice: Fix tunnel checksum offload with fragmented traffic (Petr Oros) [2131953]
- ice: handle E822 generic device ID in PLDM header (Petr Oros) [2131953]
- ice: ethtool: Prohibit improper channel config for DCB (Petr Oros) [2131953]
- ice: ethtool: advertise 1000M speeds properly (Petr Oros) [2131953]
- ice: Fix switchdev rules book keeping (Petr Oros) [2131953]
- ice: ignore protocol field in GTP offload (Petr Oros) [2131953]
- ice: fix access-beyond-end in the switch code (Petr Oros) [2131953]
- eth: ice: silence the GCC 12 array-bounds warning (Petr Oros) [2131953]
- ice: Expose RSS indirection tables for queue groups via ethtool (Petr Oros) [2131953]
- Revert "ice: Hide bus-info in ethtool for PRs in switchdev mode" (Petr Oros) [2131953]
- ice: remove period on argument description in ice_for_each_vf (Petr Oros) [2131953]
- ice: add a function comment for ice_cfg_mac_antispoof (Petr Oros) [2131953]
- ice: fix wording in comment for ice_reset_vf (Petr Oros) [2131953]
- ice: remove return value comment for ice_reset_all_vfs (Petr Oros) [2131953]
- ice: always check VF VSI pointer values (Petr Oros) [2131953]
- ice: add newline to dev_dbg in ice_vf_fdir_dump_info (Petr Oros) [2131953]
- ice: get switch id on switchdev devices (Petr Oros) [2131953]
- ice: return ENOSPC when exceeding ICE_MAX_CHAIN_WORDS (Petr Oros) [2131953]
- ice: introduce common helper for retrieving VSI by vsi_num (Petr Oros) [2131953]
- ice: use min_t() to make code cleaner in ice_gnss (Petr Oros) [2131953]
- ice, xsk: Avoid refilling single Rx descriptors (Petr Oros) [2131953]
- ice, xsk: Diversify return values from xsk_wakeup call paths (Petr Oros) [2131953]
- ice, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Petr Oros) [2131953]
- ice, xsk: Decorate ICE_XDP_REDIR with likely() (Petr Oros) [2131953]
- ice: Add mpls+tso support (Petr Oros) [2131953]
- ice: switch: convert packet template match code to rodata (Petr Oros) [2131953]
- ice: switch: use convenience macros to declare dummy pkt templates (Petr Oros) [2131953]
- ice: switch: use a struct to pass packet template params (Petr Oros) [2131953]
- ice: switch: unobscurify bitops loop in ice_fill_adv_dummy_packet() (Petr Oros) [2131953]
- ice: switch: add and use u16[] aliases to ice_adv_lkup_elem::{h, m}_u (Petr Oros) [2131953]
- ice: Fix inconsistent indenting in ice_switch (Petr Oros) [2131953]
- ice: Support GTP-U and GTP-C offload in switchdev (Petr Oros) [2131953]
- kexec_file: Fix kexec_file.c build error for riscv platform (Baoquan He) [2119002]
- x86/setup: use IS_ENABLED(CONFIG_KEXEC_CORE) instead of #ifdef (Baoquan He) [2119002]
- kexec: make crashk_res, crashk_low_res and crash_notes symbols always visible (Baoquan He) [2119002]
- s390/crash: support multi-segment iterators (Baoquan He) [2119002]
- s390/crash: use static swap buffer for copy_to_user_real() (Baoquan He) [2119002]
- s390/crash: move copy_to_user_real() to crash_dump.c (Baoquan He) [2119002]
- s390/zcore: fix race when reading from hardware system area (Baoquan He) [2119002]
- s390/crash: fix incorrect number of bytes to copy to user space (Baoquan He) [2119002]
- s390/crash: remove redundant panic() on save area allocation failure (Baoquan He) [2119002]
- s390/mm: remove unused tprot() function (Baoquan He) [2119002]
- s390/crash: make copy_oldmem_page() return number of bytes copied (Baoquan He) [2119002]
- s390/crash: add missing iterator advance in copy_oldmem_page() (Baoquan He) [2119002]
- vmcoreinfo: add kallsyms_num_syms symbol (Baoquan He) [2119002]
- vmcoreinfo: include kallsyms symbols (Baoquan He) [2119002]
- kallsyms: move declarations to internal header (Baoquan He) [2119002]
- kexec_file: increase maximum file size to 4G (Baoquan He) [2119002]
- fs/kernel_read_file: allow to read files up-to ssize_t (Baoquan He) [2119002]
- ima: force signature verification when CONFIG_KEXEC_SIG is configured (Baoquan He) [2119002]
- kernel/crash_core.c: remove redundant check of ck_cmdline (Baoquan He) [2119002]
- kexec: remove redundant assignments (Baoquan He) [2119002]
- kernel/kexec_core: move kexec_core sysctls into its own file (Baoquan He) [2119002]
- ELF: Remove elf_core_copy_kernel_regs() (Baoquan He) [2119002]
- kexec: drop weak attribute from functions (Baoquan He) [2119002]
- vmcore: convert read_from_oldmem() to take an iov_iter (Baoquan He) [2119002]
- vmcore: convert __read_vmcore to use an iov_iter (Baoquan He) [2119002]
- vmcore: convert copy_oldmem_page() to take an iov_iter (Baoquan He) [2119002]
- fs/proc/kcore.c: remove check of list iterator against head past the loop body (Baoquan He) [2119002]
- ext4: Use folio_invalidate() (Lukas Czerner) [2138131]
- locking: Add __sched to semaphore functions (Waiman Long) [2141431]
- locking/rwsem: Disable preemption while trying for rwsem lock (Waiman Long) [2141431]
- locking: Detect includes rwlock.h outside of spinlock.h (Waiman Long) [2141431]
- locking/percpu-rwsem: Add percpu_is_write_locked() and percpu_is_read_locked() (Waiman Long) [2141431]
- locking/spinlocks: Mark spinlocks noinline when inline spinlocks are disabled (Waiman Long) [2141431]
- locking/lockdep: Fix lockdep_init_map_*() confusion (Waiman Long) [2141431]
- locking/lockdep: Use sched_clock() for random numbers (Waiman Long) [2141431]
- lockdep: Delete local_irq_enable_in_hardirq() (Waiman Long) [2141431]
- locking: Add lock contention tracepoints (Waiman Long) [2141431]
- locking/rwsem: Conditionally wake waiters in reader/writer slowpaths (Waiman Long) [2141431]
- lockdep: Fix -Wunused-parameter for _THIS_IP_ (Waiman Long) [2141431]
- locking/rwsem: Optimize down_read_trylock() under highly contended case (Waiman Long) [2141431]
- sunrpc: Set sk_allocation to GFP_NOFS to avoid using current->task_frag. (Guillaume Nault) [2143920]
- fbcon: Fix delayed takeover locking (Jocelyn Falempe) [2134793]
- fbcon: use min() to make code cleaner (Jocelyn Falempe) [2134793]
- fbcon: Maintain a private array of fb_info (Jocelyn Falempe) [2134793]
- fbcon: untangle fbcon_exit (Jocelyn Falempe) [2134793]
- fbcon: Move more code into fbcon_release (Jocelyn Falempe) [2134793]
- fbcon: Move console_lock for register/unlink/unregister (Jocelyn Falempe) [2134793]
- fbcon: Consistently protect deferred_takeover with console_lock() (Jocelyn Falempe) [2134793]
- fbcon: use lock_fb_info in fbcon_open/release (Jocelyn Falempe) [2134793]
- fbcon: move more common code into fb_open() (Jocelyn Falempe) [2134793]
- fbcon: Ditch error handling for con2fb_release_oldinfo (Jocelyn Falempe) [2134793]
- fbcon: Extract fbcon_open/release helpers (Jocelyn Falempe) [2134793]
- fb: Delete fb_info->queue (Jocelyn Falempe) [2134793]
- fbcon: Replace FBCON_FLAGS_INIT with a boolean (Jocelyn Falempe) [2134793]
- fbcon: Use delayed work for cursor (Jocelyn Falempe) [2134793]
- fbdev/sysfs: Fix locking (Jocelyn Falempe) [2134793]
- fbcon: delete delayed loading code (Jocelyn Falempe) [2134793]
- fbcon: Introduce wrapper for console->fb_info lookup (Jocelyn Falempe) [2134793]
- fbcon: Move fbcon_bmove(_rec) functions (Jocelyn Falempe) [2134793]
- fbcon: delete a few unneeded forward decl (Jocelyn Falempe) [2134793]
- nfsd: fix use-after-free in nfsd_file_do_acquire tracepoint (Jeffrey Layton) [2134882]
- nfsd: put the export reference in nfsd4_verify_deleg_dentry (Jeffrey Layton) [2138866]
- nfsd: fix net-namespace logic in __nfsd_file_cache_purge (Jeffrey Layton) [2134882]
- NFSD: Cap rsize_bop result based on send buffer size (Jeffrey Layton) [2134882]
- NFSD: Remove "inline" directives on op_rsize_bop helpers (Jeffrey Layton) [2134882]
- NFSD: Remove unused nfsd4_compoundargs::cachetype field (Jeffrey Layton) [2134882]
- NFSD: Fix handling of oversized NFSv4 COMPOUND requests (Jeffrey Layton) [2134882]
- NFSD: Increase NFSD_MAX_OPS_PER_COMPOUND (Jeffrey Layton) [2134882]
- nfsd: Fix a memory leak in an error handling path (Jeffrey Layton) [2134882]
- nfsd_splice_actor(): handle compound pages (Jeffrey Layton) [2134882]
- nfsd: rework hashtable handling in nfsd_do_file_acquire (Jeffrey Layton) [2134882]
- nfsd: fix nfsd_file_unhash_and_dispose (Jeffrey Layton) [2134882]
- NFS: unlink/rmdir shouldn't call d_delete() twice on ENOENT (Jeffrey Layton) [2134882]
- SUNRPC: Fix READ_PLUS crasher (Jeffrey Layton) [2134882]
- SUNRPC: Remove pointer type casts from xdr_get_next_encode_buffer() (Jeffrey Layton) [2134882]
- SUNRPC: Clean up xdr_get_next_encode_buffer() (Jeffrey Layton) [2134882]
- vfs: fix copy_file_range() regression in cross-fs copies (Jeffrey Layton) [2134882]
- nfp: bpf: Fix typo 'the the' in comment (Stefan Assmann) [2137471]
- ip: Fix data-races around sysctl_ip_default_ttl. (Stefan Assmann) [2137471]
- nfp: flower: configure tunnel neighbour on cmsg rx (Stefan Assmann) [2137471]
- nfp: fix issue of skb segments exceeds descriptor limitation (Stefan Assmann) [2137471]
- nfp: flower: restructure flow-key for gre+vlan combination (Stefan Assmann) [2137471]
- nfp: avoid unnecessary check warnings in nfp_app_get_vf_config (Stefan Assmann) [2137471]
- nfp: remove padding in nfp_nfdk_tx_desc (Stefan Assmann) [2137471]
- nfp: only report pause frame configuration for physical device (Stefan Assmann) [2137471]
- nfp: flower: fix typo in comment (Stefan Assmann) [2137471]
- nfp: flower: support ct merging when mangle action exists (Stefan Assmann) [2137471]
- nfp: VF rate limit support (Stefan Assmann) [2137471]
- nfp: flower: fix 'variable 'flow6' set but not used' (Stefan Assmann) [2137471]
- nfp: support Corigine PCIE vendor ID (Stefan Assmann) [2137471]
- nfp: vendor neutral strings for chip and Corigne in strings for driver (Stefan Assmann) [2137471]
- nfp: flower: enable decap_v2 bit (Stefan Assmann) [2137471]
- nfp: flower: remove unused neighbour cache (Stefan Assmann) [2137471]
- nfp: flower: link pre_tun flow rules with neigh entries (Stefan Assmann) [2137471]
- nfp: flower: rework tunnel neighbour configuration (Stefan Assmann) [2137471]
- nfp: flower: update nfp_tun_neigh structs (Stefan Assmann) [2137471]
- nfp: flower: fixup ipv6/ipv4 route lookup for neigh events (Stefan Assmann) [2137471]
- nfp: flower: enforce more strict pre_tun checks (Stefan Assmann) [2137471]
- nfp: flower: add/remove predt_list entries (Stefan Assmann) [2137471]
- nfp: flower: add infrastructure for pre_tun rework (Stefan Assmann) [2137471]
- nfp: support VxLAN inner TSO with GSO_PARTIAL offload (Stefan Assmann) [2137471]
- nfp: flower: utilize the tuple iifidx in offloading ct flows (Stefan Assmann) [2137471]
- ipv6: Use ipv6_only_sock() helper in condition. (Stefan Assmann) [2137471]
- nfp: support 802.1ad VLAN assingment to VF (Stefan Assmann) [2137471]
- nfp: update nfp_X logging definitions (Stefan Assmann) [2137471]
- Revert "Merge branch 'centos-stream-9-main'" (Frantisek Hrbata)
- Add rtla subpackage for kernel-tools (John Kacur)

* Wed Nov 23 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-201.el9]
- net: sched: Fix use after free in red_enqueue() (Ivan Vecera) [2139170]
- Revert "net/sched: taprio: make qdisc_leaf() see the per-netdev-queue pfifo child qdiscs" (Ivan Vecera) [2139170]
- netfilter: egress: Report interface as outgoing (Ivan Vecera) [2139170]
- netfilter: egress: avoid a lockdep splat (Ivan Vecera) [2139170]
- netfilter: core: Fix clang warnings about unused static inlines (Ivan Vecera) [2139170]
- net: sched: act_ct: fix possible refcount leak in tcf_ct_init() (Ivan Vecera) [2139170]
- net: sched: fix possible refcount leak in tc_new_tfilter() (Ivan Vecera) [2139170]
- net/sched: taprio: make qdisc_leaf() see the per-netdev-queue pfifo child qdiscs (Ivan Vecera) [2139170]
- net/sched: taprio: avoid disabling offload when it was never enabled (Ivan Vecera) [2139170]
- sch_sfb: Also store skb len before calling child enqueue (Ivan Vecera) [2139170]
- sch_sfb: Don't assume the skb is still around after enqueueing to child (Ivan Vecera) [2139170]
- net/sched: fix netdevice reference leaks in attach_default_qdiscs() (Ivan Vecera) [2139170]
- net: sched: tbf: don't call qdisc_put() while holding tree lock (Ivan Vecera) [2139170]
- net_sched: cls_route: disallow handle of 0 (Ivan Vecera) [2139170]
- net_sched: cls_route: remove from list when handle is 0 (Ivan Vecera) [2139170]
- net/sched: remove hacks added to dev_trans_start() for bonding to work (Ivan Vecera) [2139170]
- net: bonding: replace dev_trans_start() with the jiffies of the last ARP/NS (Ivan Vecera) [2139170]
- net/sched: sch_cbq: change the type of cbq_set_lss to void (Ivan Vecera) [2139170]
- net/sched: flower: Add PPPoE filter (Ivan Vecera) [2139170]
- net/sched: cls_api: Fix flow action initialization (Ivan Vecera) [2139170]
- net/sched: remove qdisc_root_lock() helper (Ivan Vecera) [2139170]
- net/sched: sch_cbq: Delete unused delay_timer (Ivan Vecera) [2139170]
- net/sched: remove return value of unregister_tcf_proto_ops (Ivan Vecera) [2139170]
- net: extract port range fields from fl_flow_key (Ivan Vecera) [2139170]
- netfilter: flowtable: fix incorrect Kconfig dependencies (Ivan Vecera) [2139170]
- config: set CONFIG_NF_FLOW_TABLE_PROCFS (Ivan Vecera) [2139170]
- netfilter: nf_flow_table: count pending offload workqueue tasks (Ivan Vecera) [2139170]
- net/sched: act_ct: set 'net' pointer when creating new nf_flow_table (Ivan Vecera) [2139170]
- net: sched: provide shim definitions for taprio_offload_{get,free} (Ivan Vecera) [2139170]
- time64.h: consolidate uses of PSEC_PER_NSEC (Ivan Vecera) [2139170]
- selftests: tc-testing: Add testcases to test new flush behaviour (Ivan Vecera) [2139170]
- net/sched: act_api: Notify user space if any actions were flushed before error (Ivan Vecera) [2139170]
- net: Print hashed skb addresses for all net and qdisc events (Ivan Vecera) [2139170]
- tc-testing: gitignore, delete plugins directory (Ivan Vecera) [2139170]
- net/sched: sch_netem: Fix arithmetic in netem_dump() for 32-bit platforms (Ivan Vecera) [2139170]
- net_sched: em_meta: add READ_ONCE() in var_sk_bound_if() (Ivan Vecera) [2139170]
- selftests: forwarding: tc_actions: allow mirred egress test to run on non-offloaded h2 (Ivan Vecera) [2139170]
- net/sched: flower: Consider the number of tags for vlan filters (Ivan Vecera) [2139170]
- net/sched: flower: Add number of vlan tags filter (Ivan Vecera) [2139170]
- net/sched: flower: Reduce identation after is_key_vlan refactoring (Ivan Vecera) [2139170]
- net/sched: flower: Helper function for vlan ethtype checks (Ivan Vecera) [2139170]
- net: sched: support hash selecting tx queue (Ivan Vecera) [2139170]
- net: sched: use queue_mapping to pick tx queue (Ivan Vecera) [2139170]
- config: set CONFIG_NETFILTER_EGRESS (Ivan Vecera) [2139170]
- netfilter: Introduce egress hook (Ivan Vecera) [2139170]
- netfilter: Generalize ingress hook include file (Ivan Vecera) [2139170]
- netfilter: Rename ingress hook include file (Ivan Vecera) [2139170]
- net_sched: make qdisc_reset() smaller (Ivan Vecera) [2139170]
- net/sched: flower: Avoid overwriting error messages (Ivan Vecera) [2139170]
- net/sched: matchall: Avoid overwriting error messages (Ivan Vecera) [2139170]
- net/sched: cls_api: Add extack message for unsupported action offload (Ivan Vecera) [2139170]
- net/sched: act_vlan: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_tunnel_key: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_skbedit: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_police: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_pedit: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_mpls: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_mirred: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_gact: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_api: Add extack to offload_act_setup() callback (Ivan Vecera) [2139170]
- net/sched: flower: Take verbose flag into account when logging error messages (Ivan Vecera) [2139170]
- net/sched: matchall: Take verbose flag into account when logging error messages (Ivan Vecera) [2139170]
- gtp: Fix inconsistent indenting (Ivan Vecera) [2139170]
- gtp: Add support for checking GTP device type (Ivan Vecera) [2139170]
- net/sched: Allow flower to match on GTP options (Ivan Vecera) [2139170]
- gtp: Implement GTP echo request (Ivan Vecera) [2139170]
- gtp: Implement GTP echo response (Ivan Vecera) [2139170]
- gtp: Allow to create GTP device without FDs (Ivan Vecera) [2139170]
- net/vdpa: Use readers/writers semaphore instead of cf_mutex (Ivan Vecera) [2143373]
- net/vdpa: Use readers/writers semaphore instead of vdpa_dev_mutex (Ivan Vecera) [2143373]
- vdpa: Add support for querying vendor statistics (Ivan Vecera) [2143373]
- vdpa: Fix error logic in vdpa_nl_cmd_dev_get_doit (Ivan Vecera) [2143373]
- vdpa: factor out vdpa_set_features_unlocked for vdpa internal use (Ivan Vecera) [2143373]
- sctp: handle the error returned from sctp_auth_asoc_init_active_key (Xin Long) [2134900]
- sctp: leave the err path free in sctp_stream_init to sctp_stream_free (Xin Long) [2134900]
- sctp: fix sleep in atomic context bug in timer handlers (Xin Long) [2134900]
- Documentation: fix sctp_wmem in ip-sysctl.rst (Xin Long) [2134900]
- Documentation: add description for net.sctp.ecn_enable (Xin Long) [2134900]
- Documentation: add description for net.sctp.intl_enable (Xin Long) [2134900]
- Documentation: add description for net.sctp.reconf_enable (Xin Long) [2134900]
- stcp: Use memset_after() to zero sctp_stream_out_ext (Xin Long) [2134900]
- sctp: read sk->sk_bound_dev_if once in sctp_rcv() (Xin Long) [2134900]
- vdpa_sim_blk: add support for discard and write-zeroes (Stefano Garzarella) [2136818]
- vdpa_sim_blk: add support for VIRTIO_BLK_T_FLUSH (Stefano Garzarella) [2136818]
- vdpa_sim_blk: make vdpasim_blk_check_range usable by other requests (Stefano Garzarella) [2136818]
- vdpa_sim_blk: check if sector is 0 for commands other than read or write (Stefano Garzarella) [2136818]
- vdpa_sim_blk: call vringh_complete_iotlb() also in the error path (Stefano Garzarella) [2136818]
- vdpa_sim_blk: limit the number of request handled per batch (Stefano Garzarella) [2136818]
- vdpa_sim_blk: use dev_dbg() to print errors (Stefano Garzarella) [2136818]
- vringh: iterate on iotlb_translate to handle large translations (Stefano Garzarella) [2136818]
- vringh: Fix loop descriptors check in the indirect cases (Stefano Garzarella) [2136818]
- rpminspect: disable kmidiff and abidiff (Frantisek Hrbata)
- Update automotive tree for CI (kpet-db) to autosd-rhivos-rt from c9s-rt (bgrech)
- xfs: remove all COW fork extents when remounting readonly (Carlos Maiolino) [2125724]
- xfs: remove incorrect ASSERT in xfs_rename (Carlos Maiolino) [2125724]
- xfs: sync xfs_btree_split macros with userspace libxfs (Carlos Maiolino) [2125724]
- xfs: #ifdef out perag code for userspace (Carlos Maiolino) [2125724]
- xfs: use swap() to make dabtree code cleaner (Carlos Maiolino) [2125724]
- xfs: use swap() to make code cleaner (Carlos Maiolino) [2125724]
- xfs: Remove duplicated include in xfs_super (Carlos Maiolino) [2125724]
- xfs: remove unused parameter from refcount code (Carlos Maiolino) [2125724]
- xfs: reduce the size of struct xfs_extent_free_item (Carlos Maiolino) [2125724]
- xfs: rename xfs_bmap_add_free to xfs_free_extent_later (Carlos Maiolino) [2125724]
- xfs: create slab caches for frequently-used deferred items (Carlos Maiolino) [2125724]
- xfs: compact deferred intent item structures (Carlos Maiolino) [2125724]
- xfs: rename _zone variables to _cache (Carlos Maiolino) [2125724]
- xfs: remove kmem_zone typedef (Carlos Maiolino) [2125724]
- xfs: use separate btree cursor cache for each btree type (Carlos Maiolino) [2125724]
- xfs: compute absolute maximum nlevels for each btree type (Carlos Maiolino) [2125724]
- xfs: kill XFS_BTREE_MAXLEVELS (Carlos Maiolino) [2125724]
- xfs: compute the maximum height of the rmap btree when reflink enabled (Carlos Maiolino) [2125724]
- xfs: clean up xfs_btree_{calc_size,compute_maxlevels} (Carlos Maiolino) [2125724]
- xfs: compute maximum AG btree height for critical reservation calculation (Carlos Maiolino) [2125724]
- xfs: rename m_ag_maxlevels to m_allocbt_maxlevels (Carlos Maiolino) [2125724]
- xfs: dynamically allocate cursors based on maxlevels (Carlos Maiolino) [2125724]
- xfs: encode the max btree height in the cursor (Carlos Maiolino) [2125724]
- xfs: refactor btree cursor allocation function (Carlos Maiolino) [2125724]
- xfs: rearrange xfs_btree_cur fields for better packing (Carlos Maiolino) [2125724]
- xfs: prepare xfs_btree_cur for dynamic cursor heights (Carlos Maiolino) [2125724]
- xfs: dynamically allocate btree scrub context structure (Carlos Maiolino) [2125724]
- xfs: don't track firstrec/firstkey separately in xchk_btree (Carlos Maiolino) [2125724]
- xfs: reduce the size of nr_ops for refcount btree cursors (Carlos Maiolino) [2125724]
- xfs: remove xfs_btree_cur.bc_blocklog (Carlos Maiolino) [2125724]
- xfs: fix incorrect decoding in xchk_btree_cur_fsbno (Carlos Maiolino) [2125724]
- xfs: fix perag reference leak on iteration race with growfs (Carlos Maiolino) [2125724]
- xfs: terminate perag iteration reliably on agcount (Carlos Maiolino) [2125724]
- xfs: rename the next_agno perag iteration variable (Carlos Maiolino) [2125724]
- xfs: fold perag loop iteration logic into helper function (Carlos Maiolino) [2125724]
- xfs: replace snprintf in show functions with sysfs_emit (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dqblk_t typedef (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dsb_t typedef (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dinode_t typedef (Carlos Maiolino) [2125724]
- xfs: check that bc_nlevels never overflows (Carlos Maiolino) [2125724]
- xfs: stricter btree height checking when scanning for btree roots (Carlos Maiolino) [2125724]
- xfs: stricter btree height checking when looking for errors (Carlos Maiolino) [2125724]
- xfs: don't allocate scrub contexts on the stack (Carlos Maiolino) [2125724]
- xfs: remove xfs_btree_cur_t typedef (Carlos Maiolino) [2125724]
- xfs: port the defer ops capture and continue to resource capture (Carlos Maiolino) [2125724]
- xfs: formalize the process of holding onto resources across a defer roll (Carlos Maiolino) [2125724]
- xfs: Use kvcalloc() instead of kvzalloc() (Carlos Maiolino) [2125724]
- perf: Fix pmu_filter_match() (Michael Petlan) [2123229]
- perf: Fix lockdep_assert_event_ctx() (Michael Petlan) [2123229]
- perf: Add a few assertions (Michael Petlan) [2123229]
- perf test: Fix skipping branch stack sampling test (Michael Petlan) [2123229]
- tools: Fix math.h breakage (Michael Petlan) [2123229]
- perf stat: Fix cpu check to use id.cpu.cpu in aggr_printout() (Michael Petlan) [2123229]
- perf list: Fix PMU name pai_crypto in perf list on s390 (Michael Petlan) [2123229]
- perf tests stat+csv_output: Include sanity check for topology (Michael Petlan) [2123229]
- perf tests stat+json_output: Include sanity check for topology (Michael Petlan) [2123229]
- perf inject: Fix GEN_ELF_TEXT_OFFSET for jit (Michael Petlan) [2123229]
- perf lock contention: Fix a build error on 32-bit (Michael Petlan) [2123229]
- perf build: Fixup disabling of -Wdeprecated-declarations for the python scripting engine (Michael Petlan) [2123229]
- perf tests mmap-basic: Remove unused variable to address clang 15 warning (Michael Petlan) [2123229]
- perf parse-events: Ignore clang 15 warning about variable set but unused in bison produced code (Michael Petlan) [2123229]
- perf tests record: Fail the test if the 'errs' counter is not zero (Michael Petlan) [2123229]
- perf test: Fix test case 87 ("perf record tests") for hybrid systems (Michael Petlan) [2123229]
- perf arm-spe: augment the data source type with neoverse_spe list (Michael Petlan) [2123229]
- perf tests vmlinux-kallsyms: Update is_ignored_symbol function to match the kernel ignored list (Michael Petlan) [2123229]
- perf tests powerpc: Fix branch stack sampling test to include sanity check for branch filter (Michael Petlan) [2123229]
- perf parse-events: Remove "not supported" hybrid cache events (Michael Petlan) [2123229]
- perf print-events: Fix "perf list" can not display the PMU prefix for some hybrid cache events (Michael Petlan) [2123229]
- perf tools: Get a perf cgroup more portably in BPF (Michael Petlan) [2123229]
- perf tools: Honor namespace when synthesizing build-ids (Michael Petlan) [2123229]
- perf kcore_copy: Do not check /proc/modules is unchanged (Michael Petlan) [2123229]
- libperf evlist: Fix polling of system-wide events (Michael Petlan) [2123229]
- perf record: Fix cpu mask bit setting for mixed mmaps (Michael Petlan) [2123229]
- perf test: Skip wp modify test on old kernels (Michael Petlan) [2123229]
- perf jit: Include program header in ELF files (Michael Petlan) [2123229]
- perf test: Add a new test for perf stat cgroup BPF counter (Michael Petlan) [2123229]
- perf stat: Use evsel->core.cpus to iterate cpus in BPF cgroup counters (Michael Petlan) [2123229]
- perf stat: Fix cpu map index in bperf cgroup code (Michael Petlan) [2123229]
- perf stat: Fix BPF program section name (Michael Petlan) [2123229]
- perf record: Fix synthesis failure warnings (Michael Petlan) [2123229]
- perf tools: Don't install data files with x permissions (Michael Petlan) [2123229]
- perf script: Fix Cannot print 'iregs' field for hybrid systems (Michael Petlan) [2123229]
- perf lock: Remove redundant word 'contention' in help message (Michael Petlan) [2123229]
- perf dlfilter dlfilter-show-cycles: Fix types for print format (Michael Petlan) [2123229]
- perf c2c: Prevent potential memory leak in c2c_he_zalloc() (Michael Petlan) [2123229]
- perf genelf: Switch deprecated openssl MD5_* functions to new EVP API (Michael Petlan) [2123229]
- tools/perf: Fix out of bound access to cpu mask array (Michael Petlan) [2123229]
- perf affinity: Fix out of bound access to "sched_cpus" mask (Michael Petlan) [2123229]
- perf stat: Fix L2 Topdown metrics disappear for raw events (Michael Petlan) [2123229]
- perf script: Skip dummy event attr check (Michael Petlan) [2123229]
- perf metric: Return early if no CPU PMU table exists (Michael Petlan) [2123229]
- perf stat: Capitalize topdown metrics' names (Michael Petlan) [2123229]
- perf docs: Update the documentation for the save_type filter (Michael Petlan) [2123229]
- perf sched: Fix memory leaks in __cmd_record detected with -fsanitize=address (Michael Petlan) [2123229]
- perf record: Fix manpage formatting of description of support to hybrid systems (Michael Petlan) [2123229]
- perf test: Stat test for repeat with a weak group (Michael Petlan) [2123229]
- perf stat: Clear evsel->reset_group for each stat run (Michael Petlan) [2123229]
- perf tools: Fix compile error for x86 (Michael Petlan) [2123229]
- perf tools: Support reading PERF_FORMAT_LOST (Michael Petlan) [2123229]
- libperf: Add a test case for read formats (Michael Petlan) [2123229]
- libperf: Handle read format in perf_evsel__read() (Michael Petlan) [2123229]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123229]
- perf cpumap: Fix alignment for masks in event encoding (Michael Petlan) [2123229]
- perf cpumap: Compute mask size in constant time (Michael Petlan) [2123229]
- perf cpumap: Synthetic events and const/static (Michael Petlan) [2123229]
- perf cpumap: Const map for max() (Michael Petlan) [2123229]
- perf test: Refactor shell tests allowing subdirs (Michael Petlan) [2123229]
- perf vendor events: Update events for snowridgex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for skylakex (Michael Petlan) [2123229]
- perf vendor events: Update metrics for sapphirerapids (Michael Petlan) [2123229]
- perf vendor events: Update events for knightslanding (Michael Petlan) [2123229]
- perf vendor events: Update metrics for jaketown (Michael Petlan) [2123229]
- perf vendor events: Update metrics for ivytown (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for icelakex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for haswellx (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for cascadelakex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for broadwellx (Michael Petlan) [2123229]
- perf vendor events: Update metrics for broadwellde (Michael Petlan) [2123229]
- perf jevents: Fold strings optimization (Michael Petlan) [2123229]
- perf jevents: Compress the pmu_events_table (Michael Petlan) [2123229]
- perf metrics: Copy entire pmu_event in find metric (Michael Petlan) [2123229]
- perf pmu-events: Hide the pmu_events (Michael Petlan) [2123229]
- perf pmu-events: Don't assume pmu_event is an array (Michael Petlan) [2123229]
- perf pmu-events: Move test events/metrics to JSON (Michael Petlan) [2123229]
- perf test: Use full metric resolution (Michael Petlan) [2123229]
- perf pmu-events: Hide pmu_events_map (Michael Petlan) [2123229]
- perf pmu-events: Avoid passing pmu_events_map (Michael Petlan) [2123229]
- perf pmu-events: Hide pmu_sys_event_tables (Michael Petlan) [2123229]
- perf jevents: Sort JSON files entries (Michael Petlan) [2123229]
- perf jevents: Provide path to JSON file on error (Michael Petlan) [2123229]
- perf jevents: Remove the type/version variables (Michael Petlan) [2123229]
- perf jevent: Add an 'all' architecture argument (Michael Petlan) [2123229]
- perf stat: Remove duplicated include in builtin-stat.c (Michael Petlan) [2123229]
- perf scripting python: Delete repeated word in comments (Michael Petlan) [2123229]
- perf tools: Fix double word in comments (Michael Petlan) [2123229]
- perf trace: Fix double word in comments (Michael Petlan) [2123229]
- perf script: Delete repeated word "from" (Michael Petlan) [2123229]
- perf test: Fix double word in comments (Michael Petlan) [2123229]
- perf record: Improve error message of -p not_existing_pid (Michael Petlan) [2123229]
- perf build-id: Print debuginfod queries if -v option is used (Michael Petlan) [2123229]
- perf build-id: Fix coding style, replace 8 spaces by tabs (Michael Petlan) [2123229]
- perf c2c: Update documentation for new display option 'peer' (Michael Petlan) [2123229]
- perf c2c: Use 'peer' as default display for Arm64 (Michael Petlan) [2123229]
- perf c2c: Sort on peer snooping for load operations (Michael Petlan) [2123229]
- perf c2c: Refactor display string (Michael Petlan) [2123229]
- perf c2c: Refactor node header (Michael Petlan) [2123229]
- perf c2c: Rename dimension from 'percent_hitm' to 'percent_costly_snoop' (Michael Petlan) [2123229]
- perf c2c: Use explicit names for display macros (Michael Petlan) [2123229]
- perf c2c: Add mean dimensions for peer operations (Michael Petlan) [2123229]
- perf c2c: Add dimensions of peer metrics for cache line view (Michael Petlan) [2123229]
- perf c2c: Add dimensions for peer load operations (Michael Petlan) [2123229]
- perf c2c: Output statistics for peer snooping (Michael Petlan) [2123229]
- perf mem: Add statistics for peer snooping (Michael Petlan) [2123229]
- perf arm-spe: Use SPE data source for neoverse cores (Michael Petlan) [2123229]
- perf mem: Print snoop peer flag (Michael Petlan) [2123229]
- perf tools: Sync addition of PERF_MEM_SNOOPX_PEER (Michael Petlan) [2123229]
- perf arm64: Add missing -I for tools/arch/arm64/include/ to find asm/sysreg.h when building arm_spe.h (Michael Petlan) [2123229]
- perf tools: Tidy guest option documentation (Michael Petlan) [2123229]
- perf inject: Fix missing guestmount option documentation (Michael Petlan) [2123229]
- perf script: Fix missing guest option documentation (Michael Petlan) [2123229]
- perf offcpu: Update offcpu test for child process (Michael Petlan) [2123229]
- perf offcpu: Track child processes (Michael Petlan) [2123229]
- perf offcpu: Parse process id separately (Michael Petlan) [2123229]
- perf offcpu: Check process id for the given workload (Michael Petlan) [2123229]
- perf tools: Do not pass NULL to parse_events() (Michael Petlan) [2123229]
- perf tests: Fix Track with sched_switch test for hybrid case (Michael Petlan) [2123229]
- perf parse-events: Fix segfault when event parser gets an error (Michael Petlan) [2123229]
- perf machine: Fix missing free of machine->kallsyms_filename (Michael Petlan) [2123229]
- perf script: Fix reference to perf insert instead of perf inject (Michael Petlan) [2123229]
- perf sched latency: Fix subcommand matching error (Michael Petlan) [2123229]
- perf kvm: Fix subcommand matching error (Michael Petlan) [2123229]
- perf probe: Fix an error handling path in 'parse_perf_probe_command()' (Michael Petlan) [2123229]
- perf inject jit: Ignore memfd and anonymous mmap events if jitdump present (Michael Petlan) [2123229]
- perf list: Add PMU pai_crypto event description for IBM z16 (Michael Petlan) [2123229]
- perf vendor events: Remove bad jaketown uncore events (Michael Petlan) [2123229]
- perf vendor events: Remove bad ivytown uncore events (Michael Petlan) [2123229]
- perf vendor events: Remove bad broadwellde uncore events (Michael Petlan) [2123229]
- perf jevents: Add JEVENTS_ARCH make option (Michael Petlan) [2123229]
- perf jevents: Simplify generation of C-string (Michael Petlan) [2123229]
- perf jevents: Clean up pytype warnings (Michael Petlan) [2123229]
- tools build: Switch to new openssl API for test-libcrypto (Michael Petlan) [2123229]
- Revert "perf build: Suppress openssl v3 deprecation warnings in libcrypto feature test" (Michael Petlan) [2123229]
- perf test: JSON format checking (Michael Petlan) [2123229]
- perf stat: Add JSON output option (Michael Petlan) [2123229]
- perf stat: Refactor __run_perf_stat() common code (Michael Petlan) [2123229]
- perf lock: Print the number of lost entries for BPF (Michael Petlan) [2123229]
- perf lock: Add --map-nr-entries option (Michael Petlan) [2123229]
- perf lock: Introduce struct lock_contention (Michael Petlan) [2123229]
- perf scripting python: Do not build fail on deprecation warnings (Michael Petlan) [2123229]
- genelf: Use HAVE_LIBCRYPTO_SUPPORT, not the never defined HAVE_LIBCRYPTO (Michael Petlan) [2123229]
- perf build: Suppress openssl v3 deprecation warnings in libcrypto feature test (Michael Petlan) [2123229]
- perf parse-events: Break out tracepoint and printing (Michael Petlan) [2123229]
- perf parse-events: Don't #define YY_EXTRA_TYPE (Michael Petlan) [2123229]
- perf test: Add ARM SPE system wide test (Michael Petlan) [2123229]
- perf bpf: Convert legacy map definition to BTF-defined (Michael Petlan) [2123229]
- perf lock: Implement cpu and task filters for BPF (Michael Petlan) [2123229]
- perf lock: Use BPF for lock contention analysis (Michael Petlan) [2123229]
- perf lock: Pass machine pointer to is_lock_function() (Michael Petlan) [2123229]
- perf test: Add user space counter reading tests (Michael Petlan) [2123229]
- perf test: Remove x86 rdpmc test (Michael Petlan) [2123229]
- perf stat: Add topdown metrics in the default perf stat on the hybrid machine (Michael Petlan) [2123229]
- perf x86 evlist: Add default hybrid events for perf stat (Michael Petlan) [2123229]
- perf evlist: Always use arch_evlist__add_default_attrs() (Michael Petlan) [2123229]
- perf evsel: Add arch_evsel__hw_name() (Michael Petlan) [2123229]
- perf stat: Revert "perf stat: Add default hybrid events" (Michael Petlan) [2123229]
- perf test: Fix test case 95 ("Check branch stack sampling") on s390 and use same event (Michael Petlan) [2123229]
- perf vendor events arm64: Arm Cortex-A78C and X1C (Michael Petlan) [2123229]
- perf vendor events: Update Intel snowridgex (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereex (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereep-sp (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereep-dp (Michael Petlan) [2123229]
- perf vendor events: Update Intel tigerlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel skylakex (Michael Petlan) [2123229]
- perf vendor events: Update Intel skylake (Michael Petlan) [2123229]
- perf vendor events: Update Intel silvermont (Michael Petlan) [2123229]
- perf vendor events: Update Intel sapphirerapids (Michael Petlan) [2123229]
- perf vendor events: Update Intel sandybridge (Michael Petlan) [2123229]
- perf vendor events: Update Intel nehalemex (Michael Petlan) [2123229]
- perf vendor events: Update Intel nehalemep (Michael Petlan) [2123229]
- perf vendor events: Add Intel meteorlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel knightslanding (Michael Petlan) [2123229]
- perf vendor events: Update Intel jaketown (Michael Petlan) [2123229]
- perf vendor events: Update Intel ivytown (Michael Petlan) [2123229]
- perf vendor events: Update Intel ivybridge (Michael Petlan) [2123229]
- perf vendor events: Update Intel icelakex (Michael Petlan) [2123229]
- perf vendor events: Update Intel icelake (Michael Petlan) [2123229]
- perf vendor events: Update Intel haswellx (Michael Petlan) [2123229]
- perf vendor events: Update Intel haswell (Michael Petlan) [2123229]
- perf vendor events: Update goldmontplus mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update goldmont mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update Intel elkhartlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel cascadelakex (Michael Petlan) [2123229]
- perf vendor events: Update bonnell mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update Intel alderlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwellde (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwell (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwellx (Michael Petlan) [2123229]
- perf test: Avoid sysfs state affecting fake events (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for haswellx (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for broadwellx (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Snowridgex (Michael Petlan) [2123229]
- perf vendor events intel: Rename tremontx to snowridgex (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Sapphirerapids (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Alderlake (Michael Petlan) [2123229]
- perf inject: Fix spelling mistake "theads" -> "threads" (Michael Petlan) [2123229]
- perf kwork: Add workqueue trace BPF support (Michael Petlan) [2123229]
- perf kwork: Add softirq trace BPF support (Michael Petlan) [2123229]
- perf kwork: Add IRQ trace BPF support (Michael Petlan) [2123229]
- perf kwork: Implement BPF trace (Michael Petlan) [2123229]
- perf kwork: Implement perf kwork timehist (Michael Petlan) [2123229]
- perf kwork: Add workqueue latency support (Michael Petlan) [2123229]
- perf kwork: Add softirq latency support (Michael Petlan) [2123229]
- perf kwork: Implement perf kwork latency (Michael Petlan) [2123229]
- perf kwork: Add workqueue report support (Michael Petlan) [2123229]
- perf kwork: Add softirq report support (Michael Petlan) [2123229]
- perf kwork: Add irq report support (Michael Petlan) [2123229]
- perf kwork: Implement 'report' subcommand (Michael Petlan) [2123229]
- tools lib: Add list_last_entry_or_null() (Michael Petlan) [2123229]
- perf kwork: Add workqueue kwork record support (Michael Petlan) [2123229]
- perf kwork: Add softirq kwork record support (Michael Petlan) [2123229]
- perf kwork: Add irq kwork record support (Michael Petlan) [2123229]
- perf kwork: New tool to trace time properties of kernel work (such as softirq, and workqueue) (Michael Petlan) [2123229]
- perf data: Add missing unistd.h header needed for pid_t (Michael Petlan) [2123229]
- perf lock: Support -t option for 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add -k and -F options to 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add lock aggregation enum (Michael Petlan) [2123229]
- perf lock: Add flags field in the lock_stat (Michael Petlan) [2123229]
- perf test: Add test for #system_tsc_freq in metrics (Michael Petlan) [2123229]
- perf tsc: Add cpuinfo fall back for arch_get_tsc_freq() (Michael Petlan) [2123229]
- perf tsc: Add arch TSC frequency information (Michael Petlan) [2123229]
- perf lock: Fix a copy-n-paste bug (Michael Petlan) [2123229]
- perf python: Ignore unused command line arguments when building with clang (Michael Petlan) [2123229]
- perf build: Avoid defining _FORTIFY_SOURCE multiple times (Michael Petlan) [2123229]
- perf cs-etm: Fix duplicated 'the' in comment (Michael Petlan) [2123229]
- perf probe: Fix duplicated 'the' in comment (Michael Petlan) [2123229]
- perf scripting perl: Ignore some warnings to keep building with perl headers (Michael Petlan) [2123229]
- perf python: Avoid deprecation warning on distutils (Michael Petlan) [2123229]
- perf gtk: Only support --gtk if compiled in (Michael Petlan) [2123229]
- perf intel-pt: Add documentation for tracing guest machine user space (Michael Petlan) [2123229]
- perf intel-pt: Use guest pid/tid etc in guest samples (Michael Petlan) [2123229]
- perf intel-pt: Add machine_pid and vcpu to auxtrace_error (Michael Petlan) [2123229]
- perf intel-pt: Determine guest thread from guest sideband (Michael Petlan) [2123229]
- perf intel-pt: Disable sync switch with guest sideband (Michael Petlan) [2123229]
- perf intel-pt: Track guest context switches (Michael Petlan) [2123229]
- perf intel-pt: Add some more logging to intel_pt_walk_next_insn() (Michael Petlan) [2123229]
- perf intel-pt: Remove guest_machine_pid (Michael Petlan) [2123229]
- perf tools: Add perf_event__is_guest() (Michael Petlan) [2123229]
- perf tools: Handle injected guest kernel mmap event (Michael Petlan) [2123229]
- perf machine: Use realloc_array_as_needed() in machine__set_current_tid() (Michael Petlan) [2123229]
- perf inject: Add support for injecting guest sideband events (Michael Petlan) [2123229]
- perf tools: Add reallocarray_as_needed() (Michael Petlan) [2123229]
- perf tools: Automatically use guest kcore_dir if present (Michael Petlan) [2123229]
- perf tools: Make has_kcore_dir() work also for guest kcore_dir (Michael Petlan) [2123229]
- perf tools: Remove also guest kcore_dir with host kcore_dir (Michael Petlan) [2123229]
- perf script python: intel-pt-events: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf script python: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf auxtrace: Add machine_pid and vcpu to auxtrace_error (Michael Petlan) [2123229]
- perf dlfilter: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf script: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf session: Use sample->machine_pid to find guest machine (Michael Petlan) [2123229]
- perf tools: Add machine_pid and vcpu to perf_sample (Michael Petlan) [2123229]
- perf tools: Add guest_cpu to hypervisor threads (Michael Petlan) [2123229]
- perf session: Create guest machines from id_index (Michael Petlan) [2123229]
- perf tools: Add machine_pid and vcpu to id_index (Michael Petlan) [2123229]
- perf buildid-cache: Do not require purge files to also be in the file system (Michael Petlan) [2123229]
- perf buildid-cache: Add guestmount'd files to the build ID cache (Michael Petlan) [2123229]
- perf script: Add --dump-unsorted-raw-trace option (Michael Petlan) [2123229]
- perf tools: Add perf_event__synthesize_id_sample() (Michael Petlan) [2123229]
- perf tools: Factor out evsel__id_hdr_size() (Michael Petlan) [2123229]
- perf tools: Export perf_event__process_finished_round() (Michael Petlan) [2123229]
- perf ordered_events: Add ordered_events__last_flush_time() (Michael Petlan) [2123229]
- perf tools: Export dsos__for_each_with_build_id() (Michael Petlan) [2123229]
- perf tools: Fix dso_id inode generation comparison (Michael Petlan) [2123229]
- perf buildid-list: Add a "-m" option to show kernel and modules build-ids (Michael Petlan) [2123229]
- perf lock: Look up callchain for the contended locks (Michael Petlan) [2123229]
- perf record: Allow to specify max stack depth of fp callchain (Michael Petlan) [2123229]
- perf lock: Handle lock contention tracepoints (Michael Petlan) [2123229]
- perf lock: Add lock contention tracepoints record support (Michael Petlan) [2123229]
- perf lock: Skip print_bad_events() if nothing bad (Michael Petlan) [2123229]
- perf lock: Allow to use different kernel symbols (Michael Petlan) [2123229]
- perf lock: Print wait times with unit (Michael Petlan) [2123229]
- perf test: Add test for branch stack sampling (Michael Petlan) [2123229]
- perf test: Make all metrics test more tolerant (Michael Petlan) [2123229]
- perf test: Add debug line to diagnose broken metrics (Michael Petlan) [2123229]
- perf jevents: Remove jevents.c (Michael Petlan) [2123229]
- perf jevents: Switch build to use jevents.py (Michael Petlan) [2123229]
- perf jevents: Add python converter script (Michael Petlan) [2123229]
- perf python: Prefer python3 (Michael Petlan) [2123229]
- perf script ibs: Support new IBS bits in raw trace dump (Michael Petlan) [2123229]
- perf tool ibs: Sync AMD IBS header file (Michael Petlan) [2123229]
- perf header: Record non-CPU PMU capabilities (Michael Petlan) [2123229]
- perf header: Store PMU caps in an array of strings (Michael Petlan) [2123229]
- perf header: Pass "cpu" pmu name while printing caps (Michael Petlan) [2123229]
- perf pmu: Parse pmu caps sysfs only once (Michael Petlan) [2123229]
- perf record ibs: Warn about sampling period skew (Michael Petlan) [2123229]
- perf script: Add some missing event dumps (Michael Petlan) [2123229]
- perf record: Add finished init event (Michael Petlan) [2123229]
- perf record: Add new option to sample identifier (Michael Petlan) [2123229]
- perf record: Always record id index (Michael Petlan) [2123229]
- perf record: Always get text_poke events with --kcore option (Michael Petlan) [2123229]
- perf data convert: Prefer sampled CPU when exporting JSON (Michael Petlan) [2123229]
- uapi: asm-generic: fcntl: Fix typo 'the the' in comment (Michael Petlan) [2123229]
- perf/core: Fix reentry problem in perf_output_read_group() (Michael Petlan) [2123229]
- perf/x86/intel: Fix unchecked MSR access error for Alder Lake N (Michael Petlan) [2123229]
- perf/x86/intel/uncore: Fix broken read_counter() for SNB IMC PMU (Michael Petlan) [2123229]
- perf/x86/intel: Fix pebs event constraints for ADL (Michael Petlan) [2123229]
- perf/x86/intel/ds: Fix precise store latency handling (Michael Petlan) [2123229]
- perf/x86/core: Set pebs_capable and PMU_FL_PEBS_ALL for the Baseline (Michael Petlan) [2123229]
- perf/x86/lbr: Enable the branch type for the Arch LBR by default (Michael Petlan) [2123229]
- perf/core: Fix ';;' typo (Michael Petlan) [2123229]
- powerpc/perf: Include caps feature for power10 DD1 version (Michael Petlan) [2123229]
- powerpc/perf: Use PVR rather than oprofile field to determine CPU version (Michael Petlan) [2123229]
- docs: ABI: sysfs-bus-event_source-devices: Document sysfs caps entry for PMU (Michael Petlan) [2123229]
- powerpc/perf: Add support for caps under sysfs in powerpc (Michael Petlan) [2123229]
- powerpc/perf: Add __init attribute to eligible functions (Michael Petlan) [2123229]
- powerpc/perf: Give generic PMU a nice name (Michael Petlan) [2123229]
- powerpc/perf: Update MMCR2 to support event exclude_idle (Michael Petlan) [2123229]
- x86: events: Do not return bogus capabilities if PMU is broken (Michael Petlan) [2123229]
- perf/x86/intel: Fix the comment about guest LBR support on KVM (Michael Petlan) [2123229]
- perf/x86/intel: Fix PEBS data source encoding for ADL (Michael Petlan) [2123229]
- perf/x86/intel: Fix PEBS memory access info encoding for ADL (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Add PerfMonV2 RDPMC assignments (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Add PerfMonV2 DF event format (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Detect available DF counters (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Use attr_update for format attributes (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Use dynamic events array (Michael Petlan) [2123229]
- x86/events/intel/ds: Enable large PEBS for PERF_SAMPLE_WEIGHT_TYPE (Michael Petlan) [2123229]
- fuse: fix readdir cache race (Miklos Szeredi) [2142657]
- gen_compile_commands: fix missing 'sys' package (Íñigo Huguet) [2136526]
- gen_compile_commands: extract compiler command from a series of commands (Íñigo Huguet) [2136526]

* Mon Nov 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-200.el9]
- macvlan: enforce a consistent minimal mtu (Davide Caratti) [2133755]
- ipvlan: Fix out-of-bound bugs caused by unset skb->mac_header (Davide Caratti) [2133755]
- net: ipvtap - add __init/__exit annotations to module init/exit funcs (Davide Caratti) [2133755]
- perf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- perf tools: Remove bpf_map__set_priv()/bpf_map__priv() usage (Jerome Marchand) [2120966]
- perf tools: Remove bpf_program__set_priv/bpf_program__priv usage (Jerome Marchand) [2120966]
- perf bpf: Stop using deprecated bpf_object__next() API (Jerome Marchand) [2120966]
- perf bpf: Stop using deprecated bpf_load_program() API (Jerome Marchand) [2120966]
- perf: Stop using bpf_object__open_buffer() API (Jerome Marchand) [2120966]
- bpf/selftests: fix bpf selftests install (Jerome Marchand) [2120966]
- bpf: Force cookies array to follow symbols sorting (Jerome Marchand) [2120966]
- ftrace: Keep address offset in ftrace_lookup_symbols (Jerome Marchand) [2120966]
- selftests/bpf: Shuffle cookies symbols in kprobe multi test (Jerome Marchand) [2120966]
- bpf: Fix bpf_xdp_pointer return pointer (Jiri Benc) [2120966]
- selftests/bpf: Fix tc_redirect_dtime (Jiri Benc) [2120966]
- net: fix wrong network header length (Jiri Benc) [2120966]
- skbuff: clean up inconsistent indenting (Jiri Benc) [2120966]
- bpf: Disallow bpf programs call prog_run command. (Jerome Marchand) [2120966]
- bpf, x86: fix freeing of not-finalized bpf_prog_pack (Jerome Marchand) [2120966]
- selftests/bpf: Fix rare segfault in sock_fields prog test (Jerome Marchand) [2120966]
- rethook: Reject getting a rethook if RCU is not watching (Jerome Marchand) [2120966]
- selftests/bpf: Avoid skipping certain subtests (Jerome Marchand) [2120966]
- bpf: Use safer kvmalloc_array() where possible (Jerome Marchand) [2120966]
- bpf: Resolve symbols with ftrace_lookup_symbols for kprobe multi link (Jerome Marchand) [2120966]
- ftrace: Add ftrace_lookup_symbols function (Jerome Marchand) [2120966]
- kallsyms: Make kallsyms_on_each_symbol generally available (Jerome Marchand) [2120966]
- bpf: Introduce bpf_arch_text_invalidate for bpf_prog_pack (Jerome Marchand) [2120966]
- x86/alternative: Introduce text_poke_set (Jerome Marchand) [2120966]
- bpf: Fill new bpf_prog_pack with illegal instructions (Jerome Marchand) [2120966]
- scripts: dummy-tools, add pahole (Jerome Marchand) [2120966]
- kprobes: Fix KRETPROBES when CONFIG_KRETPROBE_ON_RETHOOK is set (Jerome Marchand) [2120966]
- bpf: Fix release of page_pool in BPF_PROG_RUN in test runner (Jerome Marchand) [2120966]
- x86,bpf: Avoid IBT objtool warning (Jerome Marchand) [2120966]
- bpf: Do write access check for kfunc and global func (Jerome Marchand) [2120966]
- bpf: Adjust bpf_tcp_check_syncookie selftest to test dual-stack sockets (Jerome Marchand) [2120966]
- bpf: selftests: Test fentry tracing a struct_ops program (Jerome Marchand) [2120966]
- bpf: Resolve to prog->aux->dst_prog->type only for BPF_PROG_TYPE_EXT (Jerome Marchand) [2120966]
- rethook: Fix to use WRITE_ONCE() for rethook:: Handler (Jerome Marchand) [2120966]
- selftests/bpf: Fix warning comparing pointer to 0 (Jerome Marchand) [2120966]
- bpf: Fix sparse warnings in kprobe_multi_resolve_syms (Jerome Marchand) [2120966]
- bpftool: Explicit errno handling in skeletons (Jerome Marchand) [2120966]
- selftests/bpf: Fix clang compilation errors (Jerome Marchand) [2120966]
- x86,kprobes: Fix optprobe trampoline to generate complete pt_regs (Jerome Marchand) [2120966]
- x86,rethook: Fix arch_rethook_trampoline() to generate a complete pt_regs (Jerome Marchand) [2120966]
- x86,rethook,kprobes: Replace kretprobe with rethook on x86 (Jerome Marchand) [2120966]
- kprobes: Use rethook for kretprobe if possible (Jerome Marchand) [2120966]
- kprobes: Limit max data_size of the kretprobe instances (Jerome Marchand) [2120966]
- bpftool: Fix generated code in codegen_asserts (Jerome Marchand) [2120966]
- bpf: Fix maximum permitted number of arguments check (Jerome Marchand) [2120966]
- bpf: Sync comments for bpf_get_stack (Jerome Marchand) [2120966]
- fprobe: Fix sparse warning for acccessing __rcu ftrace_hash (Jerome Marchand) [2120966]
- fprobe: Fix smatch type mismatch warning (Jerome Marchand) [2120966]
- bpf/bpftool: Add unprivileged_bpf_disabled check against value of 2 (Jerome Marchand) [2120966]
- selftests/bpf: Fix kprobe_multi test. (Jerome Marchand) [2120966]
- Revert "rethook: x86: Add rethook x86 implementation" (Jerome Marchand) [2120966]
- Revert "arm64: rethook: Add arm64 rethook implementation" (Jerome Marchand) [2120966]
- Revert "powerpc: Add rethook support" (Jerome Marchand) [2120966]
- Revert "ARM: rethook: Add rethook arm implementation" (Jerome Marchand) [2120966]
- bpftool: Fix a bug in subskeleton code generation (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack when PMU_SIZE is not defined (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack for multi-node setup (Jerome Marchand) [2120966]
- bpf: Fix warning for cast from restricted gfp_t in verifier (Jerome Marchand) [2120966]
- libbpf: Close fd in bpf_object__reuse_map (Jerome Marchand) [2120966]
- bpf: Fix kprobe_multi return probe backtrace (Jerome Marchand) [2120966]
- Revert "bpf: Add support to inline bpf_get_func_ip helper on x86" (Jerome Marchand) [2120966]
- bpf: Simplify check in btf_parse_hdr() (Jerome Marchand) [2120966]
- selftests/bpf/test_lirc_mode2.sh: Exit with proper code (Jerome Marchand) [2120966]
- bpf: Check for NULL return from bpf_get_btf_vmlinux (Jerome Marchand) [2120966]
- selftests/bpf: Test skipping stacktrace (Jerome Marchand) [2120966]
- bpf: Adjust BPF stack helper functions to accommodate skip > 0 (Jerome Marchand) [2120966]
- bpf: Select proper size for bpf_prog_pack (Jerome Marchand) [2120966]
- selftests/bpf: Fix test for 4-byte load from remote_port on big-endian (Jerome Marchand) [2120966]
- selftests/bpf: Fix u8 narrow load checks for bpf_sk_lookup remote_port (Jerome Marchand) [2120966]
- bpf: Treat bpf_sk_lookup remote_port as a 2-byte field (Jerome Marchand) [2120966]
- selftests/bpf: Test for associating multiple elements with the local storage (Jerome Marchand) [2120966]
- bpf: Enable non-atomic allocations in local storage (Jerome Marchand) [2120966]
- libbpf: Avoid NULL deref when initializing map BTF info (Jerome Marchand) [2120966]
- bpf: Always raise reference in btf_get_module_btf (Jerome Marchand) [2120966]
- bpf: Factor out fd returning from bpf_btf_find_by_name_kind (Jerome Marchand) [2120966]
- bpftool: Add BPF_TRACE_KPROBE_MULTI to attach type names table (Jerome Marchand) [2120966]
- selftests/bpf: Fix test for 4-byte load from dst_port on big-endian (Jerome Marchand) [2120966]
- selftests/bpf: Use constants for socket states in sock_fields test (Jerome Marchand) [2120966]
- selftests/bpf: Check dst_port only on the client socket (Jerome Marchand) [2120966]
- selftests/bpf: Fix error reporting from sock_fields programs (Jerome Marchand) [2120966]
- selftests/bpf: Test subskeleton functionality (Jerome Marchand) [2120966]
- bpftool: Add support for subskeletons (Jerome Marchand) [2120966]
- libbpf: Add subskeleton scaffolding (Jerome Marchand) [2120966]
- libbpf: Init btf_{key,value}_type_id on internal map open (Jerome Marchand) [2120966]
- libbpf: .text routines are subprograms in strict mode (Jerome Marchand) [2120966]
- selftests/bpf: Add cookie test for bpf_program__attach_kprobe_multi_opts (Jerome Marchand) [2120966]
- selftests/bpf: Add attach test for bpf_program__attach_kprobe_multi_opts (Jerome Marchand) [2120966]
- selftests/bpf: Add kprobe_multi bpf_cookie test (Jerome Marchand) [2120966]
- selftests/bpf: Add kprobe_multi attach test (Jerome Marchand) [2120966]
- libbpf: Add bpf_program__attach_kprobe_multi_opts function (Jerome Marchand) [2120966]
- libbpf: Add bpf_link_create support for multi kprobes (Jerome Marchand) [2120966]
- libbpf: Add libbpf_kallsyms_parse function (Jerome Marchand) [2120966]
- bpf: Add cookie support to programs attached with kprobe multi link (Jerome Marchand) [2120966]
- bpf: Add support to inline bpf_get_func_ip helper on x86 (Jerome Marchand) [2120966]
- bpf: Add bpf_get_func_ip kprobe helper for multi kprobe link (Jerome Marchand) [2120966]
- bpf: Add multi kprobe link (Jerome Marchand) [2120966]
- kallsyms: Skip the name search for empty string (Jerome Marchand) [2120966]
- lib/sort: Add priv pointer to swap function (Jerome Marchand) [2120966]
- Enable CONFIG_FPROBE (Jerome Marchand) [2120966]
- fprobe: Add a selftest for fprobe (Jerome Marchand) [2120966]
- docs: fprobe: Add fprobe description to ftrace-use.rst (Jerome Marchand) [2120966]
- fprobe: Introduce FPROBE_FL_KPROBE_SHARED flag for fprobe (Jerome Marchand) [2120966]
- fprobe: Add sample program for fprobe (Jerome Marchand) [2120966]
- fprobe: Add exit_handler support (Jerome Marchand) [2120966]
- ARM: rethook: Add rethook arm implementation (Jerome Marchand) [2120966]
- powerpc: Add rethook support (Jerome Marchand) [2120966]
- arm64: rethook: Add arm64 rethook implementation (Jerome Marchand) [2120966]
- rethook: x86: Add rethook x86 implementation (Jerome Marchand) [2120966]
- rethook: Add a generic return hook (Jerome Marchand) [2120966]
- fprobe: Add ftrace based probe APIs (Jerome Marchand) [2120966]
- ftrace: Add ftrace_set_filter_ips function (Jerome Marchand) [2120966]
- selftests/bpf: Test subprog jit when toggle bpf_jit_harden repeatedly (Jerome Marchand) [2120966]
- bpf: Fix net.core.bpf_jit_harden race (Jerome Marchand) [2120966]
- bpf, x86: Fall back to interpreter mode when extra pass fails (Jerome Marchand) [2120966]
- bpf: selftests: Remove libcap usage from test_progs (Jerome Marchand) [2120966]
- bpf: selftests: Remove libcap usage from test_verifier (Jerome Marchand) [2120966]
- bpf: selftests: Add helpers to directly use the capget and capset syscall (Jerome Marchand) [2120966]
- bpftool: man: Add missing top level docs (Jerome Marchand) [2120966]
- bpftool: Add bpf_cookie to link output (Jerome Marchand) [2120966]
- selftests/bpf: Clean up array_size.cocci warnings (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang compilation error for send_signal.c (Jerome Marchand) [2120966]
- selftests/bpf: Add a test for maximum packet size in xdp_do_redirect (Jerome Marchand) [2120966]
- bpf, test_run: Fix packet size check for live packet mode (Jerome Marchand) [2120966]
- compiler_types: Refactor the use of btf_type_tag attribute. (Jerome Marchand) [2120966]
- selftests/bpf: Check that bpf_kernel_read_file() denies reading IMA policy (Jerome Marchand) [2120966]
- selftests/bpf: Add test for bpf_lsm_kernel_read_file() (Jerome Marchand) [2120966]
- bpf-lsm: Make bpf_lsm_kernel_read_file() as sleepable (Jerome Marchand) [2120966]
- selftests/bpf: Check if the digest is refreshed after a file write (Jerome Marchand) [2120966]
- selftests/bpf: Add test for bpf_ima_file_hash() (Jerome Marchand) [2120966]
- selftests/bpf: Move sample generation code to ima_test_common() (Jerome Marchand) [2120966]
- bpf-lsm: Introduce new helper bpf_ima_file_hash() (Jerome Marchand) [2120966]
- ima: Always return a file measurement in ima_file_hash() (Jerome Marchand) [2120966]
- ima: Fix documentation-related warnings in ima_main.c (Jerome Marchand) [2120966]
- bpftool: Ensure bytes_memlock json output is correct (Jerome Marchand) [2120966]
- bpf: Use offsetofend() to simplify macro definition (Jerome Marchand) [2120966]
- bpf: Fix comment for helper bpf_current_task_under_cgroup() (Jerome Marchand) [2120966]
- bpf, lwt: Fix crash when using bpf_skb_set_tunnel_key() from bpf_xmit lwt hook (Jiri Benc) [2120966]
- selftests/bpf: Fix tunnel remote IP comments (Jiri Benc) [2120966]
- veth: Allow jumbo frames in xdp mode (Jiri Benc) [2120966]
- veth: Rework veth_xdp_rcv_skb in order to accept non-linear skb (Jiri Benc) [2120966]
- net: veth: Account total xdp_frame len running ndo_xdp_xmit (Jiri Benc) [2120966]
- samples/bpf, xdpsock: Fix race when running for fix duration of time (Jiri Benc) [2120966]
- bpf, sockmap: Fix double uncharge the mem of sk_msg (Jiri Benc) [2120966]
- bpf, sockmap: Fix more uncharged while msg has more_data (Jiri Benc) [2120966]
- bpf, sockmap: Fix memleak in tcp_bpf_sendmsg while sk msg is full (Jiri Benc) [2120966]
- bpf, sockmap: Fix memleak in sk_psock_queue_msg (Jiri Benc) [2120966]
- bpf: selftests: Update tests after s/delivery_time/tstamp/ change in bpf.h (Jiri Benc) [2120966]
- bpf: Remove BPF_SKB_DELIVERY_TIME_NONE and rename s/delivery_time_/tstamp_/ (Jiri Benc) [2120966]
- bpf: Simplify insn rewrite on BPF_WRITE __sk_buff->tstamp (Jiri Benc) [2120966]
- bpf: Simplify insn rewrite on BPF_READ __sk_buff->tstamp (Jiri Benc) [2120966]
- bpf: net: Remove TC_AT_INGRESS_OFFSET and SKB_MONO_DELIVERY_TIME_OFFSET macro (Jiri Benc) [2120966]
- bpf: Add __sk_buff->delivery_time_type and bpf_skb_set_skb_delivery_time() (Jiri Benc) [2120966]
- bpf: Keep the (rcv) timestamp behavior for the existing tc-bpf@ingress (Jiri Benc) [2120966]
- net: Postpone skb_clear_delivery_time() until knowing the skb is delivered locally (Jiri Benc) [2120966]
- net: Get rcv tstamp if needed in nfnetlink_{log, queue}.c (Jiri Benc) [2120966]
- net: ipv6: Get rcv timestamp if needed when handling hop-by-hop IOAM option (Jiri Benc) [2120966]
- net: ipv6: Handle delivery_time in ipv6 defrag (Jiri Benc) [2120966]
- net: ip: Handle delivery_time in ip defrag (Jiri Benc) [2120966]
- net: Set skb->mono_delivery_time and clear it after sch_handle_ingress() (Jiri Benc) [2120966]
- net: Clear mono_delivery_time bit in __skb_tstamp_tx() (Jiri Benc) [2120966]
- net: Handle delivery_time in skb->tstamp during network tapping with af_packet (Jiri Benc) [2120966]
- net: Add skb_clear_tstamp() to keep the mono delivery_time (Jiri Benc) [2120966]
- net: Add skb->mono_delivery_time to distinguish mono delivery_time from (rcv) timestamp (Jiri Benc) [2120966]
- net: remove net_invalid_timestamp() (Jiri Benc) [2120966]
- Documentation: update networking/page_pool.rst (Jiri Benc) [2120966]
- page_pool: Add function to batch and return stats (Jiri Benc) [2120966]
- page_pool: Add recycle stats (Jiri Benc) [2120966]
- configs: disable CONFIG_PAGE_POOL_STATS (Jiri Benc) [2120966]
- page_pool: Add allocation stats (Jiri Benc) [2120966]
- selftest/bpf: Check invalid length in test_xdp_update_frags (Jiri Benc) [2120966]
- skmsg: convert struct sk_msg_sg::copy to a bitmap (Jiri Benc) [2120966]
- bpf, test_run: Use kvfree() for memory allocated with kvmalloc() (Jerome Marchand) [2120966]
- bpf: Initialise retval in bpf_prog_test_run_xdp() (Jerome Marchand) [2120966]
- bpftool: Restore support for BPF offload-enabled feature probing (Jerome Marchand) [2120966]
- selftests/bpf: Add selftest for XDP_REDIRECT in BPF_PROG_RUN (Jiri Benc) [2120966]
- selftests/bpf: Move open_netns() and close_netns() into network_helpers.c (Jiri Benc) [2120966]
- libbpf: Support batch_size option to bpf_prog_test_run (Jerome Marchand) [2120966]
- Documentation/bpf: Add documentation for BPF_PROG_RUN (Jerome Marchand) [2120966]
- bpf: Add "live packet" mode for XDP in BPF_PROG_RUN (Jerome Marchand) [2120966]
- bpf: selftests: test skb->tstamp in redirect_neigh (Jiri Benc) [2120966]
- Improve stability of find_vma BPF test (Jerome Marchand) [2120966]
- Improve send_signal BPF test stability (Jerome Marchand) [2120966]
- Improve perf related BPF tests (sample_freq issue) (Jerome Marchand) [2120966]
- bpf/docs: Update list of architectures supported. (Jerome Marchand) [2120966]
- bpf/docs: Update vmtest docs for static linking (Jerome Marchand) [2120966]
- bpf: Remove redundant slash (Jerome Marchand) [2120966]
- libbpf: Fix array_size.cocci warning (Jerome Marchand) [2120966]
- bpf: Replace strncpy() with strscpy() (Jerome Marchand) [2120966]
- libbpf: Unmap rings when umem deleted (Jerome Marchand) [2120966]
- bpf: Determine buf_info inside check_buffer_access() (Jerome Marchand) [2120966]
- powerpc/bpf: Simplify bpf_to_ppc() and adopt it for powerpc64 (Jerome Marchand) [2120966]
- powerpc64/bpf: Store temp registers' bpf to ppc mapping (Jerome Marchand) [2120966]
- powerpc/bpf: Use _Rn macros for GPRs (Jerome Marchand) [2120966]
- powerpc/bpf: Move bpf_jit64.h into bpf_jit_comp64.c (Jerome Marchand) [2120966]
- powerpc/bpf: Cleanup bpf_jit.h (Jerome Marchand) [2120966]
- powerpc64/bpf: Get rid of PPC_BPF_[LL|STL|STLU] macros (Jerome Marchand) [2120966]
- powerpc64/bpf: Convert some of the uses of PPC_BPF_[LL|STL] to PPC_BPF_[LD|STD] (Jerome Marchand) [2120966]
- powerpc/bpf: Rename PPC_BL_ABS() to PPC_BL() (Jerome Marchand) [2120966]
- powerpc64/bpf: Optimize instruction sequence used for function calls (Jerome Marchand) [2120966]
- powerpc64/bpf elfv1: Do not load TOC before calling functions (Jerome Marchand) [2120966]
- powerpc64/bpf elfv2: Setup kernel TOC in r2 on entry (Jerome Marchand) [2120966]
- powerpc64/bpf: Use r12 for constant blinding (Jerome Marchand) [2120966]
- powerpc64/bpf: Do not save/restore LR on each call to bpf_stf_barrier() (Jerome Marchand) [2120966]
- powerpc/bpf: Handle large branch ranges with BPF_EXIT (Jerome Marchand) [2120966]
- powerpc/bpf: Emit a single branch instruction for known short branch ranges (Jerome Marchand) [2120966]
- powerpc/bpf: Skip branch range validation during first pass (Jerome Marchand) [2120966]
- bpf ppc32: Access only if addr is kernel address (Jerome Marchand) [2120966]
- powerpc32/bpf: Fix codegen for bpf-to-bpf calls (Jerome Marchand) [2120966]
- bpf ppc32: Add BPF_PROBE_MEM support for JIT (Jerome Marchand) [2120966]
- selftests/bpf: Add a test for btf_type_tag "percpu" (Jerome Marchand) [2120966]
- bpf: Reject programs that try to load __percpu memory. (Jerome Marchand) [2120966]
- compiler_types: Define __percpu as __attribute__((btf_type_tag("percpu"))) (Jerome Marchand) [2120966]
- bpf: Fix checking PTR_TO_BTF_ID in check_mem_access (Jerome Marchand) [2120966]
- selftests/bpf: Add tests for kfunc register offset checks (Jerome Marchand) [2120966]
- bpf: Replace __diag_ignore with unified __diag_ignore_all (Jerome Marchand) [2120966]
- compiler_types.h: Add unified __diag_ignore_all for GCC/LLVM (Jerome Marchand) [2120966]
- compiler-clang.h: Add __diag infrastructure for clang (Jerome Marchand) [2120966]
- bpf: Harden register offset checks for release helpers and kfuncs (Jerome Marchand) [2120966]
- bpf: Disallow negative offset in check_ptr_off_reg (Jerome Marchand) [2120966]
- bpf: Fix PTR_TO_BTF_ID var_off check (Jerome Marchand) [2120966]
- bpf: Add check_func_arg_reg_off function (Jerome Marchand) [2120966]
- selftests/bpf: Add custom SEC() handling selftest (Jerome Marchand) [2120966]
- libbpf: Support custom SEC() handlers (Jerome Marchand) [2120966]
- libbpf: Allow BPF program auto-attach handlers to bail out (Jerome Marchand) [2120966]
- bpf: Small BPF verifier log improvements (Jerome Marchand) [2120966]
- libbpf: Add a check to ensure that page_cnt is non-zero (Jerome Marchand) [2120966]
- bpf, test_run: Fix overflow in XDP frags bpf_test_finish (Jerome Marchand) [2120966]
- bpf, selftests: Use raw_tp program for atomic test (Jerome Marchand) [2120966]
- selftests/bpf: Do not export subtest as standalone test (Jerome Marchand) [2120966]
- bpf: test_run: Fix overflow in bpf_test_finish frags parsing (Jerome Marchand) [2120966]
- bpf: test_run: Fix overflow in xdp frags parsing (Jerome Marchand) [2120966]
- bpf: test_run: Fix OOB access in bpf_prog_test_run_xdp (Jerome Marchand) [2120966]
- libbpf: Deprecate bpf_prog_test_run_xattr and bpf_prog_test_run (Jerome Marchand) [2120966]
- bpftool: Migrate from bpf_prog_test_run_xattr (Jerome Marchand) [2120966]
- selftests/bpf: Migrate from bpf_prog_test_run_xattr (Jerome Marchand) [2120966]
- selftests/bpf: Migrate from bpf_prog_test_run (Jerome Marchand) [2120966]
- samples/bpf: Update cpumap/devmap sec_name (Jerome Marchand) [2120966]
- selftests/bpf: Update cpumap/devmap sec_name (Jerome Marchand) [2120966]
- libbpf: Deprecate xdp_cpumap, xdp_devmap and classifier sec definitions (Jerome Marchand) [2120966]
- page_pool: Refactor page_pool to enable fragmenting after allocation (Jiri Benc) [2120966]
- socket: Don't use u8 type in uapi socket.h (Jiri Benc) [2120966]
- tcp: Change SYN ACK retransmit behaviour to account for rehash (Jiri Benc) [2120966]
- bpf: Add SO_TXREHASH setsockopt (Jiri Benc) [2120966]
- txhash: Add txrehash sysctl description (Jiri Benc) [2120966]
- txhash: Add socket option to control TX hash rethink behavior (Jiri Benc) [2120966]
- txhash: Make rethinking txhash behavior configurable via sysctl (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_redirect: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_meta: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_tcp_check_syncookie: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_lwt_seg6local: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_vlan: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_veth: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_redirect_multi: use temp netns for testing (Jiri Benc) [2120966]
- selftest/bpf: Fix a stale comment. (Jiri Benc) [2120966]
- selftest/bpf: Test batching and bpf_(get|set)sockopt in bpf unix iter. (Jiri Benc) [2120966]
- bpf: Support bpf_(get|set)sockopt() in bpf unix iter. (Jiri Benc) [2120966]
- bpf: af_unix: Use batching algorithm in bpf unix iter. (Jiri Benc) [2120966]
- af_unix: Refactor unix_next_socket(). (Jiri Benc) [2120966]
- af_unix: Relax race in unix_autobind(). (Jiri Benc) [2120966]
- af_unix: Replace the big lock with small locks. (Jiri Benc) [2120966]
- af_unix: Save hash in sk_hash. (Jiri Benc) [2120966]
- af_unix: Add helpers to calculate hashes. (Jiri Benc) [2120966]
- af_unix: Remove UNIX_ABSTRACT() macro and test sun_path[0] instead. (Jiri Benc) [2120966]
- af_unix: Allocate unix_address in unix_bind_(bsd|abstract)(). (Jiri Benc) [2120966]
- af_unix: Remove unix_mkname(). (Jiri Benc) [2120966]
- af_unix: Copy unix_mkname() into unix_find_(bsd|abstract)(). (Jiri Benc) [2120966]
- af_unix: Cut unix_validate_addr() out of unix_mkname(). (Jiri Benc) [2120966]
- af_unix: Return an error as a pointer in unix_find_other(). (Jiri Benc) [2120966]
- af_unix: Factorise unix_find_other() based on address types. (Jiri Benc) [2120966]
- af_unix: Pass struct sock to unix_autobind(). (Jiri Benc) [2120966]
- af_unix: Use offsetof() instead of sizeof(). (Jiri Benc) [2120966]
- selftests/bpf: Do not fail build if CONFIG_NF_CONNTRACK=m/n (Jerome Marchand) [2120966]
- bpf, x86: Set header->size properly before freeing it (Jerome Marchand) [2120966]
- x86: Disable HAVE_ARCH_HUGE_VMALLOC on 32-bit x86 (Jerome Marchand) [2120966]
- selftests/bpf: Update btf_dump case for conflicting names (Jerome Marchand) [2120966]
- libbpf: Skip forward declaration when counting duplicated type names (Jerome Marchand) [2120966]
- bpf: Add some description about BPF_JIT_ALWAYS_ON in Kconfig (Jerome Marchand) [2120966]
- bpf: Cache the last valid build_id (Jerome Marchand) [2120966]
- libbpf: Fix BPF_MAP_TYPE_PERF_EVENT_ARRAY auto-pinning (Jerome Marchand) [2120966]
- bpf, arm64: Support more atomic operations (Jerome Marchand) [2120966]
- bpftool: Remove redundant slashes (Jerome Marchand) [2120966]
- Disable CONFIG_MODULE_ALLOW_BTF_MISMATCH (Jerome Marchand) [2120966]
- bpf: Add config to allow loading modules with BTF mismatches (Jerome Marchand) [2120966]
- bpf: Remove Lorenz Bauer from L7 BPF maintainers (Jerome Marchand) [2120966]
- bpf, arm64: Feed byte-offset into bpf line info (Jerome Marchand) [2120966]
- bpf, arm64: Call build_prologue() first in first JIT pass (Jerome Marchand) [2120966]
- bpf: Fix issue with bpf preload module taking over stdout/stdin of kernel. (Jerome Marchand) [2120966]
- bpftool: Bpf skeletons assert type sizes (Jerome Marchand) [2120966]
- bpf: Cleanup comments (Jerome Marchand) [2120966]
- libbpf: Simplify the find_elf_sec_sz() function (Jerome Marchand) [2120966]
- bpftool: Remove usage of reallocarray() (Jerome Marchand) [2120966]
- scripts/pahole-flags.sh: Parse DWARF and generate BTF with multithreading. (Jerome Marchand) [2120966]
- libbpf: Remove redundant check in btf_fixup_datasec() (Jerome Marchand) [2120966]
- selftests/bpf: Add test for reg2btf_ids out of bounds access (Jerome Marchand) [2120966]
- selftests/bpf: Fix btfgen tests (Jerome Marchand) [2120966]
- bpf: Initialize ret to 0 inside btf_populate_kfunc_set() (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang deprecated-declarations compilation error (Jerome Marchand) [2120966]
- bpf: Call maybe_wait_bpf_programs() only once from generic_map_delete_batch() (Jerome Marchand) [2120966]
- bpf: bpf_prog_pack: Set proper size before freeing ro_header (Jerome Marchand) [2120966]
- selftests/bpf: Fix crash in core_reloc when bpftool btfgen fails (Jerome Marchand) [2120966]
- selftests/bpf: Fix vmtest.sh to launch smp vm. (Jerome Marchand) [2120966]
- bpftool: Fix C++ additions to skeleton (Jerome Marchand) [2120966]
- selftests/bpf: Test "bpftool gen min_core_btf" (Jerome Marchand) [2120966]
- bpftool: Gen min_core_btf explanation and examples (Jerome Marchand) [2120966]
- bpftool: Implement btfgen_get_btf() (Jerome Marchand) [2120966]
- bpftool: Implement "gen min_core_btf" logic (Jerome Marchand) [2120966]
- bpftool: Add gen min_core_btf command (Jerome Marchand) [2120966]
- libbpf: Expose bpf_core_{add,free}_cands() to bpftool (Jerome Marchand) [2120966]
- libbpf: Split bpf_core_apply_relo() (Jerome Marchand) [2120966]
- bpf: Reject kfunc calls that overflow insn->imm (Jerome Marchand) [2120966]
- selftests/bpf: Add Skeleton templated wrapper as an example (Jerome Marchand) [2120966]
- bpftool: Add C++-specific open/load/etc skeleton wrappers (Jerome Marchand) [2120966]
- selftests/bpf: Fix GCC11 compiler warnings in -O2 mode (Jerome Marchand) [2120966]
- powerpc/bpf: Always reallocate BPF_REG_5, BPF_REG_AX and TMP_REG when possible (Jerome Marchand) [2120966]
- bpftool: Update versioning scheme, align on libbpf's version number (Jerome Marchand) [2120966]
- bpftool: Add libbpf's version number to "bpftool version" output (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack build for ppc64_defconfig (Jerome Marchand) [2120966]
- bpf: Convert bpf_preload.ko to use light skeleton. (Jerome Marchand) [2120966]
- bpf: Update iterators.lskel.h. (Jerome Marchand) [2120966]
- bpftool: Generalize light skeleton generation. (Jerome Marchand) [2120966]
- libbpf: Prepare light skeleton for the kernel. (Jerome Marchand) [2120966]
- bpf: Extend sys_bpf commands for bpf_syscall programs. (Jerome Marchand) [2120966]
- selftests/bpf: Cover 4-byte load from remote_port in bpf_sk_lookup (Jerome Marchand) [2120966]
- bpf: Make remote_port field in struct bpf_sk_lookup 16-bit wide (Jerome Marchand) [2120966]
- selftests/bpf: Test BPF_KPROBE_SYSCALL macro (Jerome Marchand) [2120966]
- libbpf: Add BPF_KPROBE_SYSCALL macro (Jerome Marchand) [2120966]
- libbpf: Fix accessing the first syscall argument on s390 (Jerome Marchand) [2120966]
- libbpf: Fix accessing the first syscall argument on arm64 (Jerome Marchand) [2120966]
- libbpf: Allow overriding PT_REGS_PARM1{_CORE}_SYSCALL (Jerome Marchand) [2120966]
- selftests/bpf: Skip test_bpf_syscall_macro's syscall_arg1 on arm64 and s390 (Jerome Marchand) [2120966]
- libbpf: Fix accessing syscall arguments on powerpc (Jerome Marchand) [2120966]
- selftests/bpf: Use PT_REGS_SYSCALL_REGS in bpf_syscall_macro (Jerome Marchand) [2120966]
- libbpf: Add PT_REGS_SYSCALL_REGS macro (Jerome Marchand) [2120966]
- selftests/bpf: Fix an endianness issue in bpf_syscall_macro test (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack build HPAGE_PMD_SIZE (Jerome Marchand) [2120966]
- bpf: Fix leftover header->pages in sparc and powerpc code. (Jerome Marchand) [2120966]
- bpf, x86_64: Fail gracefully on bpf_jit_binary_pack_finalize failures (Jerome Marchand) [2120966]
- bpf, x86_64: Use bpf_jit_binary_pack_alloc (Jerome Marchand) [2120966]
- bpf: Introduce bpf_jit_binary_pack_[alloc|finalize|free] (Jerome Marchand) [2120966]
- bpf: Introduce bpf_prog_pack allocator (Jerome Marchand) [2120966]
- bpf: Introduce bpf_arch_text_copy (Jerome Marchand) [2120966]
- x86/alternative: Introduce text_poke_copy (Jerome Marchand) [2120966]
- bpf: Use prog->jited_len in bpf_prog_ksym_set_addr() (Jerome Marchand) [2120966]
- bpf: Use size instead of pages in bpf_binary_header (Jerome Marchand) [2120966]
- bpf: Use bytes instead of pages for bpf_jit_[charge|uncharge]_modmem (Jerome Marchand) [2120966]
- x86/Kconfig: Select HAVE_ARCH_HUGE_VMALLOC with HAVE_ARCH_HUGE_VMAP (Jerome Marchand) [2120966]
- selftests/bpf: Fix strict mode calculation (Jerome Marchand) [2120966]
- bpftool: Fix strict mode calculation (Jerome Marchand) [2120966]
- libbpf: Remove mode check in libbpf_set_strict_mode() (Jerome Marchand) [2120966]
- selftests/bpf: Fix tests to use arch-dependent syscall entry points (Jerome Marchand) [2120966]
- libbpf: Fix build issue with llvm-readelf (Jerome Marchand) [2120966]
- selftests/bpf: Test bpf_core_types_are_compat() functionality. (Jerome Marchand) [2120966]
- bpf: Implement bpf_core_types_are_compat(). (Jerome Marchand) [2120966]
- bpf, arm64: Enable kfunc call (Jerome Marchand) [2120966]
- selftests/bpf: Add a selftest for invalid func btf with btf decl_tag (Jerome Marchand) [2120966]
- libbpf: Deprecate priv/set_priv storage (Jerome Marchand) [2120966]
- bpf, docs: Better document the atomic instructions (Jerome Marchand) [2120966]
- bpf, docs: Better document the extended instruction format (Jerome Marchand) [2120966]
- bpf, docs: Better document the legacy packet access instruction (Jerome Marchand) [2120966]
- bpf, docs: Better document the regular load and store instructions (Jerome Marchand) [2120966]
- bpf, docs: Document the byte swapping instructions (Jerome Marchand) [2120966]
- libbpf: Deprecate forgotten btf__get_map_kv_tids() (Jerome Marchand) [2120966]
- samples/bpf: Get rid of bpf_prog_load_xattr() use (Jerome Marchand) [2120966]
- selftests/bpf: Redo the switch to new libbpf XDP APIs (Jerome Marchand) [2120966]
- selftests/bpf: Remove usage of deprecated feature probing APIs (Jerome Marchand) [2120966]
- bpftool: Fix uninit variable compilation warning (Jerome Marchand) [2120966]
- bpftool: Stop supporting BPF offload-enabled feature probing (Jerome Marchand) [2120966]
- libbpf: Stop using deprecated bpf_map__is_offload_neutral() (Jerome Marchand) [2120966]
- Disable CONFIG_DEBUG_INFO_DWARF5 (Jerome Marchand) [2120966]
- lib/Kconfig.debug: Allow BTF + DWARF5 with pahole 1.21+ (Jerome Marchand) [2120966]
- lib/Kconfig.debug: Use CONFIG_PAHOLE_VERSION (Jerome Marchand) [2120966]
- scripts/pahole-flags.sh: Use pahole-version.sh (Jerome Marchand) [2120966]
- kbuild: Add CONFIG_PAHOLE_VERSION (Jerome Marchand) [2120966]
- MAINTAINERS: Add scripts/pahole-flags.sh to BPF section (Jerome Marchand) [2120966]
- bpf: Drop libbpf, libelf, libz dependency from bpf preload. (Jerome Marchand) [2120966]
- bpf: Open code obj_get_info_by_fd in bpf preload. (Jerome Marchand) [2120966]
- bpf: Convert bpf preload to light skeleton. (Jerome Marchand) [2120966]
- bpf: Remove unnecessary setrlimit from bpf preload. (Jerome Marchand) [2120966]
- libbpf: Open code raw_tp_open and link_create commands. (Jerome Marchand) [2120966]
- libbpf: Open code low level bpf commands. (Jerome Marchand) [2120966]
- libbpf: Add support for bpf iter in light skeleton. (Jerome Marchand) [2120966]
- libbpf: Deprecate btf_ext rec_size APIs (Jerome Marchand) [2120966]
- bpf: make bpf_copy_from_user_task() gpl only (Jerome Marchand) [2120966]
- selftests/bpf: Extend verifier and bpf_sock tests for dst_port loads (Jerome Marchand) [2120966]
- bpf: Make dst_port field in struct bpf_sock 16-bit wide (Jerome Marchand) [2120966]
- docs/bpf: clarify how btf_type_tag gets encoded in the type chain (Jerome Marchand) [2120966]
- selftests/bpf: specify pahole version requirement for btf_tag test (Jerome Marchand) [2120966]
- selftests/bpf: add a selftest with __user tag (Jerome Marchand) [2120966]
- selftests/bpf: rename btf_decl_tag.c to test_btf_decl_tag.c (Jerome Marchand) [2120966]
- bpf: reject program if a __user tagged memory accessed in kernel way (Jerome Marchand) [2120966]
- compiler_types: define __user as __attribute__((btf_type_tag("user"))) (Jerome Marchand) [2120966]
- cgroup/bpf: fast path skb BPF filtering (Jerome Marchand) [2120966]
- selftests/bpf: fix a clang compilation error (Jerome Marchand) [2120966]
- bpf, x86: Remove unnecessary handling of BPF_SUB atomic op (Jerome Marchand) [2120966]
- bpf: remove unused static inlines (Jerome Marchand) [2120966]
- selftests/bpf: fix uprobe offset calculation in selftests (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang compilation error (Jerome Marchand) [2120966]
- bpf: fix register_btf_kfunc_id_set for !CONFIG_DEBUG_INFO_BTF (Jerome Marchand) [2120966]
- selftests: bpf: Less strict size check in sockopt_sk (Jerome Marchand) [2120966]
- samples/bpf: use preferred getters/setters instead of deprecated ones (Jerome Marchand) [2120966]
- selftests/bpf: use preferred setter/getter APIs instead of deprecated ones (Jerome Marchand) [2120966]
- bpftool: use preferred setters/getters instead of deprecated ones (Jerome Marchand) [2120966]
- libbpf: deprecate bpf_program__is_<type>() and bpf_program__set_<type>() APIs (Jerome Marchand) [2120966]
- libbpf: deprecate bpf_map__resize() (Jerome Marchand) [2120966]
- libbpf: hide and discourage inconsistently named getters (Jerome Marchand) [2120966]
- selftests/bpf: Add a test to confirm PT_REGS_PARM4_SYSCALL (Jerome Marchand) [2120966]
- libbpf: Fix the incorrect register read for syscalls on x86_64 (Jerome Marchand) [2120966]
- libbpf: Mark bpf_object__open_xattr() deprecated (Jerome Marchand) [2120966]
- libbpf: Mark bpf_object__open_buffer() API deprecated (Jerome Marchand) [2120966]
- selftests/bpf: Add test for sleepable bpf iterator programs (Jerome Marchand) [2120966]
- libbpf: Add "iter.s" section for sleepable bpf iterator programs (Jerome Marchand) [2120966]
- bpf: Add bpf_copy_from_user_task() helper (Jerome Marchand) [2120966]
- bpf: Add support for bpf iterator programs to use sleepable helpers (Jerome Marchand) [2120966]
- xdp: disable XDP_REDIRECT for xdp frags (Jiri Benc) [2120966]
- bpf: selftests: add CPUMAP/DEVMAP selftests for xdp frags (Jiri Benc) [2120966]
- bpf: selftests: introduce bpf_xdp_{load,store}_bytes selftest (Jiri Benc) [2120966]
- net: xdp: introduce bpf_xdp_pointer utility routine (Jiri Benc) [2120966]
- bpf: generalise tail call map compatibility check (Jiri Benc) [2120966]
- libbpf: Add SEC name for xdp frags programs (Jiri Benc) [2120966]
- bpf: selftests: update xdp_adjust_tail selftest to include xdp frags (Jiri Benc) [2120966]
- bpf: test_run: add xdp_shared_info pointer in bpf_test_finish signature (Jiri Benc) [2120966]
- bpf: introduce frags support to bpf_prog_test_run_xdp() (Jiri Benc) [2120966]
- bpf: move user_size out of bpf_test_init (Jiri Benc) [2120966]
- bpf: add frags support to xdp copy helpers (Jiri Benc) [2120966]
- bpf: add frags support to the bpf_xdp_adjust_tail() API (Jiri Benc) [2120966]
- bpf: introduce bpf_xdp_get_buff_len helper (Jiri Benc) [2120966]
- xdp: add frags support to xdp_return_{buff/frame} (Jiri Benc) [2120966]
- net: xdp: add xdp_update_skb_shared_info utility routine (Jiri Benc) [2120966]
- xdp: introduce flags field in xdp_buff/xdp_frame (Jiri Benc) [2120966]
- net: skbuff: add size metadata to skb_shared_info for xdp (Jiri Benc) [2120966]
- bpf: selftests: Get rid of CHECK macro in xdp_bpf2bpf.c (Jiri Benc) [2120966]
- bpf: selftests: Get rid of CHECK macro in xdp_adjust_tail.c (Jiri Benc) [2120966]
- bpf: Fix flexible_array.cocci warnings (Jerome Marchand) [2120966]
- bpf: introduce BPF_F_XDP_HAS_FRAGS flag in prog_flags loading the ebpf program (Jerome Marchand) [2120966]
- selftests: bpf: test BPF_PROG_QUERY for progs attached to sockmap (Jerome Marchand) [2120966]
- bpf: support BPF_PROG_QUERY for progs attached to sockmap (Jerome Marchand) [2120966]
- samples/bpf: adapt samples/bpf to bpf_xdp_xxx() APIs (Jerome Marchand) [2120966]
- bpftool: use new API for attaching XDP program (Jerome Marchand) [2120966]
- libbpf: streamline low-level XDP APIs (Jerome Marchand) [2120966]
- docs/bpf: update BPF map definition example (Jerome Marchand) [2120966]
- libbpf: deprecate legacy BPF map definitions (Jerome Marchand) [2120966]
- selftests/bpf: convert remaining legacy map definitions (Jerome Marchand) [2120966]
- selftests/bpf: fail build on compilation warning (Jerome Marchand) [2120966]
- selftests/bpf: Update sockopt_sk test to the use bpf_set_retval (Jerome Marchand) [2120966]
- selftests/bpf: Test bpf_{get,set}_retval behavior with cgroup/sockopt (Jerome Marchand) [2120966]
- bpf: Add cgroup helpers bpf_{get,set}_retval to get/set syscall return value (Jerome Marchand) [2120966]
- bpf: Move getsockopt retval to struct bpf_cg_run_ctx (Jerome Marchand) [2120966]
- bpf: Make BPF_PROG_RUN_ARRAY return -err instead of allow boolean (Jerome Marchand) [2120966]
- libbpf: Improve btf__add_btf() with an additional hashmap for strings. (Jerome Marchand) [2120966]
- bpf/scripts: Raise an exception if the correct number of sycalls are not generated (Jerome Marchand) [2120966]
- bpf/scripts: Make description and returns section for helpers/syscalls mandatory (Jerome Marchand) [2120966]
- uapi/bpf: Add missing description and returns for helper documentation (Jerome Marchand) [2120966]
- bpftool: Adding support for BTF program names (Jerome Marchand) [2120966]
- selftests/bpf: Add test for race in btf_try_get_module (Jerome Marchand) [2120966]
- selftests/bpf: Extend kfunc selftests (Jerome Marchand) [2120966]
- selftests/bpf: Add test_verifier support to fixup kfunc call insns (Jerome Marchand) [2120966]
- selftests/bpf: Add test for unstable CT lookup API (Jerome Marchand) [2120966]
- net/netfilter: Add unstable CT lookup helpers for XDP and TC-BPF (Jiri Benc) [2120966]
- bpf: Add reference tracking support to kfunc (Jerome Marchand) [2120966]
- bpf: Introduce mem, size argument pair support for kfunc (Jerome Marchand) [2120966]
- bpf: Remove check_kfunc_call callback and old kfunc BTF ID API (Jerome Marchand) [2120966]
- bpf: Populate kfunc BTF ID sets in struct btf (Jerome Marchand) [2120966]
- bpf: Fix UAF due to race between btf_try_get_module and load_module (Jerome Marchand) [2120966]
- test: selftests: Remove unused various in sockmap_verdict_prog.c (Jerome Marchand) [2120966]
- tools/resolve_btfids: Build with host flags (Jerome Marchand) [2120966]
- bpf/scripts: Raise an exception if the correct number of helpers are not generated (Jerome Marchand) [2120966]
- libbpf: Deprecate bpf_map__def() API (Jerome Marchand) [2120966]
- selftests/bpf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- bpftool: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- samples/bpf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- libbpf: Fix possible NULL pointer dereference when destroying skeleton (Jerome Marchand) [2120966]
- bpftool: Only set obj->skeleton on complete success (Jerome Marchand) [2120966]
- selftests/bpf: Change bpf_prog_attach_xattr() to bpf_prog_attach_opts() (Jerome Marchand) [2120966]
- libbpf: Rename bpf_prog_attach_xattr() to bpf_prog_attach_opts() (Jerome Marchand) [2120966]
- libbpf: Use IS_ERR_OR_NULL() in hashmap__free() (Jerome Marchand) [2120966]

* Sat Nov 19 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-199.el9]
- redhat/configs: turn off NXP i.MX9 family (Steve Best) [2138010]
- soc: imx: imx93-pd: Fix the error handling path of imx93_pd_probe() (Steve Best) [2138010]
- soc: imx: add i.MX93 media blk ctrl driver (Steve Best) [2138010]
- dt-bindings: soc: add i.MX93 mediamix blk ctrl (Steve Best) [2138010]
- soc: imx: add i.MX93 SRC power domain driver (Steve Best) [2138010]
- ipv6: Fix crash when IPv6 is administratively disabled (Guillaume Nault) [2138802]
- raw: fix a typo in raw_icmp_error() (Guillaume Nault) [2138802]
- raw: remove unused variables from raw6_icmp_error() (Guillaume Nault) [2138802]
- raw: complete rcu conversion (Guillaume Nault) [2138802]
- raw: Use helpers for the hlist_nulls variant. (Guillaume Nault) [2138802]
- raw: Fix mixed declarations error in raw_icmp_error(). (Guillaume Nault) [2138802]
- raw: convert raw sockets to RCU (Guillaume Nault) [2138802]
- raw: use more conventional iterators (Guillaume Nault) [2138802]
- arm64: kdump: Reimplement crashkernel=X fixup (Eric Chanudet) [2136853]
- bnx2x: Fix comment typo (Manish Chopra) [2112159]
- bnx2x: Fix spelling mistake "regiser" -> "register" (Manish Chopra) [2112159]
- bnx2x: Fix undefined behavior due to shift overflowing the constant (Manish Chopra) [2112159]
- RDMA/qedr: Fix potential memory leak in __qedr_alloc_mr() (Manish Chopra) [2112168]
- qlogic: qed: fix clang -Wformat warnings (Manish Chopra) [2112168]
- qed: Use bitmap_empty() (Manish Chopra) [2112168]
- qed: Use the bitmap API to allocate bitmaps (Manish Chopra) [2112168]
- qlogic/qed: fix repeated words in comments (Manish Chopra) [2112168]
- RDMA/qedr: Fix reporting QP timeout attribute (Manish Chopra) [2112168]
- qed: fix typos in comments (Manish Chopra) [2112168]
- net: qed: fix typos in comments (Manish Chopra) [2112168]
- RDMA/qedr: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- net: qede: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- qed: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- qed: replace bitmap_weight with bitmap_empty in qed_roce_stop() (Manish Chopra) [2112168]
- qed: rework qed_rdma_bmap_free() (Manish Chopra) [2112168]
- qed: Remove IP services API. (Manish Chopra) [2112168]
- qed: remove an unneed NULL check on list iterator (Manish Chopra) [2112168]

* Thu Nov 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-198.el9]
- CI: Remove deprecated variable (Veronika Kabatova)
- atlantic: fix deadlock at aq_nic_stop (Íñigo Huguet) [2125601]
- sched/core: Fix comparison in sched_group_cookie_match() (Phil Auld) [2115520]
- drivers/base: Fix unsigned comparison to -1 in CPUMAP_FILE_MAX_BYTES (Phil Auld) [2115520]
- sched/debug: fix dentry leak in update_sched_domain_debugfs (Phil Auld) [2115520]
- debugfs: add debugfs_lookup_and_remove() (Phil Auld) [2115520]
- sched/psi: Remove unused parameter nbytes of psi_trigger_create() (Phil Auld) [2115520]
- sched/psi: Zero the memory of struct psi_group (Phil Auld) [2115520]
- sched/core: Do not requeue task on CPU excluded from cpus_mask (Phil Auld) [2115520]
- workqueue: Avoid a false warning in unbind_workers() (Phil Auld) [2115520]
- sched/rt: Fix Sparse warnings due to undefined rt.c declarations (Phil Auld) [2115520]
- sched/deadline: Fix BUG_ON condition for deboosted tasks (Phil Auld) [2115520]
- sched/core: Always flush pending blk_plug (Phil Auld) [2115520]
- sched/fair: fix case with reduced capacity CPU (Phil Auld) [2115520]
- sched/core: add forced idle accounting for cgroups (Phil Auld) [2115520]
- sched/core: Use try_cmpxchg in set_nr_{and_not,if}_polling (Phil Auld) [2115520]
- sched/core: Fix the bug that task won't enqueue into core tree when update cookie (Phil Auld) [2115520]
- sched/fair: Remove the energy margin in feec() (Phil Auld) [2115520]
- sched/fair: Remove task_util from effective utilization in feec() (Phil Auld) [2115520]
- sched/fair: Use the same cpumask per-PD throughout find_energy_efficient_cpu() (Phil Auld) [2115520]
- sched/fair: Rename select_idle_mask to select_rq_mask (Phil Auld) [2115520]
- sched/fair: Decay task PELT values during wakeup migration (Phil Auld) [2115520]
- sched/fair: Provide u64 read for 32-bits arch helper (Phil Auld) [2115520]
- sched: Remove unused function group_first_cpu() (Phil Auld) [2115520]
- sched/fair: Remove redundant word " *" (Phil Auld) [2115520]
- sched: only perform capability check on privileged operation (Phil Auld) [2115520]
- sched: Allow newidle balancing to bail out of load_balance (Phil Auld) [2115520]
- sched: Remove the limitation of WF_ON_CPU on wakelist if wakee cpu is idle (Phil Auld) [2115520]
- sched: Fix the check of nr_running at queue wakelist (Phil Auld) [2115520]
- sched/deadline: Use proc_douintvec_minmax() limit minimum value (Phil Auld) [2115520]
- workqueue: Wrap flush_workqueue() using a macro (Phil Auld) [2115520]
- sched/fair: Optimize and simplify rq leaf_cfs_rq_list (Phil Auld) [2115520]
- sched/autogroup: Fix sysctl move (Phil Auld) [2115520]
- psi: dont alloc memory for psi by default (Phil Auld) [2115520]
- sched: Reverse sched_class layout (Phil Auld) [2115520]
- topology: Remove unused cpu_cluster_mask() (Phil Auld) [2115520]
- sched: Update task_tick_numa to ignore tasks without an mm (Phil Auld) [2115520]
- sched/deadline: Remove superfluous rq clock update in push_dl_task() (Phil Auld) [2115520]
- sched/core: Avoid obvious double update_rq_clock warning (Phil Auld) [2115520]
- sched/fair: Remove cfs_rq_tg_path() (Phil Auld) [2115520]
- sched/fair: Remove sched_trace_*() helper functions (Phil Auld) [2115520]
- sched: Fix build warning without CONFIG_SYSCTL (Phil Auld) [2115520]
- time/sched_clock: Fix formatting of frequency reporting code (Phil Auld) [2115520]
- time/sched_clock: Use Hz as the unit for clock rate reporting below 4kHz (Phil Auld) [2115520]
- time/sched_clock: Round the frequency reported to nearest rather than down (Phil Auld) [2115520]
- sched/fair: Revise comment about lb decision matrix (Phil Auld) [2115520]
- sched/psi: report zeroes for CPU full at the system level (Phil Auld) [2115520]
- sched/fair: Delete useless condition in tg_unthrottle_up() (Phil Auld) [2115520]
- sched/fair: Fix cfs_rq_clock_pelt() for throttled cfs_rq (Phil Auld) [2115520]
- sched/fair: Move calculate of avg_load to a better location (Phil Auld) [2115520]
- workqueue: Restrict kworker in the offline CPU pool running on housekeeping CPUs (Phil Auld) [2115520]
- sched/fair: Refactor cpu_util_without() (Phil Auld) [2115520]
- sched/rt: fix build error when CONFIG_SYSCTL is disable (Phil Auld) [2115520]
- sched: Move energy_aware sysctls to topology.c (Phil Auld) [2115520]
- sched: Move cfs_bandwidth_slice sysctls to fair.c (Phil Auld) [2115520]
- sched: Move uclamp_util sysctls to core.c (Phil Auld) [2115520]
- sched: Move rr_timeslice sysctls to rt.c (Phil Auld) [2115520]
- sched: Move deadline_period sysctls to deadline.c (Phil Auld) [2115520]
- sched: Move rt_period/runtime sysctls to rt.c (Phil Auld) [2115520]
- sched: Move schedstats sysctls to core.c (Phil Auld) [2115520]
- sched: Move child_runs_first sysctls to fair.c (Phil Auld) [2115520]
- sched: move autogroup sysctls into its own file (Phil Auld) [2115520]
- psi: fix "no previous prototype" warnings when CONFIG_CGROUPS=n (Phil Auld) [2115520]
- kernel/sched: Remove dl_boosted flag comment (Phil Auld) [2115520]
- workqueue: Remove schedule() in unbind_workers() (Phil Auld) [2115520]
- workqueue: Remove outdated comment about exceptional workers in unbind_workers() (Phil Auld) [2115520]
- workqueue: Remove the advanced kicking of the idle workers in rebind_workers() (Phil Auld) [2115520]
- workqueue: Fix unbind_workers() VS wq_worker_running() race (Phil Auld) [2115520]
- firmware: tegra: bpmp: Do only aligned access to IPC memory area (Al Stone) [2122349]
- dt-bindings: firmware: tegra: Convert to json-schema (Al Stone) [2122349]
- firmware: tegra: Switch over to memdup_user() (Al Stone) [2122349]
- firmware: tegra: Fix error check return value of debugfs_create_file() (Al Stone) [2122349]
- firmware: tegra: Fix error application of sizeof() to pointer (Al Stone) [2122349]
- firmware: tegra: Reduce stack usage (Al Stone) [2122349]
- firmware: tegra: Stop using seq_get_buf() (Al Stone) [2122349]
- mm, oom: do not trigger out_of_memory from the #PF (Waiman Long) [2139747]
- redhat Kconfig: Enable virtual watchdog timers provided by PAPR hypervisors (Steve Best) [2110139]
- watchdog/pseries-wdt: initial support for H_WATCHDOG-based watchdog timers (Steve Best) [2110139]
- powerpc/pseries: register pseries-wdt device with platform bus (Steve Best) [2110139]
- powerpc/pseries: add FW_FEATURE_WATCHDOG flag (Steve Best) [2110139]
- powerpc/pseries: hvcall.h: add H_WATCHDOG opcode, H_NOOP return code (Steve Best) [2110139]

* Tue Nov 15 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-197.el9]
- rhel: Provide default powercap and DTPM config settings for Arm (Al Stone) [2126952]
- powercap: DTPM: Check for Energy Model type (Al Stone) [2126952]
- sched, drivers: Remove max param from effective_cpu_util()/sched_cpu_util() (Al Stone) [2126952]
- PM: EM: Change the order of arguments in the .active_power() callback (Al Stone) [2126952]
- PM: EM: Add artificial EM flag (Al Stone) [2126952]
- PM: EM: Add .get_cost() callback (Al Stone) [2126952]
- powercap: DTPM: Fix spelling mistake "initialze" -> "initialize" (Al Stone) [2126952]
- powercap: DTPM: dtpm_node_callback[] can be static (Al Stone) [2126952]
- powercap/dtpm_cpu: Add exit function (Al Stone) [2126952]
- powercap/dtpm: Move the 'root' reset place (Al Stone) [2126952]
- powercap/dtpm: Destroy hierarchy function (Al Stone) [2126952]
- powercap/dtpm: Fixup kfree for virtual node (Al Stone) [2126952]
- powercap/dtpm_cpu: Reset per_cpu variable in the release function (Al Stone) [2126952]
- powercap/dtpm: Change locking scheme (Al Stone) [2126952]
- powercap/drivers/dtpm: Add dtpm devfreq with energy model support (Al Stone) [2126952]
- powercap/drivers/dtpm: Add CPU DT initialization support (Al Stone) [2126952]
- powercap/drivers/dtpm: Add hierarchy creation (Al Stone) [2126952]
- powercap/drivers/dtpm: Remove unused function definition (Al Stone) [2126952]
- powercap/drivers/dtpm: Convert the init table section to a simple array (Al Stone) [2126952]
- powercap/drivers/dtpm: Reduce trace verbosity (Al Stone) [2126952]
- powercap: fix typo in a comment in idle_inject.c (Al Stone) [2126952]
- powercap: DTPM: Drop unused local variable from init_dtpm() (Al Stone) [2126952]
- powercap/drivers/dtpm: Disable DTPM at boot time (Al Stone) [2126952]
- powercap: DTPM: Fix suspend failure and kernel warning (Al Stone) [2126952]
- powercap/drivers/dtpm: Fix power limit initialization (Al Stone) [2126952]
- powercap/drivers/dtpm: Scale the power with the load (Al Stone) [2126952]
- powercap/drivers/dtpm: Use container_of instead of a private data field (Al Stone) [2126952]
- powercap/drivers/dtpm: Simplify the dtpm table (Al Stone) [2126952]
- powercap/drivers/dtpm: Encapsulate even more the code (Al Stone) [2126952]
- scsi: megaraid_sas: Clean up some inconsistent indenting (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Move megasas_dbg_lvl init to megasas_init() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Remove unnecessary memset() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Simplify megasas_update_device_list (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Correct an error message (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Correct value passed to scsi_device_lookup() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_FW_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_DRV_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP_DYNAMIC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid: Remove redundant assignment to variable mfiStatus (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Remove redundant variable cmd_type (Tomas Henzl) [2120068]
- scsi: megaraid: Remove the static variable initialisation (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Call scsi_done() directly (Tomas Henzl) [2120068]
- netfilter: nf_ct_ftp: fix deadlock when nat rewrite is needed (Ivan Vecera) [2139501]
- netfilter: nf_ct_irc: cap packet search space to 4k (Ivan Vecera) [2139501]
- netfilter: nf_ct_ftp: prefer skb_linearize (Ivan Vecera) [2139501]
- netfilter: nf_ct_h323: cap packet size at 64k (Ivan Vecera) [2139501]
- netfilter: nf_ct_sane: remove pseudo skb linearization (Ivan Vecera) [2139501]
- veth: enable BIG TCP packets (Ivan Vecera) [2139501]
- net: loopback: enable BIG TCP packets (Ivan Vecera) [2139501]
- ipv6: Add hop-by-hop header to jumbograms in ip6_output (Ivan Vecera) [2139501]
- net: allow gro_max_size to exceed 65536 (Ivan Vecera) [2139501]
- ipv6/gro: insert temporary HBH/jumbo header (Ivan Vecera) [2139501]
- ipv6/gso: remove temporary HBH/jumbo header (Ivan Vecera) [2139501]
- ipv6: add struct hop_jumbo_hdr definition (Ivan Vecera) [2139501]
- tcp_cubic: make hystart_ack_delay() aware of BIG TCP (Ivan Vecera) [2139501]
- net: limit GSO_MAX_SIZE to 524280 bytes (Ivan Vecera) [2139501]
- net: allow gso_max_size to exceed 65536 (Ivan Vecera) [2139501]
- net: Adjust sk_gso_max_size once when set (Ivan Vecera) [2139501]
- net: add IFLA_TSO_{MAX_SIZE|SEGS} attributes (Ivan Vecera) [2139501]
- gro: add ability to control gro max packet size (Ivan Vecera) [2139501]
- net: add extack arg for link ops (Ivan Vecera) [2139501]
- net/mlx5e: Fix wrong use of skb_tcp_all_headers() with encapsulation (Petr Oros) [2128182]
- net: add skb_[inner_]tcp_all_headers helpers (Petr Oros) [2128182]
- net: marvell: clean up trigraph warning on ??! string (Petr Oros) [2128182]
- sched: Always clear user_cpus_ptr in do_set_cpus_allowed() (Waiman Long) [2107354]
- sched: Enforce user requested affinity (Waiman Long) [2107354]
- sched: Always preserve the user requested cpumask (Waiman Long) [2107354]
- sched: Introduce affinity_context (Waiman Long) [2107354]
- sched: Add __releases annotations to affine_move_task() (Waiman Long) [2107354]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112183]
- tg3: Disable tg3 device on system reboot to avoid triggering AER (Ken Cox) [2112183]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix ioc->base_readl() use" (Tomas Henzl) [2115764]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix writel() use" (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix return value check of dma_get_required_mask() (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix use-after-free warning (Tomas Henzl) [2115764]
- scsi: mpt3sas: Update driver version to 43.100.00.00 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Increase cmd_per_lun to 128 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix trace buffer registration failed (Tomas Henzl) [2115764]
- scsi: mpt3sas: Don't change DMA mask while reallocating pools (Tomas Henzl) [2115764]
- scsi: mpt3sas: Prevent error handler escalation when device removed (Tomas Henzl) [2115764]
- scsi: mpt3sas: Disable MPI2_FUNCTION_FW_DOWNLOAD for ATTO devices (Tomas Henzl) [2115764]
- scsi: mpt3sas: Add support for ATTO ExpressSAS H12xx GT devices (Tomas Henzl) [2115764]
- scsi: mpt3sas: Remove flush_scheduled_work() call (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix whitespace and spelling mistake (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix typo in comment (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix out-of-bounds compiler warning (Tomas Henzl) [2115764]
- scsi: mpt3sas: Update driver version to 42.100.00.00 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Call scsi_done() directly (Tomas Henzl) [2115764]
- scsi: mpi3mr: Select CONFIG_SCSI_SAS_ATTRS (Tomas Henzl) [2115750]
- scsi: mpi3mr: Remove unnecessary cast (Tomas Henzl) [2115750]
- scsi: mpi3mr: Update driver version to 8.2.0.3.0 (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix scheduling while atomic type bug (Tomas Henzl) [2115750]
- scsi: mpi3mr: Scan the devices during resume time (Tomas Henzl) [2115750]
- scsi: mpi3mr: Free enclosure objects during driver unload (Tomas Henzl) [2115750]
- scsi: mpi3mr: Handle 0xF003 Fault Code (Tomas Henzl) [2115750]
- scsi: mpi3mr: Graceful handling of surprise removal of PCIe HBA (Tomas Henzl) [2115750]
- scsi: mpi3mr: Support new power management framework (Tomas Henzl) [2115750]
- scsi: mpi3mr: Update mpi3 header files (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix error code in mpi3mr_transport_smp_handler() (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix error codes in mpi3mr_report_manufacture() (Tomas Henzl) [2115750]
- scsi: mpi3mr: Block I/Os while refreshing target dev objects (Tomas Henzl) [2115750]
- scsi: mpi3mr: Refresh SAS ports during soft reset (Tomas Henzl) [2115750]
- scsi: mpi3mr: Support SAS transport class callbacks (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to issue MPT transport cmds (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add SAS SATA end devices to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Get target object based on rphy (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add expander devices to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable STL on HBAs where multipath is disabled (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to manage device's port (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to retrieve device objects (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to add phys to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable Enclosure device add event (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to retrieve config pages (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to issue config requests (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add config and transport related debug flags (Tomas Henzl) [2115750]
- scsi: mpi3mr: Delete a stray tab (Tomas Henzl) [2115750]
- scsi: mpi3mr: Unlock on error path (Tomas Henzl) [2115750]
- scsi: mpi3mr: Reduce VD queue depth on detecting throttling (Tomas Henzl) [2115750]
- scsi: mpi3mr: Resource Based Metering (Tomas Henzl) [2115750]
- scsi: mpi3mr: Increase cmd_per_lun to 128 (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable shared host tagset (Tomas Henzl) [2115750]
- scsi: mpi3mr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2115750]
- scsi: mpi3mr: Call scsi_done() directly (Tomas Henzl) [2115750]

* Mon Nov 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-196.el9]
- redhat/configs: add configs for new Qualcomm options (Adrien Thierry) [2122365]
- soc: qcom: Make QCOM_RPMPD depend on OF (Adrien Thierry) [2122365]
- soc: qcom: spm: Add CPU data for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: rpmpd: Add compatible for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add compatible for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: icc-bwmon: Remove unnecessary print function dev_err() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Fix the id of SA8540P SoC (Adrien Thierry) [2122365]
- soc: qcom: Make QCOM_RPMPD depend on PM (Adrien Thierry) [2122365]
- soc: qcom: icc-bwmon: Add bandwidth monitoring driver (Adrien Thierry) [2122365]
- soc/qcom: Make QCOM_RPMPD select PM_GENERIC_DOMAINS/_OF (Adrien Thierry) [2122365]
- soc: qcom: aoss: Fix refcount leak in qmp_cooling_devices_register (Adrien Thierry) [2122365]
- soc: qcom: llcc: Fix syntax errors in comments (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Fix refcount leak in of_get_ocmem (Adrien Thierry) [2122365]
- soc: qcom: cmd-db: replace strscpy_pad() with strncpy() (Adrien Thierry) [2122365]
- soc: qcom: rpmhpd: fix typos in comment (Adrien Thierry) [2122365]
- soc: qcom: correct kerneldoc (Adrien Thierry) [2122365]
- soc: qcom: cmd-db: replace strncpy() with strscpy_pad() (Adrien Thierry) [2122365]
- soc: qcom: apr: Drop redundant check in .remove() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add an ID for sc7180P (Adrien Thierry) [2122365]
- soc: qcom: geni: Disable MMIO tracing for GENI SE (Adrien Thierry) [2122365]
- soc: qcom: pdr: use static for servreg_* variables (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Sort out 8974PRO names (Adrien Thierry) [2122365]
- soc: qcom: pdr: replace usage of found with dedicated list iterator variable (Adrien Thierry) [2122365]
- soc: qcom: smsm: Fix missing of_node_put() in smsm_parse_ipc (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Fix missing of_node_put() in smp2p_parse_ipc (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add another ID for SM8450 (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add SC7280 entry to soc_id array (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Fix split-firmware condition (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add some more PMICs and SoCs (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Extract PAS operations (Adrien Thierry) [2122365]
- cpuidle: qcom-spm: Check if any CPU is managed by SPM (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Always invoke PAS mem_setup (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Reorder parts of __qcom_mdt_load() (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Extend check for split firmware (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Allow hash to reside in any segment (Adrien Thierry) [2122365]
- firmware: qcom: scm: Introduce pas_metadata context (Adrien Thierry) [2122365]
- soc: qcom: aoss: remove spurious IRQF_ONESHOT flags (Adrien Thierry) [2122365]
- soc: qcom: apr: Remove redundant 'flush_workqueue()' calls (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Fix missing put_device() call in of_get_ocmem (Adrien Thierry) [2122365]
- soc: qcom: rpmh-rsc: Fix typo in a comment (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add SM6350 and SM7225 (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add SM8450 ID (Adrien Thierry) [2122365]
- soc: qcom: aoss: constify static struct thermal_cooling_device_ops (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Use div64_ul instead of do_div (Adrien Thierry) [2122365]
- soc: qcom: stats: Add fixed sleep stats offset for older RPM firmwares (Adrien Thierry) [2122365]
- soc: qcom: qmi: Fix a typo in a comment (Adrien Thierry) [2122365]
- qcom: spm: allow compile-testing (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Add of_node_put() before goto (Adrien Thierry) [2122365]
- soc: qcom: apr: Add of_node_put() before return (Adrien Thierry) [2122365]
- soc: qcom: qcom_stats: Fix client votes offset (Adrien Thierry) [2122365]
- soc: qcom: spm: Add 8916 SPM register data (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add PM8150C and SMB2351 models (Adrien Thierry) [2122365]
- soc: qcom: smp2p: add feature negotiation and ssr ack feature support (Adrien Thierry) [2122365]
- soc: qcom: Add Sleep stats driver (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add two missing PMIC IDs (Adrien Thierry) [2122365]
- soc: qcom: apr: Add GPR support (Adrien Thierry) [2122365]
- soc: qcom: apr: make code more reuseable (Adrien Thierry) [2122365]
- soc: qcom: aoss: Drop power domain support (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Add wakeup capability to SMP2P IRQ (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add QCM2290 compatible (Adrien Thierry) [2122365]
- soc: qcom: pdr: Prefer strscpy over strcpy (Adrien Thierry) [2122365]
- soc: qcom: rpmh-rsc: Make use of the helper function devm_platform_ioremap_resource_byname() (Adrien Thierry) [2122365]
- soc: qcom: gsbi: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: aoss: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Make use of the helper function devm_platform_ioremap_resource_byname() (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add IPQ8074 family ID-s (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add compatible for MSM8953 SoC (Adrien Thierry) [2122365]
- soc: qcom: spm: Add compatible for MSM8998 SAWv4.1 L2 (Adrien Thierry) [2122365]
- soc: qcom: spm: Implement support for SAWv4.1, SDM630/660 L2 AVS (Adrien Thierry) [2122365]
- cpuidle: qcom_spm: Detach state machine from main SPM handling (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Drop PT_LOAD check on hash segment (Adrien Thierry) [2122365]
- nvmem: core: Add stubs for nvmem_cell_read_variable_le_u32/64 if !CONFIG_NVMEM (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Fixed argument passed to platform_set_data() (Adrien Thierry) [2122365]
- soc: qcom: smsm: Fix missed interrupts if state changes while masked (Adrien Thierry) [2122365]
- soc: qcom: smsm: Implement support for get_irqchip_state (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add SM6115 compatible (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Use nvmem_cell_read_variable_le_u32() (Adrien Thierry) [2122365]
- soc: qcom: aoss: Fix the out of bound usage of cooling_devs (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Don't print anything if nothing found (Adrien Thierry) [2122365]
- soc: qcom: aoss: Add generic compatible (Adrien Thierry) [2122365]
- net: drop the weight argument from netif_napi_add (Íñigo Huguet) [2139498]
- eth: octeon: fix build after netif_napi_add() changes (Íñigo Huguet) [2139498]
- net: remove netif_tx_napi_add() (Íñigo Huguet) [2139498]
- atl1c: use netif_napi_add_tx() for Tx NAPI (Íñigo Huguet) [2139498]
- ipoib: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- IB/hfi1: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- IB/hfi1: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- crypto: caam/qi2 - switch to netif_napi_add_tx_weight() (Íñigo Huguet) [2139498]
- can: can-dev: move to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- net: wan: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- net: virtio: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- r8152: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- eth: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- mt76: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- net: move snowflake callers to netif_napi_add_tx_weight() (Íñigo Huguet) [2139498]
- net: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- netdev: reshuffle netif_napi_add() APIs to allow dropping weight (Íñigo Huguet) [2139498]
- ath10k: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- rtw88: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: smsc: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: benet: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: remove remaining copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: remove copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: atlantic: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- can: m_can: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- scsi: lpfc: Update lpfc version to 14.2.0.8 (Dick Kennedy) [2114053]
- scsi: lpfc: Create a sysfs entry called lpfc_xcvr_data for transceiver info (Dick Kennedy) [2114053]
- scsi: lpfc: Log when congestion management limits are in effect (Dick Kennedy) [2114053]
- scsi: lpfc: Fix hard lockup when reading the rx_monitor from debugfs (Dick Kennedy) [2114053]
- scsi: lpfc: Set sli4_param's cmf option to zero when CMF is turned off (Dick Kennedy) [2114053]
- scsi: lpfc: Update lpfc version to 14.2.0.7 (Dick Kennedy) [2114053]
- scsi: lpfc: Fix various issues reported by tools (Dick Kennedy) [2114053]
- scsi: lpfc: Add reporting capability for Link Degrade Signaling (Dick Kennedy) [2114053]
- scsi: lpfc: Rework FDMI attribute registration for unintential padding (Dick Kennedy) [2114053]
- scsi: lpfc: Rework lpfc_fdmi_cmd() routine for cleanup and consistency (Dick Kennedy) [2114053]
- scsi: lpfc: Rename mp/bmp dma buffers to rq/rsp in lpfc_fdmi_cmd (Dick Kennedy) [2114053]
- scsi: lpfc: Update congestion mode logging for Emulex SAN Manager application (Dick Kennedy) [2114053]
- scsi: lpfc: Move scsi_host_template outside dynamically allocated/freed phba (Dick Kennedy) [2114053]
- scsi: lpfc: Fix multiple NVMe remoteport registration calls for the same NPort ID (Dick Kennedy) [2114053]
- scsi: lpfc: Add missing free iocb and nlp kref put for early return VMID cases (Dick Kennedy) [2114053]
- scsi: lpfc: Fix mbuf pool resource detected as busy at driver unload (Dick Kennedy) [2114053]
- scsi: lpfc: Fix FLOGI ACC with wrong SID in PT2PT topology (Dick Kennedy) [2114053]
- scsi: lpfc: Fix prli_fc4_req checks in PRLI handling (Dick Kennedy) [2114053]
- scsi: lpfc: Remove unneeded result variable (Dick Kennedy) [2114053]
- scsi: lpfc: Remove the unneeded result variable (Dick Kennedy) [2114053]
- scsi: lpfc: Copyright updates for 14.2.0.6 patches (Dick Kennedy) [2114053]
- scsi: lpfc: Update lpfc version to 14.2.0.6 (Dick Kennedy) [2114053]
- scsi: lpfc: Remove SANDiags related code (Dick Kennedy) [2114053]
- scsi: lpfc: Add warning notification period to CMF_SYNC_WQE (Dick Kennedy) [2114053]
- scsi: lpfc: Rework MIB Rx Monitor debug info logic (Dick Kennedy) [2114053]
- scsi: lpfc: Fix null ndlp ptr dereference in abnormal exit path for GFT_ID (Dick Kennedy) [2114053]
- scsi: lpfc: Fix unsolicited FLOGI receive handling during PT2PT discovery (Dick Kennedy) [2114053]
- scsi: lpfc: Check the return value of alloc_workqueue() (Dick Kennedy) [2114053]

* Mon Nov 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-195.el9]
- mm: prep_compound_tail() clear page->private (Nico Pache) [2089498]
- mm/huge_memory: do not clobber swp_entry_t during THP split (Nico Pache) [2089498]
- mm: Clear page->private when splitting or migrating a page (Nico Pache) [2089498]
- mm,hugetlb: take hugetlb_lock before decrementing h->resv_huge_pages (Nico Pache) [2089498]
- mm/compaction: fix set skip in fast_find_migrateblock (Nico Pache) [2089498]
- mm/hugetlb: fix races when looking up a CONT-PTE/PMD size hugetlb page (Nico Pache) [2089498]
- mm, memory_hotplug: remove obsolete generic_free_nodedata() (Nico Pache) [2089498]
- mm/page_alloc: use local variable zone_idx directly (Nico Pache) [2089498]
- mm/page_alloc: add missing is_migrate_isolate() check in set_page_guard() (Nico Pache) [2089498]
- mm: remove obsolete pgdat_is_empty() (Nico Pache) [2089498]
- mm/page_alloc: fix freeing static percpu memory (Nico Pache) [2089498]
- mm/page_alloc: add __init annotations to init_mem_debugging_and_hardening() (Nico Pache) [2089498]
- mm/page_alloc: remove obsolete comment in zone_statistics() (Nico Pache) [2089498]
- mm: remove obsolete macro NR_PCP_ORDER_MASK and NR_PCP_ORDER_WIDTH (Nico Pache) [2089498]
- mm/page_alloc: make zone_pcp_update() static (Nico Pache) [2089498]
- mm/page_alloc: ensure kswapd doesn't accidentally go to sleep (Nico Pache) [2089498]
- zsmalloc: use correct types in _first_obj_offset functions (Nico Pache) [2089498]
- mm,hwpoison: check mm when killing accessing process (Nico Pache) [2089498]
- mm/huge_memory: use pfn_to_online_page() in split_huge_pages_all() (Nico Pache) [2089498]
- mm: fix madivse_pageout mishandling on non-LRU page (Nico Pache) [2089498]
- powerpc/64s/radix: don't need to broadcast IPI for radix pmd collapse flush (Nico Pache) [2089498]
- mm: gup: fix the fast GUP race against THP collapse (Nico Pache) [2089498]
- arm64: mte: move register initialization to C (Nico Pache) [2089498]
- mm/slab_common: fix possible double free of kmem_cache (Nico Pache) [2089498]
- mm/migrate_device.c: fix a misleading and outdated comment (Nico Pache) [2089498]
- mm/vmalloc.c: support HIGHMEM pages in vmap_pages_range_noflush() (Nico Pache) [2089498]
- mm: migration: fix the FOLL_GET failure on following huge page (Nico Pache) [2089498]
- mm/vmscan: make the annotations of refaults code at the right place (Nico Pache) [2089498]
- mm/hugetlb: add dedicated func to get 'allowed' nodemask for current process (Nico Pache) [2089498]
- mm/mempolicy: fix lock contention on mems_allowed (Nico Pache) [2089498]
- mm: fix dereferencing possible ERR_PTR (Nico Pache) [2089498]
- mm/migrate_device.c: copy pte dirty bit to page (Nico Pache) [2089498]
- mm/migrate_device.c: add missing flush_cache_page() (Nico Pache) [2089498]
- mm/migrate_device.c: flush TLB while holding PTL (Nico Pache) [2089498]
- mm/page_alloc: fix race condition between build_all_zonelists and page allocation (Nico Pache) [2089498]
- mm/slub: fix to return errno if kmalloc() fails (Nico Pache) [2089498]
- mm: pagewalk: Fix race between unmap and page walker (Nico Pache) [2089498]
- mm/slab_common: Deleting kobject in kmem_cache_destroy() without holding slab_mutex/cpu_hotplug_lock (Nico Pache) [2089498]
- bootmem: remove the vmemmap pages from kmemleak in put_page_bootmem (Nico Pache) [2089498]
- writeback: avoid use-after-free after removing device (Nico Pache) [2089498]
- mm/hugetlb: avoid corrupting page->mapping in hugetlb_mcopy_atomic_pte (Nico Pache) [2089498]
- mm/hugetlb: support write-faults in shared mappings (Nico Pache) [2089498]
- mm/hugetlb: fix hugetlb not supporting softdirty tracking (Nico Pache) [2089498]
- x86/mm: Use proper mask when setting PUD mapping (Nico Pache) [2089498]
- x86/PAT: Have pat_enabled() properly reflect state when running on Xen (Nico Pache) [2089498]
- x86/numa: Use cpumask_available instead of hardcoded NULL check (Nico Pache) [2089498]
- mm/mmap.c: fix missing call to vm_unacct_memory in mmap_region (Nico Pache) [2089498]
- mm/hmm: fault non-owner device private entries (Nico Pache) [2089498]
- page_alloc: fix invalid watermark check on a negative value (Nico Pache) [2089498]
- hugetlb: fix memoryleak in hugetlb_mcopy_atomic_pte (Nico Pache) [2089498]
- mm: fix missing wake-up event for FSDAX pages (Nico Pache) [2089498]
- mm: fix page leak with multiple threads mapping the same page (Nico Pache) [2089498]
- KVM: s390: pv: handle secure storage exceptions for normal guests (Nico Pache) [2089498]
- mm/mempolicy: fix get_nodes out of bound access (Nico Pache) [2089498]
- mm/migration: fix potential pte_unmap on an not mapped pte (Nico Pache) [2089498]
- mm/migration: return errno when isolate_huge_page failed (Nico Pache) [2089498]
- mm/migration: remove unneeded lock page and PageMovable check (Nico Pache) [2089498]
- mm: split huge PUD on wp_huge_pud fallback (Nico Pache) [2089498]
- mm/damon: use set_huge_pte_at() to make huge pte old (Nico Pache) [2089498]
- mm: userfaultfd: fix UFFDIO_CONTINUE on fallocated shmem pages (Nico Pache) [2089498]
- mm: Account dirty folios properly during splits (Nico Pache) [2089498]
- powerpc/ptdump: Fix display of RW pages on FSL_BOOK3E (Nico Pache) [2089498]
- filemap: Handle sibling entries in filemap_get_read_batch() (Nico Pache) [2089498]
- mm/memremap: fix memunmap_pages() race with get_dev_pagemap() (Nico Pache) [2089498]
- mm: lru_cache_disable: use synchronize_rcu_expedited (Nico Pache) [2089498]
- init: Initialize noop_backing_dev_info early (Nico Pache) [2089498]
- writeback: Fix inode->i_io_list not be protected by inode->i_lock error (Nico Pache) [2089498]
- mm/slub: add missing TID updates on slab deactivation (Nico Pache) [2089498]
- mm/memremap: fix missing call to untrack_pfn() in pagemap_range() (Nico Pache) [2089498]
- mm/z3fold: fix z3fold_page_migrate races with z3fold_map (Nico Pache) [2089498]
- mm/z3fold: fix z3fold_reclaim_page races with z3fold_free (Nico Pache) [2089498]
- mm/z3fold: always clear PAGE_CLAIMED under z3fold page lock (Nico Pache) [2089498]
- mm/z3fold: put z3fold page back into unbuddied list when reclaim or migration fails (Nico Pache) [2089498]
- revert "mm/z3fold.c: allow __GFP_HIGHMEM in z3fold_alloc" (Nico Pache) [2089498]
- mm/z3fold: throw warning on failure of trylock_page in z3fold_alloc (Nico Pache) [2089498]
- mm/z3fold: remove buggy use of stale list for allocation (Nico Pache) [2089498]
- mm/z3fold: fix possible null pointer dereferencing (Nico Pache) [2089498]
- mm/z3fold: fix sheduling while atomic (Nico Pache) [2089498]
- mm/mempolicy: clean up the code logic in queue_pages_pte_range (Nico Pache) [2089498]
- drivers/base/node.c: fix compaction sysfs file leak (Nico Pache) [2089498]
- mm: compaction: use helper isolation_suitable() (Nico Pache) [2089498]
- mm/z3fold: remove unneeded PAGE_HEADLESS check in free_handle() (Nico Pache) [2089498]
- mm/z3fold: remove redundant list_del_init of zhdr->buddy in z3fold_free (Nico Pache) [2089498]
- mm/z3fold: move decrement of pool->pages_nr into __release_z3fold_page() (Nico Pache) [2089498]
- mm/z3fold: remove confusing local variable l reassignment (Nico Pache) [2089498]
- mm/z3fold: remove unneeded page_mapcount_reset and ClearPagePrivate (Nico Pache) [2089498]
- mm/z3fold: minor clean up for z3fold_free (Nico Pache) [2089498]
- mm/z3fold: remove obsolete comment in z3fold_alloc (Nico Pache) [2089498]
- mm/z3fold: declare z3fold_mount with __init (Nico Pache) [2089498]
- hugetlb: fix huge_pmd_unshare address update (Nico Pache) [2089498]
- powerpc/ftrace: Remove ftrace init tramp once kernel init is complete (Nico Pache) [2089498]
- zsmalloc: fix races between asynchronous zspage free and page migration (Nico Pache) [2089498]
- Revert "mm/cma.c: remove redundant cma_mutex lock" (Nico Pache) [2089498]
- mm/page_owner: use strscpy() instead of strlcpy() (Nico Pache) [2089498]
- mm: hugetlb: add missing cache flushing in hugetlb_unshare_all_pmds() (Nico Pache) [2089498]
- mm: simplify follow_invalidate_pte() (Nico Pache) [2089498]
- dax: fix missing writeprotect the pte entry (Nico Pache) [2089498]
- mm: pvmw: add support for walking devmap pages (Nico Pache) [2089498]
- mm: rmap: introduce pfn_mkclean_range() to cleans PTEs (Nico Pache) [2089498]
- dax: fix cache flush on PMD-mapped pages (Nico Pache) [2089498]
- mm: rmap: fix cache flush on THP pages (Nico Pache) [2089498]
- mm/madvise: fix potential pte_unmap_unlock pte error (Nico Pache) [2089498]
- userfaultfd: mark uffd_wp regardless of VM_WRITE flag (Nico Pache) [2089498]
- mempolicy: mbind_range() set_policy() after vma_merge() (Nico Pache) [2089498]
- cifs: fix lock length calculation (Ronnie Sahlberg) [2138995]
- cifs: move from strlcpy with unused retval to strscpy (Ronnie Sahlberg) [2138995]
- cifs: remove unused server parameter from calc_smb_size() (Ronnie Sahlberg) [2138995]
- cifs: remove useless parameter 'is_fsctl' from SMB2_ioctl() (Ronnie Sahlberg) [2138995]
- cifs: remove remaining build warnings (Ronnie Sahlberg) [2138995]
- cifs: list_for_each() -> list_for_each_entry() (Ronnie Sahlberg) [2138995]
- smb2: small refactor in smb2_check_message() (Ronnie Sahlberg) [2138995]
- cifs: remove minor build warning (Ronnie Sahlberg) [2138995]
- cifs: remove some camelCase and also some static build warnings (Ronnie Sahlberg) [2138995]
- cifs: remove unnecessary (void*) conversions. (Ronnie Sahlberg) [2138995]
- cifs: remove unnecessary type castings (Ronnie Sahlberg) [2138995]
- cifs: remove redundant initialization to variable mnt_sign_enabled (Ronnie Sahlberg) [2138995]
- smb3: check xattr value length earlier (Ronnie Sahlberg) [2138995]
- cifs: when a channel is not found for server, log its connection id (Ronnie Sahlberg) [2138995]
- smb3: add trace point for SMB2_set_eof (Ronnie Sahlberg) [2138995]
- cifs: return errors during session setup during reconnects (Ronnie Sahlberg) [2138995]
- cifs: fix reconnect on smb3 mount types (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- cifs: version operations for smb20 unneeded when legacy support disabled (Ronnie Sahlberg) [2138995]
- cifs: do not build smb1ops if legacy support is disabled (Ronnie Sahlberg) [2138995]
- cifs: remove repeated debug message on cifs_put_smb_ses() (Ronnie Sahlberg) [2138995]
- cifs: fix ntlmssp on old servers (Ronnie Sahlberg) [2138995]
- cifs: do not use tcpStatus after negotiate completes (Ronnie Sahlberg) [2138995]
- smb3: don't set rc when used and unneeded in query_info_compound (Ronnie Sahlberg) [2138995]
- smb3: check for null tcon (Ronnie Sahlberg) [2138995]
- Add various fsctl structs (Ronnie Sahlberg) [2138995]
- smb3: add trace point for oplock not found (Ronnie Sahlberg) [2138995]
- cifs: return the more nuanced writeback error on close() (Ronnie Sahlberg) [2138995]
- smb3: add trace point for lease not found issue (Ronnie Sahlberg) [2138995]
- cifs: smbd: fix typo in comment (Ronnie Sahlberg) [2138995]
- cifs: set the CREATE_NOT_FILE when opening the directory in use_cached_dir() (Ronnie Sahlberg) [2138995]
- cifs: check for smb1 in open_cached_dir() (Ronnie Sahlberg) [2138995]
- cifs: move definition of cifs_fattr earlier in cifsglob.h (Ronnie Sahlberg) [2138995]
- cifs: print TIDs as hex (Ronnie Sahlberg) [2138995]
- cifs: fix signed integer overflow when fl_end is OFFSET_MAX (Ronnie Sahlberg) [2138995]
- cifs: Use kzalloc instead of kmalloc/memset (Ronnie Sahlberg) [2138995]
- cifs: potential buffer overflow in handling symlinks (Ronnie Sahlberg) [2138995]
- cifs: Split the smb3_add_credits tracepoint (Ronnie Sahlberg) [2138995]
- cifs: Check the IOCB_DIRECT flag, not O_DIRECT (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- cifs: remove check of list iterator against head past the loop body (Ronnie Sahlberg) [2138995]
- cifs: fix potential race with cifsd thread (Ronnie Sahlberg) [2138995]
- smb3: fix ksmbd bigendian bug in oplock break, and move its struct to smbfs_common (Ronnie Sahlberg) [2138995]
- smb3: move defines for query info and query fsinfo to smbfs_common (Ronnie Sahlberg) [2138995]
- smb3: move defines for ioctl protocol header and SMB2 sizes to smbfs_common (Ronnie Sahlberg) [2138995]
- move more common protocol header definitions to smbfs_common (Ronnie Sahlberg) [2138995]
- cifs: change smb2_query_info_compound to use a cached fid, if available (Ronnie Sahlberg) [2138995]
- cifs: fix incorrect use of list iterator after the loop (Ronnie Sahlberg) [2138995]
- cifs: convert the path to utf16 in smb2_query_info_compound (Ronnie Sahlberg) [2138995]
- cifs: use a different reconnect helper for non-cifsd threads (Ronnie Sahlberg) [2138995]
- Adjust cifssb maximum read size (Ronnie Sahlberg) [2138995]
- smb3: fix incorrect session setup check for multiuser mounts (Ronnie Sahlberg) [2138995]
- cifs: fix confusing unneeded warning message on smb2.1 and earlier (Ronnie Sahlberg) [2138995]
- cifs: do not use uninitialized data in the owner/group sid (Ronnie Sahlberg) [2138995]
- cifs: fix set of group SID via NTSD xattrs (Ronnie Sahlberg) [2138995]
- cifs: mark sessions for reconnection in helper function (Ronnie Sahlberg) [2138995]
- cifs: call helper functions for marking channels for reconnect (Ronnie Sahlberg) [2138995]
- cifs: call cifs_reconnect when a connection is marked (Ronnie Sahlberg) [2138995]
- [smb3] improve error message when mount options conflict with posix (Ronnie Sahlberg) [2138995]
- cifs: unlock chan_lock before calling cifs_put_tcp_session (Ronnie Sahlberg) [2138995]
- Fix a warning about a malformed kernel doc comment in cifs (Ronnie Sahlberg) [2138995]
- smb3: add new defines from protocol specification (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- smb3: send NTLMSSP version information (Ronnie Sahlberg) [2138995]
- cifs: cifs_ses_mark_for_reconnect should also update reconnect bits (Ronnie Sahlberg) [2138995]
- cifs: update tcpStatus during negotiate and sess setup (Ronnie Sahlberg) [2138995]
- cifs: make status checks in version independent callers (Ronnie Sahlberg) [2138995]
- cifs: remove unused variable ses_selected (Ronnie Sahlberg) [2138995]
- cifs: protect all accesses to chan_* with chan_lock (Ronnie Sahlberg) [2138995]
- cifs: fix the connection state transitions with multichannel (Ronnie Sahlberg) [2138995]
- cifs: check reconnects for channels of active tcons too (Ronnie Sahlberg) [2138995]
- cifs: clean up an inconsistent indenting (Ronnie Sahlberg) [2138995]
- cifs: fix FILE_BOTH_DIRECTORY_INFO definition (Ronnie Sahlberg) [2138995]
- cifs: move superblock magic defitions to magic.h (Ronnie Sahlberg) [2138995]
- cifs: Fix smb311_update_preauth_hash() kernel-doc comment (Ronnie Sahlberg) [2138995]
- cifs: avoid race during socket reconnect between send and recv (Ronnie Sahlberg) [2138995]
- cifs: maintain a state machine for tcp/smb/tcon sessions (Ronnie Sahlberg) [2138995]
- cifs: fix hang on cifs_get_next_mid() (Ronnie Sahlberg) [2138995]
- cifs: take cifs_tcp_ses_lock for status checks (Ronnie Sahlberg) [2138995]
- cifs: reconnect only the connection and not smb session where possible (Ronnie Sahlberg) [2138995]
- cifs: add WARN_ON for when chan_count goes below minimum (Ronnie Sahlberg) [2138995]
- cifs: adjust DebugData to use chans_need_reconnect for conn status (Ronnie Sahlberg) [2138995]
- cifs: use the chans_need_reconnect bitmap for reconnect status (Ronnie Sahlberg) [2138995]
- cifs: track individual channel status using chans_need_reconnect (Ronnie Sahlberg) [2138995]
- cifs: remove redundant assignment to pointer p (Ronnie Sahlberg) [2138995]
- dt-bindings: mmc: fsl-imx-esdhc: add NXP S32G2 support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Add sdhc support for i.MXRT series (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: disable CMDQ support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: add NXP S32G2 support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: clear the buffer_read_ready to reset standard tuning circuit (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Select the correct mode for auto tuning (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Remove redundant code for manual tuning (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Remove unneeded mmc-esdhc-imx.h header (Steve Best) [2133158]
- mm/kmemleak: prevent soft lockup in kmemleak_scan()'s object iteration loops (Waiman Long) [2095633]
- mm/kmemleak: prevent soft lockup in first object iteration loop of kmemleak_scan() (Waiman Long) [2095633]
- mm/kmemleak: skip unlikely objects in kmemleak_scan() without taking lock (Waiman Long) [2095633]
- mm/kmemleak: use _irq lock/unlock variants in kmemleak_scan/_clear() (Waiman Long) [2095633]
- tcp: fix early ETIMEDOUT after spurious non-SACK RTO (Davide Caratti) [2136491]
- Revert "tcp: change pingpong threshold to 3" (Davide Caratti) [2136491]
- tcp: fix F-RTO may not work correctly when receiving DSACK (Davide Caratti) [2136491]
- tcp: fix tcp_cwnd_validate() to not forget is_cwnd_limited (Davide Caratti) [2136491]
- net: do not sense pfmemalloc status in skb_append_pagefrags() (Davide Caratti) [2136491]
- tcp: TX zerocopy should not sense pfmemalloc status (Davide Caratti) [2136491]
- net: introduce __skb_fill_page_desc_noacc (Davide Caratti) [2136491]
- tcp: make retransmitted SKB fit into the send window (Davide Caratti) [2136491]
- tcp: add a missing nf_reset_ct() in 3WHS handling (Davide Caratti) [2136491]
- tcp: tcp_rtx_synack() can be called from process context (Davide Caratti) [2136491]

* Sat Nov 12 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-194.el9]
- gfs2: Register fs after creating workqueues (Bob Peterson) [2130267]
- LoadPin: Fix Kconfig doc about format of file with verity digests (Benjamin Marzinski) [2138462]
- LoadPin: Return EFAULT on copy_from_user() failures (Benjamin Marzinski) [2138462]
- dm bufio: use the acquire memory barrier when testing for B_READING (Benjamin Marzinski) [2138462]
- provide arch_test_bit_acquire for architectures that define test_bit (Benjamin Marzinski) [2138462]
- wait_on_bit: add an acquire memory barrier (Benjamin Marzinski) [2138462]
- add barriers to buffer_uptodate and set_buffer_uptodate (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Only trust verity targets with enforcement (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Drop use of dm_table_get_num_targets() (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Use CONFIG_SECURITY_LOADPIN_VERITY for conditional compilation (Benjamin Marzinski) [2138462]
- LoadPin: Enable loading from trusted dm-verity devices (Benjamin Marzinski) [2138462]
- dm: Add verity helpers for LoadPin (Benjamin Marzinski) [2138462]
- dm clone: Fix typo in block_device format specifier (Benjamin Marzinski) [2138462]
- dm: remove unnecessary assignment statement in alloc_dev() (Benjamin Marzinski) [2138462]
- dm verity: Add documentation for try_verify_in_tasklet option (Benjamin Marzinski) [2138462]
- dm cache: delete the redundant word 'each' in comment (Benjamin Marzinski) [2138462]
- dm raid: fix typo in analyse_superblocks code comment (Benjamin Marzinski) [2138462]
- dm verity: enable WQ_HIGHPRI on verify_wq (Benjamin Marzinski) [2138462]
- dm raid: delete the redundant word 'that' in comment (Benjamin Marzinski) [2138462]
- dm: change from DMWARN to DMERR or DMCRIT for fatal errors (Benjamin Marzinski) [2138462]
- dm bufio: fix some cases where the code sleeps with spinlock held (Benjamin Marzinski) [2138462]
- dm writecache: fix smatch warning about invalid return from writecache_map (Benjamin Marzinski) [2138462]
- dm verity: fix verity_parse_opt_args parsing (Benjamin Marzinski) [2138462]
- dm verity: fix DM_VERITY_OPTS_MAX value yet again (Benjamin Marzinski) [2138462]
- dm bufio: simplify DM_BUFIO_CLIENT_NO_SLEEP locking (Benjamin Marzinski) [2138462]
- dm verity: have verify_wq use WQ_HIGHPRI if "try_verify_in_tasklet" (Benjamin Marzinski) [2138462]
- dm verity: remove WQ_CPU_INTENSIVE flag since using WQ_UNBOUND (Benjamin Marzinski) [2138462]
- dm verity: only copy bvec_iter in verity_verify_io if in_tasklet (Benjamin Marzinski) [2138462]
- dm verity: optimize verity_verify_io if FEC not configured (Benjamin Marzinski) [2138462]
- dm verity: conditionally enable branching for "try_verify_in_tasklet" (Benjamin Marzinski) [2138462]
- dm bufio: conditionally enable branching for DM_BUFIO_CLIENT_NO_SLEEP (Benjamin Marzinski) [2138462]
- dm verity: allow optional args to alter primary args handling (Benjamin Marzinski) [2138462]
- dm verity: Add optional "try_verify_in_tasklet" feature (Benjamin Marzinski) [2138462]
- dm bufio: Add DM_BUFIO_CLIENT_NO_SLEEP flag (Benjamin Marzinski) [2138462]
- dm bufio: Add flags argument to dm_bufio_client_create (Benjamin Marzinski) [2138462]
- dm: fix dm-raid crash if md_handle_request() splits bio (Benjamin Marzinski) [2138462]
- dm: Start pr_preempt from the same starting path (Benjamin Marzinski) [2138462]
- dm: Fix PR release handling for non All Registrants (Benjamin Marzinski) [2138462]
- dm: Start pr_reserve from the same starting path (Benjamin Marzinski) [2138462]
- dm: Allow dm_call_pr to be used for path searches (Benjamin Marzinski) [2138462]
- Documentation: dm writecache: Render status list as list (Benjamin Marzinski) [2138462]
- Documentation: dm writecache: add blank line before optional parameters (Benjamin Marzinski) [2138462]
- dm snapshot: fix typo in snapshot_map() comment (Benjamin Marzinski) [2138462]
- dm raid: remove redundant "the" in parse_raid_params() comment (Benjamin Marzinski) [2138462]
- dm cache: fix typo in 2 comment blocks (Benjamin Marzinski) [2138462]
- dm verity: fix checkpatch close brace error (Benjamin Marzinski) [2138462]
- dm table: rename dm_target variable in dm_table_add_target() (Benjamin Marzinski) [2138462]
- dm table: audit all dm_table_get_target() callers (Benjamin Marzinski) [2138462]
- dm table: remove dm_table_get_num_targets() wrapper (Benjamin Marzinski) [2138462]
- dm: add two stage requeue mechanism (Benjamin Marzinski) [2138462]
- dm: add dm_bio_rewind() API to DM core (Benjamin Marzinski) [2138462]
- dm: improve BLK_STS_DM_REQUEUE and BLK_STS_AGAIN handling (Benjamin Marzinski) [2138462]
- dm: refactor dm_md_mempool allocation (Benjamin Marzinski) [2138462]
- dm: unexport dm_get_reserved_rq_based_ios (Benjamin Marzinski) [2138462]
- dm: fix zoned locking imbalance due to needless check in clone_endio (Benjamin Marzinski) [2138462]
- dm: pass NULL bdev to bio_alloc_clone (Benjamin Marzinski) [2138462]
- flow_dissector: Do not count vlan tags inside tunnel payload (Ivan Vecera) [2133511]
- flow_offload: Introduce flow_match_pppoe (Ivan Vecera) [2133511]
- flow_dissector: Add PPPoE dissectors (Ivan Vecera) [2133511]
- flow_dissector: Add number of vlan tags dissector (Ivan Vecera) [2133511]
- dissector: do not set invalid PPP protocol (Ivan Vecera) [2133511]
- scsi: tracing: Fix compile error in trace_array calls when TRACING is disabled (Nilesh Javali) [2109835]
- scsi: qla2xxx: Use transport-defined speed mask for supported_speeds (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix serialization of DCBX TLV data request (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused declarations for qla2xxx (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix spelling mistake "definiton" -> "definition" (Nilesh Javali) [2109835]
- scsi: qla2xxx: Drop DID_TARGET_FAILURE use (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.900-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Define static symbols (Nilesh Javali) [2109835]
- scsi: qla2xxx: Enhance driver tracing with separate tunable and more (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add NVMe parameters support in Auxiliary Image Status (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add debugfs create/delete helpers (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109835]
- scsi: qla2xxx: Revert "scsi: qla2xxx: Fix response queue handler reading stale packets" (Nilesh Javali) [2109835]
- scsi: qla2xxx: Log message "skipping scsi_scan_host()" as informational (Nilesh Javali) [2109835]
- scsi: qla2xxx: Avoid flush_scheduled_work() usage (Nilesh Javali) [2109835]
- scsi: qla2xxx: Always wait for qlt_sess_work_fn() from qlt_stop_phase1() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused qlt_tmr_work() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused del_sess_list field (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.800-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update manufacturer details (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix sparse warning for dport_data (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix discovery issues in FC-AL topology (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix dropped IKE message (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109835]
- scsi: qla2xxx: Zero undefined mailbox IN registers (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix incorrect display of max frame size (Nilesh Javali) [2109835]
- scsi: qla2xxx: Check correct variable in qla24xx_async_gffid() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.700-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing FCP-2 targets on long port disable with I/Os (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add debug prints in the device remove path (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing target when it reappears during delete (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing FCP-2 targets during port perturbation tests (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix crash due to stale SRB access around I/O timeouts (Nilesh Javali) [2109835]
- scsi: qla2xxx: Turn off multi-queue for 8G adapters (Nilesh Javali) [2109835]
- scsi: qla2xxx: Wind down adapter after PCIe error (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add a new v2 dport diagnostic feature (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.600-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix slow session teardown (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce N2N thrashing at app_start time (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix no logout on delete for N2N (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix session thrash (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Tear down session if keys have been removed (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix no login after app start (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce disruption due to multiple app start (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Send LOGO for unexpected IKE message (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix I/O timeout due to over-subscription (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.500-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix n2n login retry for secure device (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix n2n discovery issue with secure target (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Remove old doorbell interface (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Add retry for ELS passthrough (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Synchronize NPIV deletion with authentication application (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix potential stuck session in sa update (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Add bsg interface to read doorbell events (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Wait for app to ack on sess down (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: bsg refactor (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce Initiator-Initiator thrashing (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused 'ql_dm_tgt_ex_pct' parameter (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove setting of 'req' and 'rsp' parameters (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix missed DMA unmap for aborted commands (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Remove unneeded variable (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unneeded flush_workqueue() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove free_sg command flag (Nilesh Javali) [2109835]
- tcp: fix over estimation in sk_forced_mem_schedule() (Davide Caratti) [2137858]
- net: selftests: Add stress_reuseport_listen to .gitignore (Davide Caratti) [2137858]
- mptcp: fix abba deadlock on fastopen (Davide Caratti) [2137858]
- mptcp: factor out mptcp_connect() (Davide Caratti) [2137858]
- mptcp: set msk local address earlier (Davide Caratti) [2137858]
- mptcp: update misleading comments. (Davide Caratti) [2137858]
- selftests: mptcp: update and extend fastclose test-cases (Davide Caratti) [2137858]
- mptcp: use fastclose on more edge scenarios (Davide Caratti) [2137858]
- mptcp: propagate fastclose error (Davide Caratti) [2137858]
- mptcp: fix unreleased socket in accept queue (Davide Caratti) [2137858]
- mptcp: factor out __mptcp_close() without socket lock (Davide Caratti) [2137858]
- mptcp: poll allow write call before actual connect (Davide Caratti) [2137858]
- mptcp: handle defer connect in mptcp_sendmsg (Davide Caratti) [2137858]
- mptcp: add TCP_FASTOPEN_CONNECT socket option (Davide Caratti) [2137858]
- tcp: export tcp_sendmsg_fastopen (Davide Caratti) [2137858]
- tcp: Access &tcp_hashinfo via net. (Davide Caratti) [2137858]
- mptcp: account memory allocation in mptcp_nl_cmd_add_addr() to user (Davide Caratti) [2137858]
- mptcp: allow privileged operations from user namespaces (Davide Caratti) [2137858]
- mptcp: add do_check_data_fin to replace copied (Davide Caratti) [2137858]
- selftests: mptcp: move prefix tests of addr_nr_ns2 together (Davide Caratti) [2137858]
- mptcp: add mptcp_for_each_subflow_safe helper (Davide Caratti) [2137858]
- Documentation: mptcp: fix pm_type formatting (Davide Caratti) [2137858]
- mptcp: fix fwd memory accounting on coalesce (Davide Caratti) [2137858]
- net: Fix data-races around sysctl_max_skb_frags. (Davide Caratti) [2137858]
- mptcp: do not queue data on closed subflows (Davide Caratti) [2137858]
- mptcp: move subflow cleanup in mptcp_destroy_common() (Davide Caratti) [2137858]
- mptcp: Do not return EINPROGRESS when subflow creation succeeds (Davide Caratti) [2137858]
- tcp: Fix data-races around sysctl_tcp_workaround_signed_windows. (Davide Caratti) [2137858]
- tcp: Fix data-races around sysctl_tcp_moderate_rcvbuf. (Davide Caratti) [2137858]
- selftests: mptcp: add MPC backup tests (Davide Caratti) [2137858]
- mptcp: more accurate MPC endpoint tracking (Davide Caratti) [2137858]
- mptcp: allow the in kernel PM to set MPC subflow priority (Davide Caratti) [2137858]
- mptcp: address lookup improvements (Davide Caratti) [2137858]
- mptcp: introduce and use mptcp_pm_send_ack() (Davide Caratti) [2137858]
- selftests: mptcp: validate userspace PM tests by default (Davide Caratti) [2137858]
- mptcp: fix subflow traversal at disconnect time (Davide Caratti) [2137858]
- selftests: mptcp: update pm_nl_ctl usage header (Davide Caratti) [2137858]
- selftests: mptcp: avoid Terminated messages in userspace_pm (Davide Caratti) [2137858]
- selftests: mptcp: userspace pm subflow tests (Davide Caratti) [2137858]
- selftests: mptcp: userspace pm address tests (Davide Caratti) [2137858]
- selftests: mptcp: tweak simult_flows for debug kernels (Davide Caratti) [2137858]
- mptcp: move MPTCPOPT_HMAC_LEN to net/mptcp.h (Davide Caratti) [2137858]
- mptcp: update MIB_RMSUBFLOW in cmd_sf_destroy (Davide Caratti) [2137858]
- mptcp: fix local endpoint accounting (Davide Caratti) [2137858]
- selftests: mptcp: userspace PM support for MP_PRIO signals (Davide Caratti) [2137858]
- mptcp: netlink: issue MP_PRIO signals from userspace PMs (Davide Caratti) [2137858]
- mptcp: Acquire the subflow socket lock before modifying MP_PRIO flags (Davide Caratti) [2137858]
- mptcp: Avoid acquiring PM lock for subflow priority changes (Davide Caratti) [2137858]
- mptcp: fix locking in mptcp_nl_cmd_sf_destroy() (Davide Caratti) [2137858]
- mptcp: refine memory scheduling (Davide Caratti) [2137858]
- mptcp: drop SK_RECLAIM_* macros (Davide Caratti) [2137858]
- mptcp: never fetch fwd memory from the subflow (Davide Caratti) [2137858]
- net: mptcp: fix some spelling mistake in mptcp (Davide Caratti) [2137858]
- net: keep sk->sk_forward_alloc as small as possible (Davide Caratti) [2137858]
- net: fix sk_wmem_schedule() and sk_rmem_schedule() errors (Davide Caratti) [2137858]
- net: implement per-cpu reserves for memory_allocated (Davide Caratti) [2137858]
- net: add per_cpu_fw_alloc field to struct proto (Davide Caratti) [2137858]
- net: remove SK_MEM_QUANTUM and SK_MEM_QUANTUM_SHIFT (Davide Caratti) [2137858]
- Revert "net: set SK_MEM_QUANTUM to 4096" (Davide Caratti) [2137858]
- crypto: af_alg - get rid of alg_memory_allocated (Davide Caratti) [2137858]
- mptcp: sockopt: add TCP_DEFER_ACCEPT support (Davide Caratti) [2137858]
- Revert "mptcp: add data lock for sk timers" (Davide Caratti) [2137858]
- selftests: mptcp: fix a mp_fail test warning (Davide Caratti) [2137858]
- net: selftests: Stress reuseport listen (Davide Caratti) [2137858]
- net: inet: Retire port only listening_hash (Davide Caratti) [2137858]
- net: inet: Open code inet_hash2 and inet_unhash2 (Davide Caratti) [2137858]
- net: inet: Remove count from inet_listen_hashbucket (Davide Caratti) [2137858]
- mptcp: add data lock for sk timers (Davide Caratti) [2137858]
- tcp: switch orphan_count to bare per-cpu counters (Davide Caratti) [2137858]
- fs: dlm: fix invalid derefence of sb_lvbptr (Alexander Aring) [2121789]
- fs: dlm: handle -EBUSY first in unlock validation (Alexander Aring) [2121789]
- fs: dlm: handle -EBUSY first in lock arg validation (Alexander Aring) [2121789]
- fs: dlm: fix race between test_bit() and queue_work() (Alexander Aring) [2121789]

* Fri Nov 11 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-193.el9]
- vdpa_sim_blk: set number of address spaces and virtqueue groups (Stefano Garzarella) [2133164]
- scsi: core: Fix a use-after-free (Ming Lei) [1998697]
- MAINTAINERS: pick up all vfio_ap docs for VFIO AP maintainers (Cédric Le Goater) [1871126]
- s390/docs: fix warnings for vfio_ap driver doc (Cédric Le Goater) [1871126]
- s390/docs: fix warnings for vfio_ap driver lock usage doc (Cédric Le Goater) [1871126]
- s390/Docs: new doc describing lock usage by the vfio_ap device driver (Cédric Le Goater) [1871126]
- s390/vfio-ap: bypass unnecessary processing of AP resources (Cédric Le Goater) [1871126]
- s390/vfio-ap: update docs to include dynamic config support (Cédric Le Goater) [1871126]
- s390/vfio-ap: handle config changed and scan complete notification (Cédric Le Goater) [1871126]
- s390/vfio-ap: sysfs attribute to display the guest's matrix (Cédric Le Goater) [1871126]
- s390/vfio-ap: implement in-use callback for vfio_ap driver (Cédric Le Goater) [1871126]
- s390/vfio-ap: reset queues after adapter/domain unassignment (Cédric Le Goater) [1871126]
- s390/vfio-ap: hot plug/unplug of AP devices when probed/removed (Cédric Le Goater) [1871126]
- s390/vfio-ap: allow hot plug/unplug of AP devices when assigned/unassigned (Cédric Le Goater) [1871126]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on queue probe/remove (Cédric Le Goater) [1871126]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on assign/unassign (Cédric Le Goater) [1871126]
- s390/vfio-ap: use proper locking order when setting/clearing KVM pointer (Cédric Le Goater) [1871126]
- s390/vfio-ap: introduce new mutex to control access to the KVM pointer (Cédric Le Goater) [1871126]
- s390/vfio-ap: rename matrix_dev->lock mutex to matrix_dev->mdevs_lock (Cédric Le Goater) [1871126]
- s390/vfio-ap: allow assignment of unavailable AP queues to mdev device (Cédric Le Goater) [1871126]
- s390/vfio-ap: refresh guest's APCB by filtering AP resources assigned to mdev (Cédric Le Goater) [1871126]
- s390/vfio-ap: introduce shadow APCB (Cédric Le Goater) [1871126]
- s390/vfio-ap: manage link between queue struct and matrix mdev (Cédric Le Goater) [1871126]
- s390/vfio-ap: move probe and remove callbacks to vfio_ap_ops.c (Cédric Le Goater) [1871126]
- s390/vfio-ap: use new AP bus interface to search for queue devices (Cédric Le Goater) [1871126]
- s390/ap: fix error handling in __verify_queue_reservations() (Cédric Le Goater) [1871126]
- s390/zcrypt: code cleanup (Cédric Le Goater) [1871126]
- s390/zcrypt: cleanup CPRB struct definitions (Cédric Le Goater) [1871126]
- s390/ap: uevent on apmask/aqpmask change (Cédric Le Goater) [1871126]
- s390/zcrypt: add display of ASYM master key verification pattern (Cédric Le Goater) [1871126]
- s390/zcrypt: fix using the correct variable for sizeof() (Cédric Le Goater) [1871126]
- s390: crypto: Use min_t() instead of doing it manually (Cédric Le Goater) [1871126]
- s390/pkey: fix typos in comments (Cédric Le Goater) [1871126]
- s390/ap: enable sysfs attribute scans to force AP bus rescan (Cédric Le Goater) [1871126]
- s390/ap: fix crash on older machines based on QCI info missing (Cédric Le Goater) [1871126]
- s390/ap: notify drivers on config changed and scan complete callbacks (Cédric Le Goater) [1871126]
- s390/ap: driver callback to indicate resource in use (Cédric Le Goater) [1871126]
- s390/ap: function rework based on compiler warning (Cédric Le Goater) [1871126]
- s390/ap: new module option ap.useirq (Cédric Le Goater) [1871126]
- s390/ap: Fix hanging ioctl caused by orphaned replies (Cédric Le Goater) [1871126]
- s390/zcrypt: remove incorrect kernel doc indicators (Cédric Le Goater) [1871126]
- s390/ap: fix state machine hang after failure to enable irq (Cédric Le Goater) [1871126]
- s390/zcrypt: remove gratuitious NULL check in .remove() callbacks (Cédric Le Goater) [1871126]
- s390/ap: use the common driver-data pointer (Cédric Le Goater) [1871126]
- s390/ap: use the common device_driver pointer (Cédric Le Goater) [1871126]
- s390/zcrypt: fix wrong offset index for APKA master key valid state (Cédric Le Goater) [1871126]
- Revert "Merge branch 'mlxsw-line-card-model'" (Petr Oros) [2140169]
- devlink: introduce line card device info infrastructure (Petr Oros) [2140169]
- devlink: introduce line card info get message (Petr Oros) [2140169]
- devlink: introduce line card devices support (Petr Oros) [2140169]
- devlink: add port to line card relationship set (Petr Oros) [2140169]
- devlink: implement line card active state (Petr Oros) [2140169]
- devlink: implement line card provisioning (Petr Oros) [2140169]
- devlink: add support to create line card and expose to user (Petr Oros) [2140169]
- rtla: Remove procps-ng dependency (Jerome Marchand) [2117497]
- rtla: Fix __set_sched_attr error message (Jerome Marchand) [2117497]
- rtla: Minor grammar fix for rtla README (Jerome Marchand) [2117497]
- rtla: Don't overwrite existing directory mode (Jerome Marchand) [2117497]
- rtla: Avoid record NULL pointer dereference (Jerome Marchand) [2117497]
- rtla: Documentation: fix email addresses (Jerome Marchand) [2117497]
- rtla/osnoise: Fix error message when failing to enable trace instance (Jerome Marchand) [2117497]
- rtla/osnoise: Free params at the exit (Jerome Marchand) [2117497]
- rtla: Fix systme -> system typo on man page (Jerome Marchand) [2117497]
- docs: Hook the RTLA documents into the kernel docs build (Jerome Marchand) [2117497]
- tools/rtla: Fix command symlinks (Jerome Marchand) [2117497]
- rtla: Fix tracer name (Jerome Marchand) [2117497]
- rtla: Fix double free (Jerome Marchand) [2117497]
- rtla: Fix Makefile when called from -C tools/ (Jerome Marchand) [2117497]
- rtla/utils: Use calloc and check the potential memory allocation failure (Jerome Marchand) [2117497]
- rtla: Tools main loop cleanup (Jerome Marchand) [2117497]
- rtla/timerlat: Add --dma-latency option (Jerome Marchand) [2117497]
- rtla/osnoise: Fix osnoise hist stop tracing message (Jerome Marchand) [2117497]
- rtla: Check for trace off also in the trace instance (Jerome Marchand) [2117497]
- rtla/trace: Save event histogram output to a file (Jerome Marchand) [2117497]
- rtla: Add --filter support (Jerome Marchand) [2117497]
- rtla/trace: Add trace event filter helpers (Jerome Marchand) [2117497]
- rtla: Add --trigger support (Jerome Marchand) [2117497]
- rtla/trace: Add trace event trigger helpers (Jerome Marchand) [2117497]
- rtla: Add -e/--event support (Jerome Marchand) [2117497]
- rtla/trace: Add trace events helpers (Jerome Marchand) [2117497]
- rtla/timerlat: Add the automatic trace option (Jerome Marchand) [2117497]
- rtla/osnoise: Add the automatic trace option (Jerome Marchand) [2117497]
- rtla/osnoise: Add an option to set the threshold (Jerome Marchand) [2117497]
- rtla/osnoise: Add support to adjust the tracing_thresh (Jerome Marchand) [2117497]
- rtla/hist: Make -E the short version of --entries (Jerome Marchand) [2117497]
- rtla: Fix segmentation fault when failing to enable -t (Jerome Marchand) [2117497]
- rtla/trace: Error message fixup (Jerome Marchand) [2117497]
- rtla/utils: Fix session duration parsing (Jerome Marchand) [2117497]
- rtla: Follow kernel version (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat hist documentation (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat top documentation (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise hist documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise top documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise man page (Jerome Marchand) [2117497]
- rtla: Add Documentation (Jerome Marchand) [2117497]
- rtla/timerlat: Add timerlat hist mode (Jerome Marchand) [2117497]
- rtla: Add timerlat tool and timelart top mode (Jerome Marchand) [2117497]
- rtla/osnoise: Add the hist mode (Jerome Marchand) [2117497]
- rtla/osnoise: Add osnoise top mode (Jerome Marchand) [2117497]
- rtla: Add osnoise tool (Jerome Marchand) [2117497]
- rtla: Helper functions for rtla (Jerome Marchand) [2117497]
- rtla: Real-Time Linux Analysis tool (Jerome Marchand) [2117497]
- tracing: Account bottom half disabled sections. (Jerome Marchand) [2117497]
- tracing: Add migrate-disabled counter to tracing output. (Jerome Marchand) [2117497]
- blk-mq: avoid double ->queue_rq() because of early timeout (Ming Lei) [2139962]
- netfilter: Use l3mdev flow key when re-routing mangled packets (Phil Sutter) [2129093]
- netfilter: Update ip6_route_me_harder to consider L3 domain (Phil Sutter) [2129093]
- netfilter: rpfilter/fib: Populate flowic_l3mdev field (Phil Sutter) [2129093]
- selftests: netfilter: Test reverse path filtering (Phil Sutter) [2129093]
- netfilter: nft_fib: Fix for rpath check with VRF devices (Phil Sutter) [2129093]
- net: seg6: fix seg6_lookup_any_nexthop() to handle VRFs using flowi_l3mdev (Phil Sutter) [2129093]
- net: Handle l3mdev in ip_tunnel_init_flow (Phil Sutter) [2129093]
- xfrm: Pass flowi_oif or l3mdev as oif to xfrm_dst_lookup (Phil Sutter) [2129093]
- net: Add l3mdev index to flow struct and avoid oif reset for port devices (Phil Sutter) [2129093]

* Thu Nov 10 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-192.el9]
- powerpc/pseries: Use lparcfg to reconfig VAS windows for DLPAR CPU (Steve Best) [2133101]
- rtc: lib_test: add MODULE_LICENSE (Al Stone) [2071847]
- rtc: Directly use ida_alloc()/free() (Al Stone) [2071847]
- rtc: use simple i2c probe (Al Stone) [2071847]
- rtc: Remove unused rtc_dev_exit(). (Al Stone) [2071847]
- rtc: Replace flush_scheduled_work() with flush_work(). (Al Stone) [2071847]
- rtc: mxc: Silence a clang warning (Al Stone) [2071847]
- rtc: pcf85063: Add a compatible entry for pca85073a (Al Stone) [2071847]
- rtc: check if __rtc_read_time was successful (Al Stone) [2071847]
- rtc: mc146818-lib: Fix the AltCentury for AMD platforms (Al Stone) [2071847]
- rtc: optee: add RTC driver for OP-TEE RTC PTA (Al Stone) [2071847]
- rtc: remove uie_unsupported (Al Stone) [2071847]
- rtc: rx8025: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: xgene: stop using uie_unsupported (Al Stone) [2071847]
- rtc: m41t80: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1307: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1685: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: opal: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: efi: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: efi: switch to devm_rtc_allocate_device (Al Stone) [2071847]
- rtc: add new RTC_FEATURE_ALARM_WAKEUP_ONLY feature (Al Stone) [2071847]
- rtc: pcf8563: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf8563: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: pcf8523: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: pcf8523: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf85063: set RTC_FEATURE_ALARM_RES_2S (Al Stone) [2071847]
- rtc: pcf85063: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf2127: set RTC_FEATURE_ALARM_RES_2S (Al Stone) [2071847]
- rtc: pcf2127: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf2123: set RTC_FEATURE_ALARM_RES_MINUTE (Al Stone) [2071847]
- rtc: pcf2123: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1685: drop no_irq (Al Stone) [2071847]
- rtc: pcf2127: fix bug when reading alarm registers (Al Stone) [2071847]
- rtc: pcf2127: use IRQ flags obtained from device tree if available (Al Stone) [2071847]
- rtc: pcf8523: Fix GCC 12 warning (Al Stone) [2071847]
- rtc: fix use-after-free on device removal (Al Stone) [2071847]
- rtc: Move variable into switch case statement (Al Stone) [2071847]
- rtc: pcf2127: Fix typo in comment (Al Stone) [2071847]
- rtc: mc146818-lib: extract mc146818_avoid_UIP (Al Stone) [2071847]
- rtc: mc146818-lib: fix RTC presence check (Al Stone) [2071847]
- rtc: pcf85063: add i2c_device_id name matching support (Al Stone) [2071847]
- rtc: handle alarms with a minute resolution (Al Stone) [2071847]
- rtc: pcf85063: silence cppcheck warning (Al Stone) [2071847]
- rtc: pcf8523: add BSM support (Al Stone) [2071847]
- rtc: pcf8523: allow usage on ACPI platforms (Al Stone) [2071847]
- rtc: pcf8523: remove unecessary ifdefery (Al Stone) [2071847]
- rtc: pcf8523: always compile pcf8523_rtc_ioctl (Al Stone) [2071847]
- rtc: pcf8523: switch to regmap (Al Stone) [2071847]
- rtc: expose RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf8523: avoid reading BLF in pcf8523_rtc_read_time (Al Stone) [2071847]
- rtc: add BSM parameter (Al Stone) [2071847]
- rtc: add correction parameter (Al Stone) [2071847]
- rtc: expose correction feature (Al Stone) [2071847]
- rtc: add parameter ioctl (Al Stone) [2071847]
- rtc: add alarm related features (Al Stone) [2071847]
- rtc: pcf85063: Always clear EXT_TEST from set_time (Al Stone) [2071847]
- rtc: pcf85063: add support for fixed clock (Al Stone) [2071847]
- rtc: class: check return value when calling dev_set_name() (Al Stone) [2071847]
- rtc: class: don't call cdev_device_del() when cdev_device_add() failed (Al Stone) [2071847]
- rtc: pcf2123: Add SPI ID table (Al Stone) [2071847]
- rtc: Improve performance of rtc_time64_to_tm(). Add tests. (Al Stone) [2071847]
- scsi: iscsi: iscsi_tcp: Fix null-ptr-deref while calling getpeername() (Chris Leech) [2137691]
- scsi: qedi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Chris Leech) [2137691]
- scsi: bnx2i: Fix spelling mistake "mis-match" -> "mismatch" (Chris Leech) [2137691]
- scsi: bnx2i: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Chris Leech) [2137691]
- scsi: be2iscsi: Fix use-after-free during IP updates (Chris Leech) [2137691]
- scsi: iscsi: Prefer xmit of DataOut over new commands (Chris Leech) [2137691]
- scsi: libiscsi: Call scsi_done() directly (Chris Leech) [2137691]
- scsi: iscsi: Stop using the SCSI pointer (Chris Leech) [2137691]
- scsi: libiscsi: Improve conn_send_pdu API (Chris Leech) [2137691]
- scsi: iscsi: Try to avoid taking back_lock in xmit path (Chris Leech) [2137691]
- scsi: iscsi: Remove iscsi_get_task back_lock requirement (Chris Leech) [2137691]
- scsi: iscsi: Remove unneeded task state check (Chris Leech) [2137691]
- scsi: iscsi_tcp: Drop target_alloc use (Chris Leech) [2137691]
- scsi: iscsi_tcp: Tell net when there's more data (Chris Leech) [2137691]
- scsi: iscsi: Run recv path from workqueue (Chris Leech) [2137691]
- scsi: iscsi: Add recv workqueue helpers (Chris Leech) [2137691]
- scsi: iscsi: Rename iscsi_conn_queue_work() (Chris Leech) [2137691]
- scsi: qedi: Fix ABBA deadlock in qedi_process_tmf_resp() and qedi_process_cmd_cleanup_resp() (Nilesh Javali) [2111466]
- dt-bindings: watchdog: imx7ulp-wdt: Add imx93 compatible string (Steve Best) [2137981]
- dt-bindings: watchdog: fsl-imx7ulp-wdt: Fix assigned-clock-parents (Steve Best) [2137981]
- dt-bindings: watchdog: imx7ulp-wdt: Add imx8ulp compatible string (Steve Best) [2137981]
- watchdog: imx93: add watchdog timer on imx93 (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: init wdog when it was active (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Handle wdog reconfigure failure (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Fix RCS timeout issue (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Check CMD32EN in wdog init (Steve Best) [2137981]
- watchdog: imx7ulp: Add explict memory barrier for unlock sequence (Steve Best) [2137981]
- watchdog: imx7ulp: Move suspend/resume to noirq phase (Steve Best) [2137981]
- io_uring: don't attempt to IOPOLL for MSG_RING requests (Jeff Moyer) [2113073]
- io_uring: fix ordering of args in io_uring_queue_async_work (Jeff Moyer) [2113073]
- io_uring: assign non-fixed early for async work (Jeff Moyer) [2113073]
- io_uring: check that data field is 0 in ringfd unregister (Jeff Moyer) [2113073]
- io_uring: fix uninitialized field in rw io_kiocb (Jeff Moyer) [2113073]
- io_uring: check reserved fields for recv/recvmsg (Jeff Moyer) [2113073]
- io_uring: check reserved fields for send/sendmsg (Jeff Moyer) [2113073]
- io_uring: fix leaks on IOPOLL and CQE_SKIP (Jeff Moyer) [2113073]
- io_uring: free iovec if file assignment fails (Jeff Moyer) [2113073]
- io_uring: abort file assignment prior to assigning creds (Jeff Moyer) [2113073]
- io_uring: fix poll error reporting (Jeff Moyer) [2113073]
- io_uring: fix poll file assign deadlock (Jeff Moyer) [2113073]
- io_uring: use right issue_flags for splice/tee (Jeff Moyer) [2113073]
- io_uring: verify pad field is 0 in io_get_ext_arg (Jeff Moyer) [2113073]
- io_uring: verify resv is 0 in ringfd register/unregister (Jeff Moyer) [2113073]
- io_uring: verify that resv2 is 0 in io_uring_rsrc_update2 (Jeff Moyer) [2113073]
- io_uring: move io_uring_rsrc_update2 validation (Jeff Moyer) [2113073]
- io_uring: fix assign file locking issue (Jeff Moyer) [2113073]
- io_uring: stop using io_wq_work as an fd placeholder (Jeff Moyer) [2113073]
- io_uring: move apoll->events cache (Jeff Moyer) [2113073]
- io_uring: io_kiocb_update_pos() should not touch file for non -1 offset (Jeff Moyer) [2113073]
- io_uring: flag the fact that linked file assignment is sane (Jeff Moyer) [2113073]
- io_uring: fix race between timeout flush and removal (Jeff Moyer) [2113073]
- io_uring: use nospec annotation for more indexes (Jeff Moyer) [2113073]
- io_uring: zero tag on rsrc removal (Jeff Moyer) [2113073]
- io_uring: don't touch scm_fp_list after queueing skb (Jeff Moyer) [2113073]
- io_uring: nospec index for tags on files update (Jeff Moyer) [2113073]
- io_uring: implement compat handling for IORING_REGISTER_IOWQ_AFF (Jeff Moyer) [2113073]
- Revert "io_uring: Add support for napi_busy_poll" (Jeff Moyer) [2113073]
- io_uring: drop the old style inflight file tracking (Jeff Moyer) [2113073]
- io_uring: defer file assignment (Jeff Moyer) [2113073]
- io_uring: propagate issue_flags state down to file assignment (Jeff Moyer) [2113073]
- io_uring: move read/write file prep state into actual opcode handler (Jeff Moyer) [2113073]
- io_uring: defer splice/tee file validity check until command issue (Jeff Moyer) [2113073]
- io_uring: don't check req->file in io_fsync_prep() (Jeff Moyer) [2113073]
- io_uring: defer msg-ring file validity check until command issue (Jeff Moyer) [2113073]
- io_uring: fail links if msg-ring doesn't succeeed (Jeff Moyer) [2113073]
- io_uring: fix memory leak of uid in files registration (Jeff Moyer) [2113073]
- io_uring: fix put_kbuf without proper locking (Jeff Moyer) [2113073]
- io_uring: fix invalid flags for io_put_kbuf() (Jeff Moyer) [2113073]
- io_uring: improve req fields comments (Jeff Moyer) [2113073]
- io_uring: enable EPOLLEXCLUSIVE for accept poll (Jeff Moyer) [2113073]
- io_uring: improve task work cache utilization (Jeff Moyer) [2113073]
- io_uring: fix async accept on O_NONBLOCK sockets (Jeff Moyer) [2113073]
- io_uring: remove IORING_CQE_F_MSG (Jeff Moyer) [2113073]
- io_uring: add flag for disabling provided buffer recycling (Jeff Moyer) [2113073]
- io_uring: ensure recv and recvmsg handle MSG_WAITALL correctly (Jeff Moyer) [2113073]
- io_uring: don't recycle provided buffer if punted to async worker (Jeff Moyer) [2113073]
- io_uring: fix assuming triggered poll waitqueue is the single poll (Jeff Moyer) [2113073]
- io_uring: bump poll refs to full 31-bits (Jeff Moyer) [2113073]
- io_uring: remove poll entry from list when canceling all (Jeff Moyer) [2113073]
- io_uring: fix memory ordering when SQPOLL thread goes to sleep (Jeff Moyer) [2113073]
- io_uring: ensure that fsnotify is always called (Jeff Moyer) [2113073]
- io_uring: recycle provided before arming poll (Jeff Moyer) [2113073]
- io_uring: terminate manual loop iterator loop correctly for non-vecs (Jeff Moyer) [2113073]
- io_uring: don't check unrelated req->open.how in accept request (Jeff Moyer) [2113073]
- io_uring: manage provided buffers strictly ordered (Jeff Moyer) [2113073]
- io_uring: fold evfd signalling under a slower path (Jeff Moyer) [2113073]
- io_uring: thin down io_commit_cqring() (Jeff Moyer) [2113073]
- io_uring: shuffle io_eventfd_signal() bits around (Jeff Moyer) [2113073]
- io_uring: remove extra barrier for non-sqpoll iopoll (Jeff Moyer) [2113073]
- io_uring: fix provided buffer return on failure for kiocb_done() (Jeff Moyer) [2113073]
- io_uring: extend provided buf return to fails (Jeff Moyer) [2113073]
- io_uring: refactor timeout cancellation cqe posting (Jeff Moyer) [2113073]
- io_uring: normilise naming for fill_cqe* (Jeff Moyer) [2113073]
- io_uring: cache poll/double-poll state with a request flag (Jeff Moyer) [2113073]
- io_uring: cache req->apoll->events in req->cflags (Jeff Moyer) [2113073]
- io_uring: move req->poll_refs into previous struct hole (Jeff Moyer) [2113073]
- io_uring: make tracing format consistent (Jeff Moyer) [2113073]
- io_uring: recycle apoll_poll entries (Jeff Moyer) [2113073]
- io_uring: remove duplicated member check for io_msg_ring_prep() (Jeff Moyer) [2113073]
- io_uring: allow submissions to continue on error (Jeff Moyer) [2113073]
- io_uring: recycle provided buffers if request goes async (Jeff Moyer) [2113073]
- io_uring: ensure reads re-import for selected buffers (Jeff Moyer) [2113073]
- io_uring: retry early for reads if we can poll (Jeff Moyer) [2113073]
- io-uring: Make statx API stable (Jeff Moyer) [2113073]
- namei: Standardize callers of filename_lookup() (Jeff Moyer) [2113073]
- io_uring: Add support for napi_busy_poll (Jeff Moyer) [2113073]
- io_uring: minor io_cqring_wait() optimization (Jeff Moyer) [2113073]
- io_uring: add support for IORING_OP_MSG_RING command (Jeff Moyer) [2113073]
- io_uring: speedup provided buffer handling (Jeff Moyer) [2113073]
- io_uring: add support for registering ring file descriptors (Jeff Moyer) [2113073]
- io_uring: documentation fixup (Jeff Moyer) [2113073]
- io_uring: do not recalculate ppos unnecessarily (Jeff Moyer) [2113073]
- io_uring: update kiocb->ki_pos at execution time (Jeff Moyer) [2113073]
- io_uring: remove duplicated calls to io_kiocb_ppos (Jeff Moyer) [2113073]
- io_uring: Remove unneeded test in io_run_task_work_sig() (Jeff Moyer) [2113073]
- io-uring: Make tracepoints consistent. (Jeff Moyer) [2113073]
- io-uring: add __fill_cqe function (Jeff Moyer) [2113073]
- io-wq: use IO_WQ_ACCT_NR rather than hardcoded number (Jeff Moyer) [2113073]
- io-wq: reduce acct->lock crossing functions lock/unlock (Jeff Moyer) [2113073]
- io-wq: decouple work_list protection from the big wqe->lock (Jeff Moyer) [2113073]
- io_uring: Fix use of uninitialized ret in io_eventfd_register() (Jeff Moyer) [2113073]
- io_uring: remove ring quiesce for io_uring_register (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering restrictions and enabling rings (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering async eventfd (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering/unregistering eventfd (Jeff Moyer) [2113073]
- io_uring: remove trace for eventfd (Jeff Moyer) [2113073]

* Wed Nov 09 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-191.el9]
- netfilter: nf_tables: fix nft_counters_enabled underflow at nf_tables_addchain() (Florian Westphal) [2134544]
- netfilter: ipset: enforce documented limit to prevent allocating huge memory (Florian Westphal) [2134544]
- netfilter: nf_tables: netlink notifier might race to release objects (Florian Westphal) [2134544]
- netfilter: nf_tables: relax NFTA_SET_ELEM_KEY_END set flags requirements (Florian Westphal) [2134544]
- netfilter: nf_tables: release flow rule object from commit path (Florian Westphal) [2134544]
- ipvs: use explicitly signed chars (Florian Westphal) [2134544]
- netfilter: conntrack: revisit the gc initial rescheduling bias (Florian Westphal) [2134544]
- netfilter: conntrack: fix the gc rescheduling delay (Florian Westphal) [2134544]
- netfilter: nf_tables: fix percpu memory leak at nf_tables_addchain() (Florian Westphal) [2134544]
- netfilter: nf_tables: do not leave chain stats enabled on error (Florian Westphal) [2134544]
- netfilter: nf_conntrack_sip: fix ct_sip_walk_headers (Florian Westphal) [2134544]
- netfilter: nft_osf: restrict osf to ipv4, ipv6 and inet families (Florian Westphal) [2134544]
- netfilter: nft_payload: do not truncate csum_offset and csum_type (Florian Westphal) [2134544]
- netfilter: nft_payload: report ERANGE for too long offset and length (Florian Westphal) [2134544]
- netfilter: nf_tables: make table handle allocation per-netns friendly (Florian Westphal) [2134544]
- netfilter: nf_tables: really skip inactive sets when allocating name (Florian Westphal) [2134544]
- scsi: scsi_transport_fc: Use %%u for dev_loss_tmo (Ewan D. Milne) [2126324]
- memcg: reduce size of memcg vmstats structures (Waiman Long) [2138950]
- memcg: rearrange code (Waiman Long) [2138950]
- memcg: extract memcg_vmstats from struct mem_cgroup (Waiman Long) [2138950]
- mm: deduplicate cacheline padding code (Waiman Long) [2138950]
- memcg: increase MEMCG_CHARGE_BATCH to 64 (Waiman Long) [2138950]
- mm: page_counter: rearrange struct page_counter fields (Waiman Long) [2138950]
- mm: page_counter: remove unneeded atomic ops for low/min (Waiman Long) [2138950]
- mm: Kconfig: reorganize misplaced mm options (Waiman Long) [2138950]
- zram: fix Kconfig dependency warning (Waiman Long) [2138950]
- Revert "memcg: cleanup racy sum avoidance code" (Waiman Long) [2138950]
- mm: memcontrol: fix potential oom_lock recursion deadlock (Waiman Long) [2138950]
- mm: memcontrol: add {pgscan,pgsteal}_{kswapd,direct} items in memory.stat of cgroup v2 (Waiman Long) [2138950]
- zswap: memcg accounting (Waiman Long) [2138950]
- mm: zswap: add basic meminfo and vmstat coverage (Waiman Long) [2138950]
- mm/vmstat: add events for ksm cow (Waiman Long) [2138950]
- redhat/configs: Fix ZSMALLOC problem with s390 (Waiman Long) [2138950]
- mm: Kconfig: simplify zswap configuration (Waiman Long) [2138950]
- mm: Kconfig: group swap, slab, hotplug and thp options into submenus (Waiman Long) [2138950]
- mm: Kconfig: move swap and slab config options to the MM section (Waiman Long) [2138950]
- mm: Make SLAB_MERGE_DEFAULT depend on SL[AU]B (Waiman Long) [2138950]
- mm: allow only SLUB on PREEMPT_RT (Waiman Long) [2138950]
- KVM: selftests: replace assertion with warning in access_tracking_perf_test (Emanuele Giuseppe Esposito) [2118584]
- net/sched: act_police: allow 'continue' action offload (Íñigo Huguet) [2128185]
- x86/ibt, objtool: Add IBT_NOSEAL() (Joe Lawrence) [2121207]
- x86/ibt, objtool: Don't discard text references from tracepoint section (Joe Lawrence) [2121207]
- objtool: Mark __ubsan_handle_builtin_unreachable() as noreturn (Joe Lawrence) [2121207]
- objtool: Fix objtool regression on x32 systems (Joe Lawrence) [2121207]
- objtool: Preserve special st_shndx indexes in elf_update_symbol (Joe Lawrence) [2121207]
- objtool: Fix symbol creation (Joe Lawrence) [2121207]
- objtool: Remove libsubcmd.a when make clean (Joe Lawrence) [2121207]
- objtool: Remove inat-tables.c when make clean (Joe Lawrence) [2121207]
- scripts: Create objdump-func helper script (Joe Lawrence) [2121207]
- objtool: update objtool.txt references (Joe Lawrence) [2121207]
- objtool: Update documentation (Joe Lawrence) [2121207]
- objtool: Remove --lto and --vmlinux in favor of --link (Joe Lawrence) [2121207]
- objtool: Add HAVE_NOINSTR_VALIDATION (Joe Lawrence) [2121207]
- objtool: Rename "VMLINUX_VALIDATION" -> "NOINSTR_VALIDATION" (Joe Lawrence) [2121207]
- objtool: Make noinstr hacks optional (Joe Lawrence) [2121207]
- objtool: Make jump label hack optional (Joe Lawrence) [2121207]
- objtool: Make static call annotation optional (Joe Lawrence) [2121207]
- objtool: Make stack validation frame-pointer-specific (Joe Lawrence) [2121207]
- objtool: Fix obsolete reference to CONFIG_X86_SMAP (Joe Lawrence) [2121207]
- objtool: Add CONFIG_OBJTOOL (Joe Lawrence) [2121207]
- objtool: Extricate sls from stack validation (Joe Lawrence) [2121207]
- objtool: Rework ibt and extricate from stack validation (Joe Lawrence) [2121207]
- objtool: Make stack validation optional (Joe Lawrence) [2121207]
- objtool: Add option to print section addresses (Joe Lawrence) [2121207]
- objtool: Don't print parentheses in function addresses (Joe Lawrence) [2121207]
- objtool: Ditch subcommands (Joe Lawrence) [2121207]
- objtool: Reorganize cmdline options (Joe Lawrence) [2121207]
- libsubcmd: Fix OPTION_GROUP sorting (Joe Lawrence) [2121207]
- objtool: Use offstr() to print address of missing ENDBR (Joe Lawrence) [2121207]
- objtool: Print data address for "!ENDBR" data warnings (Joe Lawrence) [2121207]
- x86/xen: Add ANNOTATE_NOENDBR to startup_xen() (Joe Lawrence) [2121207]
- x86/uaccess: Add ENDBR to __put_user_nocheck*() (Joe Lawrence) [2121207]
- objtool: Enable unreachable warnings for CLANG LTO (Joe Lawrence) [2121207]
- objtool: Fix STACK_FRAME_NON_STANDARD reloc type (Joe Lawrence) [2121207]
- x86: Fix .brk attribute in linker script (Joe Lawrence) [2121207]
- x86/mm: Fix RESERVE_BRK() for older binutils (Joe Lawrence) [2121207]
- x86/mm: Simplify RESERVE_BRK() (Joe Lawrence) [2121207]
- x86,objtool: Explicitly mark idtentry_body()s tail REACHABLE (Joe Lawrence) [2121207]
- x86,objtool: Mark cpu_startup_entry() __noreturn (Joe Lawrence) [2121207]
- x86,xen,objtool: Add UNWIND hint (Joe Lawrence) [2121207]
- lib/strn*,objtool: Enforce user_access_begin() rules (Joe Lawrence) [2121207]
- objtool: Fix type of reloc::addend (Joe Lawrence) [2121207]
- objtool: Fix code relocs vs weak symbols (Joe Lawrence) [2121207]
- objtool: Fix function fallthrough detection for vmlinux (Joe Lawrence) [2121207]
- objtool: Fix sibling call detection in alternatives (Joe Lawrence) [2121207]
- objtool: Don't set 'jump_dest' for sibling calls (Joe Lawrence) [2121207]
- x86/uaccess: Don't jump between functions (Joe Lawrence) [2121207]
- objtool: Fix IBT tail-call detection (Joe Lawrence) [2121207]
- crypto: x86/chacha20 - Avoid spurious jumps to other functions (Joe Lawrence) [2121207]
- kbuild: replace $(if A,A,B) with $(or A,B) (Joe Lawrence) [2121207]
- x86/ftrace: Remove OBJECT_FILES_NON_STANDARD usage (Joe Lawrence) [2121207]
- x86/alternative: Use .ibt_endbr_seal to seal indirect calls (Joe Lawrence) [2121207]
- objtool: Find unused ENDBR instructions (Joe Lawrence) [2121207]
- objtool: Validate IBT assumptions (Joe Lawrence) [2121207]
- objtool: Add IBT/ENDBR decoding (Joe Lawrence) [2121207]
- objtool: Read the NOENDBR annotation (Joe Lawrence) [2121207]
- x86: Annotate idtentry_df() (Joe Lawrence) [2121207]
- x86,objtool: Move the ASM_REACHABLE annotation to objtool.h (Joe Lawrence) [2121207]
- x86/bug: Prevent shadowing in __WARN_FLAGS (Joe Lawrence) [2121207]
- x86/bug: Merge annotate_reachable() into _BUG_FLAGS() asm (Joe Lawrence) [2121207]
- compiler.h: Fix annotation macro misplacement with Clang (Joe Lawrence) [2121207]
- x86: Annotate call_on_stack() (Joe Lawrence) [2121207]
- objtool: Rework ASM_REACHABLE (Joe Lawrence) [2121207]
- x86: Mark __invalid_creds() __noreturn (Joe Lawrence) [2121207]
- exit: Mark do_group_exit() __noreturn (Joe Lawrence) [2121207]
- x86: Mark stop_this_cpu() __noreturn (Joe Lawrence) [2121207]
- objtool: Ignore extra-symbol code (Joe Lawrence) [2121207]
- objtool: Rename --duplicate to --lto (Joe Lawrence) [2121207]
- kbuild: do not include include/config/auto.conf from shell scripts (Joe Lawrence) [2121207]
- x86/ibt: Ensure module init/exit points have references (Joe Lawrence) [2121207]
- x86/ibt: Dont generate ENDBR in .discard.text (Joe Lawrence) [2121207]
- x86/ibt,sev: Annotations (Joe Lawrence) [2121207]
- x86/ibt,ftrace: Annotate ftrace code patching (Joe Lawrence) [2121207]
- x86/ibt: Disable IBT around firmware (Joe Lawrence) [2121207]
- x86/ibt,kexec: Disable CET on kexec (Joe Lawrence) [2121207]
- bug: Have __warn() prototype defined unconditionally (Joe Lawrence) [2121207]
- x86/ibt: Add IBT feature, MSR and #CP handling (Joe Lawrence) [2121207]
- x86/ibt,bpf: Add ENDBR instructions to prologue and trampoline (Joe Lawrence) [2121207]
- x86/ibt,kprobes: Cure sym+0 equals fentry woes (Joe Lawrence) [2121207]
- x86/livepatch: Validate __fentry__ location (Joe Lawrence) [2121207]
- x86/ibt,ftrace: Search for __fentry__ location (Joe Lawrence) [2121207]
- x86/ibt,crypto: Add ENDBR for the jump-table entries (Joe Lawrence) [2121207]
- x86/linkage: Add ENDBR to SYM_FUNC_START*() (Joe Lawrence) [2121207]
- x86/entry,xen: Early rewrite of restore_regs_and_return_to_kernel() (Joe Lawrence) [2121207]
- x86/paravirt: Fix build PARAVIRT_XXL=y without XEN_PV (Joe Lawrence) [2121207]
- objtool: Have WARN_FUNC fall back to sym+off (Joe Lawrence) [2121207]
- objtool: Default ignore INT3 for unreachable (Joe Lawrence) [2121207]
- objtool: Add --dry-run (Joe Lawrence) [2121207]
- static_call: Avoid building empty .static_call_sites (Joe Lawrence) [2121207]
- objtool, kcsan: Remove memory barrier instrumentation from noinstr (Joe Lawrence) [2121207]
- objtool, kcsan: Add memory barrier instrumentation to whitelist (Joe Lawrence) [2121207]
- x86/xen: Mark xen_force_evtchn_callback() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make irq_disable() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make irq_enable() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make hypercall_page noinstr (Joe Lawrence) [2121207]
- x86/xen: Move hypercall_page to top of the file (Joe Lawrence) [2121207]
- x86/xen: Make save_fl() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make set_debugreg() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make get_debugreg() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make write_cr2() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make read_cr2() noinstr (Joe Lawrence) [2121207]
- x86/paravirt: Use PVOP_* for paravirt calls (Joe Lawrence) [2121207]
- x86/paravirt: Mark arch_local_irq_*() __always_inline (Joe Lawrence) [2121207]
- x86: Always inline ip_within_syscall_gap() (Joe Lawrence) [2121207]
- x86: Always inline context_tracking_guest_enter() (Joe Lawrence) [2121207]
- x86/xen: Mark cpu_bringup_and_idle() as dead_end_function (Joe Lawrence) [2121207]
- objtool: Update section header before relocations (Joe Lawrence) [2121207]
- objtool: Check for gelf_update_rel[a] failures (Joe Lawrence) [2121207]

* Tue Nov 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-190.el9]
- io_uring: disallow modification of rsrc_data during quiesce (Jeff Moyer) [2112041]
- io_uring: don't convert to jiffies for waiting on timeouts (Jeff Moyer) [2112041]
- io_uring: add a schedule point in io_add_buffers() (Jeff Moyer) [2112041]
- mm: io_uring: allow oom-killer from io_uring_setup (Jeff Moyer) [2112041]
- io_uring: Clean up a false-positive warning from GCC 9.3.0 (Jeff Moyer) [2112041]
- io_uring: remove unused argument from io_rsrc_node_alloc (Jeff Moyer) [2112041]
- io_uring: fix bug in slow unregistering of nodes (Jeff Moyer) [2112041]
- io-wq: delete dead lock shuffling code (Jeff Moyer) [2112041]
- io_uring: perform poll removal even if async work removal is successful (Jeff Moyer) [2112041]
- io-wq: add intermediate work step between pending list and active work (Jeff Moyer) [2112041]
- io-wq: perform both unstarted and started work cancelations in one go (Jeff Moyer) [2112041]
- io-wq: invoke work cancelation with wqe->lock held (Jeff Moyer) [2112041]
- io-wq: make io_worker lock a raw spinlock (Jeff Moyer) [2112041]
- io-wq: remove useless 'work' argument to __io_worker_busy() (Jeff Moyer) [2112041]
- io_uring: fix UAF due to missing POLLFREE handling (Jeff Moyer) [2112041]
- io_uring: Remove unused function req_ref_put (Jeff Moyer) [2112041]
- io_uring: fix not released cached task refs (Jeff Moyer) [2112041]
- io_uring: remove redundant tab space (Jeff Moyer) [2112041]
- io_uring: remove unused function parameter (Jeff Moyer) [2112041]
- io_uring: use completion batching for poll rem/upd (Jeff Moyer) [2112041]
- io_uring: single shot poll removal optimisation (Jeff Moyer) [2112041]
- io_uring: poll rework (Jeff Moyer) [2112041]
- io_uring: kill poll linking optimisation (Jeff Moyer) [2112041]
- io_uring: move common poll bits (Jeff Moyer) [2112041]
- io_uring: refactor poll update (Jeff Moyer) [2112041]
- io_uring: remove double poll on poll update (Jeff Moyer) [2112041]
- io_uring: code clean for some ctx usage (Jeff Moyer) [2112041]
- io_uring: batch completion in prior_task_list (Jeff Moyer) [2112041]
- io_uring: split io_req_complete_post() and add a helper (Jeff Moyer) [2112041]
- io_uring: add helper for task work execution code (Jeff Moyer) [2112041]
- io_uring: add a priority tw list for irq completion work (Jeff Moyer) [2112041]
- io-wq: add helper to merge two wq_lists (Jeff Moyer) [2112041]
- io_uring: reuse io_req_task_complete for timeouts (Jeff Moyer) [2112041]
- io_uring: tweak iopoll CQE_SKIP event counting (Jeff Moyer) [2112041]
- io_uring: simplify selected buf handling (Jeff Moyer) [2112041]
- io_uring: move up io_put_kbuf() and io_put_rw_kbuf() (Jeff Moyer) [2112041]
- io_uring: validate timespec for timeout removals (Jeff Moyer) [2112041]
- io_uring: better to use REQ_F_IO_DRAIN for req->flags (Jeff Moyer) [2112041]
- io_uring: fix no lock protection for ctx->cq_extra (Jeff Moyer) [2112041]
- io_uring: disable drain with cqe skip (Jeff Moyer) [2112041]
- io_uring: don't spinlock when not posting CQEs (Jeff Moyer) [2112041]
- io_uring: add option to skip CQE posting (Jeff Moyer) [2112041]
- io_uring: clean cqe filling functions (Jeff Moyer) [2112041]
- io_uring: improve argument types of kiocb_done() (Jeff Moyer) [2112041]
- io_uring: clean __io_import_iovec() (Jeff Moyer) [2112041]
- io_uring: improve send/recv error handling (Jeff Moyer) [2112041]
- io_uring: simplify reissue in kiocb_done (Jeff Moyer) [2112041]
- ipv4: Reject again rules with high DSCP values (Ivan Vecera) [2140160]
- mlxsw: Use dscp_t in struct mlxsw_sp_fib4_entry (Ivan Vecera) [2140160]
- netdevsim: Use dscp_t in struct nsim_fib4_rt (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_entry_notifier_info (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_rt_info (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_alias (Ivan Vecera) [2140160]
- ipv4: Reject routes specifying ECN bits in rtm_tos (Ivan Vecera) [2140160]
- ipv4: Stop taking ECN bits into account in fib4-rules (Ivan Vecera) [2140160]
- ipv6: Define dscp_t and stop taking ECN bits into account in fib6-rules (Ivan Vecera) [2140160]
- netdevsim: Fix hwstats debugfs file permissions (Ivan Vecera) [2140149]
- selftests: netdevsim: Increase sleep time in hw_stats_l3.sh test (Ivan Vecera) [2140149]
- selftests: netdevsim: hw_stats_l3: Add a new test (Ivan Vecera) [2140149]
- netdevsim: Introduce support for L3 offload xstats (Ivan Vecera) [2140149]
- rtnetlink: Fix handling of disabled L3 stats in RTM_GETSTATS replies (Ivan Vecera) [2140149]
- net: rtnetlink: fix error handling in rtnl_fill_statsinfo() (Ivan Vecera) [2140149]
- selftests: forwarding: hw_stats_l3: Add a new test (Ivan Vecera) [2140149]
- net: rtnetlink: Add UAPI toggle for IFLA_OFFLOAD_XSTATS_L3_STATS (Ivan Vecera) [2140149]
- net: rtnetlink: Add RTM_SETSTATS (Ivan Vecera) [2140149]
- net: rtnetlink: Add UAPI for obtaining L3 offload xstats (Ivan Vecera) [2140149]
- net: dev: Add hardware stats support (Ivan Vecera) [2140149]
- net: rtnetlink: rtnl_fill_statsinfo(): Permit non-EMSGSIZE error returns (Ivan Vecera) [2140149]
- net: rtnetlink: Propagate extack to rtnl_offload_xstats_fill() (Ivan Vecera) [2140149]
- net: rtnetlink: RTM_GETSTATS: Allow filtering inside nests (Ivan Vecera) [2140149]
- net: rtnetlink: Stop assuming that IFLA_OFFLOAD_XSTATS_* are dev-backed (Ivan Vecera) [2140149]
- net: rtnetlink: Namespace functions related to IFLA_OFFLOAD_XSTATS_* (Ivan Vecera) [2140149]
- net: rtnetlink: rtnl_stats_get(): Emit an extack for unset filter_mask (Ivan Vecera) [2140149]
- redhat: create /boot symvers link if it doesn't exist (Jan Stancek) [2088208]
- ethernet: add a helper for assigning port addresses (Ivan Vecera) [2140118]

* Tue Nov 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-189.el9]
- KVM: VMX: fully disable SGX if SECONDARY_EXEC_ENCLS_EXITING unavailable (Emanuele Giuseppe Esposito) [2139362]
- selftests/vm: enable running select groups of tests (Nico Pache) [2089501]
- mm: add merging after mremap resize (Nico Pache) [2089501]
- selftest: vm: remove deleted local_config.* from .gitignore (Nico Pache) [2089501]
- Kselftests: remove support of libhugetlbfs from kselftests (Nico Pache) [2089501]
- selftests: vm: add hugetlb_shared userfaultfd test to run_vmtests.sh (Nico Pache) [2089501]
- selftests/vm: add selftest to verify multi THP collapse (Nico Pache) [2089501]
- selftests/vm: add selftest to verify recollapse of THPs (Nico Pache) [2089501]
- selftests/vm: add MADV_COLLAPSE collapse context to selftests (Nico Pache) [2089501]
- selftests/vm: dedup hugepage allocation logic (Nico Pache) [2089501]
- selftests/vm: modularize collapse selftests (Nico Pache) [2089501]
- tools/testing/selftests/vm/hugetlb-madvise.c: silence uninitialized variable warning (Nico Pache) [2089501]
- selftests/vm: skip 128TBswitch on unsupported arch (Nico Pache) [2089501]
- selftests/vm: fix va_128TBswitch.sh permissions (Nico Pache) [2089501]
- selftests/vm: add protection_keys tests to run_vmtests (Nico Pache) [2089501]
- selftests/vm: only run 128TBswitch with 5-level paging (Nico Pache) [2089501]
- userfaultfd: selftests: infinite loop in faulting_process (Nico Pache) [2089501]
- userfaultfd/selftests: fix typo in comment (Nico Pache) [2089501]
- selftests: make use of GUP_TEST_FILE macro (Nico Pache) [2089501]
- selftests: vm: Fix resource leak when return error (Nico Pache) [2089501]
- selftests: vm: add the "settings" file with timeout variable (Nico Pache) [2089501]
- selftests: vm: add "test_hmm.sh" to TEST_FILES (Nico Pache) [2089501]
- selftests: vm: check numa_available() before operating "merge_across_nodes" in ksm_tests (Nico Pache) [2089501]
- selftests: vm: add migration to the .gitignore (Nico Pache) [2089501]
- selftests/vm/pkeys: fix typo in comment (Nico Pache) [2089501]
- userfaultfd/selftests: use swap() instead of open coding it (Nico Pache) [2089501]
- selftests/uffd: enable uffd-wp for shmem/hugetlbfs (Nico Pache) [2089501]
- selftest/vm: test that mremap fails on non-existent vma (Nico Pache) [2089501]
- selftests: clarify common error when running gup_test (Nico Pache) [2089501]
- selftests: vm: fix shellcheck warnings in run_vmtests.sh (Nico Pache) [2089501]
- selftests: vm: refactor run_vmtests.sh to reduce boilerplate (Nico Pache) [2089501]
- tools/testing/selftests/vm/gup_test.c: clarify error statement (Nico Pache) [2089501]
- mm: add selftests for migration entries (Nico Pache) [2089501]
- selftests/x86/corrupt_xstate_header: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests/x86/amx: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests/vm/pkeys: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests: Provide local define of __cpuid_count() (Nico Pache) [2089501]
- selftests: kselftest framework: provide "finished" helper (Nico Pache) [2089501]
- userfaultfd/selftests: enable hugetlb remap and remove event testing (Nico Pache) [2089501]
- selftests/vm: add hugetlb madvise MADV_DONTNEED MADV_REMOVE test (Nico Pache) [2089501]
- userfaultfd/selftests: fix uninitialized_var.cocci warning (Nico Pache) [2089501]
- selftests: vm: add a hugetlb test case (Nico Pache) [2089501]
- selftests, x86: fix how check_cc.sh is being invoked (Nico Pache) [2089501]
- selftests: vm: fix clang build error multiple output files (Nico Pache) [2089501]
- kselftest/vm: fix tests build with old libc (Nico Pache) [2089501]
- selftest/vm: fix map_fixed_noreplace test failure (Nico Pache) [2089501]
- selftests: vm: remove dependecy from internal kernel macros (Nico Pache) [2089501]
- selftests: vm: Add the uapi headers include variable (Nico Pache) [2089501]
- kselftest/vm: revert "tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner" (Nico Pache) [2089501]
- userfaultfd/selftests: clean up hugetlb allocation code (Nico Pache) [2089501]
- selftests/uffd: allow EINTR/EAGAIN (Nico Pache) [2089501]
- selftests/vm: make charge_reserved_hugetlb.sh work with existing cgroup setting (Nico Pache) [2089501]
- tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner (Nico Pache) [2089501]
- userfaultfd/selftests: fix hugetlb area allocations (Nico Pache) [2089501]
- selftests/vm: remove ARRAY_SIZE define from individual tests (Nico Pache) [2089501]
- selftests/vm: make MADV_POPULATE_(READ|WRITE) use in-tree headers (Nico Pache) [2089501]
- selftests: vm: add KSM huge pages merging time test (Nico Pache) [2089501]
- selftests/vm/transhuge-stress: fix ram size thinko (Nico Pache) [2089501]
- remoteproc: imx_rproc: Simplify some error message (Steve Best) [2137983]
- remoteproc: imx_rproc: Fix refcount leak in imx_rproc_addr_init (Steve Best) [2137983]
- remoteproc: imx_rproc: Support i.MX93 (Steve Best) [2137983]
- remoteproc: imx_rproc: Ignore create mem entry for resource table (Steve Best) [2137983]
- dt-bindings: remoteproc: imx_rproc: Support i.MX93 (Steve Best) [2137983]
- usb: dwc3: st: Rely on child's compatible instead of name (Torez Smith) [2113003]
- usb: typec: anx7411: Use of_get_child_by_name() instead of of_find_node_by_name() (Torez Smith) [2113003]
- media: airspy: fix memory leak in airspy probe (Torez Smith) [2113003]
- uas: ignore UAS for Thinkplus chips (Torez Smith) [2113003]
- usb-storage: Add Hiksemi USB3-FW to IGNORE_UAS (Torez Smith) [2113003]
- uas: add no-uas quirk for Hiksemi usb_disk (Torez Smith) [2113003]
- usb: dwc3: st: Fix node's child name (Torez Smith) [2113003]
- usb: typec: ucsi: Remove incorrect warning (Torez Smith) [2113003]
- usb: typec: anx7411: Fix build error without CONFIG_POWER_SUPPLY (Torez Smith) [2113003]
- thunderbolt: Explicitly reset plug events delay back to USB4 spec value (Torez Smith) [2113003]
- media: flexcop-usb: fix endpoint type check (Torez Smith) [2113003]
- USB: serial: option: add Quectel RM520N (Torez Smith) [2113003]
- USB: serial: option: add Quectel BG95 0x0203 composition (Torez Smith) [2113003]
- thunderbolt: Add support for Intel Maple Ridge single port controller (Torez Smith) [2113003]
- usb: dwc3: core: leave default DMA if the controller does not support 64-bit DMA (Torez Smith) [2113003]
- USB: core: Fix RST error in hub.c (Torez Smith) [2113003]
- Revert "usb: gadget: udc-xilinx: replace memcpy with memcpy_toio" (Torez Smith) [2113003]
- kunit: fix Kconfig for build-in tests USB4 and Nitro Enclaves (Torez Smith) [2113003]
- usb: storage: Add ASUS <0x0b05:0x1932> to IGNORE_UAS (Torez Smith) [2113003]
- USB: serial: ch341: fix disabled rx timer on older devices (Torez Smith) [2113003]
- USB: serial: ch341: fix lost character on LCR updates (Torez Smith) [2113003]
- USB: serial: cp210x: add Decagon UCA device id (Torez Smith) [2113003]
- Revert "usb: add quirks for Lenovo OneLink+ Dock" (Torez Smith) [2113003]
- media: uvcvideo: Fix InterfaceProtocol for Quanta camera (Torez Smith) [2113003]
- usb: cdns3: fix issue with rearming ISO OUT endpoint (Torez Smith) [2113003]
- usb: cdns3: fix incorrect handling TRB_SMM flag for ISOC transfer (Torez Smith) [2113003]
- usb: gadget: mass_storage: Fix cdrom data transfers on MAC-OS (Torez Smith) [2113003]
- USB: core: Prevent nested device-reset calls (Torez Smith) [2113003]
- USB: gadget: Fix obscure lockdep violation for udc_mutex (Torez Smith) [2113003]
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio (Torez Smith) [2113003]
- usb: typec: Remove retimers properly (Torez Smith) [2113003]
- usb: dwc3: disable USB core PHY management (Torez Smith) [2113003]
- usb: add quirks for Lenovo OneLink+ Dock (Torez Smith) [2113003]
- USB: serial: option: add support for Cinterion MV32-WA/WB RmNet mode (Torez Smith) [2113003]
- USB: serial: ftdi_sio: add Omron CS1W-CIF31 device id (Torez Smith) [2113003]
- USB: serial: option: add Quectel EM060K modem (Torez Smith) [2113003]
- USB: serial: option: add support for OPPO R11 diag port (Torez Smith) [2113003]
- Revert "xhci: turn off port power in shutdown" (Torez Smith) [2113003]
- xhci: Add grace period after xHC start to prevent premature runtime suspend. (Torez Smith) [2113003]
- xhci: Fix null pointer dereference in remove if xHC has only one roothub (Torez Smith) [2113003]
- Revert "usb: typec: ucsi: add a common function ucsi_unregister_connectors()" (Torez Smith) [2113003]
- usb: dwc3: qcom: suppress unused-variable warning (Torez Smith) [2113003]
- dt-bindings: usb: mtu3: add compatible for mt8188 (Torez Smith) [2113003]
- USB: cdc-acm: Add Icom PMR F3400 support (0c26:0020) (Torez Smith) [2113003]
- usb: gadget: f_uac2: fix superspeed transfer (Torez Smith) [2113003]
- usb: xhci-mtk: fix bandwidth release issue (Torez Smith) [2113003]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2113003]
- usb: typec: altmodes/displayport: correct pin assignment for UFP receptacles (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Drop reset delay in onboard_hub_power_off() (Torez Smith) [2113003]
- usb: dwc3: gadget: Avoid duplicate requests to enable Run/Stop (Torez Smith) [2113003]
- usb: dwc3: pci: Add support for Intel Raptor Lake (Torez Smith) [2113003]
- usb: typec: intel_pmc_mux: Add new ACPI ID for Meteor Lake IOM device (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: Add SM6375 compatible (Torez Smith) [2113003]
- usb: dwc3: qcom: clean up suspend callbacks (Torez Smith) [2113003]
- usb: dwc3: qcom: fix wakeup implementation (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: add wakeup-source property (Torez Smith) [2113003]
- usb: dwc3: qcom: fix peripheral and OTG suspend (Torez Smith) [2113003]
- usb: dwc3: qcom: fix runtime PM wakeup (Torez Smith) [2113003]
- usb: dwc3: qcom: fix use-after-free on runtime-PM wakeup (Torez Smith) [2113003]
- usb: dwc3: qcom: fix gadget-only builds (Torez Smith) [2113003]
- Revert "usb: dwc3: qcom: Keep power domain on to retain controller status" (Torez Smith) [2113003]
- usb: dwc3: fix PHY disable sequence (Torez Smith) [2113003]
- usb-storage: Add ignore-residue quirk for NXP PN7462AU (Torez Smith) [2113003]
- usb: typec: tcpm: Return ENOTSUPP for power supply prop writes (Torez Smith) [2113003]
- musb: fix USB_MUSB_TUSB6010 dependency (Torez Smith) [2113003]
- thunderbolt: Check router generation before connecting xHCI (Torez Smith) [2113003]
- thunderbolt: Use the actual buffer in tb_async_error() (Torez Smith) [2113003]
- usb: cdns3: Don't use priv_dev uninitialized in cdns3_gadget_ep_enable() (Torez Smith) [2113003]
- usb:udc: remove reference to AVR32 architecture in Atmel USBA Kconfig (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Remove duplicated power_on delay (Torez Smith) [2113003]
- media: uvcvideo: Fix invalid pointer in uvc_ctrl_init_ctrl() (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Add TI USB8041 hub support (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Add reset-gpio support (Torez Smith) [2113003]
- USB: usbsevseg: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113003]
- dt-bindings: usb: Add binding for TI USB8041 hub controller (Torez Smith) [2113003]
- usb: misc: onboard-hub: add support for Microchip USB2514B USB 2.0 hub (Torez Smith) [2113003]
- dt-bindings: usb: generic-ehci: allow usb-hcd schema properties (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: add bootloader support (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: define config (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: add support for stm32g0 controller (Torez Smith) [2113003]
- dt-bindings: usb: typec: add bindings for stm32g0 controller (Torez Smith) [2113003]
- usb: typec: ucsi: Acknowledge the GET_ERROR_STATUS command completion (Torez Smith) [2113003]
- usb: cdns3: change place of 'priv_ep' assignment in cdns3_gadget_ep_dequeue(), cdns3_gadget_ep_enable() (Torez Smith) [2113003]
- usb/chipidea: fix repeated words in comments (Torez Smith) [2113003]
- usb: renesas-xhci: Do not print any log while fw verif success (Torez Smith) [2113003]
- usb: typec: retimer: Add missing id check in match callback (Torez Smith) [2113003]
- USB: xhci: Fix comment typo (Torez Smith) [2113003]
- usb/typec/tcpm: fix repeated words in comments (Torez Smith) [2113003]
- usb/musb: fix repeated words in comments (Torez Smith) [2113003]
- usb/misc: fix repeated words in comments (Torez Smith) [2113003]
- usb/image: fix repeated words in comments (Torez Smith) [2113003]
- usb/host: fix repeated words in comments (Torez Smith) [2113003]
- usb/core: fix repeated words in comments (Torez Smith) [2113003]
- usb/atm: fix repeated words in comments (Torez Smith) [2113003]
- USB: gadget: Fix use-after-free Read in usb_udc_uevent() (Torez Smith) [2113003]
- USB: HCD: Fix URB giveback issue in tasklet function (Torez Smith) [2113003]
- usb: xhci_plat_remove: avoid NULL dereference (Torez Smith) [2113003]
- usb: typec: anx7411: fix passing zero to 'PTR_ERR' (Torez Smith) [2113003]
- usb: typec: anx7411: Fix error return code in anx7411_i2c_probe() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix return value check in anx7411_register_i2c_dummy_clients() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix wrong pointer passed to PTR_ERR() (Torez Smith) [2113003]
- usb: typec: anx7411: use semi-colons instead of commas (Torez Smith) [2113003]
- usb: typec: anx7411: fix error checking in anx7411_get_gpio_irq() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix an array out of bounds (Torez Smith) [2113003]
- usb: phy: remove redundant store to variable var after & operation (Torez Smith) [2113003]
- USB: serial: fix tty-port initialized comments (Torez Smith) [2113003]
- USB: serial: usb_wwan: replace DTR/RTS magic numbers with macros (Torez Smith) [2113003]
- USB: gadget: f_acm: use CDC defines (Torez Smith) [2113003]
- USB: cdc-acm: use CDC serial-state defines (Torez Smith) [2113003]
- USB: cdc-acm: use CDC control-line defines (Torez Smith) [2113003]
- USB: cdc: add serial-state defines (Torez Smith) [2113003]
- USB: cdc: add control-signal defines (Torez Smith) [2113003]
- net/cdc_ncm: Increase NTB max RX/TX values to 64kb (Torez Smith) [2113003]
- media: uvcvideo: Remove unneeded goto (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Acer EasyCamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Quanta cameras (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Quanta UVC Webcam (Torez Smith) [2113003]
- media: uvcvideo: Add support for per-device control mapping overrides (Torez Smith) [2113003]
- media: uvcvideo: Add missing value for power_line_frequency (Torez Smith) [2113003]
- media: uvcvideo: Replace broken URL (Torez Smith) [2113003]
- media: uvcvideo: Fix comment blocks style (Torez Smith) [2113003]
- usb: typec: Add retimer handle to port (Torez Smith) [2113003]
- usb: typec: Add support for retimers (Torez Smith) [2113003]
- usb: dwc3: qcom: fix missing optional irq warnings (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: refine interrupt requirements (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: add SC8280XP binding (Torez Smith) [2113003]
- usb: typec: anx7411: define config (Torez Smith) [2113003]
- usb: typec: anx7411: Add Analogix PD ANX7411 support (Torez Smith) [2113003]
- dt-bindings: usb: Add analogix anx7411 PD binding (Torez Smith) [2113003]
- usb: dwc3: core: Do not perform GCTL_CORE_SOFTRESET during bootup (Torez Smith) [2113003]
- usb: aspeed-vhub: Fix refcount leak bug in ast_vhub_init_desc() (Torez Smith) [2113003]
- usb: ldusb: replace ternary operator with max_t() (Torez Smith) [2113003]
- usb: dwc3: ep0: Properly handle setup_packet_pending scenario in data stage (Torez Smith) [2113003]
- usb: misc: onboard_hub: Fix 'missing prototype' warning (Torez Smith) [2113003]
- Revert "dt-bindings: usb: mtk-xhci: Make all clocks required" (Torez Smith) [2113003]
- usb: gadget: f_mass_storage: forced_eject attribute (Torez Smith) [2113003]
- usb: gadget: udc: amd5536 depends on HAS_DMA (Torez Smith) [2113003]
- USB: serial: fix repeated word "the" in comments (Torez Smith) [2113003]
- USB: serial: io_edgeport: fix spelling mistakes (Torez Smith) [2113003]
- USB: serial: ftdi_sio: add Belimo device ids (Torez Smith) [2113003]
- thunderbolt: test: Use kunit_test_suite() macro (Torez Smith) [2113003]
- media: pvrusb2: drop unexpected word 'a' in comments (Torez Smith) [2113003]
- media: gspca: drop unexpected word 'is' in the comments (Torez Smith) [2113003]
- usb: dwc3: gadget: fix high speed multiplier setting (Torez Smith) [2113003]
- usb: dwc3: gadget: refactor dwc3_repare_one_trb (Torez Smith) [2113003]
- drivers/usb/host/ehci-fsl: Fix interrupt setup in host mode. (Torez Smith) [2113003]
- usb: gadget: uvc: fix changing interface name via configfs (Torez Smith) [2113003]
- usb: typec: add missing uevent when partner support PD (Torez Smith) [2113003]
- tools: usb: testusb: Add super-plus speed reporting (Torez Smith) [2113003]
- tools: usb: testusb: Add super speed reporting (Torez Smith) [2113003]
- tools: usb: testusb: Add wireless speed reporting (Torez Smith) [2113003]
- usb: core: hub: Create platform devices for onboard hubs in hub_probe() (Torez Smith) [2113003]
- usb: misc: Add config for onboard_usb_hub driver (Torez Smith) [2113003]
- usb: misc: Add onboard_usb_hub driver (Torez Smith) [2113003]
- dt-bindings: usb: rts5411: Rename property 'companion-hub' to 'peer-hub' (Torez Smith) [2113003]
- usb: mtu3: support function remote wakeup (Torez Smith) [2113003]
- usb: mtu3: check capability of usb3 dual role (Torez Smith) [2113003]
- usb: typec: tcpci: move tcpci.h to include/linux/usb/ (Torez Smith) [2113003]
- gadgetfs: ep_io - wait until IRQ finishes (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: add compatible for mt8188 (Torez Smith) [2113003]
- usb: gadget: udc: atmel: convert to platform driver (Torez Smith) [2113003]
- usb: gadget: udc: atmel: check rc of devm_gpiod_get_optional() (Torez Smith) [2113003]
- USB: gadget: udc: tracing: Do not open code __string() with __dynamic_array() (Torez Smith) [2113003]
- ARM: sa1100/assabet: move dmabounce hack to ohci driver (Torez Smith) [2113003]
- dt-bindings: usb: generic-ohci: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: generic-ehci: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: sunxi-musb: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: atmel: Add Microchip LAN9662 compatible string (Torez Smith) [2113003]
- usb: host: xhci: use snprintf() in xhci_decode_trb() (Torez Smith) [2113003]
- usb: dwc3-am62: remove unnecesary clk_put() (Torez Smith) [2113003]
- usb: dwc3: gadget: Fix event pending check (Torez Smith) [2113003]
- usb: gadget: f_mass_storage: Make CD-ROM emulation works with Windows OS (Torez Smith) [2113003]
- USB: cdc-acm: use define for timeout (Torez Smith) [2113003]
- usb: musb: mpfs: add missing clk_disable_unprepare() in mpfs_remove() (Torez Smith) [2113003]
- usb: dwc3: gadget: fix a kernel-doc warning (Torez Smith) [2113003]
- usb: dwc3: document async_callbacks field (Torez Smith) [2113003]
- usb: typec_altmode: add a missing "@" at a kernel-doc parameter (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: Make all clocks required (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: Allow wakeup interrupt-names to be optional (Torez Smith) [2113003]
- usb: core: sysfs: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113003]
- media: usb: gspca: aligned '*' each line (Torez Smith) [2113003]
- media: hdpvr: fix error value returns in hdpvr_read (Torez Smith) [2113003]
- media: em28xx: Remove useless license text when SPDX-License-Identifier is already used (Torez Smith) [2113003]
- usb: gadget: u_ether: Remove duplicated include in u_ether.c (Torez Smith) [2113003]
- usb: max-3421: drop unexpected word "the" in the comments (Torez Smith) [2113003]
- usb: dwc2: drop unexpected word "the" in the comments (Torez Smith) [2113003]
- usb: dwc2: gadget: remove D+ pull-up while no vbus with usb-role-switch (Torez Smith) [2113003]
- usb: musb: mpfs: Fix error codes in probe() (Torez Smith) [2113003]
- USB: serial: use kmemdup instead of kmalloc + memcpy (Torez Smith) [2113003]
- usb: dwc2: host: add TPL support (Torez Smith) [2113003]
- dt-bindings: usb: dwc2: document TPL support (Torez Smith) [2113003]
- usb: host: ehci-platform: add TPL support (Torez Smith) [2113003]
- usb: host: ohci-platform: add TPL support (Torez Smith) [2113003]
- usb: chipidea: ci_hdrc_imx: use dev_err_probe() (Torez Smith) [2113003]
- usb: chipidea: udc: implement get_frame (Torez Smith) [2113003]
- usb: host: ehci-q: Fix ehci_submit_single_step_set_feature annotation typo (Torez Smith) [2113003]
- USB: storage: Fix typo in comment (Torez Smith) [2113003]
- USB: ohci-sm501: Fix typo in comment (Torez Smith) [2113003]
- usb: musb: core: drop redundant checks (Torez Smith) [2113003]
- usb: renesas: Fix refcount leak bug (Torez Smith) [2113003]
- usb: host: ohci-ppc-of: Fix refcount leak bug (Torez Smith) [2113003]
- usb: typec: mux: Add CONFIG guards for functions (Torez Smith) [2113003]
- usb: typec: mux: Allow muxes to specify mode-switch (Torez Smith) [2113003]
- usb: dwc3: qcom: Keep power domain on to retain controller status (Torez Smith) [2113003]
- usb: dwc3: qcom: Configure wakeup interrupts during suspend (Torez Smith) [2113003]
- usb: dwc3: qcom: Add helper functions to enable,disable wake irqs (Torez Smith) [2113003]
- usb: dwc3: core: Host wake up support from system suspend (Torez Smith) [2113003]
- dt-bindings: usb: dwc3: Add wakeup-source property support (Torez Smith) [2113003]
- usb: dwc3: core: Deprecate GCTL.CORESOFTRESET (Torez Smith) [2113003]
- usb: musb: Add support for PolarFire SoC's musb controller (Torez Smith) [2113003]
- Revert "usb: dwc3: Remove the checks of -ENOSYS" (Torez Smith) [2113003]
- media: pvrusb2: fix memory leak in pvr_probe (Torez Smith) [2113003]
- media: airspy: respect the DMA coherency rules (Torez Smith) [2113003]
- media: usbtv: Add PAL-Nc standard (Torez Smith) [2113003]
- thunderbolt: Fix typo in comment (Torez Smith) [2113003]
- dt-bindings: usb: add documentation for aspeed udc (Torez Smith) [2113003]
- usb: gadget: config Aspeed ast2600 udc driver (Torez Smith) [2113003]
- usb: gadget: add Aspeed ast2600 udc driver (Torez Smith) [2113003]
- usb: dwc3: Fix typos in Kconfig (Torez Smith) [2113003]
- usb: dwc3: Fix a repeated word checkpatch warning (Torez Smith) [2113003]
- usb: dwc3: Fix bare use of unsigned checkpatch warning (Torez Smith) [2113003]
- usb: Avoid extra usb SET_SEL requests when enabling link power management (Torez Smith) [2113003]
- usb: typec: tcpm: Register USB Power Delivery Capabilities (Torez Smith) [2113003]
- usb: typec: USB Power Delivery helpers for ports and partners (Torez Smith) [2113003]
- usb: typec: Separate USB Power Delivery from USB Type-C (Torez Smith) [2113003]
- usb: hub: port: add sysfs entry to switch port power (Torez Smith) [2113003]
- ucsi_ccg: ACPI based I2c client enumeration for AMD ASICs (Torez Smith) [2113003]
- ucsi_ccg: Do not hardcode interrupt polarity and type (Torez Smith) [2113003]
- usb: mtu3: register mtu3_irq by threaded irq (Torez Smith) [2113003]
- usb: mtu3: implement udc_async_callbacks of gadget operation (Torez Smith) [2113003]
- usb: mtu3: sync interrupt before unbind the udc (Torez Smith) [2113003]
- usb: musb: remove schedule work called after flush (Torez Smith) [2113003]
- usb: gadget: uvc: call uvc uvcg_warn on completed status instead of uvcg_info (Torez Smith) [2113003]
- usb: gadget: uvc: calculate the number of request depending on framesize (Torez Smith) [2113003]
- usb: mtu3: add support controller reset (Torez Smith) [2113003]
- usb: xhci-mtk: add support optional controller reset (Torez Smith) [2113003]
- dt-bindings: usb: mtu3: add support 'resets' property (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: add support 'resets' property (Torez Smith) [2113003]
- USB: chipidea: fix typo in comment (Torez Smith) [2113003]
- usb: gadget: bdc: fix typo in comment (Torez Smith) [2113003]
- usb: typec: tcpm: fix typo in comment (Torez Smith) [2113003]
- usb: xhci: tegra: Fix error check (Torez Smith) [2113003]
- usb: gadget: tegra-xudc: Fix error check in tegra_xudc_powerdomain_init() (Torez Smith) [2113003]
- usb: common: usb-conn-gpio: Allow wakeup from system suspend (Torez Smith) [2113003]
- usbip: vudc: Don't enable IRQs prematurely (Torez Smith) [2113003]
- USB: usbip: clean up mixed use of _irq() and _irqsave() (Torez Smith) [2113003]
- USB: Follow-up to SPDX GPL-2.0+ identifiers addition - remove now useless comments (Torez Smith) [2113003]
- USB: Follow-up to SPDX identifiers addition - remove now useless comments (Torez Smith) [2113003]
- usb: dwc3: Remove the checks of -ENOSYS (Torez Smith) [2113003]
- usb: host: ohci-at91: add support to enter suspend using SMC (Torez Smith) [2113003]
- usb: ohci-nxp: Fix refcount leak in ohci_hcd_nxp_probe (Torez Smith) [2113003]
- usb: host: Fix refcount leak in ehci_hcd_ppc_of_probe (Torez Smith) [2113003]
- usb: dwc3: add power down scale setting (Torez Smith) [2113003]
- usb: cdns3: fix random warning message when driver load (Torez Smith) [2113003]
- usb: cdns3 fix use-after-free at workaround 2 (Torez Smith) [2113003]
- usb: gadget: uvc: Fix comment blocks style (Torez Smith) [2113003]
- thunderbolt: Fix some kernel-doc comments (Torez Smith) [2113003]
- thunderbolt: Change TMU mode to HiFi uni-directional once DisplayPort tunneled (Torez Smith) [2113003]
- thunderbolt: Add CL1 support for USB4 and Titan Ridge routers (Torez Smith) [2113003]
- thunderbolt: Change downstream router's TMU rate in both TMU uni/bidir mode (Torez Smith) [2113003]
- thunderbolt: Fix typos in CLx enabling (Torez Smith) [2113003]
- thunderbolt: CLx disable before system suspend only if previously enabled (Torez Smith) [2113003]
- thunderbolt: Silently ignore CLx enabling in case CLx is not supported (Torez Smith) [2113003]
- audit: unify audit_filter_{uring(), inode_name(), syscall()} (Richard Guy Briggs) [2123857]
- audit: cache ctx->major in audit_filter_syscall() (Richard Guy Briggs) [2123857]
- audit_init_parent(): constify path (Richard Guy Briggs) [2123857]
- audit: remove selinux_audit_rule_update() declaration (Richard Guy Briggs) [2123857]
- audit: use time_after to compare time (Richard Guy Briggs) [2123857]
- audit: free audit_proctitle only on task exit (Richard Guy Briggs) [2123857]
- audit: explicitly check audit_context->context enum value (Richard Guy Briggs) [2123857]
- audit: audit_context pid unused, context enum comment fix (Richard Guy Briggs) [2123857]
- audit: fix repeated words in comments (Richard Guy Briggs) [2123857]
- lsm: clean up redundant NULL pointer check (Richard Guy Briggs) [2123857]
- audit: move audit_return_fixup before the filters (Richard Guy Briggs) [2123857]
- audit: fix potential double free on error path from fsnotify_add_inode_mark (Richard Guy Briggs) [2123857]
- audit: make is_audit_feature_set() static (Richard Guy Briggs) [2123857]
- audit: remove redundant data_len check (Richard Guy Briggs) [2123857]
- redhat: fix the branch we pull from the documentation tree (Herton R. Krzesinski)
- x86/fpu: Do not leak fpstate pointer on fork (Rafael Aquini) [2120448]
- tools headers kvm s390: Sync headers with the kernel sources (Thomas Huth) [2111086]
- KVM: s390: resetting the Topology-Change-Report (Thomas Huth) [2111086]
- KVM: s390: guest support for topology function (Thomas Huth) [2111086]
- KVM: s390: Cleanup ipte lock access and SIIF facility checks (Thomas Huth) [2111086]
- KVM: s390: Pass initialized arg even if unused (Thomas Huth) [2130487]
- KVM: s390: pv: destroy the configuration before its memory (Thomas Huth) [2130487]
- KVM: s390: pv: refactoring of kvm_s390_pv_deinit_vm (Thomas Huth) [2130487]
- KVM: s390: pv: add mmu_notifier (Thomas Huth) [2130487]
- KVM: s390: pv: Add kvm_s390_cpus_from_pv to kvm-s390.h and add documentation (Thomas Huth) [2130487]
- KVM: s390: pv: clear the state without memset (Thomas Huth) [2130487]
- KVM: s390: pv: add export before import (Thomas Huth) [2130487]
- KVM: s390: pv: usage counter instead of flag (Thomas Huth) [2130487]
- KVM: s390: pv: refactor s390_reset_acc (Thomas Huth) [2130487]
- KVM: s390: pv: handle secure storage violations for protected guests (Thomas Huth) [2130487]
- KVM: s390: pv: leak the topmost page table when destroy fails (Thomas Huth) [2130487]
- s390: Add attestation query information (Thomas Huth) [2130487]
- KVM: s390: drop unexpected word 'and' in the comments (Thomas Huth) [2130487]
- redhat: Enable CONFIG_VFIO_PCI_ZDEV_KVM for downstream builds (Thomas Huth) [1871143]
- KVM: s390: pci: fix GAIT physical vs virtual pointers usage (Thomas Huth) [1871143]
- KVM: s390: pci: fix plain integer as NULL pointer warnings (Thomas Huth) [1871143]
- KVM: s390/pci: fix include duplicates (Thomas Huth) [1871143]
- KVM: s390: pci: register pci hooks without interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: Hook to access KVM lowlevel from VFIO (Thomas Huth) [1871143]
- Documentation: kvm: extend KVM_S390_ZPCI_OP subheading underline (Thomas Huth) [1871143]
- MAINTAINERS: additional files related kvm s390 pci passthrough (Thomas Huth) [1871143]
- KVM: s390: add KVM_S390_ZPCI_OP to manage guest zPCI devices (Thomas Huth) [1871143]
- vfio-pci/zdev: different maxstbl for interpreted devices (Thomas Huth) [1871143]
- vfio-pci/zdev: add function handle to clp base capability (Thomas Huth) [1871143]
- vfio-pci/zdev: add open/close device hooks (Thomas Huth) [1871143]
- KVM: s390: pci: add routines to start/stop interpretive execution (Thomas Huth) [1871143]
- KVM: s390: pci: provide routines for enabling/disabling interrupt forwarding (Thomas Huth) [1871143]
- KVM: s390: mechanism to enable guest zPCI Interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: enable host forwarding of Adapter Event Notifications (Thomas Huth) [1871143]
- KVM: s390: pci: do initial setup for AEN interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: add basic kvm_zdev structure (Thomas Huth) [1871143]
- vfio/pci: introduce CONFIG_VFIO_PCI_ZDEV_KVM (Thomas Huth) [1871143]
- s390/pci: stash dtsm and maxstbl (Thomas Huth) [1871143]
- s390/pci: stash associated GISA designation (Thomas Huth) [1871143]
- s390/pci: externalize the SIC operation controls and routine (Thomas Huth) [1871143]
- s390/airq: allow for airq structure that uses an input vector (Thomas Huth) [1871143]
- s390/airq: pass more TPI info to airq handlers (Thomas Huth) [1871143]
- s390/ap: fix kernel doc comments (Thomas Huth) [1871143]
- s390/sclp: detect the AISI facility (Thomas Huth) [1871143]
- s390/sclp: detect the AENI facility (Thomas Huth) [1871143]
- s390/sclp: detect the AISII facility (Thomas Huth) [1871143]
- s390/sclp: detect the zPCI load/store interpretation facility (Thomas Huth) [1871143]
- s390/sclp: add detection of IPL-complete-control facility (Thomas Huth) [1871143]
- s390/pci: add error record for CC 2 retries (Thomas Huth) [1871143]
- s390/pci: add PCI access type and length to error records (Thomas Huth) [1871143]
- s390/pci: don't log availability events as errors (Thomas Huth) [1871143]
- s390/pci: make better use of zpci_dbg() levels (Thomas Huth) [1871143]
- s390/pci: rename get_zdev_by_bus() to zdev_from_bus() (Thomas Huth) [1871143]
- s390/pci: improve zpci_dev reference counting (Thomas Huth) [1871143]
- s390/pci: make zpci_set_irq()/zpci_clear_irq() static (Thomas Huth) [1871143]
- s390/pci: simplify __pciwb_mio() inline asm (Thomas Huth) [1871143]
- s390/pci: use physical addresses in DMA tables (Thomas Huth) [1871143]
- s390/pci: use phys_to_virt() for AIBVs/DIBVs (Thomas Huth) [1871143]
- s390/pci: implement minimal PCI error recovery (Thomas Huth) [1871143]
- s390/pci: implement reset_slot for hotplug slot (Thomas Huth) [1871143]
- s390/pci: refresh function handle in iomap (Thomas Huth) [1871143]
- s390/pci: add simpler s390dbf traces for events (Thomas Huth) [1871143]
- s390/pci: tolerate inconsistent handle in recover (Thomas Huth) [1871143]
- s390/pci_mmio: fully validate the VMA before calling follow_pte() (Thomas Huth) [1871143]
- s390/pci: read clp_list_pci_req only once (Thomas Huth) [1871143]
- s390/pci: fix clp_get_state() handling of -ENODEV (Thomas Huth) [1871143]
- s390/pci: improve DMA translation init and exit (Thomas Huth) [1871143]
- s390/pci: simplify CLP List PCI handling (Thomas Huth) [1871143]
- s390/pci: handle FH state mismatch only on disable (Thomas Huth) [1871143]
- s390/pci: fix misleading rc in clp_set_pci_fn() (Thomas Huth) [1871143]
- Documentation: KVM: update s390-diag.rst reference (Thomas Huth) [2130487]
- Documentation: KVM: update s390-pv.rst reference (Thomas Huth) [2130487]
- Documentation/virt/kvm/api.rst: Explain rc/rrc delivery (Thomas Huth) [2044301]
- Documentation/virt/kvm/api.rst: Add protvirt dump/info api descriptions (Thomas Huth) [2044301]
- Documentation: virt: Protected virtual machine dumps (Thomas Huth) [2044301]
- KVM: s390: Add KVM_CAP_S390_PROTECTED_DUMP (Thomas Huth) [2044301]
- KVM: s390: Add CPU dump functionality (Thomas Huth) [2044301]
- KVM: s390: Add configuration dump functionality (Thomas Huth) [2044301]
- KVM: s390: pv: Add query dump information (Thomas Huth) [2044301]
- KVM: s390: pv: Add dump support definitions (Thomas Huth) [2044301]
- KVM: s390: pv: Add query interface (Thomas Huth) [2044301]
- s390/uv: Add dump fields to query (Thomas Huth) [2044301]
- s390/uv: Add SE hdr query information (Thomas Huth) [2044301]
- s390: uv: Add offset comments to UV query struct and fix naming (Thomas Huth) [2130487]
- s390/uv: fix memblock virtual vs physical address confusion (Thomas Huth) [2130487]
- KVM: s390: Use Makefile.kvm for common files (Thomas Huth) [2130487]
- KVM: s390: Skip gfn/size sanity checks on memslot DELETE or FLAGS_ONLY (Thomas Huth) [2130487]
- netfilter: nft_fib: Fix for rpath check with VRF devices (Guillaume Nault) [2134815]
- ipv6: ping: fix wrong checksum for large frames (Guillaume Nault) [2134815]
- ipv4: Handle attempt to delete multipath route when fib_info contains an nh reference (Guillaume Nault) [2134815]
- once: rename _SLOW to _SLEEPABLE (Guillaume Nault) [2134815]
- once: add DO_ONCE_SLOW() for sleepable contexts (Guillaume Nault) [2134815]
- net, lib/once: remove {net_}get_random_once_wait macro (Guillaume Nault) [2134815]
- tcp: use alloc_large_system_hash() to allocate table_perturb (Guillaume Nault) [2134815]
- ipv4: fix ip option filtering for locally generated fragments (Guillaume Nault) [2134815]
- net: ipv4: Fix the warning for dereference (Guillaume Nault) [2134815]
- net: ipv4: Move ip_options_fragment() out of loop (Guillaume Nault) [2134815]
- x86/fpu: Prevent FPU state corruption (Oleksandr Natalenko) [2131667]
- iommu/amd: Globally detect SNP support (Jerry Snitselaar) [2117776]
- iommu/amd: Fix compile warning in init code (Jerry Snitselaar) [2117776]
- iommu/amd: Simplify and Consolidate Virtual APIC (AVIC) Enablement (Jerry Snitselaar) [2106596]
- iommu/amd: Process all IVHDs before enabling IOMMU features (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce global variable for storing common EFR and EFR2 (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce Support for Extended Feature 2 Register (Jerry Snitselaar) [2117776]
- iommu/amd: Change macro for IOMMU control register bit shift to decimal value (Jerry Snitselaar) [2117776]
- iommu/amd: Update amd_iommu_fault structure to include PCI seg ID (Jerry Snitselaar) [2117776]
- iommu/amd: Update device_state structure to include PCI seg ID (Jerry Snitselaar) [2117776]
- iommu/amd: Print PCI segment ID in error log messages (Jerry Snitselaar) [2117776]
- iommu/amd: Add PCI segment support for ivrs_[ioapic/hpet/acpihid] commands (Jerry Snitselaar) [2117776]
- iommu/amd: Specify PCI segment ID when getting pci device (Jerry Snitselaar) [2117776]
- iommu/amd: Include PCI segment ID when initialize IOMMU (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce get_device_sbdf_id() helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Flush upto last_bdf only (Jerry Snitselaar) [2117776]
- iommu/amd: Remove global amd_iommu_[dev_table/alias_table/last_bdf] (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dev_entry_bit() and get_dev_entry_bit() (Jerry Snitselaar) [2117776]
- iommu/amd: Update (un)init_device_table_dma() (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dte_irq_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Update dump_dte_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Update iommu_ignore_device (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dte_entry and clear_dte_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use per PCI segment rlookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Update alloc_irq_table and alloc_irq_index (Jerry Snitselaar) [2117776]
- iommu/amd: Update amd_irte_ops functions (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce struct amd_ir_data.iommu (Jerry Snitselaar) [2117776]
- iommu/amd: Update irq_remapping_alloc to use IOMMU lookup helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use rlookup_amd_iommu helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use per PCI segment irq_lookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment rlookup table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment alias table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment device table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment last_bdf (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment unity map list (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment alias_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment old_dev_tbl_cpy (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment dev_data_list (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment irq_lookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment rlookup table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment device table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce pci segment structure (Jerry Snitselaar) [2117776]
- iommu/amd: Update struct iommu_dev_data definition (Jerry Snitselaar) [2117776]
- iommu/amd: Indicate whether DMA remap support is enabled (Jerry Snitselaar) [2097878]
- iomap: iomap_read_inline_data cleanup (Carlos Maiolino) [2130933]
- iomap: Fix inline extent handling in iomap_readpage (Carlos Maiolino) [2130933]
- iomap: don't try to poll multi-bio I/Os in __iomap_dio_rw (Carlos Maiolino) [2130933]
- iomap: standardize tracepoint formatting and storage (Carlos Maiolino) [2130933]
- iomap: move loop control code to iter.c (Carlos Maiolino) [2130933]
- iomap: constify iomap_iter_srcmap (Carlos Maiolino) [2130933]
- fsdax: switch the fault handlers to use iomap_iter (Carlos Maiolino) [2130933]
- fsdax: factor out a dax_fault_actor() helper (Carlos Maiolino) [2130933]
- fsdax: factor out helpers to simplify the dax fault code (Carlos Maiolino) [2130933]
- iomap: rework unshare flag (Carlos Maiolino) [2130933]
- iomap: pass an iomap_iter to various buffered I/O helpers (Carlos Maiolino) [2130933]
- iomap: remove iomap_apply (Carlos Maiolino) [2130933]
- fsdax: Fix infinite loop in dax_iomap_rw() (Carlos Maiolino) [2130933]
- fsdax: switch dax_iomap_rw to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_swapfile_activate to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_seek_data to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_seek_hole to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_bmap to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_fiemap to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch __iomap_dio_rw to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_page_mkwrite to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_zero_range to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_file_unshare to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_file_buffered_write to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch readahead and readpage to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: add the new iomap_iter model (Carlos Maiolino) [2130933]
- iomap: fix the iomap_readpage_actor return value for inline data (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_read_page_sync const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_read_inline_data const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_inline_data_valid const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_inline_data const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_sector const (Carlos Maiolino) [2130933]
- fsdax: mark the iomap argument to dax_iomap_sector as const (Carlos Maiolino) [2130933]
- fs: mark the iomap argument to __block_write_begin_int const (Carlos Maiolino) [2130933]
- iomap: fix a trivial comment typo in trace.h (Carlos Maiolino) [2130933]
- iomap: pass writeback errors to the mapping (Carlos Maiolino) [2130933]
- iomap: Add another assertion to inline data handling (Carlos Maiolino) [2130933]
- iomap: Use kmap_local_page instead of kmap_atomic (Carlos Maiolino) [2130933]
- iomap: Fix some typos and bad grammar (Carlos Maiolino) [2130933]
- iomap: Support inline data with block size < page size (Carlos Maiolino) [2130933]

* Mon Nov 07 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-188.el9]
- NFSv4.1 probe offline transports for trunking on session creation (Scott Mayhew) [2131767]
- SUNRPC create a function that probes only offline transports (Scott Mayhew) [2131767]
- SUNRPC export xprt_iter_rewind function (Scott Mayhew) [2131767]
- SUNRPC restructure rpc_clnt_setup_test_and_add_xprt (Scott Mayhew) [2131767]
- NFSv4.1 remove xprt from xprt_switch if session trunking test fails (Scott Mayhew) [2131767]
- SUNRPC create an rpc function that allows xprt removal from rpc_clnt (Scott Mayhew) [2131767]
- SUNRPC enable back offline transports in trunking discovery (Scott Mayhew) [2131767]
- SUNRPC create an iterator to list only OFFLINE xprts (Scott Mayhew) [2131767]
- NFSv4.1 offline trunkable transports on DESTROY_SESSION (Scott Mayhew) [2131767]
- SUNRPC add function to offline remove trunkable transports (Scott Mayhew) [2131767]
- SUNRPC expose functions for offline remote xprt functionality (Scott Mayhew) [2131767]
- PCI: hv: Do not set PCI_COMMAND_MEMORY to reduce VM boot time (Emanuele Giuseppe Esposito) [2092794]
- xfrm: Reinject transport-mode packets through workqueue (Sabrina Dubroca) [2136174]
- xfrm: Update ipcomp_scratches with NULL when freed (Sabrina Dubroca) [2136174]
- esp: choose the correct inner protocol for GSO on inter address family tunnels (Sabrina Dubroca) [2136174]
- xfrm: fix refcount leak in __xfrm_policy_check() (Sabrina Dubroca) [2136174]
- xfrm: xfrm_policy: fix a possible double xfrm_pols_put() in xfrm_bundle_lookup() (Sabrina Dubroca) [2136174]
- net: xfrm: unexport __init-annotated xfrm4_protocol_init() (Sabrina Dubroca) [2136174]
- xfrm: do not set IPv4 DF flag when encapsulating IPv6 frames <= 1280 bytes. (Sabrina Dubroca) [2136174]
- net: Fix esp GSO on inter address family tunnels. (Sabrina Dubroca) [2136174]
- esp: Fix BEET mode inter address family tunneling on GSO (Sabrina Dubroca) [2136174]
- xfrm: fix tunnel model fragmentation behavior (Sabrina Dubroca) [2136174]
- xfrm: fix the if_id check in changelink (Sabrina Dubroca) [2136174]
- xfrm: interface with if_id 0 should return error (Sabrina Dubroca) [2136174]
- perf test: Fix test case 83 ('perf stat CSV output linter') on s390 (Michael Petlan) [2123231]
- perf tools arm64: Copy perf_regs.h from the kernel (Michael Petlan) [2123231]
- x86/cpufeatures: Add AMD Fam19h Branch Sampling feature (Michael Petlan) [2123231]
- rhel: Keep Zen3 Branch Sampling enabled (Michael Petlan) [2123231]
- perf symbol: Fail to read phdr workaround (Michael Petlan) [2123231]
- libperf evlist: Fix per-thread mmaps for multi-threaded targets (Michael Petlan) [2123231]
- perf python: Fix build when PYTHON_CONFIG is user supplied (Michael Petlan) [2123231]
- perf symbol: Skip symbols if SHF_ALLOC flag is not set (Michael Petlan) [2123231]
- perf symbol: Correct address for bss symbols (Michael Petlan) [2123231]
- perf scripts python: Let script to be python2 compliant (Michael Petlan) [2123231]
- perf trace: Fix SIGSEGV when processing syscall args (Michael Petlan) [2123231]
- perf tests: Fix Convert perf time to TSC test for hybrid (Michael Petlan) [2123231]
- perf tests: Stop Convert perf time to TSC test opening events twice (Michael Petlan) [2123231]
- perf synthetic-events: Ignore dead threads during event synthesis (Michael Petlan) [2123231]
- perf synthetic-events: Don't sort the task scan result from /proc (Michael Petlan) [2123231]
- perf unwind: Fix unitialized 'offset' variable on aarch64 (Michael Petlan) [2123231]
- perf bpf: 8 byte align bpil data (Michael Petlan) [2123231]
- perf offcpu: Accept allowed sample types only (Michael Petlan) [2123231]
- perf offcpu: Fix build failure on old kernels (Michael Petlan) [2123231]
- tools include UAPI: Sync linux/vhost.h with the kernel sources (Michael Petlan) [2123231]
- tools include UAPI: Sync linux/vhost.h with the kernel sources (Michael Petlan) [2123231]
- perf stat: Enable ignore_missing_thread (Michael Petlan) [2123231]
- perf inject: Adjust output data offset for backward compatibility (Michael Petlan) [2123231]
- perf trace beauty: Fix generation of errno id->str table on ALT Linux (Michael Petlan) [2123231]
- perf build-id: Fix caching files with a wrong build ID (Michael Petlan) [2123231]
- perf inject: Fix missing free in copy_kcore_dir() (Michael Petlan) [2123231]
- perf metrics: Ensure at least 1 id per metric (Michael Petlan) [2123231]
- perf arm-spe: Don't set data source if it's not a memory operation (Michael Petlan) [2123231]
- perf expr: Allow exponents on floating point values (Michael Petlan) [2123231]
- perf test topology: Use !strncmp(right platform) to fix guest PPC comparision check (Michael Petlan) [2123231]
- perf test: Record only user callchains on the "Check Arm64 callgraphs are complete in fp mode" test (Michael Petlan) [2123231]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123231]
- perf test: Fix variable length array undefined behavior in bp_account (Michael Petlan) [2123231]
- libperf evsel: Open shouldn't leak fd on failure (Michael Petlan) [2123231]
- perf test: Fix "perf stat CSV output linter" test on s390 (Michael Petlan) [2123231]
- perf unwind: Fix uninitialized variable (Michael Petlan) [2123231]
- perf vendor events intel: Update metrics for Alderlake (Michael Petlan) [2123231]
- perf vendor events intel: Add metrics for Sapphirerapids (Michael Petlan) [2123231]
- perf c2c: Fix sorting in percent_rmt_hitm_cmp() (Michael Petlan) [2123231]
- perf mem: Trace physical address for Arm SPE events (Michael Petlan) [2123231]
- perf list: Update event description for IBM zEC12/zBC12 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z196/z114 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z15 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z14 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z13 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z10 to latest level (Michael Petlan) [2123231]
- perf list: Add IBM z16 event description for s390 (Michael Petlan) [2123231]
- perf record: Support sample-read topdown metric group for hybrid platforms (Michael Petlan) [2123231]
- perf lock: Change to synthesize task events (Michael Petlan) [2123231]
- perf unwind: Fix segbase for ld.lld linked objects (Michael Petlan) [2123231]
- perf test arm-spe: Check if perf-record hangs when recording workload with forks (Michael Petlan) [2123231]
- perf docs: Correct typo of event_sources (Michael Petlan) [2123231]
- perf evlist: Extend arch_evsel__must_be_in_group to support hybrid systems (Michael Petlan) [2123231]
- perf scripts python: Support Arm CoreSight trace data disassembly (Michael Petlan) [2123231]
- perf scripting python: Expose dso and map information (Michael Petlan) [2123231]
- perf jevents: Fix event syntax error caused by ExtSel (Michael Petlan) [2123231]
- perf tools arm64: Add support for VG register (Michael Petlan) [2123231]
- perf unwind arm64: Decouple Libunwind register names from Perf (Michael Petlan) [2123231]
- perf unwind: Use dynamic register set for DWARF unwind (Michael Petlan) [2123231]
- perf unwind arm64: Use perf's copy of kernel headers (Michael Petlan) [2123231]
- perf c2c: Use stdio interface if slang is not supported (Michael Petlan) [2123231]
- perf test: Add a basic offcpu profiling test (Michael Petlan) [2123231]
- perf record: Add cgroup support for off-cpu profiling (Michael Petlan) [2123231]
- perf record: Handle argument change in sched_switch (Michael Petlan) [2123231]
- perf record: Implement basic filtering for off-cpu (Michael Petlan) [2123231]
- perf record: Enable off-cpu analysis with BPF (Michael Petlan) [2123231]
- perf report: Do not extend sample type of bpf-output event (Michael Petlan) [2123231]
- perf test: Add checking for perf stat CSV output. (Michael Petlan) [2123231]
- perf tools: Allow system-wide events to keep their own threads (Michael Petlan) [2123231]
- perf tools: Allow system-wide events to keep their own CPUs (Michael Petlan) [2123231]
- libperf evsel: Add comments for booleans (Michael Petlan) [2123231]
- perf stat: Add requires_cpu flag for uncore (Michael Petlan) [2123231]
- libperf evlist: Check nr_mmaps is correct (Michael Petlan) [2123231]
- libperf evlist: Allow mixing per-thread and per-cpu mmaps (Michael Petlan) [2123231]
- perf tools: Allow all_cpus to be a superset of user_requested_cpus (Michael Petlan) [2123231]
- perf intel-pt: Track sideband system-wide when needed (Michael Petlan) [2123231]
- perf intel-pt: Use evlist__add_dummy_on_all_cpus() for switch tracking (Michael Petlan) [2123231]
- perf record: Use evlist__add_dummy_on_all_cpus() in record__config_text_poke() (Michael Petlan) [2123231]
- perf evlist: Add evlist__add_dummy_on_all_cpus() (Michael Petlan) [2123231]
- perf evlist: Factor out evlist__dummy_event() (Michael Petlan) [2123231]
- perf auxtrace: Remove auxtrace_mmap_params__set_idx() per_cpu parameter (Michael Petlan) [2123231]
- perf auxtrace: Add mmap_needed to auxtrace_mmap_params (Michael Petlan) [2123231]
- perf intel-pt: Add a test for system-wide side band (Michael Petlan) [2123231]
- tools: Import ARM SMCCC definitions (Michael Petlan) [2123231]
- perf intel-pt: Add guest_code support (Michael Petlan) [2123231]
- perf kvm report: Add guest_code support (Michael Petlan) [2123231]
- perf script: Add guest_code support (Michael Petlan) [2123231]
- perf tools: Add guest_code support (Michael Petlan) [2123231]
- perf tools: Factor out thread__set_guest_comm() (Michael Petlan) [2123231]
- perf tools: Add machine to machines back pointer (Michael Petlan) [2123231]
- perf vendors events arm64: Update Cortex A57/A72 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Neoverse E1 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-X2 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-X1 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A710 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A78 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A77 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A75 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A73 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A65 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A510 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A55 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A35 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A34 (Michael Petlan) [2123231]
- perf inject: Keep a copy of kcore_dir (Michael Petlan) [2123231]
- perf data: Add has_kcore_dir() (Michael Petlan) [2123231]
- perf inject: Keep some features sections from input file (Michael Petlan) [2123231]
- libperf: Add preadn() (Michael Petlan) [2123231]
- perf header: Add ability to keep feature sections (Michael Petlan) [2123231]
- perf jevents: Modify match field (Michael Petlan) [2123231]
- perf vendor events: Fix Ivytown UNC_M_ACT_COUNT.RD umask (Michael Petlan) [2123231]
- perf vendor events: Fix Alderlake metric groups (Michael Petlan) [2123231]
- perf jevents: Append PMU description later (Michael Petlan) [2123231]
- perf test: Use skip in PERF_RECORD_* (Michael Petlan) [2123231]
- perf test: Parse events break apart tests (Michael Petlan) [2123231]
- perf test: Parse events tidy evlist_test (Michael Petlan) [2123231]
- perf test: Parse events tidy terms_test (Michael Petlan) [2123231]
- perf test: Basic mmap use skip (Michael Petlan) [2123231]
- perf test: Use skip in openat syscall (Michael Petlan) [2123231]
- perf test: Use skip in vmlinux kallsyms (Michael Petlan) [2123231]
- perf test: Skip reason for suites with 1 test (Michael Petlan) [2123231]
- perf bpf_counter: Tidy use of CPU map index (Michael Petlan) [2123231]
- perf stat: Add stat record+report test (Michael Petlan) [2123231]
- perf lock: Add -t/--thread option for report (Michael Petlan) [2123231]
- perf lock: Do not discard broken lock stats (Michael Petlan) [2123231]
- perf c2c: Update documentation for store metric 'N/A' (Michael Petlan) [2123231]
- perf c2c: Add dimensions for 'N/A' metrics of store operation (Michael Petlan) [2123231]
- perf mem: Add stats for store operation with no available memory level (Michael Petlan) [2123231]
- perf build: Error for BPF skeletons without LIBBPF (Michael Petlan) [2123231]
- perf parse-events: Move slots event for the hybrid platform too (Michael Petlan) [2123231]
- perf parse-events: Support different format of the topdown event name (Michael Petlan) [2123231]
- perf stat: Always keep perf metrics topdown events in a group (Michael Petlan) [2123231]
- perf evsel: Fixes topdown events in a weak group for the hybrid platform (Michael Petlan) [2123231]
- perf test: Add basic stat and topdown group test (Michael Petlan) [2123231]
- perf evlist: Keep topdown counters in weak group (Michael Petlan) [2123231]
- perf scripts python: intel-pt-events.py: Print ptwrite value as a string if it is ASCII (Michael Petlan) [2123231]
- perf script: Print Intel ptwrite value as a string if it is ASCII (Michael Petlan) [2123231]
- perf intel-pt: Add support for emulated ptwrite (Michael Petlan) [2123231]
- perf bench breakpoint: Fix build on 32-bit arches (Michael Petlan) [2123231]
- perf tools: Remove unused machines__find_host() (Michael Petlan) [2123231]
- perf bench: Add breakpoint benchmarks (Michael Petlan) [2123231]
- perf annotate: Add --percent-limit option (Michael Petlan) [2123231]
- perf auxtrace: Record whether an auxtrace mmap is needed (Michael Petlan) [2123231]
- libperf evlist: Add evsel as a parameter to ->idx() (Michael Petlan) [2123231]
- libperf evlist: Move ->idx() into mmap_per_evsel() (Michael Petlan) [2123231]
- libperf evlist: Remove ->idx() per_cpu parameter (Michael Petlan) [2123231]
- perf auxtrace: Do not mix up mmap idx (Michael Petlan) [2123231]
- perf auxtrace: Move evlist__enable_event_idx() to auxtrace.c (Michael Petlan) [2123231]
- perf evlist: Use libperf functions in evlist__enable_event_idx() (Michael Petlan) [2123231]
- libperf evsel: Add perf_evsel__enable_thread() (Michael Petlan) [2123231]
- perf metrics: Don't add all tool events for sharing (Michael Petlan) [2123231]
- perf metrics: Support all tool events (Michael Petlan) [2123231]
- perf evsel: Add tool event helpers (Michael Petlan) [2123231]
- perf evsel: Constify a few arrays (Michael Petlan) [2123231]
- perf test: Add skip to --per-thread test (Michael Petlan) [2123231]
- perf evlist: Clear all_cpus before propagating (Michael Petlan) [2123231]
- perf cpumap: Switch to using perf_cpu_map API (Michael Petlan) [2123231]
- perf vendor events intel: Update CLX events to v1.15 (Michael Petlan) [2123231]
- perf vendor events intel: Add uncore event list for Sapphirerapids (Michael Petlan) [2123231]
- perf vendor events intel: Update core event list for Sapphirerapids (Michael Petlan) [2123231]
- perf tools: Use Python devtools for version autodetection rather than runtime (Michael Petlan) [2123231]
- perf stat: Avoid printing cpus with no counters (Michael Petlan) [2123231]
- perf tools: Add missing headers needed by util/data.h (Michael Petlan) [2123231]
- perf vendor events intel: Update WSM-EX events to v3 (Michael Petlan) [2123231]
- perf vendor events intel: Update WSM-EP-SP events to v3 (Michael Petlan) [2123231]
- perf vendor events intel: Update SKX events to v1.27 (Michael Petlan) [2123231]
- perf vendor events intel: Update SKL events to v53 (Michael Petlan) [2123231]
- perf vendor events intel: Update IVT events to v21 (Michael Petlan) [2123231]
- perf vendor events intel: Update ICL events to v1.13 (Michael Petlan) [2123231]
- perf test: Fix test case 81 ("perf record tests") on s390x (Michael Petlan) [2123231]
- perf tools: Delete perf-with-kcore.sh script (Michael Petlan) [2123231]
- perf intel-pt: Add link to the perf wiki's Intel PT page (Michael Petlan) [2123231]
- libperf evsel: Factor out perf_evsel__ioctl() (Michael Petlan) [2123231]
- perf stat: Support hybrid --topdown option (Michael Petlan) [2123231]
- perf stat: Merge event counts from all hybrid PMUs (Michael Petlan) [2123231]
- perf vendor events intel: Add metrics for Alderlake (Michael Petlan) [2123231]
- perf list: Print all available tool events (Michael Petlan) [2123231]
- perf stat: Add user_time and system_time events (Michael Petlan) [2123231]
- perf stat: Introduce stats for the user and system rusage times (Michael Petlan) [2123231]
- perf tools: Print warning when HAVE_DEBUGINFOD_SUPPORT is not set and user tries to use debuginfod support (Michael Petlan) [2123231]
- perf version: Add HAVE_DEBUGINFOD_SUPPORT to built-in features (Michael Petlan) [2123231]
- perf vendor events intel: Update goldmont event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update goldmontplus event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update elkhartlake event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereex event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereep-sp event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereep-dp event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update tremontx uncore and topics (Michael Petlan) [2123231]
- perf vendor events intel: Update tigerlake topic (Michael Petlan) [2123231]
- perf vendor events intel: Update nehalemep event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update SKX uncore (Michael Petlan) [2123231]
- perf vendor events intel: Update CLX uncore to v1.14 (Michael Petlan) [2123231]
- perf vendor events intel: Add sapphirerapids events (Michael Petlan) [2123231]
- perf vendor events intel: Fix icelakex cstate metrics (Michael Petlan) [2123231]
- perf vendor events intel: Fix icelake cstate metrics (Michael Petlan) [2123231]
- perf mem: Print memory operation type (Michael Petlan) [2123231]
- perf test: Add basic perf record tests (Michael Petlan) [2123231]
- perf docs: Add man page entry for Arm SPE (Michael Petlan) [2123231]
- perf test: Shell - Limit to only run executable scripts in tests (Michael Petlan) [2123231]
- perf scripting python: Expose symbol offset and source information (Michael Petlan) [2123231]
- perf jitdump: Add riscv64 support (Michael Petlan) [2123231]
- libsubcmd: Fix OPTION_GROUP sorting (Michael Petlan) [2123231]
- perf session: Fix Intel LBR callstack entries and nr print message (Michael Petlan) [2123231]
- perf test bpf: Skip test if clang is not present (Michael Petlan) [2123231]
- perf test session topology: Fix test to skip the test in guest environment (Michael Petlan) [2123231]
- perf bench numa: Address compiler error on s390 (Michael Petlan) [2123231]
- perf test: Avoid shell test description infinite loop (Michael Petlan) [2123231]
- perf regs x86: Fix arch__intr_reg_mask() for the hybrid platform (Michael Petlan) [2123231]
- perf test: Fix "all PMU test" to skip hv_24x7/hv_gpci tests on powerpc (Michael Petlan) [2123231]
- perf bench: Fix two numa NDEBUG warnings (Michael Petlan) [2123231]
- perf symbol: Remove arch__symbols__fixup_end() (Michael Petlan) [2123231]
- perf symbol: Update symbols__fixup_end() (Michael Petlan) [2123231]
- perf symbol: Pass is_kallsyms to symbols__fixup_end() (Michael Petlan) [2123231]
- perf test: Add perf_event_attr test for Arm SPE (Michael Petlan) [2123231]
- perf arm-spe: Fix SPE events with phys addresses (Michael Petlan) [2123231]
- perf arm-spe: Fix addresses of synthesized SPE events (Michael Petlan) [2123231]
- perf intel-pt: Fix timeless decoding with perf.data directory (Michael Petlan) [2123231]
- perf test: Fix error message for test case 71 on s390, where it is not supported (Michael Petlan) [2123231]
- perf report: Set PERF_SAMPLE_DATA_SRC bit for Arm SPE event (Michael Petlan) [2123231]
- perf script: Always allow field 'data_src' for auxtrace (Michael Petlan) [2123231]
- perf clang: Fix header include for LLVM >= 14 (Michael Petlan) [2123231]
- perf bench: Fix numa bench to fix usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf bench: Fix numa testcase to check if CPU used to bind task is online (Michael Petlan) [2123231]
- perf record: Fix per-thread option (Michael Petlan) [2123231]
- perf tools: Fix segfault accessing sample_id xyarray (Michael Petlan) [2123231]
- perf stat: Fix error check return value of hashmap__new(), must use IS_ERR() (Michael Petlan) [2123231]
- perf tools: Fix misleading add event PMU debug message (Michael Petlan) [2123231]
- perf annotate: Drop objdump stderr to avoid getting stuck waiting for stdout output (Michael Petlan) [2123231]
- perf session: Remap buf if there is no space for event (Michael Petlan) [2123231]
- perf bench: Fix epoll bench to correct usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf bench: Fix futex bench to correct usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf tools: Fix perf's libperf_print callback (Michael Petlan) [2123231]
- perf: arm-spe: Fix perf report --mem-mode (Michael Petlan) [2123231]
- perf test tsc: Fix error message when not supported (Michael Petlan) [2123231]
- perf build: Don't use -ffat-lto-objects in the python feature test when building with clang-13 (Michael Petlan) [2123231]
- perf python: Fix probing for some clang command line options (Michael Petlan) [2123231]
- tools build: Filter out options and warnings not supported by clang (Michael Petlan) [2123231]
- tools build: Use $(shell ) instead of `` to get embedded libperl's ccopts (Michael Petlan) [2123231]
- perf python: Convert tracepoint.py example to python3 (Michael Petlan) [2123231]
- perf evlist: Directly return instead of using local ret variable (Michael Petlan) [2123231]
- perf cpumap: More cpu map reuse by merge. (Michael Petlan) [2123231]
- perf cpumap: Add is_subset function (Michael Petlan) [2123231]
- perf evlist: Rename cpus to user_requested_cpus (Michael Petlan) [2123231]
- perf tools: Stop depending on .git files for building PERF-VERSION-FILE (Michael Petlan) [2123231]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123231]
- perf stat: Avoid SEGV if core.cpus isn't set (Michael Petlan) [2123231]
- bpf: Sync comments for bpf_get_stack (Michael Petlan) [2123231]
- perf evsel: Improve AMD IBS (Instruction-Based Sampling) error handling messages (Michael Petlan) [2123231]
- perf python: Add perf_env stubs that will be needed in evsel__open_strerror() (Michael Petlan) [2123231]
- perf tools: Enhance the matching of sub-commands abbreviations (Michael Petlan) [2123231]
- tools arm64: Import cputype.h (Michael Petlan) [2123231]
- perf lock: Add -F/--field option to control output (Michael Petlan) [2123231]
- perf lock: Extend struct lock_key to have print function (Michael Petlan) [2123231]
- perf lock: Add --synth=no option for record (Michael Petlan) [2123231]
- perf stat: Fix forked applications enablement of counters (Michael Petlan) [2123231]
- perf evsel: Make evsel__env() always return a valid env (Michael Petlan) [2123231]
- perf script: Add 'brstackinsnlen' for branch stacks (Michael Petlan) [2123231]
- perf ftrace latency: Update documentation (Michael Petlan) [2123231]
- perf ftrace latency: Add -n/--use-nsec option (Michael Petlan) [2123231]
- perf tools: Fix version kernel tag (Michael Petlan) [2123231]
- perf tools: Fix dependency for version file creation (Michael Petlan) [2123231]
- perf vendor events intel: Update events for TremontX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Tigerlake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for SkylakeX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Skylake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for IcelakeX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Icelake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Elkhartlake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for CascadelakeX (Michael Petlan) [2123231]
- perf tools: Set build-id using build-id header on new mmap records (Michael Petlan) [2123231]
- tools compiler.h: Remove duplicate #ifndef noinline block (Michael Petlan) [2123231]
- perf tools: Use ARRAY_SIZE() instead of ad hoc equivalent, spotted by array_size.cocci (Michael Petlan) [2123231]
- perf script: Output branch sample type (Michael Petlan) [2123231]
- perf script: Refactor branch stack printing (Michael Petlan) [2123231]
- perf session: Print branch stack entry type in --dump-raw-trace (Michael Petlan) [2123231]
- perf evsel: Add error message for unsupported branch stack cases (Michael Petlan) [2123231]
- perf test: Add perf_event_attr tests for the arm_spe event (Michael Petlan) [2123231]
- perf vendor events intel: Add uncore event list for Alderlake (Michael Petlan) [2123231]
- perf vendor events intel: Add core event list for Alderlake (Michael Petlan) [2123231]
- perf jevents: Add support for HiSilicon CPA PMU aliasing (Michael Petlan) [2123231]
- libperf: Add API for allocating new thread map array (Michael Petlan) [2123231]
- libperf: Rename arguments of perf_thread_map APIs (Michael Petlan) [2123231]
- perf arm-spe: Use advertised caps/min_interval as default sample_period (Michael Petlan) [2123231]
- perf data: Don't mention --to-ctf if it's not supported (Michael Petlan) [2123231]
- perf data: Adding error message if perf_data__create_dir() fails (Michael Petlan) [2123231]
- perf report: Add "addr_from" and "addr_to" sort dimensions (Michael Petlan) [2123231]
- perf tools: Fix spelling mistake "commpressor" -> "compressor" (Michael Petlan) [2123231]
- perf annotate: Remove redundant 'ret' variable (Michael Petlan) [2123231]
- perf top: Remove redundant 'err' variable (Michael Petlan) [2123231]
- perf test: Make metric testing more robust (Michael Petlan) [2123231]
- perf cs-etm: Update deduction of TRCCONFIGR register for branch broadcast (Michael Petlan) [2123231]
- perf c2c: Replace bitmap_weight() with bitmap_empty() where appropriate (Michael Petlan) [2123231]
- perf tui: Only support --tui with slang (Michael Petlan) [2123231]
- perf intel-pt: Add documentation for Event Trace and TNT disable (Michael Petlan) [2123231]
- perf scripts python: export-to-postgresql.py: Export all sample flags (Michael Petlan) [2123231]
- perf scripts python: export-to-sqlite.py: Export all sample flags (Michael Petlan) [2123231]
- perf scripting python: Add all sample flags to DB export (Michael Petlan) [2123231]
- perf scripts python: intel-pt-events.py: Add Event Trace (Michael Petlan) [2123231]
- perf script: Display new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf script: Display Intel PT iflag synthesized event (Michael Petlan) [2123231]
- perf script: Display Intel PT CFE (Control Flow Event) / EVD (Event Data) synthesized event (Michael Petlan) [2123231]
- perf intel-pt: Force 'quick' mode when TNT (Taken/Not-Taken packet) is disabled (Michael Petlan) [2123231]
- perf intel-pt: Synthesize new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf intel-pt: Synthesize iflag event (Michael Petlan) [2123231]
- perf intel-pt: Synthesize CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2123231]
- perf intel-pt: Record Event Trace capability flag (Michael Petlan) [2123231]
- perf auxtrace: Add itrace option "I" (Michael Petlan) [2123231]
- perf tools: Define new D (Intr Disable) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf tools: Define Intel PT iflag synthesized event (Michael Petlan) [2123231]
- perf tools: Define Intel PT CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add MODE.Exec IFLAG processing (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add CFE (Control Flow Event) and EVD (Event Data) processing (Michael Petlan) [2123231]
- perf intel-pt: decoder: Factor out clearing of FUP (Flow Update) event variables (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add config bit definitions (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Add MODE.Exec IFLAG bit (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Add CFE and EVD packets (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Remove misplaced linebreak (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder-test: Fix scope of test_data (Michael Petlan) [2123231]
- perf vendor events: Update TremontX (Michael Petlan) [2123231]
- perf vendor events: Update Westmere EX (Michael Petlan) [2123231]
- perf vendor events: Update Westmere EP-SP (Michael Petlan) [2123231]
- perf vendor events: Update Tigerlake (Michael Petlan) [2123231]
- perf vendor events: Update Silvermont (Michael Petlan) [2123231]
- perf vendor events: Update Sandybridge (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Skylake (Michael Petlan) [2123231]
- perf vendor events: Update Nehalem EP (Michael Petlan) [2123231]
- perf vendor events: Update Knights Landing (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Jaketown (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Ivytown (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Icelake (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Haswell (Michael Petlan) [2123231]
- perf vendor events: Update for GoldmontPlus (Michael Petlan) [2123231]
- perf vendor events: Update for Goldmont (Michael Petlan) [2123231]
- perf vendor events: Update metrics for BroadwellX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Broadwell (Michael Petlan) [2123231]
- perf vendor events: Update for Bonnell (Michael Petlan) [2123231]
- perf vendor events: Update metrics for IcelakeX (Michael Petlan) [2123231]
- perf vendor events: Update for Westmere EP-DP (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Ivybridge (Michael Petlan) [2123231]
- perf vendor events: Update metrics for HaswellX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for CascadelakeX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Broadwell DE (Michael Petlan) [2123231]
- perf test: Allow skip for all metrics test (Michael Petlan) [2123231]
- perf map: Make map__contains_symbol() args const (Michael Petlan) [2123231]
- perf maps: Move maps code to own C file (Michael Petlan) [2123231]
- perf maps: Reduce scope of init and exit (Michael Petlan) [2123231]
- perf test: Use pointer for maps (Michael Petlan) [2123231]
- perf maps: Use a pointer for kmaps (Michael Petlan) [2123231]
- perf namespaces: Add functions to access nsinfo (Michael Petlan) [2123231]
- perf map: Add const to map_ip and unmap_ip (Michael Petlan) [2123231]
- perf cpumap: Use for each loop (Michael Petlan) [2123231]
- perf cpumap: Migrate to libperf cpumap api (Michael Petlan) [2123231]
- perf report: Output data file name in raw trace dump (Michael Petlan) [2123231]
- perf session: Load data directory files for analysis (Michael Petlan) [2123231]
- perf record: Implement compatibility checks (Michael Petlan) [2123231]
- perf record: Extend --threads command line option (Michael Petlan) [2123231]
- perf record: Introduce --threads command line option (Michael Petlan) [2123231]
- perf record: Introduce data transferred and compressed stats (Michael Petlan) [2123231]
- perf record: Introduce compressor at mmap buffer object (Michael Petlan) [2123231]
- perf record: Introduce bytes written stats (Michael Petlan) [2123231]
- perf record: Introduce data file at mmap buffer object (Michael Petlan) [2123231]
- perf record: Start threads in the beginning of trace streaming (Michael Petlan) [2123231]
- perf record: Stop threads in the end of trace streaming (Michael Petlan) [2123231]
- perf record: Introduce thread local variable (Michael Petlan) [2123231]
- perf record: Introduce function to propagate control commands (Michael Petlan) [2123231]
- perf record: Introduce thread specific data array (Michael Petlan) [2123231]
- tools lib: Introduce fdarray duplicate function (Michael Petlan) [2123231]
- perf record: Introduce thread affinity and mmap masks (Michael Petlan) [2123231]
- perf lock: Carefully combine lock stats for discarded entries (Michael Petlan) [2123231]
- perf lock: Add -c/--combine-locks option (Michael Petlan) [2123231]
- perf lock: Fix lock name length check for printing (Michael Petlan) [2123231]
- perf lock: Sort map info based on class name (Michael Petlan) [2123231]
- perf lock: Change type of lock_stat->addr to u64 (Michael Petlan) [2123231]
- perf lock: Convert lockhash_table to use hlist (Michael Petlan) [2123231]
- perf annotate: Try chroot filename for objdump (Michael Petlan) [2123231]
- perf inject: Try chroot directory when reading build-id (Michael Petlan) [2123231]
- perf tools: Try chroot'ed filename when opening dso/symbol (Michael Petlan) [2123231]
- tools/include: Add phys_addr_t to types.h (Michael Petlan) [2123231]
- perf: use generic bpf_program__set_type() to set BPF prog type (Michael Petlan) [2123231]
- perf/tests: Add AVX512-FP16 instructions to x86 instruction decoder test (Michael Petlan) [2123231]
- perf/tests: Add misc instructions to the x86 instruction decoder test (Michael Petlan) [2123231]
- perf/tests: Add AMX instructions to x86 instruction decoder test (Michael Petlan) [2123231]
- perf/x86/intel/lbr: Fix unchecked MSR access error on HSW (Michael Petlan) [2123231]
- perf/core: Fix data race between perf_event_set_output() and perf_mmap_close() (Michael Petlan) [2123231]
- perf/core: Remove unused local variable (Michael Petlan) [2123231]
- perf/x86/intel: Fix event constraints for ICL (Michael Petlan) [2123231]
- perf/x86/Kconfig: Fix indentation in the Kconfig file (Michael Petlan) [2123231]
- perf/x86/amd/core: Fix reloading events for SVM (Michael Petlan) [2123231]
- perf/x86/amd: Run AMD BRS code only on supported hw (Michael Petlan) [2123231]
- perf/x86/amd: Fix AMD BRS period adjustment (Michael Petlan) [2123231]
- perf/x86/amd: Remove unused variable 'hwc' (Michael Petlan) [2123231]
- perf/ibs: Fix comment (Michael Petlan) [2123231]
- perf/amd/ibs: Advertise zen4_ibs_extensions as pmu capability attribute (Michael Petlan) [2123231]
- perf/amd/ibs: Add support for L3 miss filtering (Michael Petlan) [2123231]
- perf/amd/ibs: Use ->is_visible callback for dynamic attributes (Michael Petlan) [2123231]
- perf/amd/ibs: Cascade pmu init functions' return value (Michael Petlan) [2123231]
- perf/amd/ibs: Use interrupt regs ip for stack unwinding (Michael Petlan) [2123231]
- perf/x86/amd/core: Add PerfMonV2 overflow handling (Michael Petlan) [2123231]
- perf/x86/amd/core: Add PerfMonV2 counter control (Michael Petlan) [2123231]
- perf/x86/amd/core: Detect available counters (Michael Petlan) [2123231]
- perf/x86/amd/core: Detect PerfMonV2 support (Michael Petlan) [2123231]
- x86/msr: Add PerfCntrGlobal* registers (Michael Petlan) [2123231]
- x86/cpufeatures: Add PerfMonV2 feature bit (Michael Petlan) [2123231]
- signal: Deliver SIGTRAP on perf event asynchronously if blocked (Michael Petlan) [2123231]
- perf/x86: Unify format of events sysfs show (Michael Petlan) [2123231]
- perf/x86/amd: Add idle hooks for branch sampling (Michael Petlan) [2123231]
- ACPI: Add perf low power callback (Michael Petlan) [2123231]
- perf/x86/amd: Make Zen3 branch sampling opt-in (Michael Petlan) [2123231]
- perf/x86/amd: Add AMD branch sampling period adjustment (Michael Petlan) [2123231]
- perf/x86/amd: Enable branch sampling priv level filtering (Michael Petlan) [2123231]
- perf/x86/amd: Add branch-brs helper event for Fam19h BRS (Michael Petlan) [2123231]
- perf/x86/amd: Add AMD Fam19h Branch Sampling support (Michael Petlan) [2123231]
- perf/core: Add perf_clear_branch_entry_bitfields() helper (Michael Petlan) [2123231]
- perf/core: Fix perf_mmap fail when CONFIG_PERF_USE_VMALLOC enabled (Michael Petlan) [2123231]
- perf/core: Always set cpuctx cgrp when enable cgroup event (Michael Petlan) [2123231]
- perf/core: Fix perf_cgroup_switch() (Michael Petlan) [2123231]
- perf/core: Use perf_cgroup_info->active to check if cgroup is active (Michael Petlan) [2123231]
- perf/core: Don't pass task around when ctx sched in (Michael Petlan) [2123231]
- perf/core: Inherit event_caps (Michael Petlan) [2123231]
- perf/x86/intel/uncore: Fix the build on !CONFIG_PHYS_ADDR_T_64BIT (Michael Petlan) [2123231]
- perf: Add irq and exception return branch types (Michael Petlan) [2123231]
- perf/x86/intel/pt: Add a capability and config bit for disabling TNTs (Michael Petlan) [2123231]
- perf/x86/intel/pt: Add a capability and config bit for event tracing (Michael Petlan) [2123231]
- perf/x86/intel: Increase max number of the fixed counters (Michael Petlan) [2123231]
- perf/x86/intel: Enable PEBS format 5 (Michael Petlan) [2123231]
- perf/core: Allow kernel address filter when not filtering the kernel (Michael Petlan) [2123231]
- perf/x86/intel/pt: Fix address filter config for 32-bit kernel (Michael Petlan) [2123231]
- perf/core: Fix address filter parser for multiple filters (Michael Petlan) [2123231]
- drivers/perf: arm_pmu: Handle 47 bit counters (Michael Petlan) [2123231]
- x86: clean up symbol aliasing (Michael Petlan) [2123231]
- linkage: remove SYM_FUNC_{START,END}_ALIAS() (Michael Petlan) [2123231]
- af_key: Do not call xfrm_probe_algs in parallel (Sabrina Dubroca) [2122370] {CVE-2022-3028}

* Sat Nov 05 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-187.el9]
- drm/mgag200: Fix PLL setup for G200_SE_A rev >=4 (Jocelyn Falempe) [1960467]
- mm: slub: fix flush_cpu_slab()/__free_slab() invocations in task context. (Izabela Bakollari) [2091165]
- redhat/docs: Update with DISTLOCALVERSION (Frantisek Hrbata)
- redhat/Makefile: Rename LOCALVERSION to DISTLOCALVERSION (Frantisek Hrbata)
- net: move netif_set_gso_max helpers (Ivan Vecera) [2128180]
- net: make drivers set the TSO limit not the GSO limit (Ivan Vecera) [2128180]
- net: don't allow user space to lift the device limits (Ivan Vecera) [2128180]
- net: add netif_inherit_tso_max() (Ivan Vecera) [2128180]
- net: extract a few internals from netdevice.h (Ivan Vecera) [2128180]
- net: unexport a handful of dev_* functions (Ivan Vecera) [2128180]
- net: remove .ndo_change_proto_down (Ivan Vecera) [2128180]
- tipc: fix an information leak in tipc_topsrv_kern_subscr (Xin Long) [2134964]
- tipc: Fix recognition of trial period (Xin Long) [2134964]
- tipc: fix shift wrapping bug in map_get() (Xin Long) [2134964]
- scsi: mpi3mr: Schedule IRQ kthreads only on non-RT kernels (Tomas Henzl) [2136223]
- drm: fix duplicated code in drm_connector_register (Karol Herbst) [2132575]
- iavf: Fix adminq error handling (Petr Oros) [2003608]

* Thu Nov 03 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-186.el9]
- perf/arm-cmn: Decode CAL devices properly in debugfs (Jeremy Linton) [2118804]
- perf/arm-cmn: Fix filter_sel lookup (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CMN-700 support (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor occupancy filter selector (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CMN-650 support (Jeremy Linton) [2118804]
- dt-bindings: perf: arm-cmn: Add CMN-650 and CMN-700 (Jeremy Linton) [2118804]
- perf/arm-cmn: Update watchpoint format (Jeremy Linton) [2118804]
- perf/arm-cmn: Hide XP PUB events for CMN-600 (Jeremy Linton) [2118804]
- perf/arm-cmn: Make arm_cmn_debugfs static (Jeremy Linton) [2118804]
- perf/arm-cmn: Add debugfs topology info (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CI-700 Support (Jeremy Linton) [2118804]
- dt-bindings: perf: arm-cmn: Add CI-700 (Jeremy Linton) [2118804]
- perf/arm-cmn: Support new IP features (Jeremy Linton) [2118804]
- perf/arm-cmn: Demarcate CMN-600 specifics (Jeremy Linton) [2118804]
- perf/arm-cmn: Move group validation data off-stack (Jeremy Linton) [2118804]
- perf/arm-cmn: Optimise DTC counter accesses (Jeremy Linton) [2118804]
- perf/arm-cmn: Optimise DTM counter reads (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor DTM handling (Jeremy Linton) [2118804]
- perf/arm-cmn: Streamline node iteration (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor node ID handling (Jeremy Linton) [2118804]
- perf/arm-cmn: Drop compile-test restriction (Jeremy Linton) [2118804]
- perf/arm-cmn: Account for NUMA affinity (Jeremy Linton) [2118804]
- perf/arm-cmn: Fix CPU hotplug unregistration (Jeremy Linton) [2118804]
- selftests: cgroup: add a selftest for memory.reclaim (Waiman Long) [1880574]
- selftests: cgroup: fix alloc_anon_noexit() instantly freeing memory (Waiman Long) [1880574]
- selftests: cgroup: return -errno from cg_read()/cg_write() on failure (Waiman Long) [1880574]
- selftests: memcg: test high limit for single entry allocation (Waiman Long) [1880574]
- memcg: introduce per-memcg reclaim interface (Waiman Long) [1880574]
- spec: fix path to `installing_core` stamp file for subpackages (Jonathan Lebon) [2134215]
- redhat/configs: enable RTC_DRV_RV8803 for x86_64 (David Arcari) [2136121]
- rtc: rv8803: fix missing unlock on error in rv8803_set_time() (David Arcari) [2136121]
- rtc: rv8803: re-initialize all Epson RX8803 registers on voltage loss (David Arcari) [2136121]
- rtc: rv8803: initialize registers on post-probe voltage loss (David Arcari) [2136121]
- rtc: rv8803: factor out existing register initialization to function (David Arcari) [2136121]
- rtc: rv8803: Add support for the Epson RX8804 RTC (David Arcari) [2136121]
- rtc: rv8803: fix writing back ctrl in flag register (David Arcari) [2136121]
- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse (Waiman Long) [2137587] {CVE-2022-42703}
- mm/rmap: Fix typos in comments (Waiman Long) [2137587] {CVE-2022-42703}
- blk-mq: don't add non-pt request with ->end_io to batch (Ming Lei) [2131144]
- blktrace: remove unnessary stop block trace in 'blk_trace_shutdown' (Ming Lei) [2131144]
- blktrace: fix possible memleak in '__blk_trace_remove' (Ming Lei) [2131144]
- blktrace: introduce 'blk_trace_{start,stop}' helper (Ming Lei) [2131144]
- bio: safeguard REQ_ALLOC_CACHE bio put (Ming Lei) [2131144]
- block, bfq: remove unused variable for bfq_queue (Ming Lei) [2131144]
- drbd: only clone bio if we have a backing device (Ming Lei) [2131144]
- blk-mq: fix null pointer dereference in blk_mq_clear_rq_mapping() (Ming Lei) [2131144]
- block: fix leaking minors of hidden disks (Ming Lei) [2131144]
- block: avoid sign extend problem with default queue flags mask (Ming Lei) [2131144]
- blk-wbt: fix that 'rwb->wc' is always set to 1 in wbt_init() (Ming Lei) [2131144]
- block: Remove the repeat word 'can' (Ming Lei) [2131144]
- sbitmap: fix lockup while swapping (Ming Lei) [2131144]
- block: add rationale for not using blk_mq_plug() when applicable (Ming Lei) [2131144]
- block: adapt blk_mq_plug() to not plug for writes that require a zone lock (Ming Lei) [2131144]
- blk-cgroup: don't update the blkg lookup hint in blkg_conf_prep (Ming Lei) [2131144]
- blk-mq: use quiesced elevator switch when reinitializing queues (Ming Lei) [2131144]
- block: replace blk_queue_nowait with bdev_nowait (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to the blkg allocation helpers (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkcg_schedule_throttle (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkg_destroy_all (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_cancel_bios (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_register_queue (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_init and blk_throtl_exit (Ming Lei) [2131144]
- blk-iocost: cleanup ioc_qos_write (Ming Lei) [2131144]
- blk-iocost: pass a gendisk to blk_iocost_init (Ming Lei) [2131144]
- blk-iocost: simplify ioc_name (Ming Lei) [2131144]
- blk-iolatency: pass a gendisk to blk_iolatency_init (Ming Lei) [2131144]
- blk-ioprio: pass a gendisk to blk_ioprio_init and blk_ioprio_exit (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkcg_init_queue and blkcg_exit_queue (Ming Lei) [2131144]
- blk-cgroup: remove blkg_lookup_check (Ming Lei) [2131144]
- blk-cgroup: cleanup the blkg_lookup family of functions (Ming Lei) [2131144]
- blk-cgroup: remove open coded blkg_lookup instances (Ming Lei) [2131144]
- blk-cgroup: remove blk_queue_root_blkg (Ming Lei) [2131144]
- blk-cgroup: fix error unwinding in blkcg_init_queue (Ming Lei) [2131144]
- blk-mq: don't redirect completion for hctx withs only one ctx mapping (Ming Lei) [2131144]
- blk-throttle: improve bypassing bios checkings (Ming Lei) [2131144]
- blk-throttle: remove THROTL_TG_HAS_IOPS_LIMIT (Ming Lei) [2131144]
- block/blk-rq-qos: delete useless enmu RQ_QOS_IOPRIO (Ming Lei) [2131144]
- block: aoe: use DEFINE_SHOW_ATTRIBUTE to simplify aoe_debugfs (Ming Lei) [2131144]
- block: move from strlcpy with unused retval to strscpy (Ming Lei) [2131144]
- block/drbd: remove useless comments in receive_DataReply() (Ming Lei) [2131144]
- drbd: remove orphan _req_may_be_done() declaration (Ming Lei) [2131144]
- blk-wbt: call rq_qos_add() after wb_normal is initialized (Ming Lei) [2131144]
- rnbd-srv: remove struct rnbd_dev (Ming Lei) [2131144]
- rnbd-srv: remove rnbd_dev_{open,close} (Ming Lei) [2131144]
- rnbd-srv: remove rnbd_endio (Ming Lei) [2131144]
- rnbd-srv: simplify rnbd_srv_fill_msg_open_rsp (Ming Lei) [2131144]
- block: Fix the enum blk_eh_timer_return documentation (Ming Lei) [2131144]
- blk-iocost: Remove unnecessary (void*) conversions (Ming Lei) [2131144]
- block: remove PSI accounting from the bio layer (Ming Lei) [2131144]
- sched/psi: export psi_memstall_{enter,leave} (Ming Lei) [2131144]
- mm: add PSI accounting around ->read_folio and ->readahead calls (Ming Lei) [2131144]
- block: fix comment typo in submit_bio of block-core.c. (Ming Lei) [2131144]
- block/drbd: remove unused w_start_resync declaration (Ming Lei) [2131144]
- blk-throttle: cleanup tg_update_disptime() (Ming Lei) [2131144]
- blk-throttle: calling throtl_dequeue/enqueue_tg in pairs (Ming Lei) [2131144]
- blk-throttle: use 'READ/WRITE' instead of '0/1' (Ming Lei) [2131144]
- blk-throttle: fix io hung due to configuration updates (Ming Lei) [2131144]
- blk-throttle: factor out code to calculate ios/bytes_allowed (Ming Lei) [2131144]
- blk-throttle: prevent overflow while calculating wait time (Ming Lei) [2131144]
- blk-throttle: fix that io throttle can only work for single bio (Ming Lei) [2131144]
- sbitmap: fix batched wait_cnt accounting (Ming Lei) [2131144]
- sbitmap: Use atomic_long_try_cmpxchg in __sbitmap_queue_get_batch (Ming Lei) [2131144]
- nbd: Fix hung when signal interrupts nbd_start_device_ioctl() (Ming Lei) [2131144]
- sbitmap: Avoid leaving waitqueue in invalid state in __sbq_wake_up() (Ming Lei) [2131144]
- rnbd-srv: remove redundant setting of blk_open_flags (Ming Lei) [2131144]
- rnbd-srv: make process_msg_close returns void (Ming Lei) [2131144]
- rnbd-srv: add comment in rnbd_srv_rdma_ev (Ming Lei) [2131144]
- block: remove unneeded return value of bio_check_ro() (Ming Lei) [2131144]
- blk-mq: remove unneeded needs_restart check (Ming Lei) [2131144]
- blk-throttle: clean up codes that can't be reached (Ming Lei) [2131144]
- Revert "sbitmap: fix batched wait_cnt accounting" (Ming Lei) [2131144]
- block: enable per-cpu bio caching for the fs bio set (Ming Lei) [2131144]
- sbitmap: fix batched wait_cnt accounting (Ming Lei) [2131144]
- sbitmap: remove unnecessary code in __sbitmap_queue_get_batch (Ming Lei) [2131144]
- block/rnbd-clt: Remove the unneeded result variable (Ming Lei) [2131144]
- sbitmap: fix possible io hung due to lost wakeup (Ming Lei) [2131144]
- block: shrink rq_map_data a bit (Ming Lei) [2131144]
- block, bfq: remove useless parameter for bfq_add/del_bfqq_busy() (Ming Lei) [2131144]
- block, bfq: remove useless checking in bfq_put_queue() (Ming Lei) [2131144]
- block, bfq: remove unused functions (Ming Lei) [2131144]
- block: Change the return type of blk_mq_map_queues() into void (Ming Lei) [2131144]
- null_blk: Modify the behavior of null_map_queues() (Ming Lei) [2131144]
- block/rnbd-srv: Add event tracing support (Ming Lei) [2131144]
- block: sed-opal: Add ioctl to return device status (Ming Lei) [2131144]
- block: extend functionality to map bvec iterator (Ming Lei) [2131144]
- block: factor out blk_rq_map_bio_alloc helper (Ming Lei) [2131144]
- block: rename bio_map_put to blk_mq_map_bio_put (Ming Lei) [2131144]
- block: enable bio caching use for passthru IO (Ming Lei) [2131144]
- block: add blk_rq_map_user_io (Ming Lei) [2131144]
- block: allow end_io based requests in the completion batch handling (Ming Lei) [2131144]
- block: change request end_io handler to pass back a return value (Ming Lei) [2131144]
- block: enable batched allocation for blk_mq_alloc_request() (Ming Lei) [2131144]
- block: kill deprecated BUG_ON() in the flush handling (Ming Lei) [2131144]
- virtio-blk: validate num_queues during probe (Ming Lei) [2131144]
- selftests/bpf: Limit unroll_count for pyperf600 test (Frantisek Hrbata) [2139836]
- devdax: Fix soft-reservation memory description (Mark Langsdorf) [2122317]
- ACPI: CPPC: Fix enabling CPPC on AMD systems with shared memory (Mark Langsdorf) [2122317]
- arm64: cacheinfo: Fix incorrect assignment of signed error value to unsigned fw_level (Mark Langsdorf) [2122317]
- ACPI: property: Remove default association from integer maximum values (Mark Langsdorf) [2122317]
- ACPI: property: Ignore already existing data node tags (Mark Langsdorf) [2122317]
- ACPI: property: Fix type detection of unified integer reading functions (Mark Langsdorf) [2122317]
- ACPI: processor: Remove freq Qos request for all CPUs (Mark Langsdorf) [2122317]
- ACPI: CPPC: Do not prevent CPPC from working in the future (Mark Langsdorf) [2122317]
- ACPI: CPPC: Don't require flexible address space if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: Don't require _OSC if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: fix typo in comment (Mark Langsdorf) [2122317]
- cpufreq: CPPC: Enable fast_switch (Mark Langsdorf) [2122317]
- ACPI: CPPC: Assume no transition latency if no PCCT (Mark Langsdorf) [2122317]
- ACPI: bus: Set CPPC _OSC bits for all and when CPPC_LIB is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: Check _OSC for flexible address space (Mark Langsdorf) [2122317]
- ACPI: property: Fix error handling in acpi_init_properties() (Mark Langsdorf) [2122317]
- ACPI: VIOT: Do not dereference fwnode in struct device (Mark Langsdorf) [2122317]
- ACPI/PCI: Remove useless NULL pointer checks (Mark Langsdorf) [2122317]
- ACPI: property: Read buffer properties as integers (Mark Langsdorf) [2122317]
- ACPI: property: Add support for parsing buffer property UUID (Mark Langsdorf) [2122317]
- ACPI: property: Unify integer value reading functions (Mark Langsdorf) [2122317]
- ACPI: property: Switch node property referencing from ifs to a switch (Mark Langsdorf) [2122317]
- ACPI: property: Move property ref argument parsing into a new function (Mark Langsdorf) [2122317]
- ACPI: property: Use acpi_object_type consistently in property ref parsing (Mark Langsdorf) [2122317]
- ACPI: property: Tie data nodes to acpi handles (Mark Langsdorf) [2122317]
- ACPI: property: Return type of acpi_add_nondev_subnodes() should be bool (Mark Langsdorf) [2122317]
- ACPI: PM: x86: Print messages regarding LPS0 idle support (Mark Langsdorf) [2122317]
- ACPI: PPTT: Leave the table mapped for the runtime usage (Mark Langsdorf) [2122317]
- ACPI: resource: skip IRQ override on AMD Zen platforms (Mark Langsdorf) [2122317]
- ACPI: irq: Allow acpi_gsi_to_irq() to have an arch-specific fallback (Mark Langsdorf) [2122317]
- APCI: irq: Add support for multiple GSI domains (Mark Langsdorf) [2122317]
- ACPI: video: Use native backlight on Dell Inspiron N4010 (Mark Langsdorf) [2122317]
- ACPI: PM: s2idle: Use LPS0 idle if ACPI_FADT_LOW_POWER_S0 is unset (Mark Langsdorf) [2122317]
- Revert "ACPI / PM: LPIT: Register sysfs attributes based on FADT" (Mark Langsdorf) [2122317]
- ACPI: utils: Add api to read _SUB from ACPI (Mark Langsdorf) [2122317]
- PCI: loongson: Add ACPI init support (Mark Langsdorf) [2122317]
- ACPI: video: Shortening quirk list by identifying Clevo by board_name only (Mark Langsdorf) [2122317]
- ACPI: video: Force backlight native for some TongFang devices (Mark Langsdorf) [2122317]
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (Mark Langsdorf) [2122317]
- ACPI: PM: s2idle: Add support for upcoming AMD uPEP HID AMDI008 (Mark Langsdorf) [2122317]
- ACPI: PPTT: Use table offset as fw_token instead of virtual address (Mark Langsdorf) [2122317]
- ACPI: Move PRM config option under the main ACPI config (Mark Langsdorf) [2122317]
- ACPI: Enable Platform Runtime Mechanism(PRM) support on ARM64 (Mark Langsdorf) [2122317]
- efi: Simplify arch_efi_call_virt() macro (Mark Langsdorf) [2122317]
- ACPI: PRM: Change handler_addr type to void pointer (Mark Langsdorf) [2122317]
- ACPI: bus: Drop driver member of struct acpi_device (Mark Langsdorf) [2122317]
- ACPI: bus: Drop redundant check in acpi_device_remove() (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix _EINJ vs EFI_MEMORY_SP (Mark Langsdorf) [2122317]
- ACPI: LPSS: Fix missing check in register_device_clock() (Mark Langsdorf) [2122317]
- ACPI: APEI: Better fix to avoid spamming the console with old error logs (Mark Langsdorf) [2122317]
- ACPI: PM: save NVS memory for Lenovo G40-45 (Mark Langsdorf) [2122317]
- ACPI: EC: Drop unused ident initializers from dmi_system_id tables (Mark Langsdorf) [2122317]
- ACPI: EC: Re-use boot_ec when possible even when EC_FLAGS_TRUST_DSDT_GPE is set (Mark Langsdorf) [2122317]
- ACPI: EC: Drop the EC_FLAGS_IGNORE_DSDT_GPE quirk (Mark Langsdorf) [2122317]
- ACPI: EC: Remove duplicate ThinkPad X1 Carbon 6th entry from DMI quirks (Mark Langsdorf) [2122317]
- ACPI: processor: Drop leftover acpi_processor_get_limit_info() declaration (Mark Langsdorf) [2122317]
- ACPI: processor: Split out thermal initialization from ACPI PSS (Mark Langsdorf) [2122317]
- redhat/configs: move CONFIG_ACPI_VIDEO to common/generic (Mark Langsdorf) [2122317]
- ACPI: video: Drop X86 dependency from Kconfig (Mark Langsdorf) [2122317]
- ACPI: video: Fix acpi_video_handles_brightness_key_presses() (Mark Langsdorf) [2122317]
- ACPI: video: Change how we determine if brightness key-presses are handled (Mark Langsdorf) [2122317]
- ACPI / MMC: PM: Unify fixing up device power (Mark Langsdorf) [2122317]
- mmc: sdhci-acpi: Use the new soc_intel_is_byt() helper (Mark Langsdorf) [2122317]
- mmc: sdhci-acpi: Remove special handling for GPD win/pocket devices (Mark Langsdorf) [2122317]
- ACPI: scan: Walk ACPI device's children using driver core (Mark Langsdorf) [2122317]
- ACPI: bus: Introduce acpi_dev_for_each_child_reverse() (Mark Langsdorf) [2122317]
- ACPI: video: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: bus: Export acpi_dev_for_each_child() to modules (Mark Langsdorf) [2122317]
- ACPI: property: Use acpi_dev_for_each_child() for child lookup (Mark Langsdorf) [2122317]
- ACPI: container: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: glue: Introduce acpi_find_child_by_adr() (Mark Langsdorf) [2122317]
- ACPI: glue: Introduce acpi_dev_has_children() (Mark Langsdorf) [2122317]
- ACPI: glue: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: glue: Use acpi_device_adr() in acpi_find_child_device() (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix double word in a comment (Mark Langsdorf) [2122317]
- ACPI: processor/idle: Annotate more functions to live in cpuidle section (Mark Langsdorf) [2122317]
- ACPI: video: improve PM notifer callback (Mark Langsdorf) [2122317]
- ACPI: utils: include UUID in _DSM evaluation warning (Mark Langsdorf) [2122317]
- acpi/nfit: rely on mce->misc to determine poison granularity (Mark Langsdorf) [2122317]
- ACPI: PM: Block ASUS B1400CEAE from suspend to idle by default (Mark Langsdorf) [2122317]
- ACPI: clean up white space in a few places for consistency (Mark Langsdorf) [2122317]
- ACPI: glue: Rearrange find_child_checks() (Mark Langsdorf) [2122317]
- ACPI: DPTF: Add support for high frequency impedance notification (Mark Langsdorf) [2122317]
- ACPI: processor: idle: Expose max_cstate/nocst/bm_check_disable read-only in sysfs (Mark Langsdorf) [2122317]
- ACPI: battery: Make "not-charging" the default on no charging or full info (Mark Langsdorf) [2122317]
- PCI/ACPI: negotiate CXL _OSC (Mark Langsdorf) [2122317]
- PCI/ACPI: Prefer CXL _OSC instead of PCIe _OSC for CXL host bridges (Mark Langsdorf) [2122317]
- PCI/ACPI: add a helper for retrieving _OSC Control DWORDs (Mark Langsdorf) [2122317]
- ACPI: OSL: Remove the helper for deactivating memory region (Mark Langsdorf) [2122317]
- ACPI: bus: Avoid non-ACPI device objects in walks over children (Mark Langsdorf) [2122317]
- ACPI: DPTF: Correct description of INT3407 / INT3532 attributes (Mark Langsdorf) [2122317]
- ACPI: BGRT: use static for BGRT_SHOW kobj_attribute defines (Mark Langsdorf) [2122317]
- ACPI, APEI, EINJ: Refuse to inject into the zero page (Mark Langsdorf) [2122317]
- ACPI: PM: Always print final debug message in acpi_device_set_power() (Mark Langsdorf) [2122317]
- ACPI: SPCR: Add support for NVIDIA 16550-compatible port subtype (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix missing ERST record id (Mark Langsdorf) [2122317]
- ACPICA: iASL/MADT: Add OEM-defined subtable (Mark Langsdorf) [2122317]
- ACPICA: Add support for ARM Performance Monitoring Unit Table. (Mark Langsdorf) [2122317]
- ACPICA: Headers: Replace zero-length array with flexible-array member (Mark Langsdorf) [2122317]
- ACPICA: Removed some tabs and // comments (Mark Langsdorf) [2122317]
- ACPICA: Update copyright notices to the year 2022 (Mark Langsdorf) [2122317]
- ACPICA: Clean up double word in comment (Mark Langsdorf) [2122317]
- ACPICA: Add new ACPI 6.4 semantics for LoadTable() operator (Mark Langsdorf) [2122317]
- ACPICA: Add new ACPI 6.4 semantics to the Load() operator (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Rename linux specific strucures to device_info (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Fix parsing undocumented bytes at the end of Endpoint Descriptor (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Treat Terminator as specific_config (Mark Langsdorf) [2122317]
- ACPICA: Add the subtable CFMWS to the CEDT table (Mark Langsdorf) [2122317]
- ACPICA: Add support for the Windows 11 _OSI string (Mark Langsdorf) [2122317]
- ACPI: property: Release subnode properties with data nodes (Mark Langsdorf) [2122317]
- PCI: ACPI: PM: Power up devices in D3cold before scanning them (Mark Langsdorf) [2122317]
- ACPI: PM: Introduce acpi_dev_power_up_children_with_adr() (Mark Langsdorf) [2122317]
- ACPI: bus: Introduce acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: PM: Unify debug messages in acpi_device_set_power() (Mark Langsdorf) [2122317]
- ACPI: PM: Change pr_fmt() in device_pm.c (Mark Langsdorf) [2122317]
- ACPI: PM: Convert debug message in acpi_device_get_power() (Mark Langsdorf) [2122317]
- ACPI: property: Move acpi_fwnode_device_get_match_data() up (Mark Langsdorf) [2122317]
- ACPI: Add perf low power callback (Mark Langsdorf) [2122317]

* Wed Nov 02 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-185.el9]
- drm/amdgpu: make sure to init common IP before gmc (Myron Stowe) [2124638]
- drm/amdgpu: move nbio sdma_doorbell_range() into sdma code for vega (Myron Stowe) [2124638]
- drm/amdgpu: move nbio ih_doorbell_range() into ih code for vega (Myron Stowe) [2124638]
- drm/amdgpu: Don't enable LTR if not supported (Myron Stowe) [2124638]
- PCI: imx6: Support more than Gen2 speed link mode (Myron Stowe) [2124638]
- PCI: imx6: Set PCIE_DBI_RO_WR_EN before writing DBI registers (Myron Stowe) [2124638]
- PCI: imx6: Reformat suspend callback to keep symmetric with resume (Myron Stowe) [2124638]
- PCI: imx6: Move the imx6_pcie_ltssm_disable() earlier (Myron Stowe) [2124638]
- PCI: imx6: Disable clocks in reverse order of enable (Myron Stowe) [2124638]
- PCI: imx6: Do not hide PHY driver callbacks and refine the error handling (Myron Stowe) [2124638]
- PCI: imx6: Reduce resume time by only starting link if it was up before suspend (Myron Stowe) [2124638]
- PCI: imx6: Mark the link down as non-fatal error (Myron Stowe) [2124638]
- PCI: imx6: Move regulator enable out of imx6_pcie_deassert_core_reset() (Myron Stowe) [2124638]
- PCI: imx6: Turn off regulator when system is in suspend mode (Myron Stowe) [2124638]
- PCI: imx6: Call host init function directly in resume (Myron Stowe) [2124638]
- PCI: imx6: Disable i.MX6QDL clock when disabling ref clocks (Myron Stowe) [2124638]
- PCI: imx6: Propagate .host_init() errors to caller (Myron Stowe) [2124638]
- PCI: imx6: Collect clock enables in imx6_pcie_clk_enable() (Myron Stowe) [2124638]
- PCI: imx6: Factor out ref clock disable to match enable (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_clk_disable() earlier (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_enable_ref_clk() earlier (Myron Stowe) [2124638]
- PCI: imx6: Move PHY management functions together (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_grp_offset(), imx6_pcie_configure_type() earlier (Myron Stowe) [2124638]
- PCI: imx6: Convert to NOIRQ_SYSTEM_SLEEP_PM_OPS() (Myron Stowe) [2124638]
- PCI: exynos: Correct generic PHY usage (Myron Stowe) [2124638]
- phy: samsung: phy-exynos-pcie: sanitize init/power_on callbacks (Myron Stowe) [2124638]
- dt-bindings: PCI: qcom: Support additional MSI vectors (Myron Stowe) [2124638]
- PCI: dwc: Handle MSIs routed to multiple GIC interrupts (Myron Stowe) [2124638]
- PCI: dwc: Convert struct pcie_port.msi_irq to an array (Myron Stowe) [2124638]
- PCI: dwc: Split MSI IRQ parsing/allocation to a separate function (Myron Stowe) [2124638]
- PCI: dwc: Correct msi_irq condition in dw_pcie_free_msi() (Myron Stowe) [2124638]
- PCI: dwc: Use the bitmap API to allocate bitmaps (Myron Stowe) [2124638]
- PCI: dwc: Fix MSI msi_msg DMA mapping (Myron Stowe) [2124638]
- PCI: dwc: Check iATU in/outbound range setup status (Myron Stowe) [2124638]
- PCI: dwc: Validate iATU outbound mappings against hardware constraints (Myron Stowe) [2124638]
- PCI: dwc: Add iATU regions size detection procedure (Myron Stowe) [2124638]
- PCI: dwc: Simplify in/outbound iATU setup methods (Myron Stowe) [2124638]
- PCI: dwc: Drop enum dw_pcie_region_type in favor of PCIE_ATU_REGION_DIR_IB/OB (Myron Stowe) [2124638]
- PCI: dwc: Drop enum dw_pcie_as_type in favor of PCIE_ATU_TYPE_MEM/IO (Myron Stowe) [2124638]
- PCI: dwc: Add dw_pcie_ops.host_deinit() callback (Myron Stowe) [2124638]
- PCI: tegra194: Drop manual DW PCIe controller version setup (Myron Stowe) [2124638]
- PCI: intel-gw: Drop manual DW PCIe controller version setup (Myron Stowe) [2124638]
- PCI: dwc: Add macros to compare Synopsys IP core versions (Myron Stowe) [2124638]
- PCI: dwc: Read DWC IP core version from register (Myron Stowe) [2124638]
- PCI: dwc: Use native DWC IP core version representation (Myron Stowe) [2124638]
- PCI: dwc: Detect iATU settings after getting "addr_space" resource (Myron Stowe) [2124638]
- PCI: dwc: Log link speed and width if it comes up (Myron Stowe) [2124638]
- PCI: qcom: Allow ASPM L1 and substates for 2.7.0 (Myron Stowe) [2124638]
- sparc: Use generic pci_mmap_resource_range() (Myron Stowe) [2124638]
- PCI: Remove pci_mmap_page_range() wrapper (Myron Stowe) [2124638]
- PCI: Stub __pci_ioport_map() for arches that don't support it at all (Myron Stowe) [2124638]
- PCI: Convert to new *_PM_OPS macros (Myron Stowe) [2124638]
- PCI: brcmstb: Rename .map_bus() functions to end with 'map_bus' (Myron Stowe) [2124638]
- PCI: brcmstb: Disable/enable regulators in suspend/resume (Myron Stowe) [2124638]
- PCI: brcmstb: Enable child bus device regulators from DT (Myron Stowe) [2124638]
- PCI: brcmstb: Split post-link up initialization to brcm_pcie_start_link() (Myron Stowe) [2124638]
- PCI: brcmstb: Prevent config space access when link is down (Myron Stowe) [2124638]
- PCI: brcmstb: Remove unnecessary forward declarations (Myron Stowe) [2124638]
- x86/cyrix: include header linux/isa-dma.h (Myron Stowe) [2124638]
- asm-generic: Add new pci.h and use it (Myron Stowe) [2124638]
- csky: PCI: Define ARCH_GENERIC_PCI_MMAP_RESOURCE (Myron Stowe) [2124638]
- PCI: Move isa_dma_bridge_buggy out of asm/dma.h (Myron Stowe) [2124638]
- PCI: Remove pci_get_legacy_ide_irq() and asm-generic/pci.h (Myron Stowe) [2124638]
- PCI: tegra194: Add Tegra234 PCIe support (Myron Stowe) [2124638]
- PCI: tegra194: Extend Endpoint mode support (Myron Stowe) [2124638]
- PCI: tegra194: Fix link up retry sequence (Myron Stowe) [2124638]
- PCI: tegra194: Clean up the exit path for Endpoint mode (Myron Stowe) [2124638]
- PCI: tegra194: Enable support for 256 Byte payload (Myron Stowe) [2124638]
- PCI: tegra194: Clear bandwidth management status (Myron Stowe) [2124638]
- PCI: tegra194: Fix Root Port interrupt handling (Myron Stowe) [2124638]
- PCI: tegra194: Find RAS DES PCIe capability offset (Myron Stowe) [2124638]
- Revert "PCI: tegra194: Rename tegra_pcie_dw to tegra194_pcie" (Myron Stowe) [2124638]
- PCI: Disable MSI for Tegra234 Root Ports (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra234: Add schema for tegra234 Endpoint mode (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra234: Add schema for tegra234 Root Port mode (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra194: Convert to json-schema (Myron Stowe) [2124638]
- s390/pci: allow zPCI zbus without a function zero (Myron Stowe) [2124638]
- PCI: Extend isolated function probing to s390 (Myron Stowe) [2124638]
- PCI: Move jailhouse's isolated function handling to pci_scan_slot() (Myron Stowe) [2124638]
- PCI: Split out next_ari_fn() from next_fn() (Myron Stowe) [2124638]
- PCI: Clean up pci_scan_slot() (Myron Stowe) [2124638]
- PCI/ACPI: Update link to PCI firmware specification (Myron Stowe) [2124638]
- MAINTAINERS: Add Xilinx Versal CPM Root Port maintainers (Myron Stowe) [2124638]
- PCI: xilinx-cpm: Add support for Versal CPM5 Root Port (Myron Stowe) [2124638]
- dt-bindings: PCI: xilinx-cpm: Add Versal CPM5 Root Port (Myron Stowe) [2124638]
- PCI: loongson: Work around LS7A incorrect Interrupt Pin registers (Myron Stowe) [2124638]
- PCI: fu740: Remove unnecessary include files (Myron Stowe) [2124638]
- dt-bindings: PCI: qcom: Fix description typo (Myron Stowe) [2124638]
- PCI: qcom: Add IPQ60xx support (Myron Stowe) [2124638]
- PCI: qcom: Define slot capabilities using PCI_EXP_SLTCAP_* (Myron Stowe) [2124638]
- PCI: dwc: Move GEN3_RELATED DBI definitions to common header (Myron Stowe) [2124638]
- PCI: qcom: Drop manual pipe_clk_src handling (Myron Stowe) [2124638]
- PCI: loongson: Don't access non-existent devices (Myron Stowe) [2124638]
- PCI: loongson: Add ACPI init support (Myron Stowe) [2124638]
- PCI: loongson: Use generic 8/16/32-bit config ops on LS2K/LS7A (Myron Stowe) [2124638]
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (Myron Stowe) [2124638]
- PCI: qcom: Remove unnecessary pipe_clk handling (Myron Stowe) [2124638]
- PCI: qcom: Power on PHY before DBI register accesses (Myron Stowe) [2124638]
- PCI: qcom: Power on PHY before IPQ8074 DBI register accesses (Myron Stowe) [2124638]
- PCI: qcom: Set up rev 2.1.0 PARF_PHY before enabling clocks (Myron Stowe) [2124638]
- PCI/AER: Iterate over error counters instead of error strings (Myron Stowe) [2124638]
- PCI/AER: Enable error reporting when AER is native (Myron Stowe) [2124638]
- PCI/portdrv: Don't disable AER reporting in get_port_device_capability() (Myron Stowe) [2124638]
- PCI/ASPM: Unexport pcie_aspm_support_enabled() (Myron Stowe) [2124638]
- PCI: endpoint: Enable DMA tests for endpoints with DMA capabilities (Myron Stowe) [2124638]
- PCI/doc: Convert examples to generic power management (Myron Stowe) [2124638]
- PCI/AER: Configure ECRC for every device (Myron Stowe) [2124638]
- PCI: endpoint: Don't stop controller when unbinding endpoint function (Myron Stowe) [2124638]
- PCI: Drop of_match_ptr() to avoid unused variables (Myron Stowe) [2124638]
- PCI: dwc-plat: Drop dw_plat_pcie_of_match[] forward declaration (Myron Stowe) [2124638]
- PCI: dwc-plat: Drop unused regmap pointer (Myron Stowe) [2124638]
- PCI: dwc-plat: Simplify dw_plat_pcie_probe() return values (Myron Stowe) [2124638]
- PCI: dwc: Rename struct pcie_port to dw_pcie_rp (Myron Stowe) [2124638]
- PCI: dwc: Move io_cfg_atu_shared to struct pcie_port (Myron Stowe) [2124638]
- PCI: dwc: Add start_link/stop_link inlines (Myron Stowe) [2124638]
- PCI: dwc: Reuse local pointer to the resource data (Myron Stowe) [2124638]
- PCI: dwc: Organize local variable usage (Myron Stowe) [2124638]
- PCI: dwc: Convert dw_pcie_link_up() to use dw_pcie_readl_dbi() (Myron Stowe) [2124638]
- PCI: dwc: Simplify unrolled iATU detection (Myron Stowe) [2124638]
- PCI: dwc: Add newlines to log messages (Myron Stowe) [2124638]
- PCI: dwc: Add braces to multi-line if-else statements (Myron Stowe) [2124638]
- PCI: dwc: Always enable CDM check if "snps,enable-cdm-check" exists (Myron Stowe) [2124638]
- PCI: dwc: Deallocate EPC memory on dw_pcie_ep_init() errors (Myron Stowe) [2124638]
- PCI: dwc: Set INCREASE_REGION_SIZE flag based on limit address (Myron Stowe) [2124638]
- PCI: dwc: Disable outbound windows only for controllers using iATU (Myron Stowe) [2124638]
- PCI: dwc: Add unroll iATU space support to dw_pcie_disable_atu() (Myron Stowe) [2124638]
- PCI: dwc: Stop link on host_init errors and de-initialization (Myron Stowe) [2124638]
- PCI: Clear PCI_STATUS when setting up device (Myron Stowe) [2124638]
- PCI: iproc: Use bitmap API to allocate bitmaps (Myron Stowe) [2124638]
- PCI: vmd: Add DID 8086:7D0B and 8086:AD0B for Intel MTL SKUs (Myron Stowe) [2124638]
- PCI: rcar-gen2: Add RZ/N1 SOC family compatible string (Myron Stowe) [2124638]
- dt-bindings: PCI: renesas,pci-rcar-gen2: Add device tree support for R9A06G032 (Myron Stowe) [2124638]
- dt-bindings: PCI: pci-rcar-gen2: Convert bindings to json-schema (Myron Stowe) [2124638]
- dmaengine: dw-edma: Add support for chip-specific flags (Myron Stowe) [2124638]
- dmaengine: dw-edma: Fix eDMA Rd/Wr-channels and DMA-direction semantics (Myron Stowe) [2124638]
- dmaengine: dw-edma: Drop dma_slave_config.direction field usage (Myron Stowe) [2124638]
- dmaengine: dw-edma: Rename wr(rd)_ch_cnt to ll_wr(rd)_cnt in struct dw_edma_chip (Myron Stowe) [2124638]
- dmaengine: dw-edma: Change rg_region to reg_base in struct dw_edma_chip (Myron Stowe) [2124638]
- dmaengine: dw-edma: Detach the private data and chip info structures (Myron Stowe) [2124638]
- dmaengine: dw-edma: Remove unused irq field in struct dw_edma_chip (Myron Stowe) [2124638]
- PCI: mediatek-gen3: Print LTSSM state when PCIe link down (Myron Stowe) [2124638]
- PCI: mediatek: Allow building for ARCH_AIROHA (Myron Stowe) [2124638]
- dt-bindings: PCI: mediatek: Add Airoha EN7532 support (Myron Stowe) [2124638]
- PCI: aardvark: Fix reporting Slot capabilities on emulated bridge (Myron Stowe) [2124638]
- PCI: aardvark: Add support for AER registers on emulated bridge (Myron Stowe) [2124638]
- PCI: vmd: Use devm_kasprintf() instead of simple kasprintf() (Myron Stowe) [2124638]
- PCI: Add ACS quirk for Broadcom BCM5750x NICs (Myron Stowe) [2124638]
- PCI: switchtec: Prefer ida_alloc()/free() over ida_simple_get()/remove() (Myron Stowe) [2124638]
- PCI: mediatek-gen3: Fix refcount leak in mtk_pcie_init_irq_domains() (Myron Stowe) [2124638]
- PCI: tegra194: Fix PM error handling in tegra_pcie_config_ep() (Myron Stowe) [2124638]
- PCI: microchip: Fix refcount leak in mc_pcie_init_irq_domains() (Myron Stowe) [2124638]
- PCI/ERR: Recognize disconnected devices in report_error_detected() (Myron Stowe) [2124638]
- dt-bindings: PCI: xilinx-cpm: Fix reg property order (Myron Stowe) [2124638]
- dt-bindings: Fix properties without any type (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Fix -Wunused-function with CONFIG_PM_SLEEP=n (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Log the pending interrupt during resume (Myron Stowe) [2124638]
- PCI: brcmstb: Augment driver for MIPs SOCs (Myron Stowe) [2124638]
- PM: core: Add new *_PM_OPS macros, deprecate old ones (Myron Stowe) [2124638]
- PM: core: Redefine pm_ptr() macro (Myron Stowe) [2124638]
- dt-bindings: PCI: designware: Fix 'unevaluatedProperties' warnings (Myron Stowe) [2124638]
- PCI: Add pci_find_dvsec_capability to find designated VSEC (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra194: Fix PCIe endpoint node names (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Enable loading QCOM_IPCC as a module (Myron Stowe) [2124638]
- s390/pci: reset zdev->zbus on registration failure (Myron Stowe) [2124638]
- dt-bindings: PCI: kirin: Add support for Kirin970 (Myron Stowe) [2124638]
- dt-bindings: PCI: kirin: Convert kirin-pcie.txt to yaml (Myron Stowe) [2124638]
- dt-bindings: pci: Add DT binding for Toshiba Visconti PCIe controller (Myron Stowe) [2124638]
- dt-bindings: PCI: add snps,dw-pcie-ep.yaml (Myron Stowe) [2124638]
- dt-bindings: PCI: add snps,dw-pcie.yaml (Myron Stowe) [2124638]
- powerpc/pseries/vas: Pass hw_cpu_id to node associativity HCALL (Steve Best) [2131650]
- net: team: Unsync device addresses on ndo_stop (Hangbin Liu) [2135284]
- crypto: xts - restrict key lengths to approved values in FIPS mode (Vladis Dronov) [2136829]
- io_uring: zero iocb->ki_pos for stream file types (Jeff Moyer) [2107743]
- io-wq: drop wqe lock before creating new worker (Jeff Moyer) [2107743]
- io-wq: check for wq exit after adding new worker task_work (Jeff Moyer) [2107743]
- io_uring: ensure task_work gets run as part of cancelations (Jeff Moyer) [2107743]
- io-wq: remove spurious bit clear on task_work addition (Jeff Moyer) [2107743]
- io-wq: don't retry task_work creation failure on fatal conditions (Jeff Moyer) [2107743]
- io_uring: Fix undefined-behaviour in io_issue_sqe (Jeff Moyer) [2107743]
- io_uring: fix soft lockup when call __io_remove_buffers (Jeff Moyer) [2107743]
- io_uring: fix link traversal locking (Jeff Moyer) [2107743]
- io_uring: fail cancellation for EXITING tasks (Jeff Moyer) [2107743]
- io_uring: correct link-list traversal locking (Jeff Moyer) [2107743]
- io_uring: fix missed comment from *task_file rename (Jeff Moyer) [2107743]
- io-wq: serialize hash clear with wakeup (Jeff Moyer) [2107743]
- io_uring: honour zeroes as io-wq worker limits (Jeff Moyer) [2107743]
- io_uring: remove dead 'sqe' store (Jeff Moyer) [2107743]
- io_uring: remove redundant assignment to ret in io_register_iowq_max_workers() (Jeff Moyer) [2107743]
- io-wq: fix max-workers not correctly set on multi-node system (Jeff Moyer) [2107743]
- io_uring: clean up io_queue_sqe_arm_apoll (Jeff Moyer) [2107743]
- io-wq: remove worker to owner tw dependency (Jeff Moyer) [2107743]
- io_uring: harder fdinfo sq/cq ring iterating (Jeff Moyer) [2107743]
- fs: get rid of the res2 iocb->ki_complete argument (Jeff Moyer) [2107743]
- io_uring: clusterise ki_flags access in rw_prep (Jeff Moyer) [2107743]
- io_uring: kill unused param from io_file_supports_nowait (Jeff Moyer) [2107743]
- io_uring: clean up timeout async_data allocation (Jeff Moyer) [2107743]
- io_uring: don't try io-wq polling if not supported (Jeff Moyer) [2107743]
- io_uring: check if opcode needs poll first on arming (Jeff Moyer) [2107743]
- io_uring: clean iowq submit work cancellation (Jeff Moyer) [2107743]
- io_uring: clean io_wq_submit_work()'s main loop (Jeff Moyer) [2107743]
- io-wq: use helper for worker refcounting (Jeff Moyer) [2107743]
- io_uring: implement async hybrid mode for pollable requests (Jeff Moyer) [2107743]
- io_uring: Use ERR_CAST() instead of ERR_PTR(PTR_ERR()) (Jeff Moyer) [2107743]
- io_uring: split logic of force_nonblock (Jeff Moyer) [2107743]
- io-wq: max_worker fixes (Jeff Moyer) [2107743]
- io_uring: warning about unused-but-set parameter (Jeff Moyer) [2107743]
- io_uring: inform block layer of how many requests we are submitting (Jeff Moyer) [2107743]
- io_uring: simplify io_file_supports_nowait() (Jeff Moyer) [2107743]
- io_uring: combine REQ_F_NOWAIT_{READ,WRITE} flags (Jeff Moyer) [2107743]
- io_uring: arm poll for non-nowait files (Jeff Moyer) [2107743]
- fs/io_uring: Prioritise checking faster conditions first in io_write (Jeff Moyer) [2107743]
- io_uring: clean io_prep_rw() (Jeff Moyer) [2107743]
- io_uring: optimise fixed rw rsrc node setting (Jeff Moyer) [2107743]
- io_uring: return iovec from __io_import_iovec (Jeff Moyer) [2107743]
- io_uring: optimise io_import_iovec fixed path (Jeff Moyer) [2107743]
- io_uring: kill io_wq_current_is_worker() in iopoll (Jeff Moyer) [2107743]
- io_uring: optimise req->ctx reloads (Jeff Moyer) [2107743]
- io_uring: rearrange io_read()/write() (Jeff Moyer) [2107743]
- io_uring: clean up io_import_iovec (Jeff Moyer) [2107743]
- io_uring: optimise io_import_iovec nonblock passing (Jeff Moyer) [2107743]
- io_uring: optimise read/write iov state storing (Jeff Moyer) [2107743]
- io_uring: encapsulate rw state (Jeff Moyer) [2107743]
- io_uring: optimise rw comletion handlers (Jeff Moyer) [2107743]
- io_uring: prioritise read success path over fails (Jeff Moyer) [2107743]
- io_uring: consistent typing for issue_flags (Jeff Moyer) [2107743]
- io_uring: optimise rsrc referencing (Jeff Moyer) [2107743]
- io_uring: optimise io_req_set_rsrc_node() (Jeff Moyer) [2107743]
- io_uring: fix io_free_batch_list races (Jeff Moyer) [2107743]
- io_uring: remove extra io_ring_exit_work wake up (Jeff Moyer) [2107743]
- io_uring: optimise out req->opcode reloading (Jeff Moyer) [2107743]
- io_uring: reshuffle io_submit_state bits (Jeff Moyer) [2107743]
- io_uring: safer fallback_work free (Jeff Moyer) [2107743]
- io_uring: optimise plugging (Jeff Moyer) [2107743]
- io_uring: correct fill events helpers types (Jeff Moyer) [2107743]
- io_uring: inline io_poll_complete (Jeff Moyer) [2107743]
- io_uring: inline io_req_needs_clean() (Jeff Moyer) [2107743]
- io_uring: remove struct io_completion (Jeff Moyer) [2107743]
- io_uring: control ->async_data with a REQ_F flag (Jeff Moyer) [2107743]
- io_uring: optimise io_free_batch_list() (Jeff Moyer) [2107743]
- io_uring: mark cold functions (Jeff Moyer) [2107743]
- io_uring: optimise ctx referencing by requests (Jeff Moyer) [2107743]
- io_uring: merge CQ and poll waitqueues (Jeff Moyer) [2107743]
- io_uring: don't wake sqpoll in io_cqring_ev_posted (Jeff Moyer) [2107743]
- io_uring: optimise INIT_WQ_LIST (Jeff Moyer) [2107743]
- io_uring: optimise request allocation (Jeff Moyer) [2107743]
- io_uring: delay req queueing into compl-batch list (Jeff Moyer) [2107743]
- io_uring: add more likely/unlikely() annotations (Jeff Moyer) [2107743]
- io_uring: optimise kiocb layout (Jeff Moyer) [2107743]
- io_uring: add flag to not fail link after timeout (Jeff Moyer) [2107743]
- io_uring: clean up buffer select (Jeff Moyer) [2107743]
- io_uring: init opcode in io_init_req() (Jeff Moyer) [2107743]
- io_uring: don't return from io_drain_req() (Jeff Moyer) [2107743]
- io_uring: extra a helper for drain init (Jeff Moyer) [2107743]
- io_uring: disable draining earlier (Jeff Moyer) [2107743]
- io_uring: comment why inline complete calls io_clean_op() (Jeff Moyer) [2107743]
- io_uring: kill off ->inflight_entry field (Jeff Moyer) [2107743]
- io_uring: restructure submit sqes to_submit checks (Jeff Moyer) [2107743]
- io_uring: reshuffle queue_sqe completion handling (Jeff Moyer) [2107743]
- io_uring: inline hot path of __io_queue_sqe() (Jeff Moyer) [2107743]
- io_uring: split slow path from io_queue_sqe (Jeff Moyer) [2107743]
- io_uring: remove drain_active check from hot path (Jeff Moyer) [2107743]
- io_uring: deduplicate io_queue_sqe() call sites (Jeff Moyer) [2107743]
- io_uring: don't pass state to io_submit_state_end (Jeff Moyer) [2107743]
- io_uring: don't pass tail into io_free_batch_list (Jeff Moyer) [2107743]
- io_uring: inline completion batching helpers (Jeff Moyer) [2107743]
- io_uring: optimise batch completion (Jeff Moyer) [2107743]
- io_uring: convert iopoll_completed to store_release (Jeff Moyer) [2107743]
- io_uring: add a helper for batch free (Jeff Moyer) [2107743]
- io_uring: use single linked list for iopoll (Jeff Moyer) [2107743]
- io_uring: split iopoll loop (Jeff Moyer) [2107743]
- io_uring: replace list with stack for req caches (Jeff Moyer) [2107743]
- io-wq: add io_wq_work_node based stack (Jeff Moyer) [2107743]
- io_uring: remove allocation cache array (Jeff Moyer) [2107743]
- io_uring: use slist for completion batching (Jeff Moyer) [2107743]
- io_uring: make io_do_iopoll return number of reqs (Jeff Moyer) [2107743]
- io_uring: force_nonspin (Jeff Moyer) [2107743]
- io_uring: mark having different creds unlikely (Jeff Moyer) [2107743]
- io_uring: return boolean value for io_alloc_async_data (Jeff Moyer) [2107743]
- io_uring: optimise io_req_init() sqe flags checks (Jeff Moyer) [2107743]
- io_uring: remove ctx referencing from complete_post (Jeff Moyer) [2107743]
- io_uring: add more uring info to fdinfo for debug (Jeff Moyer) [2107743]
- io_uring: kill extra wake_up_process in tw add (Jeff Moyer) [2107743]
- io_uring: dedup CQE flushing non-empty checks (Jeff Moyer) [2107743]
- io_uring: inline linked part of io_req_find_next (Jeff Moyer) [2107743]
- io_uring: inline io_dismantle_req (Jeff Moyer) [2107743]
- io_uring: kill off ios_left (Jeff Moyer) [2107743]
- io-wq: Remove duplicate code in io_workqueue_create() (Jeff Moyer) [2107743]
- io_uring: dump sqe contents if issue fails (Jeff Moyer) [2107743]
- lsm,io_uring: add LSM hooks to io_uring (Jeff Moyer) [2107743]
- selftests: netfilter: Fix nft_fib.sh for all.rp_filter=1 (Hangbin Liu) [2128202]
- selftests: Fix the if conditions of in test_extra_filter() (Hangbin Liu) [2128202]
- selftests: forwarding: add shebang for sch_red.sh (Hangbin Liu) [2128202]
- selftests: forwarding: fix error message in learning_test (Hangbin Liu) [2128202]
- selftests/net: pass ipv6_args to udpgso_bench's IPv6 TCP test (Hangbin Liu) [2128202]
- selftests: forwarding: fix missing backslash (Hangbin Liu) [2128202]
- selftests/net/forwarding: add missing tests to Makefile (Hangbin Liu) [2128202]
- fs: vfs: fs/dcache: Move wakeup out of i_seq_dir write held region (Ian Kent) [2118965]
- fs: vfs: fs/dcache: Move the wakeup from __d_lookup_done() to the caller (Ian Kent) [2118965]
- fs: vfs: fs/dcache: Disable preemption on i_dir_seq write side on PREEMPT_RT (Ian Kent) [2118965]
- fs: vfs: d_add_ci(): make sure we don't miss d_lookup_done() (Ian Kent) [2118965]

* Tue Nov 01 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-184.el9]
- platform/x86/intel: pmc/core: Add Raptor Lake support to pmc core driver (David Arcari) [2076733]
- powercap: intel_rapl: Add support for RAPTORLAKE_P (David Arcari) [2076727]
- iommu/vt-d: Check correct capability for sagaw determination (Jerry Snitselaar) [2112024]
- Revert "iommu/vt-d: Fix possible recursive locking in intel_iommu_init()" (Jerry Snitselaar) [2112024]
- dma-mapping: mark dma_supported static (Jerry Snitselaar) [2112024]
- swiotlb: fix a typo (Jerry Snitselaar) [2112024]
- swiotlb: avoid potential left shift overflow (Jerry Snitselaar) [2112024]
- dma-debug: improve search for partial syncs (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix possible recursive locking in intel_iommu_init() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Correctly calculate sagaw value of IOMMU (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix kdump kernels boot failure with scalable mode (Jerry Snitselaar) [2121155]
- iommu/amd: use full 64-bit value in build_completion_wait() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix recursive lock issue in iommu_flush_dev_iotlb() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix lockdep splat due to klist iteration in atomic context (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Remove pci_p2pdma_[un]map_sg() (Jerry Snitselaar) [2112024]
- nvme-pci: convert to using dma_map_sgtable() (Jerry Snitselaar) [2112024]
- nvme-pci: check DMA ops when indicating support for PCI P2PDMA (Jerry Snitselaar) [2112024]
- RDMA/rw: drop pci_p2pdma_[un]map_sg() (Jerry Snitselaar) [2112024]
- RDMA/core: introduce ib_dma_pci_p2p_dma_supported() (Jerry Snitselaar) [2112024]
- dma-mapping: reformat comment to suppress htmldoc warning (Jerry Snitselaar) [2112024]
- iommu/dma: support PCI P2PDMA pages in dma-iommu map_sg (Jerry Snitselaar) [2112024]
- iommu: Explicitly skip bus address marked segments in __iommu_map_sg() (Jerry Snitselaar) [2112024]
- dma-mapping: add flags to dma_map_ops to indicate PCI P2PDMA support (Jerry Snitselaar) [2112024]
- dma-direct: support PCI P2PDMA pages in dma-direct map_sg (Jerry Snitselaar) [2112024]
- dma-mapping: allow EREMOTEIO return code for P2PDMA transfers (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Introduce helpers for dma_map_sg implementations (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Attempt to set map_type if it has not been set (Jerry Snitselaar) [2112024]
- lib/scatterlist: add flag for indicating P2PDMA segments in an SGL (Jerry Snitselaar) [2112024]
- x86/swiotlb: fix param usage in boot-options.rst (Jerry Snitselaar) [2112024]
- swiotlb: fix passing local variable to debugfs_create_ulong() (Jerry Snitselaar) [2112024]
- swiotlb: clean up some coding style and minor issues (Jerry Snitselaar) [2112024]
- dma-iommu: add iommu_dma_opt_mapping_size() (Jerry Snitselaar) [2112024]
- dma-mapping: add dma_opt_mapping_size() (Jerry Snitselaar) [2112024]
- swiotlb: move struct io_tlb_slot to swiotlb.c (Jerry Snitselaar) [2112024]
- swiotlb: ensure a segment doesn't cross the area boundary (Jerry Snitselaar) [2112024]
- swiotlb: consolidate rounding up default_nslabs (Jerry Snitselaar) [2112024]
- swiotlb: remove unused fields in io_tlb_mem (Jerry Snitselaar) [2112024]
- swiotlb: fix use after free on error handling path (Jerry Snitselaar) [2112024]
- swiotlb: split up the global swiotlb lock (Jerry Snitselaar) [2112024]
- swiotlb: fail map correctly with failed io_tlb_default_mem (Jerry Snitselaar) [2112024]
- swiotlb: remove a useless return in swiotlb_init (Jerry Snitselaar) [2112024]
- swiotlb: remove the unused swiotlb_force declaration (Jerry Snitselaar) [2112024]
- rhel/configs: Add ARM_SMMU_QCOM_DEBUG (Jerry Snitselaar) [2112024]
- dma-mapping: Fix build error unused-value (Jerry Snitselaar) [2112024]
- dma-mapping: Add dma_release_coherent_memory to DMA API (Jerry Snitselaar) [2112024]
- iommu/vt-d: avoid invalid memory access via node_online(NUMA_NO_NODE) (Jerry Snitselaar) [2112024]
- MAINTAINERS: Add Robin Murphy as IOMMU SUBSYTEM reviewer (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: cleanup arm_smmu_dev_{enable,disable}_feature (Jerry Snitselaar) [2112024]
- iommu: remove the put_resv_regions method (Jerry Snitselaar) [2112024]
- iommu: remove iommu_dev_feature_enabled (Jerry Snitselaar) [2112024]
- iommu: remove the unused dev_has_feat method (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove global g_iommus array (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unnecessary check in intel_iommu_add() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Refactor iommu information of each domain (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use IDA interface to manage iommu sequence id (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unused domain_get_iommu() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Convert global spinlock into per domain lock (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use device_domain_lock accurately (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fold __dmar_remove_one_dev_info() into its caller (Jerry Snitselaar) [2112024]
- iommu/vt-d: Check device list of domain in domain free path (Jerry Snitselaar) [2112024]
- iommu/vt-d: Acquiring lock in pasid manipulation helpers (Jerry Snitselaar) [2112024]
- iommu/vt-d: Acquiring lock in domain ID allocation helpers (Jerry Snitselaar) [2112024]
- iommu/vt-d: Replace spin_lock_irqsave() with spin_lock() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Unnecessary spinlock for root table alloc and free (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use pci_get_domain_bus_and_slot() in pgtable_walk() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove clearing translation data in disable_dmar_iommu() (Jerry Snitselaar) [2112024]
- iommu/vt-d: debugfs: Remove device_domain_lock usage (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unused iovad from dmar_domain (Jerry Snitselaar) [2112024]
- iommu/vt-d: Move include/linux/intel-iommu.h under iommu (Jerry Snitselaar) [2112024]
- x86/boot/tboot: Move tboot_force_iommu() to Intel IOMMU (Jerry Snitselaar) [2112024]
- drm/i915: Remove unnecessary include (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unnecessary exported symbol (Jerry Snitselaar) [2112024]
- agp/intel: Use per device iommu check (Jerry Snitselaar) [2112024]
- iommu/vt-d: Move trace/events/intel_iommu.h under iommu (Jerry Snitselaar) [2112024]
- iommu/virtio: Add map/unmap_pages() callbacks implementation (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-qcom: Add SM6375 SMMU compatible (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-qcom: Add debug support for TLB sync timeouts (Jerry Snitselaar) [2112024]
- ACPI/IORT: Fix build error implicit-function-declaration (Jerry Snitselaar) [2112024]
- iommu/amd: Handle return of iommu_device_sysfs_add (Jerry Snitselaar) [2112024]
- iommu: arm-smmu-impl: Add 8250 display compatible to the client list. (Jerry Snitselaar) [2112024]
- iommu/iova: change IOVA_MAG_SIZE to 127 to save memory (Jerry Snitselaar) [2112024]
- iommu: Clean up release_device checks (Jerry Snitselaar) [2112024]
- iommu: Make .release_device optional (Jerry Snitselaar) [2112024]
- iommu: Use dev_iommu_ops() for probe_finalize (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: Get associated RMR info and install bypass SMR (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Get associated RMR info and install bypass STE (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Refactor arm_smmu_init_bypass_stes() to force bypass (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Introduce strtab init helper (Jerry Snitselaar) [2112024]
- ACPI/IORT: Add a helper to retrieve RMR info directly (Jerry Snitselaar) [2112024]
- ACPI/IORT: Add support to retrieve IORT RMR reserved regions (Jerry Snitselaar) [2112024]
- ACPI/IORT: Provide a generic helper to retrieve reserve regions (Jerry Snitselaar) [2112024]
- ACPI/IORT: Make iort_iommu_msi_get_resv_regions() return void (Jerry Snitselaar) [2112024]
- ACPICA: IORT: Updates for revision E.d (Jerry Snitselaar) [2112024]
- iommu: Introduce a callback to struct iommu_resv_region (Jerry Snitselaar) [2112024]
- iommu/amd: Use try_cmpxchg64 in alloc_pte and free_clear_pte (Jerry Snitselaar) [2112024]
- iommu/dma: Fix race condition during iova_domain initialization (Jerry Snitselaar) [2112024]
- iommu: Directly use ida_alloc()/free() (Jerry Snitselaar) [2112024]
- selftests dma: fix compile error for dma_map_benchmark (Jerry Snitselaar) [2112024]
- MAINTAINERS: Remove iommu@lists.linux-foundation.org (Jerry Snitselaar) [2112024]
- MAINTAINERS: Add new IOMMU development mailing list (Jerry Snitselaar) [2112024]
- MAINTAINERS: Update SWIOTLB maintainership (Jerry Snitselaar) [2112024]
- MAINTAINERS: update maintainer list of DMA MAPPING BENCHMARK (Jerry Snitselaar) [2112024]
- perf/smmuv3: Don't cast parameter in bit operations (Jerry Snitselaar) [2112024]
- ARM: ixp4xx: Drop custom DMA coherency and bouncing (Jerry Snitselaar) [2112024]
- swiotlb: fix setting ->force_bounce (Jerry Snitselaar) [2112024]
- iommu: Log iova range in map/unmap trace events (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove hard coding PGSNP bit in PASID entries (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove domain_update_iommu_snooping() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Check domain force_snooping against attached devices (Jerry Snitselaar) [2112024]
- iommu/vt-d: Block force-snoop domain attaching if no SC support (Jerry Snitselaar) [2112024]
- iommu/vt-d: Size Page Request Queue to avoid overflow condition (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fold dmar_insert_one_dev_info() into its caller (Jerry Snitselaar) [2112024]
- iommu/vt-d: Change return type of dmar_insert_one_dev_info() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unneeded validity check on dev (Jerry Snitselaar) [2112024]
- iommu/dma: Explicitly sort PCI DMA windows (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: Support Tegra234 SMMU (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: check return value after calling platform_get_resource() (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: fix possible null-ptr-deref in arm_smmu_device_probe() (Jerry Snitselaar) [2112024]
- swiotlb: use the right nslabs-derived sizes in swiotlb_init_late (Jerry Snitselaar) [2112024]
- swiotlb: use the right nslabs value in swiotlb_init_remap (Jerry Snitselaar) [2112024]
- swiotlb: don't panic when the swiotlb buffer can't be allocated (Jerry Snitselaar) [2112024]
- swiotlb-xen: this is PV-only on x86 (Jerry Snitselaar) [2112024]
- x86: remove cruft from <asm/dma-mapping.h> (Jerry Snitselaar) [2112024]
- swiotlb: remove swiotlb_init_with_tbl and swiotlb_init_late_with_tbl (Jerry Snitselaar) [2112024]
- swiotlb: merge swiotlb-xen initialization into swiotlb (Jerry Snitselaar) [2112024]
- swiotlb: provide swiotlb_init variants that remap the buffer (Jerry Snitselaar) [2112024]
- swiotlb: pass a gfp_mask argument to swiotlb_init_late (Jerry Snitselaar) [2112024]
- swiotlb: add a SWIOTLB_ANY flag to lift the low memory restriction (Jerry Snitselaar) [2112024]
- swiotlb: make the swiotlb_init interface more useful (Jerry Snitselaar) [2112024]
- x86: centralize setting SWIOTLB_FORCE when guest memory encryption is enabled (Jerry Snitselaar) [2112024]
- x86: remove the IOMMU table infrastructure (Jerry Snitselaar) [2112024]
- xen/pci-swiotlb: reduce visibility of symbols (Jerry Snitselaar) [2112024]
- swiotlb: rename swiotlb_late_init_with_default_size (Jerry Snitselaar) [2112024]
- swiotlb: simplify swiotlb_max_segment (Jerry Snitselaar) [2112024]
- iommu/vt-d: Add RPLS to quirk list to skip TE disabling (Jerry Snitselaar) [2112024]
- iommu: Remove trivial ops->capable implementations (Jerry Snitselaar) [2112024]
- iommu/vtd: Replace acpi_bus_get_device() (Jerry Snitselaar) [2112024]
- iommu/tegra-smmu: Fix missing put_device() call in tegra_smmu_find (Jerry Snitselaar) [2112024]
- iommu/tegra-smmu: Use devm_bitmap_zalloc when applicable (Jerry Snitselaar) [2112024]
- lib/scatterlist: cleanup macros into static inline functions (Jerry Snitselaar) [2112024]
- ASoC: hdmi-codec: Update to modern DAI terminology (Karol Herbst) [2115866]
- PCI: Move PCI_VENDOR_ID_MICROSOFT/PCI_DEVICE_ID_HYPERV_VIDEO definitions to pci_ids.h (Karol Herbst) [2115866]
- Revert "workqueue: remove unused cancel_work()" (Karol Herbst) [2115866]
- x86/gpu: include drm/i915_pciids.h directly in early quirks (Karol Herbst) [2115866]
- fbdev: Put mmap for deferred I/O into drivers (Karol Herbst) [2115866]
- fbdev: Track deferred-I/O pages in pageref struct (Karol Herbst) [2115866]
- fbdev: defio: fix the pagelist corruption (Karol Herbst) [2115866]
- fbdev: Don't sort deferred-I/O pages by default (Karol Herbst) [2115866]
- fbdev/defio: Early-out if page is already enlisted (Karol Herbst) [2115866]
- md: Fix spelling mistake in comments of r5l_log (Nigel Croxon) [2113822]
- md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d (Nigel Croxon) [2113822]
- md/raid10: convert resync_lock to use seqlock (Nigel Croxon) [2113822]
- md/raid10: fix improper BUG_ON() in raise_barrier() (Nigel Croxon) [2113822]
- md/raid10: prevent unnecessary calls to wake_up() in fast path (Nigel Croxon) [2113822]
- md/raid10: don't modify 'nr_waitng' in wait_barrier() for the case nowait (Nigel Croxon) [2113822]
- md/raid10: factor out code from wait_barrier() to stop_waiting_barrier() (Nigel Croxon) [2113822]
- md: Remove extra mddev_get() in md_seq_start() (Nigel Croxon) [2113822]
- md/raid5: Remove unnecessary bio_put() in raid5_read_one_chunk() (Nigel Croxon) [2113822]
- md/raid5: Ensure stripe_fill happens on non-read IO with journal (Nigel Croxon) [2113822]
- md/raid5: Don't read ->active_stripes if it's not needed (Nigel Croxon) [2113822]
- md/raid5: Cleanup prototype of raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md/raid5: Drop extern on function declarations in raid5.h (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md: Replace snprintf with scnprintf (Nigel Croxon) [2113822]
- md/raid10: fix compile warning (Nigel Croxon) [2113822]
- md/raid5: Fix spelling mistakes in comments (Nigel Croxon) [2113822]
- md: call __md_stop_writes in md_stop (Nigel Croxon) [2113822]
- md: Flush workqueue md_rdev_misc_wq in md_alloc() (Nigel Croxon) [2113822]
- drivers:md:fix a potential use-after-free bug (Nigel Croxon) [2113822]
- md/raid5: Ensure batch_last is released before sleeping for quiesce (Nigel Croxon) [2113822]
- md/raid5: Move stripe_request_ctx up (Nigel Croxon) [2113822]
- md/raid5: Drop unnecessary call to r5c_check_stripe_cache_usage() (Nigel Croxon) [2113822]
- md/raid5: Make is_inactive_blocked() helper (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md-raid10: fix KASAN warning (Nigel Croxon) [2113822]
- md: return the allocated devices from md_alloc (Nigel Croxon) [2113822]
- md: open code md_probe in autorun_devices (Nigel Croxon) [2113822]
- md: remove unneeded semicolon (Nigel Croxon) [2113822]
- md: fix build failure for !MODULE (Nigel Croxon) [2113822]
- raid5: fix duplicate checks for rdev->saved_raid_disk (Nigel Croxon) [2113822]
- md: simplify md_open (Nigel Croxon) [2113822]
- md: only delete entries from all_mddevs when the disk is freed (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_exit (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_notify_reboot (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_do_sync (Nigel Croxon) [2113822]
- md: factor out the rdev overlaps check from rdev_size_store (Nigel Croxon) [2113822]
- md: rename md_free to md_kobj_release (Nigel Croxon) [2113822]
- md: implement ->free_disk (Nigel Croxon) [2113822]
- md: fix error handling in md_alloc (Nigel Croxon) [2113822]
- md: fix mddev->kobj lifetime (Nigel Croxon) [2113822]
- md/raid5: Convert prepare_to_wait() to wait_woken() api (Nigel Croxon) [2113822]
- md/raid5: Fix sectors_to_do bitmap overflow in raid5_make_request() (Nigel Croxon) [2113822]
- md: Fix spelling mistake in comments (Nigel Croxon) [2113822]
- md/raid5: Increase restriction on max segments per request (Nigel Croxon) [2113822]
- md/raid5: Improve debug prints (Nigel Croxon) [2113822]
- md/raid5: Pivot raid5_make_request() (Nigel Croxon) [2113822]
- md/raid5: Check all disks in a stripe_head for reshape progress (Nigel Croxon) [2113822]
- md/raid5: Refactor add_stripe_bio() (Nigel Croxon) [2113822]
- md/raid5: Keep a reference to last stripe_head for batch (Nigel Croxon) [2113822]
- md/raid5: Refactor for loop in raid5_make_request() into while loop (Nigel Croxon) [2113822]
- md/raid5: Move read_seqcount_begin() into make_stripe_request() (Nigel Croxon) [2113822]
- md/raid5: Drop the do_prepare flag in raid5_make_request() (Nigel Croxon) [2113822]
- md/raid5: Factor out helper from raid5_make_request() loop (Nigel Croxon) [2113822]
- md/raid5: Move common stripe get code into new find_get_stripe() helper (Nigel Croxon) [2113822]
- md/raid5: Move stripe_add_to_batch_list() call out of add_stripe_bio() (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_make_request loop (Nigel Croxon) [2113822]
- md/raid5: Factor out ahead_of_reshape() function (Nigel Croxon) [2113822]
- md/raid5: Make logic blocking check consistent with logic that blocks (Nigel Croxon) [2113822]
- md: unlock mddev before reap sync_thread in action_store (Nigel Croxon) [2113822]
- md: Explicitly create command-line configured devices (Nigel Croxon) [2113822]
- md: Notify sysfs sync_completed in md_reap_sync_thread() (Nigel Croxon) [2113822]
- md: Ensure resync is reported after it starts (Nigel Croxon) [2113822]
- md: Use enum for overloaded magic numbers used by mddev->curr_resync (Nigel Croxon) [2113822]
- md/raid5-cache: Annotate pslot with __rcu notation (Nigel Croxon) [2113822]
- md/raid5-cache: Clear conf->log after finishing work (Nigel Croxon) [2113822]
- md/raid5-cache: Drop RCU usage of conf->log (Nigel Croxon) [2113822]
- md/raid5-cache: Take mddev_lock in r5c_journal_mode_show() (Nigel Croxon) [2113822]
- md/raid5: suspend the array for calls to log_exit() (Nigel Croxon) [2113822]
- md/raid5-ppl: Drop unused argument from ppl_handle_flush_request() (Nigel Croxon) [2113822]
- md/raid5-log: Drop extern decorators for function prototypes (Nigel Croxon) [2113822]
- md/raid5: missing error code in setup_conf() (Nigel Croxon) [2113822]
- Revert "md: don't unregister sync_thread with reconfig_mutex held" (Nigel Croxon) [2113822]

* Mon Oct 31 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-183.el9]
- tracing: Disable interrupt or preemption before acquiring arch_spinlock_t (Waiman Long) [2128231]
- docs: security: Add secrets/coco documentation (Lenny Szubowicz) [1994744]
- virt: Add efi_secret module to expose confidential computing secrets (Lenny Szubowicz) [1994744]
- Enable CONFIG_EFI_SECRET as a module for x86_64 (Lenny Szubowicz) [1994744]
- crypto: ccp - Remove the unneeded result variable (Vladis Dronov) [2119181]
- crypto: ccp - Release dma channels before dmaengine unrgister (Vladis Dronov) [2119181]
- crypto: ccp - Fail the PSP initialization when writing psp data file failed (Vladis Dronov) [2119181]
- crypto: ccp - Initialize PSP when reading psp data file failed (Vladis Dronov) [2119181]
- crypto: ccp - Add a quirk to firmware update (Vladis Dronov) [2119181]
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [2119181]
- crypto: ccp - During shutdown, check SEV data pointer before using (Vladis Dronov) [2119181]
- crypto: ccp - fix typo in comment (Vladis Dronov) [2119181]
- crypto: ccp - Use kzalloc for sev ioctl interfaces to prevent kernel memory leak (Vladis Dronov) [2119181]
- crypto: ccp - Fix the INIT_EX data file open failure (Vladis Dronov) [2119181]
- crypto: ccp - Log when resetting PSP SEV state (Vladis Dronov) [2119181]
- crypto: ccp - When TSME and SME both detected notify user (Vladis Dronov) [2119181]
- crypto: ccp - Allow PSP driver to load without SEV/TEE support (Vladis Dronov) [2119181]
- crypto: ccp - Export PSP security bits to userspace (Vladis Dronov) [2119181]
- crypto: ccp - cache capability into psp device (Vladis Dronov) [2119181]
- mm: fix BUG splat with kvmalloc + GFP_ATOMIC (Chris von Recklinghausen) [2131716]
- mm/hugetlb: correct demote page offset logic (Chris von Recklinghausen) [2131716]
- frontswap: don't call ->init if no ops are registered (Chris von Recklinghausen) [2131716]
- Revert "powerpc: Remove unused FW_FEATURE_NATIVE references" (Chris von Recklinghausen) [2131716]
- Docs/admin-guide/mm/damon/usage: fix the example code snip (Chris von Recklinghausen) [2131716]

* Thu Oct 27 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-182.el9]
- cgroup/cpuset: remove unreachable code (Waiman Long) [1946801]
- kselftest/cgroup: Add cpuset v2 partition root state test (Waiman Long) [1946801]
- cgroup/cpuset: Update description of cpuset.cpus.partition in cgroup-v2.rst (Waiman Long) [1946801]
- cgroup/cpuset: Make partition invalid if cpumask change violates exclusivity rule (Waiman Long) [1946801]
- cgroup/cpuset: Relocate a code block in validate_change() (Waiman Long) [1946801]
- cgroup/cpuset: Show invalid partition reason string (Waiman Long) [1946801]
- cgroup/cpuset: Add a new isolated cpus.partition type (Waiman Long) [1946801]
- cgroup/cpuset: Relax constraints to partition & cpus changes (Waiman Long) [1946801]
- cgroup/cpuset: Allow no-task partition to have empty cpuset.cpus.effective (Waiman Long) [1946801]
- cgroup/cpuset: Miscellaneous cleanups & add helper functions (Waiman Long) [1946801]
- cgroup/cpuset: Enable update_tasks_cpumask() on top_cpuset (Waiman Long) [1946801]
- cpuset: convert 'allowed' in __cpuset_node_allowed() to be boolean (Waiman Long) [1946801]
- cgroup/cpuset: Remove cpus_allowed/mems_allowed setup in cpuset_init_smp() (Waiman Long) [1946801]
- cgroup: cleanup comments (Waiman Long) [1946801]
- tcp: Fix data races around icsk->icsk_af_ops. (Hangbin Liu) [2135319]
- ipv6: Fix data races around sk->sk_prot. (Hangbin Liu) [2135319]
- ipv6: annotate some data-races around sk->sk_prot (Hangbin Liu) [2135319]
- tcp/udp: Call inet6_destroy_sock() in IPv6 sk->sk_destruct(). (Hangbin Liu) [2135319]
- udp: Call inet6_destroy_sock() in setsockopt(IPV6_ADDRFORM). (Hangbin Liu) [2135319]
- tcp/udp: Fix memory leak in ipv6_renew_options(). (Hangbin Liu) [2135319]
- ipv6: sr: fix out-of-bounds read when setting HMAC data. (Hangbin Liu) [2135319]
- net: fix potential refcount leak in ndisc_router_discovery() (Hangbin Liu) [2135319]
- ipv6: do not use RT_TOS for IPv6 flowlabel (Hangbin Liu) [2135319]
- ipv6: fix lockdep splat in in6_dump_addrs() (Hangbin Liu) [2135319]
- ipv6/sit: fix ipip6_tunnel_get_prl return value (Hangbin Liu) [2135319]
- selftests/bpf: Fix passing arguments via function in test_kmod.sh (Yauheni Kaliuta) [2102053]
- selftests: bpf: test_kmod.sh: Pass parameters to the module (Yauheni Kaliuta) [2102053]
- Kconfig: Add option for asm goto w/ tied outputs to workaround clang-13 bug (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: Add SPDX-License-Identifier tag (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add virtual CPU errata documentation (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add separate directories for architecture-specific documentation (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove __NR_userfaultfd syscall fallback (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Fix hypercall bitmap writeback when vcpus have already run (Vitaly Kuznetsov) [2119111]
- KVM: x86: Inject #UD on emulated XSETBV if XSAVES isn't enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86: Always enable legacy FP/SSE in allowed user XFEATURES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reinstate kvm_vcpu_arch.guest_supported_xcr0 (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: add missing update to max_mmu_rmap_size (Vitaly Kuznetsov) [2119111]
- selftests: kvm: Fix a compile error in selftests/kvm/rseq_test.c (Vitaly Kuznetsov) [2119111]
- KVM/VMX: Restore previously dropped ENDBR in vmx_vmexit (Vitaly Kuznetsov) [2119111]
- Documentation: kvm: clarify histogram units (Vitaly Kuznetsov) [2119111]
- KVM: x86: document limitations of MSR filtering (Vitaly Kuznetsov) [2119111]
- docs: kvm: fix WARNINGs from api.rst (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers cpufeatures: Sync with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync KVM's vmx.h header with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers cpufeatures: Sync with the kernel sources (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __vcalloc() in kvm_page_track_write_tracking_alloc() (Vitaly Kuznetsov) [2119111]
- x86/kvm: Fix "missing ENDBR" BUG for fastop functions (Vitaly Kuznetsov) [2119111]
- x86/ibt, objtool: Add IBT_NOSEAL() (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- perf/x86/core: Completely disable guest PEBS via guest's global_ctrl (Vitaly Kuznetsov) [2119111]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2119111]
- x86/extable: Prefer local labels in .set directives (Vitaly Kuznetsov) [2119111]
- x86/entry_32: Fix segment exceptions (Vitaly Kuznetsov) [2119111]
- Merge branch 'kvm-fixes-for-5.18-rc5' into HEAD (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- x86/kvm: Simplify FOP_SETCC() (Vitaly Kuznetsov) [2119111]
- KVM: x86: check validity of argument to KVM_SET_MP_STATE (Vitaly Kuznetsov) [2119111]
- KVM: x86: fix memoryleak in kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Mask off unsupported and unknown bits of IA32_ARCH_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix ambiguous mov in KVM_ASM_SAFE() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix KVM_EXCEPTION_MAGIC build with Clang (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Heed the 'msr' argument in msr_write_intercepted() (Vitaly Kuznetsov) [2119111]
- kvm: x86: mmu: Always flush TLBs when enabling dirty logging (Vitaly Kuznetsov) [2119111]
- kvm: x86: mmu: Drop the need_remote_flush() function (Vitaly Kuznetsov) [2119111]
- KVM: Drop unnecessary initialization of "ops" in kvm_ioctl_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: Drop unnecessary initialization of "npages" in hva_to_pfn_slow() (Vitaly Kuznetsov) [2119111]
- KVM: Rename mmu_notifier_* to mmu_invalidate_* (Vitaly Kuznetsov) [2119111]
- KVM: Rename KVM_PRIVATE_MEM_SLOTS to KVM_INTERNAL_MEM_SLOTS (Vitaly Kuznetsov) [2119111]
- KVM: Move coalesced MMIO initialization (back) into kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: Unconditionally get a ref to /dev/kvm module when creating a VM (Vitaly Kuznetsov) [2119111]
- KVM: Properly unwind VM creation if creating debugfs fails (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Adjust number of LBR records for PERF_CAPABILITIES at refresh (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use proper type-safe functions for vCPU => LBRs helpers (Vitaly Kuznetsov) [2119111]
- KVM: x86: Refresh PMU after writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test all possible "invalid" PERF_CAPABILITIES.LBR_FMT vals (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use getcpu() instead of sched_getcpu() in rseq_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make rseq compatible with glibc-2.35 (Vitaly Kuznetsov) [2119111]
- KVM: Actually create debugfs in kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: Pass the name of the VM fd to kvm_create_vm_debugfs() (Vitaly Kuznetsov) [2119111]
- KVM: Get an fd before creating the VM (Vitaly Kuznetsov) [2119111]
- KVM: Shove vcpu stats_id init into kvm_vcpu_init() (Vitaly Kuznetsov) [2119111]
- KVM: Shove vm stats_id init into kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add sanity check that MMIO SPTE mask doesn't overlap gen (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rename trace function name for asynchronous page fault (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Stop Xen timer before changing IRQ (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Initialize Xen timer only once (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Disable SEV-ES support if MMIO caching is disable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Fully re-evaluate MMIO caching when SPTE masks change (Vitaly Kuznetsov) [2119111]
- KVM: x86: Tag kvm_mmu_x86_module_init() with __init (Vitaly Kuznetsov) [2119111]
- KVM: x86: emulator: Fix illegal LEA handling (Vitaly Kuznetsov) [2119111]
- KVM: X86: avoid uninitialized 'fault.async_page_fault' from fixed-up #PF (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if an accelerated x2APIC trap occurs on a "bad" reg (Vitaly Kuznetsov) [2119111]
- selftests: kvm: fix compilation (Vitaly Kuznetsov) [2119111]
- selftests: kvm: set rax before vmcall (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Add exponent check for boolean stats (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Provide descriptive assertions in kvm_binary_stats_test (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Check stat name before other fields (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove unused variable (Vitaly Kuznetsov) [2119111]
- KVM: Add gfp_custom flag in struct kvm_mmu_memory_cache (Vitaly Kuznetsov) [2119111]
- KVM, x86/mmu: Fix the comment around kvm_tdp_mmu_zap_leafs() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Dump Virtual Machine Save Area (VMSA) to klog (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Treat NX as a valid SPTE bit for NPT (Vitaly Kuznetsov) [2119111]
- KVM: x86: Do not block APIC write for non ICR registers (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not virtualize MSR accesses for APIC LVTT register (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Verify VMX MSRs can be restored to KVM-supported values (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Set UMIP bit CR4_FIXED1 MSR when emulating UMIP (Vitaly Kuznetsov) [2119111]
- Revert "KVM: nVMX: Expose load IA32_PERF_GLOBAL_CTRL VM-{Entry,Exit} control" (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Attempt to load PERF_GLOBAL_CTRL on nVMX xfer iff it exists (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Add helper to check if the guest PMU has PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Mark all PERF_GLOBAL_(OVF)_CTRL bits reserved if there's no vPMU (Vitaly Kuznetsov) [2119111]
- Revert "KVM: nVMX: Do not expose MPX VMX controls when guest MPX disabled" (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Let userspace set nVMX MSR to any _host_ supported value (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Rename handle_vm{on,off}() to handle_vmx{on,off}() (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Account for KVM reserved CR4 bits in consistency checks (Vitaly Kuznetsov) [2119111]
- KVM: x86: Split kvm_is_valid_cr4() and export only the non-vendor bits (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add an option to run vCPUs while disabling dirty logging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't bottom out on leafs when zapping collapsible SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Document the "rules" for using host_pfn_mapping_level() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't require refcounted "struct page" to create huge SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Restrict mapping level based on guest MTRR iff they're used (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add shadow mask for effective host MTRR memtype (Vitaly Kuznetsov) [2119111]
- KVM: x86: Drop unnecessary goto+label in kvm_arch_init() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reject loading KVM if host.PAT[0] != WB (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Fix x2APIC MSRs interception (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Remove underscores from __pte_list_remove() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename pte_list_{destroy,remove}() to show they zap SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename rmap zap helpers to eliminate "unmap" wrapper (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename __kvm_zap_rmaps() to align with other nomenclature (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop the "p is for pointer" from rmap helpers (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Directly "destroy" PTE list when recycling rmaps (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Return a u64 (the old SPTE) from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Pull CS.Base from actual VMCB12 for soft int/ex re-injection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Protect the unused bits in MSR exiting flags (Vitaly Kuznetsov) [2119111]
- KVM: stats: Fix value for KVM_STATS_UNIT_MAX for boolean stats (Vitaly Kuznetsov) [2119111]
- KVM: x86: Remove unnecessary include (Vitaly Kuznetsov) [2119111]
- KVM: x86: Check target, not vCPU's x2APIC ID, when applying hotplug hack (Vitaly Kuznetsov) [2119111]
- KVM: x86: Restrict get_mt_mask() to a u8, use KVM_X86_OP_OPTIONAL_RET0 (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add dedicated helper to get CPUID entry with significant index (Vitaly Kuznetsov) [2119111]
- KVM: SVM: fix task switch emulation on INTn instruction. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Fix typo and tweak comment for split_desc_cache capacity (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Expand quadrant comment for PG_LEVEL_4K shadow pages (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add optimized helper to retrieve an SPTE's index (Vitaly Kuznetsov) [2119111]
- kvm: stats: tell userspace which values are boolean (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Update PT MSR intercepts during filter change iff PT in host+guest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unused SVM_CPUID_FUNC macro (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use the common cpuid() helper in cpu_vendor_string_is() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up requirements for XFD-aware XSAVE features (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Skip AMX test if ARCH_REQ_XCOMP_GUEST_PERM isn't supported (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Check KVM's supported CPUID, not host CPUID, for XFD (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Inline "get max CPUID leaf" helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename kvm_get_supported_cpuid_index() to __..._entry() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unnecessary use of kvm_get_supported_cpuid_index() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use this_cpu_has() to detect SVM support in L1 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use this_cpu_has() in CR4/CPUID sync test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add this_cpu_has() to query X86_FEATURE_* via cpuid() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Set input function/index in raw CPUID helper(s) (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make get_supported_cpuid() returns "const" (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_clear_cpuid_feature() to clear x2APIC (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_{set,clear}_cpuid_feature() in nVMX state test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_get_cpuid_entry() in CPUID test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vCPU's CPUID directly in Hyper-V test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_get_cpuid_entry() in PV features test (sort of) (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_clear_cpuid_feature() in monitor_mwait_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add and use helper to set vCPU's CPUID maxphyaddr (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm->pa_bits to generate reserved PA bits (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add helpers to get and modify a vCPU's CPUID entries (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use get_cpuid_entry() in kvm_get_supported_cpuid_index() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename and tweak get_cpuid() to get_cpuid_entry() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Don't use a static local in vcpu_get_supported_hv_cpuid() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache CPUID in struct kvm_vcpu (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split out kvm_cpuid2_size() from allocate_kvm_cpuid2() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Verify that kvm_cpuid2.entries layout is unchanged by KVM (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nSVM soft INT injection test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for KVM's PV steal time (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove the obsolete/dead MMU role test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for XSAVE in cr4_cpuid_sync_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() in AMX test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Check for _both_ XTILE data and cfg in AMX test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for XSAVES in XSS MSR test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop redundant vcpu_set_cpuid() from PMU selftest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() to query PDCM in PMU selftest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nested VMX checks (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nested SVM checks (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() in the SEV migration test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add framework to query KVM CPUID bits (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use CPUID_* instead of X86_FEATURE_* for one-off usage (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Set KVM's supported CPUID as vCPU's CPUID during recreate (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix filename reporting in guest asserts (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Write REPORT_GUEST_ASSERT macros to pair with GUEST_ASSERT (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Increase UCALL_MAX_ARGS to 7 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: enumerate GUEST_ASSERT arguments (Vitaly Kuznetsov) [2119111]
- KVM: x86: WARN only once if KVM leaves a dangling userspace I/O request (Vitaly Kuznetsov) [2119111]
- KVM: x86: Set error code to segment selector on LLDT/LTR non-canonical #GP (Vitaly Kuznetsov) [2119111]
- KVM: x86: Mark TSS busy during LTR emulation _after_ all fault checks (Vitaly Kuznetsov) [2119111]
- KVM: x86: Tweak name of MONITOR/MWAIT #UD quirk to make it #UD specific (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use "a" and "d" to set EAX/EDX for wrmsr_safe() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Provide valid inputs for MONITOR/MWAIT regs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test MONITOR and MWAIT, not just MONITOR for quirk (Vitaly Kuznetsov) [2119111]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor, again (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Replace UNMAPPED_GVA with INVALID_GPA for gva_to_gpa() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fix handling of APIC LVT updates when userspace changes MCG_CAP (Vitaly Kuznetsov) [2119111]
- KVM: x86: Initialize number of APIC LVT entries during APIC creation (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Buffer nested MMU split_desc_cache only by default capacity (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use "unsigned int", not "u32", for SPTEs' @access info (Vitaly Kuznetsov) [2119111]
- KVM: SEV-ES: reuse advance_sev_es_emulated_ins for OUT too (Vitaly Kuznetsov) [2119111]
- KVM: x86: de-underscorify __emulator_pio_in (Vitaly Kuznetsov) [2119111]
- KVM: x86: wean fast IN from emulator_pio_in (Vitaly Kuznetsov) [2119111]
- KVM: x86: wean in-kernel PIO from vcpu->arch.pio* (Vitaly Kuznetsov) [2119111]
- KVM: x86: move all vcpu->arch.pio* setup in emulator_pio_in_out() (Vitaly Kuznetsov) [2119111]
- KVM: x86: drop PIO from unregistered devices (Vitaly Kuznetsov) [2119111]
- KVM: x86: inline kernel_pio into its sole caller (Vitaly Kuznetsov) [2119111]
- KVM: x86: complete fast IN directly with complete_emulator_pio_in() (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: optimize svm_set_x2apic_msr_interception (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Add AVIC doorbell tracepoint (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Use target APIC ID to complete x2AVIC IRQs when possible (Vitaly Kuznetsov) [2119111]
- KVM: x86: Warning APICv inconsistency only when vcpu APIC mode is valid (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce hybrid-AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not throw warning when calling avic_vcpu_load on a running vcpu (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce logic to (de)activate x2AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: always intercept x2apic msrs (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Refresh AVIC configuration when changing APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: x86: Deactivate APICv on vCPU with APIC disabled (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Adding support for configuring x2APIC MSRs interception (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not support updating APIC ID when in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Update avic_kick_target_vcpus to support 32-bit APIC ID (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Update max number of vCPUs supported for x2AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Detect X2APIC virtualization (x2AVIC) support (Vitaly Kuznetsov) [2119111]
- KVM: x86: lapic: Rename [GET/SET]_APIC_DEST_FIELD to [GET/SET]_XAPIC_DEST_FIELD (Vitaly Kuznetsov) [2119111]
- x86/cpufeatures: Introduce x2AVIC CPUID bit (Vitaly Kuznetsov) [2119111]
- KVM: debugfs: expose pid of vcpu threads (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: clean up posted interrupt descriptor try_cmpxchg (Vitaly Kuznetsov) [2119111]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Enhance handling WRMSR ICR register in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a self test for CMCI and UCNA emulations. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Enable CMCI capability by default and handle injected UCNA errors (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add emulation for MSR_IA32_MCx_CTL2 MSRs. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use kcalloc to allocate the mce_banks array. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add Corrected Machine Check Interrupt (CMCI) emulation to lapic. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add APIC_LVTx() macro. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Avoid unnecessary flush on eager page split (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fill apic_lvt_mask with enums / explicit entries. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Make APIC_VERSION capture only the magic 0x14UL. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Extend Eager Page Splitting to nested MMUs (Vitaly Kuznetsov) [2119111]
- KVM: Allow for different capacities in kvm_mmu_memory_cache structs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull call to drop_large_spte() into __link_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Zap collapsible SPTEs in shadow MMU at all possible levels (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Extend make_huge_page_split_spte() for the shadow MMU (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Cache the access bits of shadowed translations (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Update page stats in __rmap_add() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Decouple rmap_add() and link_shadow_page() from kvm_vcpu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass const memslot to rmap_add() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Allow NULL @vcpu in kvm_mmu_find_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass kvm pointer separately from vcpu to kvm_mmu_find_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Replace vcpu with kvm in kvm_mmu_alloc_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass memory caches to allocate SPs separately (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Move guest PT write-protection to account_shadowed() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename shadow MMU functions that deal with shadow pages (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Consolidate shadow page allocation and initialization (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Decompose kvm_mmu_get_page() into separate functions (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Always pass 0 for @quadrant when gptes are 8 bytes (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Derive shadow MMU page role from parent (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Stop passing "direct" to mmu_alloc_root() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use a bool for direct (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Optimize MMU page cache lookup for all direct SPs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache binary stats metadata for duration of test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test disabling NX hugepages on a VM (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add NX huge pages test (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: properly format KVM_CAP_VM_DISABLE_NX_HUGE_PAGES capability table (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: extend KVM_CAP_VM_DISABLE_NX_HUGE_PAGES heading underline (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: Allow NX huge pages to be disabled on a per-vm basis (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add API issues section (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fix errant brace in KVM capability handling (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stat data in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up coding style in binary stats test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stats desc in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stats header in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove dynamic memory allocation for stats header (Vitaly Kuznetsov) [2119111]
- KVM: x86/svm: add __GFP_ACCOUNT to __sev_dbg_{en,de}crypt_user() (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Handle compiler optimizations in ucall (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add MONITOR/MWAIT quirk test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use exception fixup for #UD/#GP Hyper-V MSR/hcall tests (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Mostly fix broken Hyper-V Features test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add x86-64 support for exception fixup (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add a quirk for KVM's "MONITOR/MWAIT are NOPs!" behavior (Vitaly Kuznetsov) [2119111]
- KVM: x86: Ignore benign host writes to "unsupported" F15H_PERF_CTL MSRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: Ignore benign host accesses to "unsupported" PEBS and BTS MSRs (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use vcpu_get_perf_capabilities() to get guest-visible value (Vitaly Kuznetsov) [2119111]
- Revert "KVM: x86: always allow host-initiated writes to PMU MSRs" (Vitaly Kuznetsov) [2119111]
- Revert "KVM: x86/pmu: Accept 0 for absent PMU MSRs when host-initiated if !enable_pmu" (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Give host userspace full control of MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Give host userspace full control of MSR_IA32_MISC_ENABLES (Vitaly Kuznetsov) [2119111]
- x86: kvm: remove NULL check before kfree (Vitaly Kuznetsov) [2119111]
- KVM: Do not zero initialize 'pfn' in hva_to_pfn() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Shove refcounted page dependency into host_pfn_mapping_level() (Vitaly Kuznetsov) [2119111]
- KVM: Rename/refactor kvm_is_reserved_pfn() to kvm_pfn_to_refcounted_page() (Vitaly Kuznetsov) [2119111]
- KVM: Take a 'struct page', not a pfn in kvm_is_zone_device_page() (Vitaly Kuznetsov) [2119111]
- KVM: Remove kvm_vcpu_gfn_to_page() and kvm_vcpu_gpa_to_page() (Vitaly Kuznetsov) [2119111]
- KVM: Don't WARN if kvm_pfn_to_page() encounters a "reserved" pfn (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Use kvm_vcpu_map() to get/pin vmcs12's APIC-access page (Vitaly Kuznetsov) [2119111]
- KVM: Avoid pfn_to_page() and vice versa when releasing pages (Vitaly Kuznetsov) [2119111]
- KVM: Don't set Accessed/Dirty bits for ZERO_PAGE (Vitaly Kuznetsov) [2119111]
- KVM: Drop bogus "pfn != 0" guard from kvm_release_pfn() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use common logic for computing the 32/64-bit base PA mask (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Truncate paging32's PT_BASE_ADDR_MASK to 32 bits (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use common macros to compute 32/64-bit paging masks (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use separate namespaces for guest PTEs and shadow PTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Dedup macros for computing various page table masks (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Bury 32-bit PSE paging helpers in paging_tmpl.h (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Refactor 32-bit PSE PT creation to avoid using MMU macro (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use lapic_in_kernel() to query in-kernel APIC in APICv helper (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move "apicv_active" into "struct kvm_lapic" (Vitaly Kuznetsov) [2119111]
- KVM: x86: Check for in-kernel xAPIC when querying APICv for directed yield (Vitaly Kuznetsov) [2119111]
- KVM: x86: Drop @vcpu parameter from kvm_x86_ops.hwapic_isr_update() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Drop unused AVIC / kvm_x86_ops declarations (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Update vmcs12 on BNDCFGS write, not at vmcs02=>vmcs12 sync (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Save BNDCFGS to vmcs12 iff relevant controls are exposed to L1 (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Rename nested.vmcs01_* fields to nested.pre_vmenter_* (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Snapshot pre-VM-Enter DEBUGCTL for !nested_run_pending case (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Snapshot pre-VM-Enter BNDCFGS for !nested_run_pending case (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use try_cmpxchg64 in fast_pf_fix_direct_spte (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use try_cmpxchg64 in pi_try_set_control (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use try_cmpxchg64 in tdp_mmu_set_spte_atomic (Vitaly Kuznetsov) [2119111]
- locking/atomic/x86: Introduce arch_try_cmpxchg64 (Vitaly Kuznetsov) [2119111]
- locking/atomic: Add generic try_cmpxchg64 support (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Skip filter updates for MSRs that KVM is already intercepting (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop unused CMPXCHG macro from paging_tmpl.h (Vitaly Kuznetsov) [2119111]
- KVM: X86/SVM: Use root_level in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Remove useless mmu_topup_memory_caches() in kvm_mmu_pte_write() (Vitaly Kuznetsov) [2119111]
- KVM: Rename ack_flush() to ack_kick() (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Remove unused PT32_DIR_BASE_ADDR_MASK from mmu.c (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Fix memop extension capability check (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Hide SEV migration lockdep goo behind CONFIG_PROVE_LOCKING (Vitaly Kuznetsov) [2119111]
- KVM: SEV: fix misplaced closing parenthesis (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove the mismatched parameter comments (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_has_cap(), not kvm_check_cap(), where possible (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop a duplicate TEST_ASSERT() in vm_nr_pages_required() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Call a dummy helper in VM/vCPU ioctls() to enforce type (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a missing apostrophe in comment to show ownership (Vitaly Kuznetsov) [2119111]
- KVM: selftests: kvm_binary_stats_test: Fix index expressions (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Sanity check input to ioctls() at build time (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use TAP-friendly ksft_exit_skip() in __TEST_REQUIRE (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add TEST_REQUIRE macros to reduce skipping copy+paste (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the memop test (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftest: Test suppression indication on key prot exception (Vitaly Kuznetsov) [2119111]
- KVM: s390: Don't indicate suppression on dirtying, failing memop (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add kvm_has_cap() to provide syntactic sugar (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return an 'unsigned int' from kvm_check_cap() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop DEFAULT_GUEST_PHY_PAGES, open code the magic number (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Trust that MAXPHYADDR > memslot0 in vmx_apic_access_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move per-VM/per-vCPU nr pages calculation to __vm_create() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @num_percpu_pages from __vm_create_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @slot0_mem_pages from __vm_create_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Open code and drop 'struct kvm_vm' accessors (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_state() helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop vcpu_get(), rename vcpu_find() => vcpu_exists() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Purge vm+vcpu_id == vcpu silliness (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Require vCPU output array when creating VM with vCPUs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_get() usage from dirty_log_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Stop conflating vCPU index and ID in perf tests (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Stop hardcoding vCPU IDs in vcpu_width_config (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert get-reg-list away from its "VCPU_ID" (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_binary_stats_test away from vCPU IDs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_page_table_test away from reliance on vcpu_id (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @vcpuids param from VM creators (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop vm_create_default* helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_with_vcpus() in max_guest_memory_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create() in tsc_scaling_sync (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert tprot away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the tprot test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert s390x/diag318_test_handler away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert memop away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert s390's "resets" test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the reset test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert sync_regs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the sync_regs test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xapic_ipi_test away from *_VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hypercalls test away from vm_create_default() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Sync stage before VM is freed in hypercalls test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Consolidate KVM_{G,S}ET_ONE_REG helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vgic_init away from vm_create_default_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert triple_fault_event_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_nested_soft_inject_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert arch_timer away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert steal_time away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add VM creation helper that "returns" vCPUs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hardware_disable_test to pass around vCPU objects (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert psci_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_boot_cpu_id away from global VCPU_IDs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_vcpu_add* helpers to better show relationships (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return created vcpu from vm_vcpu_add_default() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add "arch" to common utils that have arch implementations (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move vm_is_unrestricted_guest() to x86-64 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make arm64's guest_get_vcpuid() declaration arm64-only (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vgic_irq away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert fix_hypercall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert debug-exceptions away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xapic_state_test away from hardcoded vCPU ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Track kvm_vcpu object in tsc_scaling_sync (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert system_counter_offset_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_memory_region_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert dirty_log_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xen_shinfo_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xen_vmcall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_invalid_nested_guest_state away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert userspace_io_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert cpuid_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert cr4_cpuid_sync_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert amx_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add proper helper for advancing RIP in debug_regs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert debug_regs away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert emulator_error_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert evmcs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_clock away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_features away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_svm_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_clock_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert tsc_msrs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_exception_with_invalid_guest_state away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert userspace_msr_exit_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_apic_access_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_close_while_nested_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_dirty_log_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_sregs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_nested_tsc_scaling_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert platform_info_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_pv_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_cpuid away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert sync_regs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_vmcall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_int_ctl_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert state_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert smm_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert pmu_event_filter_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert mmu_role_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_tsc_adjust_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_set_nested_state_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_pmu_msrs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_preemption_timer_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xss_msr_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert rseq_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert memslot_perf_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return the created vCPU from vm_vcpu_add() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename 'struct vcpu' to 'struct kvm_vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vcpu.state => vcpu.run (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename xAPIC state test's vcpu struct (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vm_create() a wrapper that specifies VM_MODE_DEFAULT (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_create_without_vcpus() => vm_create() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_create() => vm_create_barebones(), drop param (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Avoid memory allocations when adding vCPU in get-reg-list (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in psci_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in hardware_disable_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in dirty_log_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in set_boot_cpu_id (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Push vm_adjust_num_guest_pages() into "w/o vCPUs" helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add vm_create_*() variants to expose/return 'struct vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftest: Add proper helpers for x86-specific save/restore ioctls (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename MP_STATE and GUEST_DEBUG helpers for consistency (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Dedup MSR index list helpers, simplify dedicated test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Harden and comment XSS / KVM_SET_MSRS interaction (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache list of MSRs to save/restore (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Simplify KVM_ENABLE_CAP helper APIs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Consolidate KVM_ENABLE_CAP usage (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a VM backpointer to 'struct vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Dedup vgic_init's asserts and improve error messages (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split get/set device_attr helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop 'int' return from asserting *_has_device_attr() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename KVM_HAS_DEVICE_ATTR helpers for consistency (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Multiplex return code and fd in __kvm_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move KVM_CREATE_DEVICE_TEST code to separate helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @test param from kvm_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use KVM_IOCTL_ERROR() for one-off arm64 ioctls (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Get rid of kvm_util_internal.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make x86-64's register dump helpers static (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use __KVM_SYSCALL_ERROR() to handle non-KVM syscall errors (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make kvm_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use vm_ioctl() and __vm_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vm_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add vcpu_get() to retrieve and assert on vCPU existence (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_get_fd() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_access_device_attr() in arm64 code (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add __vcpu_run() helper (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use vcpu_ioctl() and __vcpu_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split vcpu_set_nested_state() into two helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @mode from common vm_create() helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vcpu_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add another underscore to inner ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Always open VM file descriptors with O_RDWR (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop stale declarations from kvm_util_base.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix typo in vgic_init test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix buggy-but-benign check in test_v3_new_redist_regions() (Vitaly Kuznetsov) [2119111]
- selftests: KVM: aarch64: Add the bitmap firmware registers to get-reg-list (Vitaly Kuznetsov) [2119111]
- selftests: KVM: aarch64: Introduce hypercall ABI test (Vitaly Kuznetsov) [2119111]
- tools: Import ARM SMCCC definitions (Vitaly Kuznetsov) [2119111]
- Docs: KVM: Add doc for the bitmap firmware registers (Vitaly Kuznetsov) [2119111]
- Docs: KVM: Rename psci.rst to hypercalls.rst (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add vendor hypervisor firmware register (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add standard hypervisor firmware register (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Setup a framework for hypercall bitmap firmware registers (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Factor out firmware register handling from psci.c (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Test SYSTEM_SUSPEND PSCI call (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Refactor psci_test to make it amenable to new tests (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Use KVM_SET_MP_STATE to power off vCPU in psci_test (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Create helper for making SMCCC calls (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Rename psci_cpu_on_test to psci_test (Vitaly Kuznetsov) [2119111]
- KVM: Fix references to non-existent KVM_CAP_TRIPLE_FAULT_EVENT (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM on an out-of-bounds data read (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if the emulator generates a bogus exception vector (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if the emulator accesses a non-existent GPR (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reduce the number of emulator GPRs to '8' for 32-bit KVM (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use 16-bit fields to track dirty/valid emulator GPRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: Omit VCPU_REGS_RIP from emulator's _regs array (Vitaly Kuznetsov) [2119111]
- KVM: x86: Harden _regs accesses to guard against buggy input (Vitaly Kuznetsov) [2119111]
- KVM: x86: Grab regs_dirty in local 'unsigned long' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Restrict test region to 48-bit physical addresses when using nested (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add option to run dirty_log_perf_test vCPUs in L2 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up LIBKVM files in Makefile (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Link selftests directly with lib object files (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unnecessary rule for STATIC_LIBS (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a helper to check EPT/VPID capabilities (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move VMX_EPT_VPID_CAP_AD_BITS to vmx.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Refactor nested_map() to specify target level (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop stale function parameter comment for nested_map() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add option to create 2M and 1G EPT mappings (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Replace x86_page_size with PG_LEVEL_XX (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: fix nested PAUSE filtering when L0 intercepts PAUSE (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: drop preempt-safe wrappers for avic_vcpu_load/put (Vitaly Kuznetsov) [2119111]
- KVM: x86: disable preemption around the call to kvm_arch_vcpu_{un|}blocking (Vitaly Kuznetsov) [2119111]
- KVM: x86: disable preemption while updating apicv inhibition (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: fix avic_kick_target_vcpus_fast (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: remove avic's broken code that updated APIC ID (Vitaly Kuznetsov) [2119111]
- KVM: x86: inhibit APICv/AVIC on changes to APIC ID or APIC base (Vitaly Kuznetsov) [2119111]
- KVM: x86: document AVIC/APICv inhibit reasons (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Set memory encryption "value", not "mask", in shadow PDPTRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: PIT: Preserve state of speaker port data bit (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Reject kvm_intel if an inconsistent VMCS config is detected (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Sanitize VM-Entry/VM-Exit control pairs at kvm_intel load time (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Accept 0 for absent PMU MSRs when host-initiated if !enable_pmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Restrict advanced features based on module enable_pmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Avoid exposing Intel BTS feature (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Update global enable_pmu when PMU is undetected (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Enable Notify VM exit (Vitaly Kuznetsov) [2119111]
- KVM: x86: Introduce "struct kvm_caps" to track misc caps/settings (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a test to get/set triple fault event (Vitaly Kuznetsov) [2119111]
- KVM: x86: Extend KVM_{G,S}ET_VCPU_EVENTS to support pending triple fault (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop amd_event_mapping[] in the KVM context (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Replace pmc_perf_hw_id() with perf_get_hw_event_config() (Vitaly Kuznetsov) [2119111]
- perf: x86/core: Add interface to query perfmon_event_map[] directly (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Use PERF_TYPE_RAW to merge reprogram_{gp,fixed}counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Use only the uniform interface reprogram_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop "u8 ctrl, int idx" for reprogram_fixed_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop "u64 eventsel" for reprogram_gp_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Pass only "struct kvm_pmc *pmc" to reprogram_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Extract check_pmu_event_filter() handling both GP and fixed counters (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Update comments for AMD gp counters (Vitaly Kuznetsov) [2119111]
- KVM: x86: always allow host-initiated writes to PMU MSRs (Vitaly Kuznetsov) [2119111]
- KVM: vmx, pmu: accept 0 for host-initiated write to MSR_IA32_DS_AREA (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Ignore pmu->global_ctrl check if vPMU doesn't support global_ctrl (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Don't overwrite the pmu->global_ctrl when refreshing (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: remove useless prototype (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Move the vmx_icl_pebs_cpu[] definition out of the header file (Vitaly Kuznetsov) [2119111]
- selftests: kvm: replace ternary operator with min() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Expose CPUIDs feature bits PDCM, DS, DTES64 (Vitaly Kuznetsov) [2119111]
- KVM: x86/cpuid: Refactor host/guest CPU model consistency check (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add kvm_pmu_cap to optimize perf_get_x86_pmu_capability (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Disable guest PEBS temporarily in two rare situations (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Move pmc_speculative_in_use() to arch/x86/kvm/pmu.h (Vitaly Kuznetsov) [2119111]
- KVM: x86: Set PEBS_UNAVAIL in IA32_MISC_ENABLE when PEBS is enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add PEBS_DATA_CFG MSR emulation to support adaptive PEBS (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add IA32_DS_AREA MSR emulation to support guest DS (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Adjust precise_ip to emulate Ice Lake guest PDIR counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Reprogram PEBS event to emulate guest PEBS counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add IA32_PEBS_ENABLE MSR emulation for extended PEBS (Vitaly Kuznetsov) [2119111]
- x86/perf/core: Add pebs_capable to store valid PEBS_COUNTER_MASK value (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Introduce the ctrl_mask value for fixed counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Set MSR_IA32_MISC_ENABLE_EMON bit when vPMU is enabled (Vitaly Kuznetsov) [2119111]
- perf/x86/core: Pass "struct kvm_pmu *" to determine the guest values (Vitaly Kuznetsov) [2119111]
- perf/x86/intel: Handle guest PEBS overflow PMI for KVM guest (Vitaly Kuznetsov) [2119111]
- perf/x86/intel: Add EPT-Friendly PEBS for Ice Lake Server (Vitaly Kuznetsov) [2119111]
- KVM: VMX: enable IPI virtualization (Vitaly Kuznetsov) [2119111]
- kvm: selftests: Add KVM_CAP_MAX_VCPU_ID cap test (Vitaly Kuznetsov) [2119111]
- KVM: x86: Allow userspace to set maximum VCPU id for VM (Vitaly Kuznetsov) [2119111]
- KVM: Move kvm_arch_vcpu_precreate() under kvm->lock (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Clean up vmx_refresh_apicv_exec_ctrl() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add support for vICR APIC-write VM-Exits in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Report tertiary_exec_control field in dump_vmcs() (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Detect Tertiary VM-Execution control when setup VMCS config (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Extend BUILD_CONTROLS_SHADOW macro to support 64-bit variation (Vitaly Kuznetsov) [2119111]
- x86/cpu: Add new VMX feature, Tertiary VM-Execution control (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Comment FNAME(sync_page) to document TLB flushing logic (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop RWX=0 SPTEs during ept_sync_page() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: nSVM: Add svm_nested_soft_inject_test (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Transparently handle L1 -> L2 NMI re-injection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Differentiate Soft vs. Hard IRQs vs. reinjected in tracepoint (Vitaly Kuznetsov) [2119111]
- KVM: x86: Print error code in exception injection tracepoint iff valid (Vitaly Kuznetsov) [2119111]
- KVM: x86: Trace re-injected exceptions (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Re-inject INTn instead of retrying the insn on "failure" (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Re-inject INT3/INTO instead of retrying the instruction (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Stuff next_rip on emulated INT3 injection if NRIPS is supported (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Unwind "speculative" RIP advancement if INTn injection "fails" (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Don't BUG if userspace injects an interrupt with GIF=0 (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Sync next_rip field from vmcb12 to vmcb02 (Vitaly Kuznetsov) [2119111]
- KVM: x86: do not report a vCPU as preempted outside instruction boundaries (Vitaly Kuznetsov) [2119111]
- KVM: x86: do not set st->preempted when going back to user space (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make hyperv_clock selftest more stable (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: Zap non-leaf SPTEs when disabling dirty logging (Vitaly Kuznetsov) [2119111]
- KVM: Don't null dereference ops->destroy (Vitaly Kuznetsov) [2119111]
- KVM: x86: hyper-v: replace bitmap_weight() with hweight64() (Vitaly Kuznetsov) [2119111]
- x86: Fix all occurences of the "the the" typo (Vitaly Kuznetsov) [2119111]
- KVM: Do not pin pages tracked by gfn=>pfn caches (Vitaly Kuznetsov) [2119111]
- KVM: Fix multiple races in gfn=>pfn cache refresh (Vitaly Kuznetsov) [2119111]
- KVM: Fully serialize gfn=>pfn cache refresh via mutex (Vitaly Kuznetsov) [2119111]
- KVM: Do not incorporate page offset into gfn=>pfn cache user address (Vitaly Kuznetsov) [2119111]
- KVM: Put the extra pfn reference when reusing a pfn in the gpc cache (Vitaly Kuznetsov) [2119111]
- KVM: Drop unused @gpa param from gfn=>pfn cache's __release_gpc() helper (Vitaly Kuznetsov) [2119111]
- KVM: set_msr_mce: Permit guests to ignore single-bit ECC errors (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Print VM-instruction error as unsigned (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Print VM-instruction error when it may be helpful (Vitaly Kuznetsov) [2119111]
- KVM: selftests: x86: Sync the new name of the test case to .gitignore (Vitaly Kuznetsov) [2119111]
- x86, kvm: use correct GFP flags for preemption disabled (Vitaly Kuznetsov) [2119111]
- x86/kvm: Alloc dummy async #PF token outside of raw spinlock (Vitaly Kuznetsov) [2119111]
- KVM: selftests: x86: Fix test failure on arch lbr capable platforms (Vitaly Kuznetsov) [2119111]
- KVM: LAPIC: Trace LAPIC timer expiration on every vmentry (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: fix NULL pointer dereference on guest INVPCID (Vitaly Kuznetsov) [2119111]
- KVM: x86: hyper-v: fix type of valid_bank_mask (Vitaly Kuznetsov) [2119111]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Update number of zapped pages even if page list is stable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Speed up slot_rmap_walk_next for sparsely populated rmaps (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Include MKTME KeyID bits in shadow_zero_check (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add shadow_me_value and repurpose shadow_me_mask (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename reset_rsvds_bits_mask() (Vitaly Kuznetsov) [2119111]
- KVM: x86: a vCPU with a pending triple fault is runnable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Expand and clean up page fault stats (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use IS_ENABLED() to avoid RETPOLINE for TDP page faults (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Make all page fault handlers internal to the MMU (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add RET_PF_CONTINUE to eliminate bool+int* "returns" (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop exec/NX check from "page fault can be fast" (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't attempt fast page fault just because EPT is in use (Vitaly Kuznetsov) [2119111]
- KVM: VMX: clean up pi_wakeup_handler (Vitaly Kuznetsov) [2119111]
- KVM: x86: fix typo in __try_cmpxchg_user causing non-atomicness (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use vcpu_to_pi_desc() uniformly in posted_intr.c (Vitaly Kuznetsov) [2119111]
- KVM: Add max_vcpus field in common 'struct kvm' (Vitaly Kuznetsov) [2119111]
- KVM: x86: replace bitmap_weight with bitmap_empty where appropriate (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Fix shadowing 5-level NPT for 4-level NPT L1 guest (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Add sp_has_gptes() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce trace point for the slow-path of avic_kic_target_vcpus (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Use target APIC ID to complete AVIC IRQs when possible (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace direct_map with root_role.direct (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace root_level with cpu_role.base.level (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace shadow_root_level with root_role.level (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull CPU mode computation to kvm_init_mmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: simplify and/or inline computation of shadow MMU roles (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove redundant bits from extended role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rename kvm_mmu_role union (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove extended bits from mmu_role, rename field (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: store shadow EFER.NX in the MMU role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: cleanup computation of MMU roles for shadow paging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: cleanup computation of MMU roles for two-dimensional paging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove kvm_calc_shadow_root_page_role_common (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove ept_ad field (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: do not recompute root level from kvm_mmu_role_regs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: split cpu_role from mmu_role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove "bool base_only" arguments (Vitaly Kuznetsov) [2119111]
- KVM: x86: Clean up and document nested #PF workaround (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rephrase unclear comment (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull computation of kvm_mmu_role_regs to kvm_init_mmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: constify uses of struct kvm_mmu_role_regs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: nested EPT cannot be used in SMM (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use enable_mmio_caching to track if MMIO caching is enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Check for host MMIO exclusion from mem encrypt iff necessary (Vitaly Kuznetsov) [2119111]
- KVM: SEV-ES: Use V_TSC_AUX if available instead of RDTSC/MSR_TSC_AUX intercepts (Vitaly Kuznetsov) [2119111]
- x86/cpufeatures: Add virtual TSC_AUX feature bit (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Implement PSCI SYSTEM_SUSPEND (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add support for userspace to suspend a vCPU (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Return a value from check_vcpu_requests() (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Rename the KVM_REQ_SLEEP handler (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Track vCPU power state using MP state values (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Dedupe vCPU power off helpers (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Don't depend on fallthrough to hide SYSTEM_RESET2 (Vitaly Kuznetsov) [2119111]
- KVM: fix bad user ABI for KVM_EXIT_SYSTEM_EVENT (Vitaly Kuznetsov) [2119111]
- KVM: SPDX style and spelling fixes (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bail to userspace if emulation of atomic user access faults (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __try_cmpxchg_user() to emulate atomic accesses (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __try_cmpxchg_user() to update guest PTE A/D bits (Vitaly Kuznetsov) [2119111]
- x86: drop bogus "cc" clobber from __try_cmpxchg_user_asm() (Vitaly Kuznetsov) [2119111]
- x86/uaccess: Implement macros for CMPXCHG on user addresses (Vitaly Kuznetsov) [2119111]
- objtool: Remove .fixup handling (Vitaly Kuznetsov) [2119111]
- x86: Remove .fixup section (Vitaly Kuznetsov) [2119111]
- x86/word-at-a-time: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/usercopy: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/usercopy_32: Simplify __copy_user_intel_nocache() (Vitaly Kuznetsov) [2119111]
- x86/checksum_32: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/kvm: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/segment: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/fpu: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/xen: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/uaccess: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/futex: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/msr: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/extable: Extend extable functionality (Vitaly Kuznetsov) [2119111]
- x86/entry_32: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/entry_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/copy_mc_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/copy_mc: Use EX_TYPE_DEFAULT_MCE_SAFE for exception fixups (Vitaly Kuznetsov) [2119111]
- x86/copy_user_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- bitfield.h: Fix "type of reg too small for mask" test (Vitaly Kuznetsov) [2119111]
- x86/ftrace: Remove fault protection code in prepare_ftrace_return (Vitaly Kuznetsov) [2119111]
- KVM, SEV: Add KVM_EXIT_SHUTDOWN metadata for SEV-ES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use static calls to reduce kvm_pmu_ops overhead (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move .pmu_ops to kvm_x86_init_ops and tag as __initdata (Vitaly Kuznetsov) [2119111]
- KVM: x86: Copy kvm_pmu_ops by value to eliminate layer of indirection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move kvm_ops_static_call_update() to x86.c (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Derive EPT violation RWX bits from EPTE RWX bits (Vitaly Kuznetsov) [2119111]
- KVM: VMX: replace 0x180 with EPT_VIOLATION_* definition (Vitaly Kuznetsov) [2119111]
- x86/kvm: Don't waste kvmclock memory if there is nopv parameter (Vitaly Kuznetsov) [2119111]
- kvm: vmx: remove redundant parentheses (Vitaly Kuznetsov) [2119111]
- kvm: x86: Adjust the location of pkru_mask of kvm_mmu to reduce memory (Vitaly Kuznetsov) [2119111]
- selftests: kvm/x86/xen: Replace a comma in the xen_shinfo_test with semicolon (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Remove the redundantly included header file lapic.h (Vitaly Kuznetsov) [2119111]
- x86/kvm/svm: Force-inline GHCB accessors (Vitaly Kuznetsov) [2119111]
- KVM: x86: optimize PKU branching in kvm_load_{guest|host}_xsave_state (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: allow AVIC to co-exist with a nested guest running (Vitaly Kuznetsov) [2119111]
- KVM: x86: allow per cpu apicv inhibit reasons (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: implement nested vGIF (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: support PAUSE filtering when L0 doesn't intercept PAUSE (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: remove vgif_enabled() (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: use vmcb01 in init_vmcb (Vitaly Kuznetsov) [2119111]
- KVM: x86: Support the vCPU preemption check with nopvspin and realtime hint (Vitaly Kuznetsov) [2119111]
- KVM: x86: Test case for TSC scaling and offset sync (Vitaly Kuznetsov) [2119111]
- KVM: x86: Don't snapshot "max" TSC if host TSC is constant (Vitaly Kuznetsov) [2119111]
- KVM: x86: Accept KVM_[GS]ET_TSC_KHZ as a VM ioctl. (Vitaly Kuznetsov) [2119111]
- KVM: x86/i8259: Remove a dead store of irq in a conditional block (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Prepare VMCS setting for posted interrupt enabling when APICv is available (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Update self test for Xen PV timers (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Add self tests for KVM_XEN_HVM_CONFIG_EVTCHN_SEND (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV spinlocks slowpath (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Advertise and document KVM_XEN_HVM_CONFIG_EVTCHN_SEND (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Support per-vCPU event channel upcall via local APIC (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Kernel acceleration for XENVER_version (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV timers oneshot mode (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Add KVM_XEN_VCPU_ATTR_TYPE_VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV IPI vcpu yield (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: intercept EVTCHNOP_send from guests (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Support direct injection of event channel events (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Make kvm_xen_set_evtchn() reusable from other places (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for vcpu_time_info (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for vcpu_info (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use gfn_to_pfn_cache for pv_time (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for runstate area (Vitaly Kuznetsov) [2119111]
- KVM: x86: mark synthetic SMM vmexit as SVM_EXIT_SW (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: allow to force AVIC to be enabled (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Test KVM_X86_QUIRK_FIX_HYPERCALL_INSN (Vitaly Kuznetsov) [2119111]
- KVM: x86: Allow userspace to opt out of hypercall patching (Vitaly Kuznetsov) [2119111]
- x86/ibt,paravirt: Sprinkle ENDBR (Vitaly Kuznetsov) [2119111]
- x86/vmx: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (other cases) (Jose Ignacio Tornos Martinez) [2111745]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (Jose Ignacio Tornos Martinez) [2111745]

* Wed Oct 26 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-181.el9]
- perf test: Record only user callchains on the "Check Arm64 callgraphs are complete in fp mode" test (Michael Petlan) [2049125]
- scsi: core: Allow the ALUA transitioning state enough time (Ewan D. Milne) [2132461]
- scsi: ch: Do not initialise statics to 0 (Ewan D. Milne) [2132461]
- scsi: core: Fix warning in scsi_alloc_sgtables() (Ewan D. Milne) [2132461]
- scsi: sg: Allow waiting for commands to complete on removed device (Ewan D. Milne) [2132461]
- scsi: core: Move the definition of SCSI_QUEUE_DELAY (Ewan D. Milne) [2132461]
- scsi: core: Shorten long warning messages (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix zone transition to full condition (Ewan D. Milne) [2132461]
- scsi: sd: Fix interpretation of VPD B9h length (Ewan D. Milne) [2132461]
- scsi: core: Return BLK_STS_TRANSPORT for ALUA transitioning (Ewan D. Milne) [2132461]
- scsi: sd_zbc: Prevent zone information memory leak (Ewan D. Milne) [2132461]
- scsi: sd: Fix potential NULL pointer dereference (Ewan D. Milne) [2132461]
- scsi: sd: Don't call blk_cleanup_disk() in sd_probe() (Ewan D. Milne) [2132461]
- scsi: sr: Add memory allocation failure handling for get_capabilities() (Ewan D. Milne) [2132461]
- scsi: sd: Reorganize DIF/DIX code to avoid calling revalidate twice (Ewan D. Milne) [2132461]
- scsi: sd: Optimal I/O size should be a multiple of reported granularity (Ewan D. Milne) [2132461]
- scsi: sd: Switch to using scsi_device VPD pages (Ewan D. Milne) [2132461]
- scsi: sd: Use cached ATA Information VPD page (Ewan D. Milne) [2132461]
- scsi: core: Do not truncate INQUIRY data on modern devices (Ewan D. Milne) [2132461]
- scsi: core: Cache VPD pages b0, b1, b2 (Ewan D. Milne) [2132461]
- scsi: core: Pick suitable allocation length in scsi_report_opcode() (Ewan D. Milne) [2132461]
- scsi: core: Query VPD size before getting full page (Ewan D. Milne) [2132461]
- scsi: fcoe: Fix Wstringop-overflow warnings in fcoe_wwn_from_mac() (Ewan D. Milne) [2132461]
- scsi: core: Refine how we set tag_set NUMA node (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add gap zone support (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Rename zone type constants (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix a typo (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Hide gap zones (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Return early in sd_zbc_check_zoned_characteristics() (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Introduce struct zoned_disk_info (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Use logical blocks as unit when querying zones (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Verify that the zone size is a power of two (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Improve source code documentation (Ewan D. Milne) [2132461]
- scsi: core: Increase max device queue_depth to 4096 (Ewan D. Milne) [2132461]
- scsi: sr: Do not leak information in ioctl (Ewan D. Milne) [2132461]
- scsi: sd: Clean up gendisk if device_add_disk() failed (Ewan D. Milne) [2132461]
- scsi: sd: sd_read_cpr() requires VPD pages (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix sdebug_blk_mq_poll() in_use_bm bitmap use (Ewan D. Milne) [2132461]
- scsi: core: sysfs: Remove comments that conflict with the actual logic (Ewan D. Milne) [2132461]
- scsi: core: Remove unreachable code warning (Ewan D. Milne) [2132461]
- scsi: libfc: Fix use after free in fc_exch_abts_resp() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix qc_lock use in sdebug_blk_mq_poll() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Silence unexpected unlock warnings (Ewan D. Milne) [2132461]
- scsi: Remove unused member cmd_pool for structure scsi_host_template (Ewan D. Milne) [2132461]
- scsi: core: Make "access_state" sysfs attribute always visible (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add environmental reporting log subpage (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add no_rwlock parameter (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Divide power on reset UNIT ATTENTION (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Refine sdebug_blk_mq_poll() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Call scsi_done() directly (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Use TASK SET FULL more (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Strengthen defer_t accesses (Ewan D. Milne) [2132461]
- scsi: ch: Don't use GFP_DMA (Ewan D. Milne) [2132461]
- wireguard: netlink: avoid variable-sized memcpy on sockaddr (Hangbin Liu) [2135317]
- rhel: Enable imx8 I2C configs properly (Al Stone) [2071838]
- i2c: imx: fix typo in comment (Al Stone) [2071838]
- i2c: dev: Force case user pointers in compat_i2cdev_ioctl() (Al Stone) [2071838]
- i2c: dev: check return value when calling dev_set_name() (Al Stone) [2071838]
- i2c: imx: Implement errata ERR007805 or e7805 bus frequency limit (Al Stone) [2071838]
- i2c: mux: demux-pinctrl: do not deactivate a master that is not active (Al Stone) [2071838]
- i2c: add tracepoints for I2C slave events (Al Stone) [2071838]
- i2c: tegra: Add SMBus block read function (Al Stone) [2071838]
- i2c: core: Use generic_handle_irq_safe() in i2c_handle_smbus_host_notify(). (Al Stone) [2071838]
- i2c: smbus: Check for parent device before dereference (Al Stone) [2071838]
- i2c: imx: allow COMPILE_TEST (Al Stone) [2071838]
- i2c: don't expose function which is only used internally (Al Stone) [2071838]
- i2c: ACPI: Replace acpi_bus_get_device() (Al Stone) [2071838]
- i2c: smbus: Use device_*() functions instead of of_*() (Al Stone) [2071838]
- Revert "i2c: core: support bus regulator controlling in adapter" (Al Stone) [2071838]
- i2c: validate user data in compat ioctl (Al Stone) [2071838]
- i2c: acpi: Do not instantiate I2C-clients on boards with known bogus DSDT entries (Al Stone) [2071838]
- i2c: acpi: Add i2c_acpi_new_device_by_fwnode() function (Al Stone) [2071838]
- i2c: acpi: Use acpi_dev_ready_for_enumeration() helper (Al Stone) [2071838]
- i2c: tegra: use i2c_timings for bus clock freq (Al Stone) [2071838]
- i2c: virtio: fix completion handling (Al Stone) [2071838]
- i2c: enable async suspend/resume on i2c client devices (Al Stone) [2071838]
- i2c: enable async suspend/resume for i2c adapters (Al Stone) [2071838]
- i2c: tegra: Add the ACPI support (Al Stone) [2071838]
- i2c: mux: gpio: Use array_size() helper (Al Stone) [2071838]
- i2c: mux: gpio: Don't dereference fwnode from struct device (Al Stone) [2071838]
- i2c: mux: gpio: Replace custom acpi_get_local_address() (Al Stone) [2071838]
- i2c: imx: Add timer for handling the stop condition (Al Stone) [2071838]
- i2c: virtio: disable timeout handling (Al Stone) [2071838]
- i2c: Allow an ACPI driver to manage the device's power state during probe (Al Stone) [2071838]
- i2c: virtio: Add support for zero-length requests (Al Stone) [2071838]
- i2c: tegra: Ensure that device is suspended before driver is removed (Al Stone) [2071838]
- i2c: acpi: Replace custom function with device_match_acpi_handle() (Al Stone) [2071838]
- i2c: switch from 'pci_' to 'dma_' API (Al Stone) [2071838]
- i2c: acpi: fix resource leak in reconfiguration device addition (Al Stone) [2071838]
- i2c: virtio: add a virtio i2c frontend driver (Al Stone) [2071838]
- i2c: remove dead PMC MSP TWI/SMBus/I2C driver (Al Stone) [2071838]
- i2c: dev: Use sysfs_emit() in "show" functions (Al Stone) [2071838]
- i2c: dev: Define pr_fmt() and drop duplication substrings (Al Stone) [2071838]
- i2c: imx: : use proper DMAENGINE API for termination (Al Stone) [2071838]
- remove CONFIG_PTE_MARKER and add CONFIG_PTE_MARKER_UFFD_WP (Chris von Recklinghausen) [2136480]
- mm/uffd: move USERFAULTFD configs into mm/ (Chris von Recklinghausen) [2136480]
- mm: enable PTE markers by default (Chris von Recklinghausen) [2136480]
- mm/uffd: PTE_MARKER_UFFD_WP (Chris von Recklinghausen) [2136480]
- scsi: qedf: Populate sysfs attributes for vport (Nilesh Javali) [2125169]
- scsi: qedf: Fix typo in comment (Nilesh Javali) [2111468]
- scsi: qedf: Remove redundant variable op (Nilesh Javali) [2111468]
- scsi: qedf: Remove an unneeded NULL check on list iterator (Nilesh Javali) [2111468]
- scsi: qedf: Remove unnecessary code (Nilesh Javali) [2111468]
- scsi: bnx2fc: Avoid using get_cpu() in bnx2fc_cmd_alloc() (Nilesh Javali) [2119312]
- scsi: bnx2fc: Fix spelling mistake "mis-match" -> "mismatch" (Nilesh Javali) [2119312]
- scsi: bnx2fc: Make use of the helper macro kthread_run() (Nilesh Javali) [2119312]
- scsi: bnx2fc: Fix typo in comments (Nilesh Javali) [2119312]

* Tue Oct 25 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-180.el9]
- s390/qeth: cache link_info for ethtool (Tobias Huschle) [2110436]
- s390/qeth: Fix typo 'the the' in comment (Tobias Huschle) [2110436]
- s390/qdio: Fix spelling mistake (Tobias Huschle) [2110436]
- s390/lcs: fix variable dereferenced before check (Tobias Huschle) [2110436]
- s390/ctcm: fix potential memory leak (Tobias Huschle) [2110436]
- s390/ctcm: fix variable dereferenced before check (Tobias Huschle) [2110436]
- qeth: remove a copy of the NAPI_POLL_WEIGHT define (Tobias Huschle) [2110436]
- nfp: nfdk: implement xdp tx path for NFDK (Stefan Assmann) [2124279]
- nfp: add support for NFDK data path (Stefan Assmann) [2124279]
- nfp: choose data path based on version (Stefan Assmann) [2124279]
- nfp: add per-data path feature mask (Stefan Assmann) [2124279]
- nfp: use TX ring pointer write back (Stefan Assmann) [2124279]
- nfp: move tx_ring->qcidx into cold data (Stefan Assmann) [2124279]
- nfp: prepare for multi-part descriptors (Stefan Assmann) [2124279]
- nfp: use callbacks for slow path ring related functions (Stefan Assmann) [2124279]
- nfp: move the fast path code to separate files (Stefan Assmann) [2124279]
- nfp: calculate ring masks without conditionals (Stefan Assmann) [2124279]
- nfp: flower: avoid newline at the end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: add support for NFP3800/NFP3803 PCIe devices (Stefan Assmann) [2124279]
- nfp: take chip version into account for ring sizes (Stefan Assmann) [2124279]
- nfp: parametrize QCP offset/size using dev_info (Stefan Assmann) [2124279]
- nfp: use dev_info for the DMA mask (Stefan Assmann) [2124279]
- nfp: use dev_info for PCIe config space BAR offsets (Stefan Assmann) [2124279]
- nfp: introduce dev_info static chip data (Stefan Assmann) [2124279]
- nfp: sort the device ID tables (Stefan Assmann) [2124279]
- nfp: use PluDevice register for model for non-NFP6000 chips (Stefan Assmann) [2124279]
- nfp: use PCI_DEVICE_ID_NETRONOME_NFP6000_VF for VFs instead (Stefan Assmann) [2124279]
- nfp: remove pessimistic NFP_QCP_MAX_ADD limits (Stefan Assmann) [2124279]
- nfp: remove define for an unused control bit (Stefan Assmann) [2124279]
- nfp: xsk: fix a warning when allocating rx rings (Stefan Assmann) [2124279]
- nfp: xsk: avoid newline at the end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: xsk: add AF_XDP zero-copy Rx and Tx support (Stefan Assmann) [2124279]
- nfp: xsk: add configuration check for XSK socket chunk size (Stefan Assmann) [2124279]
- nfp: xsk: add an array of xsk buffer pools to each data path (Stefan Assmann) [2124279]
- nfp: wrap napi add/del logic (Stefan Assmann) [2124279]
- nfp: expose common functions to be used for AF_XDP (Stefan Assmann) [2124279]
- nfp: flower: Remove usage of the deprecated ida_simple_xxx API (Stefan Assmann) [2124279]
- nfp: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: add NFP_FL_FEATS_QOS_METER to host features to enable meter offload (Stefan Assmann) [2124279]
- nfp: add support to offload police action from flower table (Stefan Assmann) [2124279]
- nfp: add process to get action stats from hardware (Stefan Assmann) [2124279]
- nfp: add hash table to store meter table (Stefan Assmann) [2124279]
- nfp: add support to offload tc action to hardware (Stefan Assmann) [2124279]
- nfp: refactor policer config to support ingress/egress meter (Stefan Assmann) [2124279]
- nfp: flower: Fix a potential leak in nfp_tunnel_add_shared_mac() (Stefan Assmann) [2124279]
- nfp: flower: netdev offload check for ip6gretap (Stefan Assmann) [2124279]
- nfp: flower: fix ida_idx not being released (Stefan Assmann) [2124279]
- nfp: Simplify array allocation (Stefan Assmann) [2124279]
- nfp: only use kdoc style comments for kdoc (Stefan Assmann) [2124279]
- nfp: flower: Use struct_size() helper in kmalloc() (Stefan Assmann) [2124279]
- nfp: flower: refine the use of circular buffer (Stefan Assmann) [2124279]
- nfp: Fix memory leak in nfp_cpp_area_cache_add() (Stefan Assmann) [2124279]
- nfp: checking parameter process for rx-usecs/tx-usecs is invalid (Stefan Assmann) [2124279]
- nfp: flower: correction of error handling (Stefan Assmann) [2124279]
- nfp: fix potential deadlock when canceling dim work (Stefan Assmann) [2124279]
- nfp: fix NULL pointer access when scheduling dim work (Stefan Assmann) [2124279]
- nfp: flower: Allow ipv6gretap interface for offloading (Stefan Assmann) [2124279]
- ethernet: constify references to netdev->dev_addr in drivers (Stefan Assmann) [2124279]
- nfp: Prefer struct_size over open coded arithmetic (Stefan Assmann) [2124279]
- nfp: bpf: silence bitwise vs. logical OR warning (Stefan Assmann) [2124279]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Stefan Assmann) [2124279]
- nfp: flow_offload: move flow_indr_dev_register from app init to app start (Stefan Assmann) [2124279]
- nfp: use netif_set_real_num_queues() (Stefan Assmann) [2124279]
- nfp: flower-ct: fix error return code in nfp_fl_ct_add_offload() (Stefan Assmann) [2124279]
- nfp: add support for coalesce adaptive feature (Stefan Assmann) [2124279]
- nfp: fix return statement in nfp_net_parse_meta() (Stefan Assmann) [2124279]
- nfp: flower-tc: add flow stats updates for ct (Stefan Assmann) [2124279]
- nfp: flower-ct: add offload calls to the nfp (Stefan Assmann) [2124279]
- nfp: flower-ct: add flow_pay to the offload table (Stefan Assmann) [2124279]
- nfp: flower-ct: add actions into flow_pay for offload (Stefan Assmann) [2124279]
- nfp: flower-ct: compile match sections of flow_payload (Stefan Assmann) [2124279]
- nfp: flower-ct: calculate required key_layers (Stefan Assmann) [2124279]
- nfp: flower: refactor action offload code slightly (Stefan Assmann) [2124279]
- nfp: flower: refactor match functions to take flow_rule as input (Stefan Assmann) [2124279]
- nfp: flower: make the match compilation functions reusable (Stefan Assmann) [2124279]
- mmu_gather: fix the CONFIG_MMU_GATHER_NO_RANGE case (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Force tlb-flush VM_PFNMAP vmas (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Let there be one tlb_{start,end}_vma() implementation (Waiman Long) [2130164] {CVE-2022-39188}
- csky/tlb: Remove tlb_flush() define (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Remove per arch tlb_{start,end}_vma() (Waiman Long) [2130164] {CVE-2022-39188}
- s390/dasd: add device ping attribute (Tobias Huschle) [2044384]
- s390/dasd: suppress generic error messages for PPRC secondary devices (Tobias Huschle) [2044384]
- s390/dasd: add ioctl to perform a swap of the drivers copy pair (Tobias Huschle) [2044384]
- s390/dasd: add copy pair swap capability (Tobias Huschle) [2044384]
- s390/dasd: add copy pair setup (Tobias Huschle) [2044384]
- s390/dasd: add query PPRC function (Tobias Huschle) [2044384]
- s390/dasd: put block allocation in separate function (Tobias Huschle) [2044384]
- s390/dasd: fix Oops in dasd_alias_get_start_dev due to missing pavgroup (Tobias Huschle) [2044384]
- net: stmmac: Fix unset max_speed difference between DT and non-DT platforms (Al Stone) [2071844]
- usb: dwc2: fix wrong order of phy_power_on and phy_init (Al Stone) [2071844]
- net: stmmac: remove phylink_config.pcs_poll usage (Al Stone) [2071844]
- net: stmmac: use .mac_select_pcs() interface (Al Stone) [2071844]
- net: stmmac: convert to phylink_generic_validate() (Al Stone) [2071844]
- net: stmmac: convert to phylink_get_linkmodes() (Al Stone) [2071844]
- lan743x: fix deadlock in lan743x_phy_link_status_change() (Al Stone) [2071844]
- net: phy: c45 baset1: do not skip aneg configuration if clock role is not specified (Al Stone) [2071844]
- rhel: Enable configs for imx8m PHYs (Al Stone) [2071844]
- phy: freescale: Add i.MX8qm Mixel LVDS PHY support (Al Stone) [2071844]
- units: Add SI metric prefix definitions (Al Stone) [2071844]
- phy: tegra: Add PCIe PIPE2UPHY support for Tegra234 (Al Stone) [2071844]
- net: phy: Don't trigger state machine while in suspend (Al Stone) [2071844]
- net: phy: Fix race condition on link status change (Al Stone) [2071844]
- net: phy: Convert to mdiobus_c45_{read|write} (Al Stone) [2071844]
- net: phy: fix duplex out of sync problem while changing settings (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_set: Lock the PHY while changing settings (Al Stone) [2071844]
- phy: phy_start_aneg: Add an unlocked version (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_set: Move after phy_start_aneg (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_get: Lock the phy for consistency (Al Stone) [2071844]
- linux/phy.h: add phydev_err_probe() wrapper for dev_err_probe() (Al Stone) [2071844]
- net: phy: export genphy_c45_baset1_read_status() (Al Stone) [2071844]
- net: phy: genphy_c45_pma_baset1_read_master_slave: read actual configuration (Al Stone) [2071844]
- net: phy: introduce genphy_c45_pma_baset1_read_master_slave() (Al Stone) [2071844]
- net: phy: genphy_c45_pma_baset1_setup_master_slave: do no set unknown configuration (Al Stone) [2071844]
- net: phy: introduce genphy_c45_pma_baset1_setup_master_slave() (Al Stone) [2071844]
- net: phy: genphy_c45_baset1_an_config_aneg: do no set unknown configuration (Al Stone) [2071844]
- net: phy: Add 10BASE-T1L support in phy-c45 (Al Stone) [2071844]
- net: mdio: add helpers to extract clause 45 regad and devad fields (Al Stone) [2071844]
- net: mdio: Add helper functions for accessing MDIO devices (Al Stone) [2071844]
- net: mdio: add mdiobus_modify_changed() (Al Stone) [2071844]
- net: mdio: introduce a shutdown method to mdio device drivers (Al Stone) [2071844]
- net: phy: Add BaseT1 auto-negotiation registers (Al Stone) [2071844]
- net: phy: Add 10-BaseT1L registers (Al Stone) [2071844]
- ethtool: Add 10base-T1L link mode entry (Al Stone) [2071844]
- phy: freescale: imx8m-pcie: Handle IMX8_PCIE_REFCLK_PAD_UNUSED (Al Stone) [2071844]
- phy: core: Warn when phy_power_on is called before phy_init (Al Stone) [2071844]
- phy: core: Update documentation syntax (Al Stone) [2071844]
- phy: core: Add documentation of phy operation order (Al Stone) [2071844]
- phy: freescale: phy-fsl-imx8-mipi-dphy: Add i.MX8qxp LVDS PHY mode support (Al Stone) [2071844]
- phy: Add LVDS configuration options (Al Stone) [2071844]
- net: phylink: remove phylink_helper_basex_speed() (Al Stone) [2071844]
- phy: phy-can-transceiver: Add support for setting mux (Al Stone) [2071844]
- phy: PHY_FSL_LYNX_28G should depend on ARCH_LAYERSCAPE (Al Stone) [2071844]
- phy: Remove duplicated include in phy-fsl-lynx-28g.c (Al Stone) [2071844]
- phy: add support for the Layerscape SerDes 28G (Al Stone) [2071844]
- net: phy: correct spelling error of media in documentation (Al Stone) [2071844]
- net: phy: exported the genphy_read_master_slave function (Al Stone) [2071844]
- net: phylink: remove phylink_set_pcs() (Al Stone) [2071844]
- phy: dphy: Correct lpx parameter and its derivatives(ta_{get,go,sure}) (Al Stone) [2071844]
- net: phylink: remove phylink_config's pcs_poll (Al Stone) [2071844]
- net: phylink: remove phylink_set_10g_modes() (Al Stone) [2071844]
- phy: make phy_set_max_speed() *void* (Al Stone) [2071844]
- phy: freescale: i.MX8 PHYs should depend on ARCH_MXC && ARM64 (Al Stone) [2071844]
- phy: freescale: pcie: cosmetic clean-up (Al Stone) [2071844]
- net: phylink: add pcs_validate() method (Al Stone) [2071844]
- net: phylink: add mac_select_pcs() method to phylink_mac_ops (Al Stone) [2071844]
- phy: freescale: pcie: explicitly add bitfield.h (Al Stone) [2071844]
- phy: freescale: pcie: Initialize the imx8 pcie standalone phy driver (Al Stone) [2071844]
- phy: tegra: xusb: Fix return value of tegra_xusb_find_port_node function (Al Stone) [2071844]
- net: phylink: use legacy_pre_march2020 (Al Stone) [2071844]
- net: phylink: add legacy_pre_march2020 indicator (Al Stone) [2071844]
- net: phy: Remove unnecessary indentation in the comments of phy_device (Al Stone) [2071844]
- phy: phy-can-transceiver: Make devm_gpiod_get optional (Al Stone) [2071844]
- net: phylink: Add helpers for c22 registers without MDIO (Al Stone) [2071844]
- net: phylink: add 1000base-KX to phylink_caps_to_linkmodes() (Al Stone) [2071844]
- net: document SMII and correct phylink's new validation mechanism (Al Stone) [2071844]
- net: phylink: add generic validate implementation (Al Stone) [2071844]
- net: phylink: avoid mvneta warning when setting pause parameters (Al Stone) [2071844]
- net: phylink: use supported_interfaces for phylink validation (Al Stone) [2071844]
- net: phylink: Convert some users of mdiobus_* to mdiodev_* (Al Stone) [2071844]
- net: phylink: Support disabling autonegotiation for PCS (Al Stone) [2071844]
- net: phylink: rejig SFP interface selection in ksettings_set() (Al Stone) [2071844]
- net: phylink: use mdiobus_modify_changed() helper (Al Stone) [2071844]
- kernel-doc: support DECLARE_PHY_INTERFACE_MASK() (Al Stone) [2071844]
- net: phylink: add MAC phy_interface_t bitmap (Al Stone) [2071844]
- net: phy: add phy_interface_t bitmap support (Al Stone) [2071844]
- net: phy: add genphy_c45_fast_retrain (Al Stone) [2071844]
- net: phy: add constants for fast retrain related register (Al Stone) [2071844]
- net: phylink: add phylink_set_10g_modes() helper (Al Stone) [2071844]
- net: phylink: don't call netif_carrier_off() with NULL netdev (Al Stone) [2071844]
- net: phylink: Update SFP selected interface on advertising changes (Al Stone) [2071844]
- net: phylink: add suspend/resume support (Al Stone) [2071844]
- net: phylink: cleanup ksettings_set (Al Stone) [2071844]
- net: phylink: add phy change pause mode debug (Al Stone) [2071844]
- phy: tegra: xusb: mark PM functions as __maybe_unused (Al Stone) [2071844]
- s390/pai: Add support for PAI Extension 1 NNPA counters (Tobias Huschle) [2127436]

* Mon Oct 24 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-179.el9]
- dmaengine: imx-sdma: Add FIFO stride support for multi FIFO script (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Correct IAX operation code names (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Add missing struct documentation (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: use strscpy to replace strlcpy (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Improve the SDMA irq name (Jerry Snitselaar) [2112028]
- MAINTAINERS: idxd driver maintainer update (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: Replace symbolic permissions by octal permissions (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: Remove spaces before tabs (Jerry Snitselaar) [2112028]
- dma:dw: remove reference to AVR32 architecture in core.c (Jerry Snitselaar) [2112028]
- dmaengine: qcom_hidma: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: only restart cyclic channel when enabled (Jerry Snitselaar) [2112028]
- dmaengine: idxd: force wq context cleanup on device disable path (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Only call idxd_enable_system_pasid() if succeeded in enabling SVA feature (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Allow imx8m for imx7 FW revs (Jerry Snitselaar) [2112028]
- dmaengine: Revert "dmaengine: add verification of DMA_INTERRUPT capability for dmatest" (Jerry Snitselaar) [2112028]
- dmaengine: ptdma: statify pt_tx_status (Jerry Snitselaar) [2112028]
- dmaengine: Document dmaengine_prep_dma_memset (Jerry Snitselaar) [2112028]
- dmaengine: PTDMA: support polled mode (Jerry Snitselaar) [2112028]
- dmaengine: Remove a useless mutex (Jerry Snitselaar) [2112028]
- dmaengine: idxd: update IAA definitions for user header (Jerry Snitselaar) [2112028]
- MAINTAINERS: update my email address (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Add multi fifo support (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: error out on unsupported transfer types (Jerry Snitselaar) [2112028]
- dmaengine: imx: Move header to include/dma/ (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Fix error checking in sdma_event_remap (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: fix init of uart scripts (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: clean up some inconsistent indenting (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: fix cyclic buffer race condition (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: restart cyclic channel if needed (Jerry Snitselaar) [2112028]
- dmaengine: iot: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112028]
- dmaengine: ioatdma: use default_groups in kobj_type (Jerry Snitselaar) [2112028]
- Documentation: dmaengine: Correctly describe dmatest with channel unset (Jerry Snitselaar) [2112028]
- Documentation: dmaengine: Add a description of what dmatest does (Jerry Snitselaar) [2112028]
- dmaengine: Add documentation for new memcpy scatter-gather function (Jerry Snitselaar) [2112028]
- dmaengine: remove slave_id config field (Jerry Snitselaar) [2112028]
- dmaengine: ioat: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: hsu: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: dw: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: dmaengine_desc_callback_valid(): Check for `callback_result` (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove space after sizeof (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: align statement to open parenthesis (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add missed braces (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove useless braces (Jerry Snitselaar) [2112028]
- dmaengine: Remove redundant initialization of variable err (Jerry Snitselaar) [2112028]
- dmaengine: Extend the dma_slave_width for 128 bytes (Jerry Snitselaar) [2112028]
- dmaengine: ioat: depends on !UML (Jerry Snitselaar) [2112028]
- dmaengine: idxd: depends on !UML (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add terminated list for freed descriptor in worker (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add uart rom script (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove ERR009165 on i.mx6ul (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add mcu_2_ecspi script (Jerry Snitselaar) [2112028]
- dmaengine: dma: imx-sdma: add fw_loaded and is_ram_script (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove duplicated sdma_load_context (Jerry Snitselaar) [2112028]
- Revert "dmaengine: imx-sdma: refine to load context only once" (Jerry Snitselaar) [2112028]
- pinctrl: bcm2835: implement hook for missing gpio-ranges (Adrien Thierry) [2124693]
- gpiolib: of: Introduce hook for missing gpio-ranges (Adrien Thierry) [2124693]
- pinctrl: bcm2835: Fix a few error paths (Adrien Thierry) [2124693]
- ARM: dts: gpio-ranges property is now required (Adrien Thierry) [2124693]
- pinctrl: bcm2835: Change init order for gpio hogs (Adrien Thierry) [2124693]
- nvmet-auth: don't try to cancel a non-initialized work_struct (Gopal Tiwari) [2124526]
- Enabling configs for AUTH support. (Gopal Tiwari) [2124526]
- nvme: requeue aen after firmware activation (Gopal Tiwari) [2124526]
- nvmet: fix mar and mor off-by-one errors (Gopal Tiwari) [2124526]
- nvme-tcp: fix regression that causes sporadic requests to time out (Gopal Tiwari) [2124526]
- nvme-tcp: fix UAF when detecting digest errors (Gopal Tiwari) [2124526]
- nvmet: fix a use-after-free (Gopal Tiwari) [2124526]
- nvmet-tcp: fix unhandled tcp states in nvmet_tcp_state_change() (Gopal Tiwari) [2124526]
- nvmet-auth: add missing goto in nvmet_setup_auth() (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM610 (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG GAMMIX S70 (Gopal Tiwari) [2124526]
- nvme-fabrics: Fix a typo in an error message (Gopal Tiwari) [2124526]
- nvme-tcp: check if the queue is allocated before stopping it (Gopal Tiwari) [2124526]
- nvme-fabrics: parse nvme connect Linux error codes (Gopal Tiwari) [2124526]
- nvmet-auth: use kmemdup instead of kmalloc + memcpy (Gopal Tiwari) [2124526]
- nvme: enable generic interface (/dev/ngXnY) for unknown command sets (Gopal Tiwari) [2124526]
- nvmet-tcp: fix lockdep complaint on nvmet_tcp_wq flush during queue teardown (Gopal Tiwari) [2124526]
- nvme: factor out a nvme_ns_is_readonly helper (Gopal Tiwari) [2124526]
- nvme: refactor namespace probing (Gopal Tiwari) [2124526]
- nvmet: don't check for NULL pointer before kfree in nvmet_host_release (Gopal Tiwari) [2124526]
- nvme: catch -ENODEV from nvme_revalidate_zones again (Gopal Tiwari) [2124526]
- nvmet-auth: fix return value check in auth receive (Gopal Tiwari) [2124526]
- nvmet-auth: fix a couple of spelling mistakes (Gopal Tiwari) [2124526]
- nvmet: fix a format specifier in nvmet_auth_ctrl_exponential (Gopal Tiwari) [2124526]
- nvme: generalize the nvme_multi_css check in nvme_scan_ns (Gopal Tiwari) [2124526]
- nvmet-auth: select the intended CRYPTO_DH_RFC7919_GROUPS (Gopal Tiwari) [2124526]
- nvme-apple: stop casting function pointer signatures (Gopal Tiwari) [2124526]
- nvmet-auth: fix return value check in auth send (Gopal Tiwari) [2124526]
- nvme: rename nvme_validate_or_alloc_ns to nvme_scan_ns (Gopal Tiwari) [2124526]
- nvme-pci: split nvme_alloc_admin_tags (Gopal Tiwari) [2124526]
- nvme: don't always build constants.o (Gopal Tiwari) [2124526]
- nvme-rdma: split nvme_rdma_alloc_tagset (Gopal Tiwari) [2124526]
- nvme: define compat_ioctl again to unbreak 32-bit userspace. (Gopal Tiwari) [2124526]
- nvme-pci: print the command name of aborted commands (Gopal Tiwari) [2124526]
- nvme-auth: uninitialized variable in nvme_auth_transform_key() (Gopal Tiwari) [2124526]
- nvme-auth: fix off by one checks (Gopal Tiwari) [2124526]
- nvme-pci: remove useless assignment in nvme_pci_setup_prps (Gopal Tiwari) [2124526]
- nvme-tcp: split nvme_tcp_alloc_tagset (Gopal Tiwari) [2124526]
- nvme-pci: split nvme_dev_add (Gopal Tiwari) [2124526]
- nvme: use command_id instead of req->tag in trace_nvme_complete_rq() (Gopal Tiwari) [2124526]
- nvme-multipath: refactor nvme_mpath_add_disk (Gopal Tiwari) [2124526]
- nvme-tcp: use in-capsule data for I/O connect (Gopal Tiwari) [2124526]
- nvme-pci: use nvme core helper to cancel requests in tagset (Gopal Tiwari) [2124526]
- nvme-apple: use nvme core helper to cancel requests in tagset (Gopal Tiwari) [2124526]
- nvme-rdma: remove timeout for getting RDMA-CM established event (Gopal Tiwari) [2124526]
- nvmet-auth: Diffie-Hellman key exchange support (Gopal Tiwari) [2124526]
- crypto: add crypto_has_kpp() (Gopal Tiwari) [2124526]
- nvmet-auth: expire authentication sessions (Gopal Tiwari) [2124526]
- nvmet: implement basic In-Band Authentication (Gopal Tiwari) [2124526]
- nvme-auth: Diffie-Hellman key exchange support (Gopal Tiwari) [2124526]
- crypto: add crypto_has_shash() (Gopal Tiwari) [2124526]
- lib/base64: RFC4648-compliant base64 encoding (Gopal Tiwari) [2124526]
- nvme: add definitions for NVMe In-Band authentication (Gopal Tiwari) [2124526]
- nvme: implement In-Band authentication (Gopal Tiwari) [2124526]
- nvmet: parse fabrics commands on io queues (Gopal Tiwari) [2124526]
- nvme-loop: use nvme core helpers to cancel all requests in a tagset (Gopal Tiwari) [2124526]
- nvme: remove a double word in a comment (Gopal Tiwari) [2124526]
- nvme: fix qid param blk_mq_alloc_request_hctx (Gopal Tiwari) [2124526]
- nvme: remove unused timeout parameter (Gopal Tiwari) [2124526]
- nvme-fabrics: decode 'authentication required' connect error (Gopal Tiwari) [2124526]
- nvme: handle the persistent internal error AER (Gopal Tiwari) [2124526]
- nvme-pci: Crucial P2 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme: fix block device naming collision (Gopal Tiwari) [2124526]
- nvme-pci: fix freeze accounting for error handling (Gopal Tiwari) [2124526]
- nvme: use struct group for generic command dwords (Gopal Tiwari) [2124526]
- nvme-pci: phison e16 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA IM2P33F8ABR1 (Gopal Tiwari) [2124526]
- nvmet: add a clear_ids attribute for passthru targets (Gopal Tiwari) [2124526]
- nvme: fix regression when disconnect a recovering ctrl (Gopal Tiwari) [2124526]
- nvme-tcp: always fail a request when sending it failed (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG SX6000LNP (AKA SPECTRIX S40G) (Gopal Tiwari) [2124526]
- nvmet-tcp: fix regression in data_digest calculation (Gopal Tiwari) [2124526]
- block: simplify disk shutdown (Gopal Tiwari) [2124526]
- nvme: move the Samsung X5 quirk entry to the core quirks (Gopal Tiwari) [2124526]
- nvme: add a bogus subsystem NQN quirk for Micron MTFDKBA2T0TFH (Gopal Tiwari) [2124526]
- nvme-pci: disable write zeros support on UMIC and Samsung SSDs (Gopal Tiwari) [2124526]
- nvme-pci: smi has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: sk hynix p31 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: avoid the deepest sleep state on ZHITAI TiPro7000 SSDs (Gopal Tiwari) [2124526]
- nvme-pci: add trouble shooting steps for timeouts (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG GAMMIX S50 (Gopal Tiwari) [2124526]
- nvme-pci: phison e12 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme: add bug report info for global duplicate id (Gopal Tiwari) [2124526]
- nvme: add device name to warning in uuid_show() (Gopal Tiwari) [2124526]
- nvmet: fix typo in comment (Gopal Tiwari) [2124526]
- nvme: set controller enable bit in a separate write (Gopal Tiwari) [2124526]
- nvme-pci: disable namespace identifiers for the MAXIO MAP1001 (Gopal Tiwari) [2124526]
- nvme: set non-mdts limits in nvme_scan_work (Gopal Tiwari) [2124526]
- nvme: add support for TP4084 - Time-to-Ready Enhancements (Gopal Tiwari) [2124526]
- nvme-fabrics: add a request timeout helper (Gopal Tiwari) [2124526]
- nvme-pci: harden drive presence detect in nvme_dev_disable() (Gopal Tiwari) [2124526]
- nvme-pci: fix a NULL pointer dereference in nvme_alloc_admin_tags (Gopal Tiwari) [2124526]
- nvme: remove unneeded include from constants file (Gopal Tiwari) [2124526]
- nvme: set dma alignment to dword (Gopal Tiwari) [2124526]
- nvme: fix interpretation of DMRSL (Gopal Tiwari) [2124526]
- nvme-apple: fix sparse endianess warnings (Gopal Tiwari) [2124526]
- nvme-apple: Add initial Apple SoC NVMe driver (Gopal Tiwari) [2124526]
- nvmet: remove redundant assignment after left shift (Gopal Tiwari) [2124526]
- nvme: allow duplicate NSIDs for private namespaces (Gopal Tiwari) [2124526]
- nvmet: use a private workqueue instead of the system workqueue (Gopal Tiwari) [2124526]
- nvme: fix the read-only state for zoned namespaces with unsupposed features (Gopal Tiwari) [2124526]
- nvme: warn about shared namespaces without CONFIG_NVME_MULTIPATH (Gopal Tiwari) [2124526]
- nvme: remove nvme_alloc_request and nvme_alloc_request_qid (Gopal Tiwari) [2124526]
- nvme: cleanup how disk->disk_name is assigned (Gopal Tiwari) [2124526]
- nvmet: move the call to nvmet_ns_changed out of nvmet_ns_revalidate (Gopal Tiwari) [2124526]
- nvmet-fc: fix kernel-doc warning for nvmet_fc_register_targetport (Gopal Tiwari) [2124526]
- nvmet-rdma: fix kernel-doc warning for nvmet_rdma_device_removal (Gopal Tiwari) [2124526]
- nvmet: use snprintf() with PAGE_SIZE in configfs (Gopal Tiwari) [2124526]
- nvme-tcp: lockdep: annotate in-kernel sockets (Gopal Tiwari) [2124526]
- nvmet: don't fold lines (Gopal Tiwari) [2124526]
- nvmet-fc: fix kernel-doc warning for nvmet_fc_unregister_targetport (Gopal Tiwari) [2124526]
- nvme-tcp: don't fold the line (Gopal Tiwari) [2124526]
- nvme-multipath: call bio_io_error in nvme_ns_head_submit_bio (Gopal Tiwari) [2124526]
- nvme-multipath: use vmalloc for ANA log buffer (Gopal Tiwari) [2124526]
- nvme-tcp: don't initialize ret variable (Gopal Tiwari) [2124526]
- nvme: fix the check for duplicate unique identifiers (Gopal Tiwari) [2124526]
- nvme: check that EUI/GUID/UUID are globally unique (Gopal Tiwari) [2124526]
- nvme: check for duplicate identifiers earlier (Gopal Tiwari) [2124526]
- nvme: cleanup __nvme_check_ids (Gopal Tiwari) [2124526]
- nvme: add a helper to initialize connect_q (Gopal Tiwari) [2124526]
- nvme: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet-rdma: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet: allow bdev in buffered_io mode (Gopal Tiwari) [2124526]
- nvmet-fc: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-rdma: add helpers for mapping/unmapping request (Gopal Tiwari) [2124526]
- nvmet-tcp: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-fc: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet: use i_size_read() to set size for file-ns (Gopal Tiwari) [2124526]
- nvmet: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-core: remove unnecessary function parameter (Gopal Tiwari) [2124526]
- nvme-fabrics: use consistent zeroout pattern (Gopal Tiwari) [2124526]
- nvme-fabrics: remove unnecessary braces for case (Gopal Tiwari) [2124526]
- nvme-fabrics: use unsigned int type (Gopal Tiwari) [2124526]
- nvme-core: remove unnecessary semicolon (Gopal Tiwari) [2124526]
- nvme-fabrics: use unsigned int type (Gopal Tiwari) [2124526]
- watch_queue: Fix missing locking in add_watch_to_object() (Carlos Maiolino) [2090382] {CVE-2022-1882}
- watch_queue: Fix missing rcu annotation (Carlos Maiolino) [2090382] {CVE-2022-1882}
- watchqueue: make sure to serialize 'wqueue->defunct' properly (Carlos Maiolino) [2090382] {CVE-2022-1882}
- cgroup: cgroup_get_from_id() must check the looked-up kn is a directory (Ming Lei) [2122632]
- Add skb drop reasons to IPv6 UDP receive path (Antoine Tenart) [2059161]
- net: skb: export skb drop reaons to user by TRACE_DEFINE_ENUM (Antoine Tenart) [2059161]
- docs/conf.py: add function attribute '__fix_address' to conf.py (Antoine Tenart) [2059161]
- net: skb: prevent the split of kfree_skb_reason() by gcc (Antoine Tenart) [2059161]
- tcp: md5: fix IPv4-mapped support (Antoine Tenart) [2059161]
- net: dropreason: reformat the comment fo skb drop reasons (Antoine Tenart) [2059161]
- net: skb: use auto-generation to convert skb drop reason to string (Antoine Tenart) [2059161]
- net: skb: move enum skb_drop_reason to standalone header file (Antoine Tenart) [2059161]
- tcp_ipv6: set the drop_reason in the right place (Antoine Tenart) [2059161]
- net: tcp: reset 'drop_reason' to NOT_SPCIFIED in tcp_v{4,6}_rcv() (Antoine Tenart) [2059161]
- net: skb: change the definition SKB_DR_SET() (Antoine Tenart) [2059161]
- net: skb: check the boundrary of drop reason in kfree_skb_reason() (Antoine Tenart) [2059161]
- net: dm: check the boundary of skb drop reasons (Antoine Tenart) [2059161]
- tcp: fix signed/unsigned comparison (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_ofo_queue() (Antoine Tenart) [2059161]
- tcp: add drop reasons to tcp_rcv_synsent_state_process() (Antoine Tenart) [2059161]
- tcp: make tcp_rcv_synsent_state_process() drop monitor friend (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_prune_ofo_queue() (Antoine Tenart) [2059161]
- tcp: add two drop reasons for tcp_ack() (Antoine Tenart) [2059161]
- tcp: add drop reasons to tcp_rcv_state_process() (Antoine Tenart) [2059161]
- tcp: make tcp_rcv_state_process() drop monitor friendly (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_validate_incoming() (Antoine Tenart) [2059161]
- tcp: get rid of rst_seq_match (Antoine Tenart) [2059161]
- tcp: consume incoming skb leading to a reset (Antoine Tenart) [2059161]
- tcp: tcp_send_challenge_ack delete useless param `skb` (Antoine Tenart) [2059161]
- ipv6: fix NULL deref in ip6_rcv_core() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_protocol_deliver_rcu() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_rcv_core() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to TLV parse (Antoine Tenart) [2059161]
- net: ipv6: remove redundant statistics in ipv6_hop_jumbo() (Antoine Tenart) [2059161]
- net: icmp: introduce function icmpv6_param_prob_reason() (Antoine Tenart) [2059161]
- net: ip: add skb drop reasons to ip forwarding (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_pkt_drop() (Antoine Tenart) [2059161]
- net: ipv4: add skb drop reasons to ip_error() (Antoine Tenart) [2059161]
- skb: add some helpers for skb drop reasons (Antoine Tenart) [2059161]
- net: icmp: add skb drop reasons to icmp protocol (Antoine Tenart) [2059161]
- net: icmp: introduce __ping_queue_rcv_skb() to report drop reasons (Antoine Tenart) [2059161]
- net: skb: rename SKB_DROP_REASON_PTYPE_ABSENT (Antoine Tenart) [2059161]
- net: sock: introduce sock_queue_rcv_skb_reason() (Antoine Tenart) [2059161]
- net: tcp: fix shim definition of tcp_inbound_md5_hash (Antoine Tenart) [2059161]
- skb: make drop reason booleanable (Antoine Tenart) [2059161]
- net/tcp: Merge TCP-MD5 inbound callbacks (Antoine Tenart) [2059161]
- net: tun: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059161]
- net: tun: split run_ebpf_filter() and pskb_trim() into different "if statement" (Antoine Tenart) [2059161]
- net: tap: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for __netif_receive_skb_core() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for sch_handle_ingress() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for do_xdp_generic() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for enqueue_to_backlog() (Antoine Tenart) [2059161]
- net: dev: add skb drop reasons to __dev_xmit_skb() (Antoine Tenart) [2059161]
- net: skb: introduce the function kfree_skb_list_reason() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for sch_handle_egress() (Antoine Tenart) [2059161]
- net: neigh: add skb drop reasons to arp_error_report() (Antoine Tenart) [2059161]
- net: neigh: use kfree_skb_reason() for __neigh_event_send() (Antoine Tenart) [2059161]
- net: ip: add skb drop reasons for ip egress path (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_data_queue_ofo() (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_data_queue() (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_rcv_established() (Antoine Tenart) [2059161]
- net: tcp: use kfree_skb_reason() for tcp_v{4,6}_do_rcv() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_add_backlog() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_v{4,6}_inbound_md5_hash() (Antoine Tenart) [2059161]
- net: tcp: use kfree_skb_reason() for tcp_v6_rcv() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_v4_rcv() (Antoine Tenart) [2059161]
- net: tcp: introduce tcp_drop_reason() (Antoine Tenart) [2059161]
- ipv6: Add reasons for skb drops to __udp6_lib_rcv (Antoine Tenart) [2059161]
- net: udp: use kfree_skb_reason() in __udp_queue_rcv_skb() (Antoine Tenart) [2059161]
- net: udp: use kfree_skb_reason() in udp_queue_rcv_one_skb() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_protocol_deliver_rcu() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_rcv_finish_core() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_rcv_core() (Antoine Tenart) [2059161]
- net: netfilter: use kfree_drop_reason() for NF_DROP (Antoine Tenart) [2059161]
- net: skb_drop_reason: add document for drop reasons (Antoine Tenart) [2059161]
- net: socket: rename SKB_DROP_REASON_SOCKET_FILTER (Antoine Tenart) [2059161]
- arm64/kexec: Fix missing extra range for crashkres_low (Pingfan Liu) [2130054]
- irqdomain: Export irq_domain_disconnect_hierarchy() (Eric Chanudet) [2132140]
- add config var for CONFIG_PTE_MARKER (Chris von Recklinghausen) [2120352]
- mm/mprotect: only reference swap pfn page if type match (Chris von Recklinghausen) [2120352]
- mm: fix NULL pointer dereference in wp_page_reuse() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: separate path for hwpoison entry in copy_hugetlb_page_range() (Chris von Recklinghausen) [2120352]
- mm/rmap: fix dereferencing invalid subpage pointer in try_to_migrate_one() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: handle uffd-wp during fork() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: introduce huge pte version of uffd-wp helpers (Chris von Recklinghausen) [2120352]
- mm/shmem: handle uffd-wp during fork() (Chris von Recklinghausen) [2120352]
- mm: introduce PTE_MARKER swap entry (Chris von Recklinghausen) [2120352]
- powerpc/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE for book3s (Chris von Recklinghausen) [2120352]
- powerpc/pgtable: remove _PAGE_BIT_SWAP_TYPE for book3s (Chris von Recklinghausen) [2120352]
- s390/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- s390/pgtable: cleanup description of swp pte layout (Chris von Recklinghausen) [2120352]
- arm64/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- x86/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- mm/debug_vm_pgtable: add tests for __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- mm/swap: remember PG_anon_exclusive via a swp pte bit (Chris von Recklinghausen) [2120352]
- mm/gup: sanity-check with CONFIG_DEBUG_VM that anonymous pages are exclusive when (un)pinning (Chris von Recklinghausen) [2120352]
- mm/gup: trigger FAULT_FLAG_UNSHARE when R/O-pinning a possibly shared anonymous page (Chris von Recklinghausen) [2120352]
- mm: support GUP-triggered unsharing of anonymous pages (Chris von Recklinghausen) [2120352]
- mm/gup: disallow follow_page(FOLL_PIN) (Chris von Recklinghausen) [2120352]
- mm/rmap: fail try_to_migrate() early when setting a PMD migration entry fails (Chris von Recklinghausen) [2120352]
- mm: remember exclusively mapped anonymous pages with PG_anon_exclusive (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove outdated VM_WARN_ON_ONCE_PAGE from unmap_page() (Chris von Recklinghausen) [2120352]
- mm/rmap: use page_move_anon_rmap() when reusing a mapped PageAnon() page exclusively (Chris von Recklinghausen) [2120352]
- mm/rmap: drop "compound" parameter from page_add_new_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: pass rmap flags to hugepage_add_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: remove do_page_add_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: convert RMAP flags to a proper distinct rmap_t type (Chris von Recklinghausen) [2120352]
- mm/rmap: split page_dup_rmap() into page_dup_file_rmap() and page_try_dup_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/memory: slightly simplify copy_present_pte() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: take src_mm->write_protect_seq in copy_hugetlb_page_range() (Chris von Recklinghausen) [2120352]
- mm/rmap: fix missing swap_free() in try_to_unmap() after arch_unmap_one() failed (Chris von Recklinghausen) [2120352]
- s390/smp: fix memblock_phys_free() vs memblock_free() confusion (Chris von Recklinghausen) [2120352]
- compiler_types: mark __compiletime_assert failure as __noreturn (Chris von Recklinghausen) [2120352]
- config: set CONFIG_KFENCE_DEFERRABLE (Chris von Recklinghausen) [2120352]
- config: set CONFIG_CACHEFILES_ERROR_INJECTION (Chris von Recklinghausen) [2120352]
- config: set CONFIG_ANON_VMA_NAME (Chris von Recklinghausen) [2120352]
- config: set CONFIG_DAMON_SYSFS (Chris von Recklinghausen) [2120352]
- mm/gup: fix FOLL_FORCE COW security issue and remove FOLL_COW (Chris von Recklinghausen) [2120352]
- mm, hwpoison: set PG_hwpoison for busy hugetlb pages (Chris von Recklinghausen) [2120352]
- mm/mprotect: fix soft-dirty check in can_change_pte_writable() (Chris von Recklinghausen) [2120352]
- hugetlb_cgroup: fix wrong hugetlb cgroup numa stat (Chris von Recklinghausen) [2120352]
- mm/damon/reclaim: fix potential memory leak in damon_reclaim_init() (Chris von Recklinghausen) [2120352]
- userfaultfd: provide properly masked address for huge-pages (Chris von Recklinghausen) [2120352]
- mm: handling Non-LRU pages returned by vm_normal_pages (Chris von Recklinghausen) [2120352]
- mm/mprotect: try avoiding write faults for exclusive anonymous pages when changing protection (Chris von Recklinghausen) [2120352]
- kasan: fix zeroing vmalloc memory with HW_TAGS (Chris von Recklinghausen) [2120352]
- mm/memory-failure: disable unpoison once hw error happens (Chris von Recklinghausen) [2120352]
- mm/slub: Move the stackdepot related allocation out of IRQ-off section. (Chris von Recklinghausen) [2120352]
- include/linux/find: Fix documentation (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: fix CONFIG_HUGETLB_PAGE_FREE_VMEMMAP_DEFAULT_ON (Chris von Recklinghausen) [2120352]
- video: fbdev: vesafb: Fix a use-after-free due early fb_info cleanup (Chris von Recklinghausen) [2120352]
- mm: kasan: fix input of vmalloc_to_page() (Chris von Recklinghausen) [2120352]
- ceph: no need to invalidate the fscache twice (Chris von Recklinghausen) [2120352]
- mm/swap: clean up the comment of find_next_to_unuse (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: add hugetlb_optimize_vmemmap sysctl (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: use kstrtobool for hugetlb_vmemmap param parsing (Chris von Recklinghausen) [2120352]
- mm: memory_hotplug: override memmap_on_memory when hugetlb_free_vmemmap=on (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: disable hugetlb_optimize_vmemmap when struct page crosses page boundaries (Chris von Recklinghausen) [2120352]
- arm64/mm: enable ARCH_SUPPORTS_PAGE_TABLE_CHECK (Chris von Recklinghausen) [2120352]
- mm: hugetlb: considering PMD sharing when flushing cache/TLBs (Chris von Recklinghausen) [2120352]
- mm/mprotect: use mmu_gather (Chris von Recklinghausen) [2120352]
- mm/page-flags: reuse PG_mappedtodisk as PG_anon_exclusive for PageAnon() pages (Chris von Recklinghausen) [2120352]
- mm/kfence: reset PG_slab and memcg_data before freeing __kfence_pool (Chris von Recklinghausen) [2120352]
- mm: mremap: fix sign for EFAULT error return value (Chris von Recklinghausen) [2120352]
- fbdev: efifb: Fix a use-after-free due early fb_info cleanup (Chris von Recklinghausen) [2120352]
- kthread: Don't allocate kthread_struct for init and umh (Chris von Recklinghausen) [2120352]
- fbdev: vesafb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- fbdev: efifb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- fbdev: simplefb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- Revert "fbdev: Make fb_release() return -ENODEV if fbdev was unregistered" (Chris von Recklinghausen) [2120352]
- fbdev: Make fb_release() return -ENODEV if fbdev was unregistered (Chris von Recklinghausen) [2120352]
- mm/migration: fix possible do_pages_stat_array racing with memory offline (Chris von Recklinghausen) [2120352]
- mm/migration: fix potential invalid node access for reclaim-based migration (Chris von Recklinghausen) [2120352]
- mm/migration: fix potential page refcounts leak in migrate_pages (Chris von Recklinghausen) [2120352]
- Revert "mm/memory-failure.c: fix race with changing page compound again" (Chris von Recklinghausen) [2120352]
- mm/huge_memory: do not overkill when splitting huge_zero_page (Chris von Recklinghausen) [2120352]
- Revert "mm/memory-failure.c: skip huge_zero_page in memory_failure()" (Chris von Recklinghausen) [2120352]
- kasan: prevent cpu_quarantine corruption when CPU offline and cache shrink occur at same time (Chris von Recklinghausen) [2120352]
- no-MMU: expose vmalloc_huge() for alloc_large_system_hash() (Chris von Recklinghausen) [2120352]
- kvmalloc: use vmalloc_huge for vmalloc allocations (Chris von Recklinghausen) [2120352]
- page_alloc: use vmalloc_huge for large system hash (Chris von Recklinghausen) [2120352]
- mm/vmalloc: huge vmalloc backing pages should be split rather than compound (Chris von Recklinghausen) [2120352]
- mm/mmu_notifier.c: fix race in mmu_interval_notifier_remove() (Chris von Recklinghausen) [2120352]
- memcg: sync flush only if periodic flush is delayed (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: skip huge_zero_page in memory_failure() (Chris von Recklinghausen) [2120352]
- mm/hwpoison: fix race between hugetlb free/demotion and memory_failure_hugetlb() (Chris von Recklinghausen) [2120352]
- vmalloc: replace VM_NO_HUGE_VMAP with VM_ALLOW_HUGE_VMAP (Chris von Recklinghausen) [2120352]
- mm/vmalloc: fix spinning drain_vmap_work after reading from /proc/vmcore (Chris von Recklinghausen) [2120352]
- mm: compaction: fix compiler warning when CONFIG_COMPACTION=n (Chris von Recklinghausen) [2120352]
- mm: fix unexpected zeroed page mapping with zram swap (Chris von Recklinghausen) [2120352]
- mm, page_alloc: fix build_zonerefs_node() (Chris von Recklinghausen) [2120352]
- mm, kfence: support kmem_dump_obj() for KFENCE objects (Chris von Recklinghausen) [2120352]
- kasan: fix hw tags enablement when KUNIT tests are disabled (Chris von Recklinghausen) [2120352]
- mm/secretmem: fix panic when growing a memfd_secret (Chris von Recklinghausen) [2120352]
- mm/slub: remove unused parameter in setup_object*() (Chris von Recklinghausen) [2120352]
- s390: current_stack_pointer shouldn't be a function (Chris von Recklinghausen) [2120352]
- mm/list_lru.c: revert "mm/list_lru: optimize memcg_reparent_list_lru_node()" (Chris von Recklinghausen) [2120352]
- mm/mempolicy: fix mpol_new leak in shared_policy_replace (Chris von Recklinghausen) [2120352]
- mmmremap.c: avoid pointless invalidate_range_start/end on mremap(old_size=0) (Chris von Recklinghausen) [2120352]
- mm/sparsemem: fix 'mem_section' will never be NULL gcc 12 warning (Chris von Recklinghausen) [2120352]
- highmem: fix checks in __kmap_local_sched_{in,out} (Chris von Recklinghausen) [2120352]
- mmc: core: improve API to make clear mmc_hw_reset is for cards (Chris von Recklinghausen) [2120352]
- mm/huge_memory: Avoid calling pmd_page() on a non-leaf PMD (Chris von Recklinghausen) [2120352]
- fbdev: Fix unregistering of framebuffers without device (Chris von Recklinghausen) [2120352]
- mm/slub: use stackdepot to save stack trace in objects (Chris von Recklinghausen) [2120352]
- mm/slub: move struct track init out of set_track() (Chris von Recklinghausen) [2120352]
- lib/stackdepot: allow requesting early initialization dynamically (Chris von Recklinghausen) [2120352]
- Revert "mm/page_alloc: mark pagesets as __maybe_unused" (Chris von Recklinghausen) [2120352]
- mm/damon: prevent activated scheme from sleeping by deactivated schemes (Chris von Recklinghausen) [2120352]
- mm/kmemleak: reset tag when compare object pointer (Chris von Recklinghausen) [2120352]
- mm, kasan: fix __GFP_BITS_SHIFT definition breaking LOCKDEP (Chris von Recklinghausen) [2120352]
- mm,hwpoison: unmap poisoned page before invalidation (Chris von Recklinghausen) [2120352]
- mm: kfence: fix objcgs vector allocation (Chris von Recklinghausen) [2120352]
- Revert "mm: madvise: skip unmapped vma holes passed to process_madvise" (Chris von Recklinghausen) [2120352]
- ntfs: Correct mark_ntfs_record_dirty() folio conversion (Chris von Recklinghausen) [2120352]
- fs: Pass an iocb to generic_perform_write() (Chris von Recklinghausen) [2120352]
- readahead: Update comments (Chris von Recklinghausen) [2120352]
- mm: remove the skip_page argument to read_pages (Chris von Recklinghausen) [2120352]
- mm: remove the pages argument to read_pages (Chris von Recklinghausen) [2120352]
- fs: Remove ->readpages address space operation (Chris von Recklinghausen) [2120352]
- readahead: Remove read_cache_pages() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: validate buddy before check its migratetype. (Chris von Recklinghausen) [2120352]
- mm/balloon_compaction: make balloon page compaction callbacks static (Chris von Recklinghausen) [2120352]
- mm: kfence: fix missing objcg housekeeping for SLAB (Chris von Recklinghausen) [2120352]
- s390/test_unwind: extend kretprobe test (Chris von Recklinghausen) [2120352]
- mm: madvise: MADV_DONTNEED_LOCKED (Chris von Recklinghausen) [2120352]
- mm: fix race between MADV_FREE reclaim and blkdev direct IO read (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove stale locking logic from __split_huge_pmd() (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove stale page_trans_huge_mapcount() (Chris von Recklinghausen) [2120352]
- mm/swapfile: remove stale reuse_swap_page() (Chris von Recklinghausen) [2120352]
- mm/khugepaged: remove reuse_swap_page() usage (Chris von Recklinghausen) [2120352]
- mm/huge_memory: streamline COW logic in do_huge_pmd_wp_page() (Chris von Recklinghausen) [2120352]
- mm: streamline COW logic in do_swap_page() (Chris von Recklinghausen) [2120352]
- mm: slightly clarify KSM logic in do_swap_page() (Chris von Recklinghausen) [2120352]
- mm: optimize do_wp_page() for fresh pages in local LRU pagevecs (Chris von Recklinghausen) [2120352]
- mm: optimize do_wp_page() for exclusive pages in the swapcache (Chris von Recklinghausen) [2120352]
- mm/huge_memory: make is_transparent_hugepage() static (Chris von Recklinghausen) [2120352]
- mm: enable MADV_DONTNEED for hugetlb mappings (Chris von Recklinghausen) [2120352]
- kasan: disable LOCKDEP when printing reports (Chris von Recklinghausen) [2120352]
- kasan: move and hide kasan_save_enable/restore_multi_shot (Chris von Recklinghausen) [2120352]
- kasan: reorder reporting functions (Chris von Recklinghausen) [2120352]
- kasan: respect KASAN_BIT_REPORTED in all reporting routines (Chris von Recklinghausen) [2120352]
- kasan: add comment about UACCESS regions to kasan_report (Chris von Recklinghausen) [2120352]
- kasan: rename kasan_access_info to kasan_report_info (Chris von Recklinghausen) [2120352]
- kasan: move and simplify kasan_report_async (Chris von Recklinghausen) [2120352]
- kasan: call print_report from kasan_report_invalid_free (Chris von Recklinghausen) [2120352]
- kasan: merge __kasan_report into kasan_report (Chris von Recklinghausen) [2120352]
- kasan: restructure kasan_report (Chris von Recklinghausen) [2120352]
- kasan: simplify kasan_find_first_bad_addr call sites (Chris von Recklinghausen) [2120352]
- kasan: split out print_report from __kasan_report (Chris von Recklinghausen) [2120352]
- kasan: move disable_trace_on_warning to start_report (Chris von Recklinghausen) [2120352]
- kasan: move update_kunit_status to start_report (Chris von Recklinghausen) [2120352]
- kasan: check CONFIG_KASAN_KUNIT_TEST instead of CONFIG_KUNIT (Chris von Recklinghausen) [2120352]
- kasan: simplify kasan_update_kunit_status() and call sites (Chris von Recklinghausen) [2120352]
- kasan: simplify async check in end_report() (Chris von Recklinghausen) [2120352]
- kasan: print basic stack frame info for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: improve stack frame info in reports (Chris von Recklinghausen) [2120352]
- kasan: rearrange stack frame info in reports (Chris von Recklinghausen) [2120352]
- kasan: more line breaks in reports (Chris von Recklinghausen) [2120352]
- kasan: drop addr check from describe_object_addr (Chris von Recklinghausen) [2120352]
- kasan: print virtual mapping info in reports (Chris von Recklinghausen) [2120352]
- kasan: update function name in comments (Chris von Recklinghausen) [2120352]
- mm/kasan: remove unnecessary CONFIG_KASAN option (Chris von Recklinghausen) [2120352]
- kasan: test: support async (again) and asymm modes for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: improve vmalloc tests (Chris von Recklinghausen) [2120352]
- kasan: documentation updates (Chris von Recklinghausen) [2120352]
- arm64: select KASAN_VMALLOC for SW/HW_TAGS modes (Chris von Recklinghausen) [2120352]
- kasan: allow enabling KASAN_VMALLOC and SW/HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: add kasan.vmalloc command line flag (Chris von Recklinghausen) [2120352]
- kasan: clean up feature flags for HW_TAGS mode (Chris von Recklinghausen) [2120352]
- kasan: mark kasan_arg_stacktrace as __initdata (Chris von Recklinghausen) [2120352]
- kasan, arm64: don't tag executable vmalloc allocations (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: only tag normal vmalloc allocations (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: add vmalloc tagging for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: allow skipping memory init for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: allow skipping unpoisoning for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, mm: only define ___GFP_SKIP_KASAN_POISON with HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: unpoison VM_ALLOC pages after mapping (Chris von Recklinghausen) [2120352]
- kasan, vmalloc, arm64: mark vmalloc mappings as pgprot_tagged (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: add vmalloc tagging for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, arm64: reset pointer tags of vmapped stacks (Chris von Recklinghausen) [2120352]
- kasan, fork: reset pointer tags of vmapped stacks (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: reset tags in vmalloc functions (Chris von Recklinghausen) [2120352]
- kasan: add wrappers for vmalloc hooks (Chris von Recklinghausen) [2120352]
- kasan: reorder vmalloc hooks (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: drop outdated VM_KASAN comment (Chris von Recklinghausen) [2120352]
- kasan, x86, arm64, s390: rename functions for modules shadow (Chris von Recklinghausen) [2120352]
- kasan: define KASAN_VMALLOC_INVALID for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: clean up metadata byte definitions (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: rework kasan_unpoison_pages call site (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move kernel_init_free_pages in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move SetPageSkipKASanPoison in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: combine tag_clear_highpage calls in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: merge kasan_alloc_pages into post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: refactor init checks in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan: only apply __GFP_ZEROTAGS when memory is zeroed (Chris von Recklinghausen) [2120352]
- mm: clarify __GFP_ZEROTAGS comment (Chris von Recklinghausen) [2120352]
- kasan: drop skip_kasan_poison variable in free_pages_prepare (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: init memory of skipped pages on free (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: simplify kasan_poison_pages call site (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: merge kasan_free_pages into free_pages_prepare (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move tag_clear_highpage out of kernel_init_free_pages (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: deduplicate should_skip_kasan_poison (Chris von Recklinghausen) [2120352]
- mm: unexport page_init_poison (Chris von Recklinghausen) [2120352]
- kasan: no need to unset panic_on_warn in end_report() (Chris von Recklinghausen) [2120352]
- mm/mlock: fix two bugs in user_shm_lock() (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: remove repeat container_of() in damon_sysfs_kdamond_release() (Chris von Recklinghausen) [2120352]
- Docs/ABI/testing: add DAMON sysfs interface ABI document (Chris von Recklinghausen) [2120352]
- Docs/admin-guide/mm/damon/usage: document DAMON sysfs interface (Chris von Recklinghausen) [2120352]
- selftests/damon: add a test for DAMON sysfs interface (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS stats (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS watermarks (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support schemes prioritization (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS quotas (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support the physical address space monitoring (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: link DAMON for virtual address spaces monitoring (Chris von Recklinghausen) [2120352]
- mm/damon: implement a minimal stub for sysfs-based DAMON interface (Chris von Recklinghausen) [2120352]
- mm/damon/core: add number of each enum type values (Chris von Recklinghausen) [2120352]
- mm/damon/core: allow non-exclusive DAMON start/stop (Chris von Recklinghausen) [2120352]
- Docs/damon: update outdated term 'regions update interval' (Chris von Recklinghausen) [2120352]
- Docs/vm/damon/design: update DAMON-Idle Page Tracking interference handling (Chris von Recklinghausen) [2120352]
- Docs/vm/damon: call low level monitoring primitives the operations (Chris von Recklinghausen) [2120352]
- mm/damon: remove unnecessary CONFIG_DAMON option (Chris von Recklinghausen) [2120352]
- mm/damon/paddr,vaddr: remove damon_{p,v}a_{target_valid,set_operations}() (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs-test: fix is_target_id() change (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs: use operations id for knowing if the target has pid (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs: use damon_select_ops() instead of damon_{v,p}a_set_operations() (Chris von Recklinghausen) [2120352]
- mm/damon/reclaim: use damon_select_ops() instead of damon_{v,p}a_set_operations() (Chris von Recklinghausen) [2120352]
- mm/damon/paddr,vaddr: register themselves to DAMON in subsys_initcall (Chris von Recklinghausen) [2120352]
- mm/damon: let monitoring operations can be registered and selected (Chris von Recklinghausen) [2120352]
- mm/damon: rename damon_primitives to damon_operations (Chris von Recklinghausen) [2120352]
- mm/damon: remove redundant page validation (Chris von Recklinghausen) [2120352]
- mm/damon: remove the target id concept (Chris von Recklinghausen) [2120352]
- mm/damon/core: move damon_set_targets() into dbgfs (Chris von Recklinghausen) [2120352]
- Docs/admin-guide/mm/damon/usage: update for changed initail_regions file input (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs/init_regions: use target index instead of target id (Chris von Recklinghausen) [2120352]
- mm/hmm.c: remove unneeded local variable ret (Chris von Recklinghausen) [2120352]
- kfence: allow use of a deferrable timer (Chris von Recklinghausen) [2120352]
- mm/page_table_check.c: use strtobool for param parsing (Chris von Recklinghausen) [2120352]
- mm/highmem: remove unnecessary done label (Chris von Recklinghausen) [2120352]
- mm/early_ioremap: declare early_memremap_pgprot_adjust() (Chris von Recklinghausen) [2120352]
- mm: uninline copy_overflow() (Chris von Recklinghausen) [2120352]
- mm: remove usercopy_warn() (Chris von Recklinghausen) [2120352]
- mm/zswap.c: allow handling just same-value filled pages (Chris von Recklinghausen) [2120352]
- mm/thp: ClearPageDoubleMap in first page_add_file_rmap() (Chris von Recklinghausen) [2120352]
- mm: only re-generate demotion targets when a numa node changes its N_CPU state (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: fix misplaced comment in offline_pages (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: clean up try_offline_node (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: avoid calling zone_intersects() for ZONE_NORMAL (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: remove obsolete comment of __add_pages (Chris von Recklinghausen) [2120352]
- mm: madvise: skip unmapped vma holes passed to process_madvise (Chris von Recklinghausen) [2120352]
- mm/madvise: use vma_lookup() instead of find_vma() (Chris von Recklinghausen) [2120352]
- mm/ksm: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- mm/vmstat: add event for ksm swapping in copy (Chris von Recklinghausen) [2120352]
- mm: page_io: fix psi memory pressure error on cold swapins (Chris von Recklinghausen) [2120352]
- memory tiering: skip to scan fast memory (Chris von Recklinghausen) [2120352]
- NUMA balancing: optimize page placement for memory tiering system (Chris von Recklinghausen) [2120352]
- NUMA Balancing: add page promotion counter (Chris von Recklinghausen) [2120352]
- mm/migrate: fix race between lock page and clear PG_Isolated (Chris von Recklinghausen) [2120352]
- mm,migrate: fix establishing demotion target (Chris von Recklinghausen) [2120352]
- mm/oom_kill: remove unneeded is_memcg_oom check (Chris von Recklinghausen) [2120352]
- mm: compaction: cleanup the compaction trace events (Chris von Recklinghausen) [2120352]
- mm: vmscan: fix documentation for page_check_references() (Chris von Recklinghausen) [2120352]
- mm/list_lru: optimize memcg_reparent_list_lru_node() (Chris von Recklinghausen) [2120352]
- mm: __isolate_lru_page_prepare() in isolate_migratepages_block() (Chris von Recklinghausen) [2120352]
- mm/fs: delete PF_SWAPWRITE (Chris von Recklinghausen) [2120352]
- userfaultfd: provide unmasked address on page-fault (Chris von Recklinghausen) [2120352]
- mm: remove unneeded local variable follflags (Chris von Recklinghausen) [2120352]
- mm/hugetlb: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- mm/hugetlb: generalize ARCH_WANT_GENERAL_HUGETLB (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: make non-LRU movable pages unhandlable (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: avoid calling invalidate_inode_page() with unexpected pages (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: fix race with changing page compound again (Chris von Recklinghausen) [2120352]
- mm/hwpoison: add in-use hugepage hwpoison filter judgement (Chris von Recklinghausen) [2120352]
- mm/hwpoison: avoid the impact of hwpoison_filter() return value on mce handler (Chris von Recklinghausen) [2120352]
- mm/hwpoison-inject: support injecting hwpoison to free page (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove unnecessary PageTransTail check (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove obsolete comment in __soft_offline_page (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: rework the try_to_unmap logic in hwpoison_user_map (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove PageSlab check in hwpoison_filter_dev (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: fix race with changing page more robustly (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: rework the signaling logic in kill_proc (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: catch unexpected -EFAULT from vma_address() (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: minor clean up for memory_failure_dev_pagemap (Chris von Recklinghausen) [2120352]
- mm: invalidate hwpoison page cache page in fault path (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove obsolete comment (Chris von Recklinghausen) [2120352]
- mm/page_alloc: call check_new_pages() while zone spinlock is not held (Chris von Recklinghausen) [2120352]
- mm: count time in drain_all_pages during direct reclaim as memory pressure (Chris von Recklinghausen) [2120352]
- mm: enforce pageblock_order < MAX_ORDER (Chris von Recklinghausen) [2120352]
- mm/page_alloc: don't pass pfn to free_unref_page_commit() (Chris von Recklinghausen) [2120352]
- mm/mmzone.h: remove unused macros (Chris von Recklinghausen) [2120352]
- mm/mmzone.c: use try_cmpxchg() in page_cpupid_xchg_last() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: avoid merging non-fallbackable pageblocks with others (Chris von Recklinghausen) [2120352]
- mm/vmalloc.c: fix "unused function" warning (Chris von Recklinghausen) [2120352]
- mm/vmalloc: eliminate an extra orig_gfp_mask (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add adjust_search_size parameter (Chris von Recklinghausen) [2120352]
- mm/vmalloc: Move draining areas out of caller context (Chris von Recklinghausen) [2120352]
- mm/vmalloc: remove unneeded function forward declaration (Chris von Recklinghausen) [2120352]
- mm/sparse: make mminit_validate_memmodel_limits() static (Chris von Recklinghausen) [2120352]
- mm/mremap:: use vma_lookup() instead of find_vma() (Chris von Recklinghausen) [2120352]
- mm/mmap: remove obsolete comment in ksys_mmap_pgoff (Chris von Recklinghausen) [2120352]
- mm: _install_special_mapping() apply VM_LOCKED_CLEAR_MASK (Chris von Recklinghausen) [2120352]
- mm/memory.c: use helper macro min and max in unmap_mapping_range_tree() (Chris von Recklinghausen) [2120352]
- mm/memory.c: use helper function range_in_vma() (Chris von Recklinghausen) [2120352]
- mm/mmap: return 1 from stack_guard_gap __setup() handler (Chris von Recklinghausen) [2120352]
- mm/memcontrol: return 1 from cgroup.memory __setup() handler (Chris von Recklinghausen) [2120352]
- memcg: synchronously enforce memory.high for large overcharges (Chris von Recklinghausen) [2120352]
- memcg: unify force charging conditions (Chris von Recklinghausen) [2120352]
- memcg: refactor mem_cgroup_oom (Chris von Recklinghausen) [2120352]
- mm/memcg: mem_cgroup_per_node is already set to 0 on allocation (Chris von Recklinghausen) [2120352]
- memcg: replace in_interrupt() with !in_task() (Chris von Recklinghausen) [2120352]
- mm: shmem: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- tmpfs: support for file creation time (Chris von Recklinghausen) [2120352]
- mm/gup: remove unused get_user_pages_locked() (Chris von Recklinghausen) [2120352]
- mm: change lookup_node() to use get_user_pages_fast() (Chris von Recklinghausen) [2120352]
- mm/gup: remove unused pin_user_pages_locked() (Chris von Recklinghausen) [2120352]
- mm/gup: follow_pfn_pte(): -EEXIST cleanup (Chris von Recklinghausen) [2120352]
- mm: fs: fix lru_cache_disabled race in bh_lru (Chris von Recklinghausen) [2120352]
- mm/writeback: minor clean up for highmem_dirtyable_memory (Chris von Recklinghausen) [2120352]
- filemap: remove find_get_pages() (Chris von Recklinghausen) [2120352]
- mm/memremap: avoid calling kasan_remove_zero_shadow() for device private memory (Chris von Recklinghausen) [2120352]
- remove bdi_congested() and wb_congested() and related functions (Chris von Recklinghausen) [2120352]
- remove inode_congested() (Chris von Recklinghausen) [2120352]
- mm: improve cleanup when ->readpages doesn't process all pages (Chris von Recklinghausen) [2120352]
- mm: document and polish read-ahead code (Chris von Recklinghausen) [2120352]
- mm/damon: minor cleanup for damon_pa_young (Chris von Recklinghausen) [2120352]
- mm/readahead: Align file mappings for non-DAX (Chris von Recklinghausen) [2120352]
- mm/huge_memory: Convert __split_huge_pmd() to take a folio (Chris von Recklinghausen) [2120352]
- mm: swap: get rid of livelock in swapin readahead (Chris von Recklinghausen) [2120352]
- fs: Remove aops ->set_page_dirty (Chris von Recklinghausen) [2120352]
- fb_defio: Use noop_dirty_folio() (Chris von Recklinghausen) [2120352]
- fs: Convert __set_page_dirty_no_writeback to noop_dirty_folio (Chris von Recklinghausen) [2120352]
- fs: Convert __set_page_dirty_buffers to block_dirty_folio (Chris von Recklinghausen) [2120352]
- afs: Convert afs_dir_set_page_dirty() to afs_dir_dirty_folio() (Chris von Recklinghausen) [2120352]
- fs: Convert trivial uses of __set_page_dirty_nobuffers to filemap_dirty_folio (Chris von Recklinghausen) [2120352]
- fscache: Convert fscache_set_page_dirty() to fscache_dirty_folio() (Chris von Recklinghausen) [2120352]
- fuse: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2120352]
- afs: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2120352]
- ceph: Convert from invalidatepage to invalidate_folio (Chris von Recklinghausen) [2120352]
- fs: Remove noop_invalidatepage() (Chris von Recklinghausen) [2120352]
- fs: Turn block_invalidatepage into block_invalidate_folio (Chris von Recklinghausen) [2120352]
- fs: Convert is_partially_uptodate to folios (Chris von Recklinghausen) [2120352]
- resume_user_mode: Move to resume_user_mode.h (Chris von Recklinghausen) [2120352]
- resume_user_mode: Remove #ifdef TIF_NOTIFY_RESUME in set_notify_resume (Chris von Recklinghausen) [2120352]
- signal: Move set_notify_signal and clear_notify_signal into sched/signal.h (Chris von Recklinghausen) [2120352]
- task_work: Decouple TIF_NOTIFY_SIGNAL and task_work (Chris von Recklinghausen) [2120352]
- task_work: Call tracehook_notify_signal from get_signal on all architectures (Chris von Recklinghausen) [2120352]
- task_work: Introduce task_work_pending (Chris von Recklinghausen) [2120352]
- task_work: Remove unnecessary include from posix_timers.h (Chris von Recklinghausen) [2120352]
- ptrace: Remove tracehook_signal_handler (Chris von Recklinghausen) [2120352]
- ptrace: Remove arch_syscall_{enter,exit}_tracehook (Chris von Recklinghausen) [2120352]
- ptrace: Create ptrace_report_syscall_{entry,exit} in ptrace.h (Chris von Recklinghausen) [2120352]
- ptrace: Move ptrace_report_syscall into ptrace.h (Chris von Recklinghausen) [2120352]
- mm: slub: Delete useless parameter of alloc_slab_page() (Chris von Recklinghausen) [2120352]
- s390/test_unwind: add kretprobe tests (Chris von Recklinghausen) [2120352]
- mm/slub: remove forced_order parameter in calculate_sizes (Chris von Recklinghausen) [2120352]
- mm/slub: refactor deactivate_slab() (Chris von Recklinghausen) [2120352]
- mm/slub: limit number of node partial slabs only in cache creation (Chris von Recklinghausen) [2120352]
- mm/slub: use helper macro __ATTR_XX_MODE for SLAB_ATTR(_RO) (Chris von Recklinghausen) [2120352]
- memfd: fix F_SEAL_WRITE after shmem huge page allocated (Chris von Recklinghausen) [2120352]
- mm: fix use-after-free when anon vma name is used after vma is freed (Chris von Recklinghausen) [2120352]
- mm: prevent vm_area_struct::anon_name refcount saturation (Chris von Recklinghausen) [2120352]
- mm: refactor vm_area_struct::anon_vma_name usage code (Chris von Recklinghausen) [2120352]
- mm: build migrate_vma_* for all configs with ZONE_DEVICE support (Chris von Recklinghausen) [2099722 2120352]
- mm: move the migrate_vma_* device migration code into its own file (Chris von Recklinghausen) [2120352]
- mm: refactor the ZONE_DEVICE handling in migrate_vma_pages (Chris von Recklinghausen) [2099722 2120352]
- mm: refactor the ZONE_DEVICE handling in migrate_vma_insert_page (Chris von Recklinghausen) [2099722 2120352]
- mm: generalize the pgmap based page_free infrastructure (Chris von Recklinghausen) [2099722 2120352]
- fsdax: depend on ZONE_DEVICE || FS_DAX_LIMITED (Chris von Recklinghausen) [2099722 2120352]
- mm: remove the extra ZONE_DEVICE struct page refcount (Chris von Recklinghausen) [2099722 2120352]
- mm: remove the __KERNEL__ guard from <linux/mm.h> (Chris von Recklinghausen) [2099722 2120352]
- mm: remove a pointless CONFIG_ZONE_DEVICE check in memremap_pages (Chris von Recklinghausen) [2099722 2120352]
- s390/test_unwind: fix and extend kprobes test (Chris von Recklinghausen) [2120352]
- s390/test_unwind: add ftrace test (Chris von Recklinghausen) [2120352]
- s390/test_unwind: minor cleanup (Chris von Recklinghausen) [2120352]
- s390/test_unwind: show tests as skipped if unsupported (Chris von Recklinghausen) [2120352]
- mm/hugetlb: fix kernel crash with hugetlb mremap (Chris von Recklinghausen) [2120352]
- usercopy: Check valid lifetime via stack depth (Chris von Recklinghausen) [2120352]
- Convert NFS from readpages to readahead (Chris von Recklinghausen) [2120352]
- uaccess: remove CONFIG_SET_FS (Chris von Recklinghausen) [2120352]
- uaccess: generalize access_ok() (Chris von Recklinghausen) [2120352]
- arm64: simplify access_ok() (Chris von Recklinghausen) [2120352]
- uaccess: add generic __{get,put}_kernel_nofault (Chris von Recklinghausen) [2120352]
- x86: use more conventional access_ok() definition (Chris von Recklinghausen) [2120352]
- x86: remove __range_not_ok() (Chris von Recklinghausen) [2120352]
- mm/slab_common: use helper function is_power_of_2() (Chris von Recklinghausen) [2120352]
- mm/slob: make kmem_cache_boot static (Chris von Recklinghausen) [2120352]
- tools/cgroup/slabinfo: update to work with struct slab (Chris von Recklinghausen) [2120352]
- memblock: __next_mem_pfn_range_in_zone: remove unneeded local variable nid (Chris von Recklinghausen) [2120352]
- memblock: use kfree() to release kmalloced memblock regions (Chris von Recklinghausen) [2120352]
- mm: vmscan: remove deadlock due to throttling failing to make progress (Chris von Recklinghausen) [2120352]
- signal: HANDLER_EXIT should clear SIGNAL_UNKILLABLE (Chris von Recklinghausen) [2120352]
- ref_tracker: remove filter_irq_stacks() call (Chris von Recklinghausen) [2120352]
- mm/kmemleak: avoid scanning potential huge holes (Chris von Recklinghausen) [2120352]
- mm/page_table_check: use unsigned long for page counters and cleanup (Chris von Recklinghausen) [2120352]
- Revert "mm/page_isolation: unset migratetype directly for non Buddy page" (Chris von Recklinghausen) [2120352]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Chris von Recklinghausen) [2120352]
- mm, kasan: use compare-exchange operation to set KASAN page tag (Chris von Recklinghausen) [2120352]
- memory-failure: fetch compound_head after pgmap_pfn_valid() (Chris von Recklinghausen) [2120352]
- fbdev/simplefb: Request memory region in driver (Chris von Recklinghausen) [2120352]
- fbdev: Hot-unplug firmware fb devices on forced removal (Chris von Recklinghausen) [2120352]
- selftests/lkdtm: Remove dead config option (Chris von Recklinghausen) [2120352]
- mm: hide the FRONTSWAP Kconfig symbol (Chris von Recklinghausen) [2120352]
- frontswap: remove support for multiple ops (Chris von Recklinghausen) [2120352]
- mm: mark swap_lock and swap_active_head static (Chris von Recklinghausen) [2120352]
- frontswap: simplify frontswap_register_ops (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_test (Chris von Recklinghausen) [2120352]
- mm: simplify try_to_unuse (Chris von Recklinghausen) [2120352]
- frontswap: remove the frontswap exports (Chris von Recklinghausen) [2120352]
- frontswap: simplify frontswap_init (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_curr_pages (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_shrink (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_tmem_exclusive_gets (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_writethrough (Chris von Recklinghausen) [2120352]
- mm: remove cleancache (Chris von Recklinghausen) [2120352]
- lib/stackdepot: always do filter_irq_stacks() in stack_depot_save() (Chris von Recklinghausen) [2120352]
- lib/stackdepot: allow optional init and stack_table allocation by kvmalloc() (Chris von Recklinghausen) [2120352]
- sysctl: move some boundary constants from sysctl.c to sysctl_vals (Chris von Recklinghausen) [2120352]
- delayacct: track delays from memory compact (Chris von Recklinghausen) [2120352]
- delayacct: support swapin delay accounting for swapping without blkio (Chris von Recklinghausen) [2120352]
- mm: percpu: add generic pcpu_populate_pte() function (Chris von Recklinghausen) [2120352]
- mm: percpu: add generic pcpu_fc_alloc/free funciton (Chris von Recklinghausen) [2120352]
- mm: percpu: add pcpu_fc_cpu_to_node_fn_t typedef (Chris von Recklinghausen) [2120352]
- mm: percpu: generalize percpu related config (Chris von Recklinghausen) [2120352]
- bitmap: unify find_bit operations (Chris von Recklinghausen) [2120352]
- mm/percpu: micro-optimize pcpu_is_populated() (Chris von Recklinghausen) [2120352]
- find: micro-optimize for_each_{set,clear}_bit() (Chris von Recklinghausen) [2120352]
- include/linux: move for_each_bit() macros from bitops.h to find.h (Chris von Recklinghausen) [2120352]
- lib: add find_first_and_bit() (Chris von Recklinghausen) [2120352]
- arch: remove GENERIC_FIND_FIRST_BIT entirely (Chris von Recklinghausen) [2120352]
- include: move find.h from asm_generic to linux (Chris von Recklinghausen) [2120352]
- bitops: move find_bit_*_le functions from le.h to find.h (Chris von Recklinghausen) [2120352]
- mm/hmm.c: allow VM_MIXEDMAP to work with hmm_range_fault (Chris von Recklinghausen) [2120352]
- mm: fix some comment errors (Chris von Recklinghausen) [2120352]
- zpool: remove the list of pools_head (Chris von Recklinghausen) [2120352]
- mm/rmap: fix potential batched TLB flush race (Chris von Recklinghausen) [2120352]
- mm: memcg/percpu: account extra objcg space to memory cgroups (Chris von Recklinghausen) [2120352]
- mm: ksm: fix use-after-free kasan report in ksm_might_need_to_copy (Chris von Recklinghausen) [2120352]
- mm/migrate: remove redundant variables used in a for-loop (Chris von Recklinghausen) [2120352]
- mm/migrate: move node demotion code to near its user (Chris von Recklinghausen) [2120352]
- mm: migrate: add more comments for selecting target node randomly (Chris von Recklinghausen) [2120352]
- mm: migrate: support multiple target nodes demotion (Chris von Recklinghausen) [2120352]
- mm: compaction: fix the migration stats in trace_mm_compaction_migratepages() (Chris von Recklinghausen) [2120352]
- mm: migrate: correct the hugetlb migration stats (Chris von Recklinghausen) [2120352]
- mm: migrate: fix the return value of migrate_pages() (Chris von Recklinghausen) [2120352]
- mm, oom: OOM sysrq should always kill a process (Chris von Recklinghausen) [2120352]
- mm/mempolicy: fix all kernel-doc warnings (Chris von Recklinghausen) [2120352]
- mm/mempolicy: add set_mempolicy_home_node syscall (Chris von Recklinghausen) [2120352]
- mm/mempolicy: use policy_node helper with MPOL_PREFERRED_MANY (Chris von Recklinghausen) [2120352]
- mm/page_isolation: unset migratetype directly for non Buddy page (Chris von Recklinghausen) [2120352]
- vmscan: make drop_slab_node static (Chris von Recklinghausen) [2120352]
- hugetlb: add hugetlb.*.numa_stat file (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: modify the comment section for alloc_contig_pages() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: fix building error on -Werror=array-compare (Chris von Recklinghausen) [2120352]
- mm/pagealloc: sysctl: change watermark_scale_factor max limit to 30%% (Chris von Recklinghausen) [2120352]
- mm: allow !GFP_KERNEL allocations for kvmalloc (Chris von Recklinghausen) [2120352]
- mm/vmalloc: be more explicit about supported gfp flags. (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add support for __GFP_NOFAIL (Chris von Recklinghausen) [2120352]
- mm/vmalloc: alloc GFP_NO{FS,IO} for vmalloc (Chris von Recklinghausen) [2120352]
- mm/dmapool.c: revert "make dma pool to use kmalloc_node" (Chris von Recklinghausen) [2120352]
- mm: remove the total_mapcount argument from page_trans_huge_mapcount() (Chris von Recklinghausen) [2120352]
- mm: remove the total_mapcount argument from page_trans_huge_map_swapcount() (Chris von Recklinghausen) [2120352]
- mm: remove last argument of reuse_swap_page() (Chris von Recklinghausen) [2120352]
- mm: move tlb_flush_pending inline helpers to mm_inline.h (Chris von Recklinghausen) [2120352]
- mm: move anon_vma declarations to linux/mm_inline.h (Chris von Recklinghausen) [2120352]
- mm: add anonymous vma name refcounting (Chris von Recklinghausen) [2120352]
- mm: add a field to store names for private anonymous memory (Chris von Recklinghausen) [2120352]
- mm: rearrange madvise code to allow for reuse (Chris von Recklinghausen) [2120352]
- mm/memcg: use struct_size() helper in kzalloc() (Chris von Recklinghausen) [2120352]
- mm/memcg: add oom_group_kill memory event (Chris von Recklinghausen) [2120352]
- mm/page_counter: remove an incorrect call to propagate_protected_usage() (Chris von Recklinghausen) [2120352]
- mm: memcontrol: make cgroup_memory_nokmem static (Chris von Recklinghausen) [2120352]
- mm/frontswap.c: use non-atomic '__set_bit()' when possible (Chris von Recklinghausen) [2120352]
- shmem: fix a race between shmem_unused_huge_shrink and shmem_evict_inode (Chris von Recklinghausen) [2120352]
- mm: shmem: don't truncate page if memory failure happens (Chris von Recklinghausen) [2120352]
- mm/gup.c: stricter check on THP migration entry during follow_pmd_mask (Chris von Recklinghausen) [2120352]
- gup: avoid multiple user access locking/unlocking in fault_in_{read/write}able (Chris von Recklinghausen) [2120352]
- mm/debug_vm_pgtable: update comments regarding migration swap entries (Chris von Recklinghausen) [2120352]
- mm,fs: split dump_mapping() out from dump_page() (Chris von Recklinghausen) [2120352]
- mm/memremap: add ZONE_DEVICE support for compound pages (Chris von Recklinghausen) [2120352]
- mm/page_alloc: refactor memmap_init_zone_device() page init (Chris von Recklinghausen) [2120352]
- mm/page_alloc: split prep_compound_page into head and tail subparts (Chris von Recklinghausen) [2120352]
- mm: defer kmemleak object creation of module_alloc() (Chris von Recklinghausen) [2120352]
- kmemleak: fix kmemleak false positive report with HW tag-based kasan enable (Chris von Recklinghausen) [2120352]
- mm: slab: make slab iterator functions static (Chris von Recklinghausen) [2120352]
- virtio-mem: prepare fake page onlining code for granularity smaller than MAX_ORDER - 1 (Chris von Recklinghausen) [2120352]
- virtio-mem: prepare page onlining code for granularity smaller than MAX_ORDER - 1 (Chris von Recklinghausen) [2120352]
- fscache: Rewrite documentation (Chris von Recklinghausen) [2120352]
- ptrace: Remove unused regs argument from ptrace_report_syscall (Chris von Recklinghausen) [2120352]
- ptrace: Remove second setting of PT_SEIZED in ptrace_attach (Chris von Recklinghausen) [2120352]
- taskstats: Cleanup the use of task->exit_code (Chris von Recklinghausen) [2120352]
- exit: Use the correct exit_code in /proc/<pid>/stat (Chris von Recklinghausen) [2120352]
- exit: Fix the exit_code for wait_task_zombie (Chris von Recklinghausen) [2120352]
- exit: Coredumps reach do_group_exit (Chris von Recklinghausen) [2120352]
- exit: Remove profile_handoff_task (Chris von Recklinghausen) [2120352]
- exit: Remove profile_task_exit & profile_munmap (Chris von Recklinghausen) [2120352]
- signal: clean up kernel-doc comments (Chris von Recklinghausen) [2120352]
- signal: Remove the helper signal_group_exit (Chris von Recklinghausen) [2120352]
- signal: Rename group_exit_task group_exec_task (Chris von Recklinghausen) [2120352]
- coredump: Stop setting signal->group_exit_task (Chris von Recklinghausen) [2120352]
- signal: Remove SIGNAL_GROUP_COREDUMP (Chris von Recklinghausen) [2120352]
- signal: During coredumps set SIGNAL_GROUP_EXIT in zap_process (Chris von Recklinghausen) [2120352]
- signal: Make coredump handling explicit in complete_signal (Chris von Recklinghausen) [2120352]
- signal: Have prepare_signal detect coredumps using signal->core_state (Chris von Recklinghausen) [2120352]
- signal: Have the oom killer detect coredumps using signal->core_state (Chris von Recklinghausen) [2120352]
- exit: Move force_uaccess back into do_exit (Chris von Recklinghausen) [2120352]
- exit: Guarantee make_task_dead leaks the tsk when calling do_task_exit (Chris von Recklinghausen) [2120352]
- h8300: Fix build errors from do_exit() to make_task_dead() transition (Chris von Recklinghausen) [2120352]
- kthread: Generalize pf_io_worker so it can point to struct kthread (Chris von Recklinghausen) [2120352]
- mm: Remove slab from struct page (Chris von Recklinghausen) [2120352]
- mm/slob: Remove unnecessary page_mapcount_reset() function call (Chris von Recklinghausen) [2120352]
- bootmem: Use page->index instead of page->freelist (Chris von Recklinghausen) [2120352]
- mm/slub: Define struct slab fields for CONFIG_SLUB_CPU_PARTIAL only when enabled (Chris von Recklinghausen) [2120352]
- mm/slub: Simplify struct slab slabs field definition (Chris von Recklinghausen) [2120352]
- mm/sl*b: Differentiate struct slab fields by sl*b implementations (Chris von Recklinghausen) [2120352]
- mm/kfence: Convert kfence_guarded_alloc() to struct slab (Chris von Recklinghausen) [2120352]
- mm/kasan: Convert to struct folio and struct slab (Chris von Recklinghausen) [2120352]
- mm/slob: Convert SLOB to use struct slab and struct folio (Chris von Recklinghausen) [2120352]
- mm/memcg: Convert slab objcgs from struct page to struct slab (Chris von Recklinghausen) [2120352]
- mm: Convert struct page to struct slab in functions used by other subsystems (Chris von Recklinghausen) [2120352]
- mm/slab: Convert most struct page to struct slab by spatch (Chris von Recklinghausen) [2120352]
- mm/slab: Convert kmem_getpages() and kmem_freepages() to struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Finish struct page to struct slab conversion (Chris von Recklinghausen) [2120352]
- mm/slub: Convert most struct page to struct slab by spatch (Chris von Recklinghausen) [2120352]
- mm/slub: Convert pfmemalloc_match() to take a struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Convert __slab_lock() and __slab_unlock() to struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Make object_err() static (Chris von Recklinghausen) [2120352]
- mm/slab: Dissolve slab_map_pages() in its caller (Chris von Recklinghausen) [2120352]
- mm: vmscan: reduce throttling due to a failure to make progress -fix (Chris von Recklinghausen) [2120352]
- mm: vmscan: Reduce throttling due to a failure to make progress (Chris von Recklinghausen) [2120352]
- kthread: Never put_user the set_child_tid address (Chris von Recklinghausen) [2120352]
- kthread: Warn about failed allocations for the init kthread (Chris von Recklinghausen) [2120352]
- fork: Rename bad_fork_cleanup_threadgroup_lock to bad_fork_cleanup_delayacct (Chris von Recklinghausen) [2120352]
- fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA (Chris von Recklinghausen) [2120352]
- iomap: Convert to_iomap_page to take a folio (Chris von Recklinghausen) [2120352]
- objtool: Add a missing comma to avoid string concatenation (Chris von Recklinghausen) [2120352]
- exit/kthread: Fix the kerneldoc comment for kthread_complete_and_exit (Chris von Recklinghausen) [2120352]
- exit/kthread: Move the exit code for kernel threads into struct kthread (Chris von Recklinghausen) [2120352]
- kthread: Ensure struct kthread is present for all kthreads (Chris von Recklinghausen) [2120352]
- exit: Rename complete_and_exit to kthread_complete_and_exit (Chris von Recklinghausen) [2120352]
- exit: Rename module_put_and_exit to module_put_and_kthread_exit (Chris von Recklinghausen) [2120352]
- exit: Implement kthread_exit (Chris von Recklinghausen) [2120352]
- exit: Stop exporting do_exit (Chris von Recklinghausen) [2120352]
- exit: Stop poorly open coding do_task_dead in make_task_dead (Chris von Recklinghausen) [2120352]
- exit: Move oops specific logic from do_exit into make_task_dead (Chris von Recklinghausen) [2120352]
- exit: Add and use make_task_dead. (Chris von Recklinghausen) [2120352]
- exit/s390: Remove dead reference to do_exit from copy_thread (Chris von Recklinghausen) [2120352]
- mm: bdi: initialize bdi_min_ratio when bdi is unregistered (Chris von Recklinghausen) [2120352]
- selftests/damon: split test cases (Chris von Recklinghausen) [2120352]
- selftests/damon: test wrong DAMOS condition ranges input (Chris von Recklinghausen) [2120352]
- selftests/damon: skip test if DAMON is running (Chris von Recklinghausen) [2120352]
- mm, kcsan: Enable barrier instrumentation (Chris von Recklinghausen) [2120352]
- percpu: km: ensure it is used with NOMMU (either UP or SMP) (Chris von Recklinghausen) [2120352]
- memremap: remove support for external pgmap refcounts (Chris von Recklinghausen) [2120352]
- powerpc/modules: Don't WARN on first module allocation attempt (Chris von Recklinghausen) [2120352]
- s390/test_unwind: use raw opcode instead of invalid instruction (Chris von Recklinghausen) [2120352]
- hugetlbfs: flush before unlock on move_hugetlb_page_tables() (Chris von Recklinghausen) [2120352]
- kmap_local: don't assume kmap PTEs are linear arrays in memory (Chris von Recklinghausen) [2120352]
- hugetlb: fix hugetlb cgroup refcounting during mremap (Chris von Recklinghausen) [2120352]
- mm: kmemleak: slob: respect SLAB_NOLEAKTRACE flag (Chris von Recklinghausen) [2120352]
- mm: emit the "free" trace report before freeing memory in kmem_cache_free() (Chris von Recklinghausen) [2120352]
- mm/swap.c:put_pages_list(): reinitialise the page list (Chris von Recklinghausen) [2120352]
- signal: Replace force_fatal_sig with force_exit_sig when in doubt (Chris von Recklinghausen) [2120352]
- signal: Don't always set SA_IMMUTABLE for forced signals (Chris von Recklinghausen) [2120352]
- signal: Requeue ptrace signals (Chris von Recklinghausen) [2120352]
- signal: Requeue signals in the appropriate queue (Chris von Recklinghausen) [2120352]
- mm/migrate.c: remove MIGRATE_PFN_LOCKED (Chris von Recklinghausen) [2120352]
- mm/page_owner.c: modify the type of argument "order" in some functions (Chris von Recklinghausen) [2120352]
- mm: kasan: use is_kernel() helper (Chris von Recklinghausen) [2120352]
- mm,hugetlb: remove mlock ulimit for SHM_HUGETLB (Chris von Recklinghausen) [2120352]
- vfs: keep inodes with page cache off the inode shrinker LRU (Chris von Recklinghausen) [2120352]
- selftests/damon: support watermarks (Chris von Recklinghausen) [2120352]
- tools/selftests/damon: update for regions prioritization of schemes (Chris von Recklinghausen) [2120352]
- mm/damon/selftests: support schemes quotas (Chris von Recklinghausen) [2120352]
- selftests/damon: add 'schemes' debugfs tests (Chris von Recklinghausen) [2120352]
- include/linux/damon.h: fix kernel-doc comments for 'damon_callback' (Chris von Recklinghausen) [2120352]
- include/linux/mm.h: move nr_free_buffer_pages from swap.h to mm.h (Chris von Recklinghausen) [2120352]
- mm: remove HARDENED_USERCOPY_FALLBACK (Chris von Recklinghausen) [2120352]
- mm/highmem: remove deprecated kmap_atomic (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: indicate MEMBLOCK_DRIVER_MANAGED with IORESOURCE_SYSRAM_DRIVER_MANAGED (Chris von Recklinghausen) [2120352]
- memblock: add MEMBLOCK_DRIVER_MANAGED to mimic IORESOURCE_SYSRAM_DRIVER_MANAGED (Chris von Recklinghausen) [2120352]
- memblock: allow to specify flags with memblock_add_node() (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: handle memblock_add_node() failures in add_memory_resource() (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: remove HIGHMEM leftovers (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: add static qualifier for online_policy_to_str() (Chris von Recklinghausen) [2120352]
- mm: vmstat.c: make extfrag_index show more pretty (Chris von Recklinghausen) [2120352]
- mm: nommu: kill arch_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- mm/readahead.c: fix incorrect comments for get_init_ra_size (Chris von Recklinghausen) [2120352]
- mm: migrate: make demotion knob depend on migration (Chris von Recklinghausen) [2120352]
- mm/migrate: de-duplicate migrate_reason strings (Chris von Recklinghausen) [2120352]
- mm: mark the OOM reaper thread as freezable (Chris von Recklinghausen) [2120352]
- mm/vmpressure: fix data-race with memcg->socket_pressure (Chris von Recklinghausen) [2120352]
- mm/vmscan: delay waking of tasks throttled on NOPROGRESS (Chris von Recklinghausen) [2120352]
- mm/vmscan: increase the timeout if page reclaim is not making progress (Chris von Recklinghausen) [2120352]
- mm/vmscan: centralise timeout values for reclaim_throttle (Chris von Recklinghausen) [2120352]
- mm/page_alloc: remove the throttling logic from the page allocator (Chris von Recklinghausen) [2120352]
- mm/writeback: throttle based on page writeback instead of congestion (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim when no progress is being made (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim and compaction when too may pages are isolated (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim until some writeback completes if congested (Chris von Recklinghausen) [2120352]
- mm/vmscan.c: fix -Wunused-but-set-variable warning (Chris von Recklinghausen) [2120352]
- mm/page_isolation: guard against possible putback unisolated page (Chris von Recklinghausen) [2120352]
- mm/page_isolation: fix potential missing call to unset_migratetype_isolate() (Chris von Recklinghausen) [2120352]
- hugetlb: remove redundant VM_BUG_ON() in add_reservation_in_range() (Chris von Recklinghausen) [2120352]
- hugetlb: remove redundant validation in has_same_uncharge_info() (Chris von Recklinghausen) [2120352]
- hugetlb: replace the obsolete hugetlb_instantiation_mutex in the comments (Chris von Recklinghausen) [2120352]
- hugetlb_cgroup: remove unused hugetlb_cgroup_from_counter macro (Chris von Recklinghausen) [2120352]
- mm, hugepages: add mremap() support for hugepage backed vma (Chris von Recklinghausen) [2120352]
- mm: khugepaged: recalculate min_free_kbytes after stopping khugepaged (Chris von Recklinghausen) [2120352]
- mm/hugetlb: drop __unmap_hugepage_range definition from hugetlb.h (Chris von Recklinghausen) [2120352]
- mm/memory_failure: constify static mm_walk_ops (Chris von Recklinghausen) [2120352]
- mm/page_alloc: use clamp() to simplify code (Chris von Recklinghausen) [2120352]
- mm: page_alloc: use migrate_disable() in drain_local_pages_wq() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: show watermark_boost of zone in zoneinfo (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: do not acquire zone lock in is_free_buddy_page() (Chris von Recklinghausen) [2120352]
- mm/page_alloc: use accumulated load when building node fallback list (Chris von Recklinghausen) [2120352]
- mm/page_alloc: print node fallback order (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: use helper function zone_spans_pfn() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: simplify the code by using macro K() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: remove meaningless VM_BUG_ON() in pindex_to_order() (Chris von Recklinghausen) [2120352]
- mm/mprotect.c: avoid repeated assignment in do_mprotect_pkey() (Chris von Recklinghausen) [2120352]
- mm/memory.c: avoid unnecessary kernel/user pointer conversion (Chris von Recklinghausen) [2120352]
- mm: use __pfn_to_section() instead of open coding it (Chris von Recklinghausen) [2120352]
- mm/mmap.c: fix a data race of mm->total_vm (Chris von Recklinghausen) [2120352]
- memcg: prohibit unconditional exceeding the limit of dying tasks (Chris von Recklinghausen) [2120352]
- mm, oom: pagefault_out_of_memory: don't force global OOM for dying tasks (Chris von Recklinghausen) [2120352]
- mm: optimise put_pages_list() (Chris von Recklinghausen) [2120352]
- mm: don't read i_size of inode unless we need it (Chris von Recklinghausen) [2120352]
- mm: simplify bdi refcounting (Chris von Recklinghausen) [2120352]
- mm: don't automatically unregister bdis (Chris von Recklinghausen) [2120352]
- fs: explicitly unregister per-superblock BDIs (Chris von Recklinghausen) [2120352]
- mtd: call bdi_unregister explicitly (Chris von Recklinghausen) [2120352]
- mm: export bdi_unregister (Chris von Recklinghausen) [2120352]
- mm: stop filemap_read() from grabbing a superfluous page (Chris von Recklinghausen) [2120352]
- mm/page_ext.c: fix a comment (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add __alloc_size attributes for better bounds checking (Chris von Recklinghausen) [2120352]
- mm: debug_vm_pgtable: don't use __P000 directly (Chris von Recklinghausen) [2120352]
- mm/smaps: use vma->vm_pgoff directly when counting partial swap (Chris von Recklinghausen) [2120352]
- signal: Add SA_IMMUTABLE to ensure forced siganls do not get changed (Chris von Recklinghausen) [2120352]
- signal: Replace force_sigsegv(SIGSEGV) with force_fatal_sig(SIGSEGV) (Chris von Recklinghausen) [2120352]
- signal/x86: In emulate_vsyscall force a signal instead of calling do_exit (Chris von Recklinghausen) [2120352]
- exit/syscall_user_dispatch: Send ordinary signals on failure (Chris von Recklinghausen) [2120352]
- signal: Implement force_fatal_sig (Chris von Recklinghausen) [2120352]
- signal/s390: Use force_sigsegv in default_trap_handler (Chris von Recklinghausen) [2120352]
- ipv6: enable net.ipv6.route.max_size sysctl in network namespace (Chris von Recklinghausen) [2120352]
- MAINTAINERS: drop obsolete file pattern in SDHCI DRIVER section (Chris von Recklinghausen) [2120352]
- signal/vm86_32: Properly send SIGSEGV when the vm86 state cannot be saved. (Chris von Recklinghausen) [2120352]
- signal/powerpc: On swapcontext failure force SIGSEGV (Chris von Recklinghausen) [2120352]
- docs: translations: zh_CN: memory-hotplug.rst: fix a typo (Chris von Recklinghausen) [2120352]
- mmc: sdhci-pci: Remove dead code (struct sdhci_pci_data et al) (Chris von Recklinghausen) [2120352]
- mm: use pidfd_get_task() (Chris von Recklinghausen) [2120352]
- pid: add pidfd_get_task() helper (Chris von Recklinghausen) [2120352]
- mmc: core: Add host specific tuning support for eMMC HS400 mode (Chris von Recklinghausen) [2120352]
- s390/test_unwind: convert to KUnit (Chris von Recklinghausen) [2120352]
- coredump: Limit coredumps to a single thread group (Chris von Recklinghausen) [2120352]
- kasan: Extend KASAN mode kernel parameter (Chris von Recklinghausen) [2120352]
- kasan: Remove duplicate of kasan_flag_async (Chris von Recklinghausen) [2120352]
- coredump: Don't perform any cleanups before dumping core (Chris von Recklinghausen) [2120352]
- exit: Factor coredump_exit_mm out of exit_mm (Chris von Recklinghausen) [2120352]
- exec: Check for a pending fatal signal instead of core_state (Chris von Recklinghausen) [2120352]
- ptrace: Remove the unnecessary arguments from arch_ptrace_stop (Chris von Recklinghausen) [2120352]
- signal: Remove the bogus sigkill_pending in ptrace_stop (Chris von Recklinghausen) [2120352]
- scs: Release kasan vmalloc poison in scs_free process (Chris von Recklinghausen) [2120352]
- entry: rseq: Call rseq_handle_notify_resume() in tracehook_notify_resume() (Chris von Recklinghausen) [2120352]
- mm/ksm: remove old GCC 4.9+ check (Chris von Recklinghausen) [2120352]
- s390/unwind: use current_frame_address() to unwind current task (Chris von Recklinghausen) [2120352]
- io-wq: make worker creation resilient against signals (Chris von Recklinghausen) [2120352]
- io-wq: get rid of FIXED worker flag (Chris von Recklinghausen) [2120352]
- io-wq: split bounded and unbounded work into separate lists (Chris von Recklinghausen) [2120352]
- io-wq: fix queue stalling race (Chris von Recklinghausen) [2120352]
- io-wq: fix race between adding work and activating a free worker (Chris von Recklinghausen) [2120352]
- io-wq: fix wakeup race when adding new work (Chris von Recklinghausen) [2120352]
- io-wq: wqe and worker locks no longer need to be IRQ safe (Chris von Recklinghausen) [2120352]
- io-wq: check max_worker limits if a worker transitions bound state (Chris von Recklinghausen) [2120352]
- io-wq: provide a way to limit max number of workers (Chris von Recklinghausen) [2120352]
- signal/seccomp: Refactor seccomp signal and coredump generation (Chris von Recklinghausen) [2120352]
- s390: remove do_signal() prototype and do_notify_resume() function (Chris von Recklinghausen) [2120352]
- mmc: core: Update ->card_busy() callback comment (Chris von Recklinghausen) [2120352]
- io-wq: move nr_running and worker_refs out of wqe->lock protection (Chris von Recklinghausen) [2120352]
- io_uring: remove files pointer in cancellation functions (Chris von Recklinghausen) [2120352]
- io_uring: extract io_uring_files_cancel() in io_uring_task_cancel() (Chris von Recklinghausen) [2120352]
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Chris von Recklinghausen) [2120352]
- fs: add a filemap_fdatawrite_wbc helper (Chris von Recklinghausen) [2120352]
- fbdev/efifb: Release PCI device's runtime PM ref during FB destroy (Chris von Recklinghausen) [2120352]
- kernel/pid.c: remove static qualifier from pidfd_create() (Chris von Recklinghausen) [2120352]
- asm-generic: uaccess: remove inline strncpy_from_user/strnlen_user (Chris von Recklinghausen) [2120352]
- asm-generic/uaccess.h: remove __strncpy_from_user/__strnlen_user (Chris von Recklinghausen) [2120352]
- memcg: enable accounting for IP address and routing-related objects (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api protection keys translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api memory_hotplug translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api cpu_hotplug translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api genericirq translation (Chris von Recklinghausen) [2120352]
- Revert "fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA" (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_COMMAND_LINE_SIZE to RHEL s390 configs collection (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON to RHEL generic configs collection (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_PAGE_TABLE_CHECK to RHEL generic configs collection (Chris von Recklinghausen) [2120352]
- s390/mm: do not trigger write fault when vma does not allow VM_WRITE (Chris von Recklinghausen) [2120352]
- x86/pat: Fix x86_has_pat_wp() (Chris von Recklinghausen) [2120352]
- mm: sparsemem: fix missing higher order allocation splitting (Chris von Recklinghausen) [2120352]
- arm64: hugetlb: Restore TLB invalidation for BBM on contiguous ptes (Chris von Recklinghausen) [2120352]
- powerpc/memhotplug: Add add_pages override for PPC (Chris von Recklinghausen) [2120352]
- powerpc/64e: Fix early TLB miss with KUAP (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix PUD allocation size in map_kernel_page() (Chris von Recklinghausen) [2120352]
- arm64: mm: Don't invalidate FROM_DEVICE buffers at start of DMA transfer (Chris von Recklinghausen) [2120352]
- powerpc/book3e: get rid of #include <generated/compile.h> (Chris von Recklinghausen) [2120352]
- s390/mm: use non-quiescing sske for KVM switch to keyed guest (Chris von Recklinghausen) [2120352]
- s390/gmap: voluntarily schedule during key setting (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Fix building errors in huge_ptep_clear_flush() (Chris von Recklinghausen) [2120352]
- mm/page_table_check: fix accessing unmapped ptep (Chris von Recklinghausen) [2120352]
- x86/mm: Use PAGE_ALIGNED(x) instead of IS_ALIGNED(x, PAGE_SIZE) (Chris von Recklinghausen) [2120352]
- powerpc/64s: Only set HAVE_ARCH_UNMAPPED_AREA when CONFIG_PPC_64S_HASH_MMU is set (Chris von Recklinghausen) [2120352]
- powerpc/fsl_book3e: Don't set rodata RO too early (Chris von Recklinghausen) [2120352]
- powerpc/microwatt: Add mmu bits to device tree (Chris von Recklinghausen) [2120352]
- powerpc: Fix all occurences of "the the" (Chris von Recklinghausen) [2120352]
- powerpc/numa: Associate numa node to its cpu earlier (Chris von Recklinghausen) [2120352]
- arm64: mm: avoid writable executable mappings in kexec/hibernate code (Chris von Recklinghausen) [2120352]
- arm64: lds: move special code sections out of kernel exec segment (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Implement arm64 specific huge_ptep_get() (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Use ptep_get() to get the pte value of a huge page (Chris von Recklinghausen) [2120352]
- mm: change huge_ptep_clear_flush() to return the original pte (Chris von Recklinghausen) [2120352]
- mm: functions may simplify the use of return values (Chris von Recklinghausen) [2120352]
- x86/mm: Fix marking of unused sub-pmd ranges (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Drop TLB flush from get_clear_flush() (Chris von Recklinghausen) [2120352]
- powerpc: align address to page boundary in change_page_attr() (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Simplify flush_tlb_kernel_range() (Chris von Recklinghausen) [2120352]
- powerpc: Simplify and move arch_randomize_brk() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Convert to default topdown mmap layout (Chris von Recklinghausen) [2120352]
- powerpc/mm: Enable full randomisation of memory mappings (Chris von Recklinghausen) [2120352]
- powerpc/mm: Move get_unmapped_area functions to slice.c (Chris von Recklinghausen) [2120352]
- powerpc/mm: Use generic_hugetlb_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Use generic_get_unmapped_area() and call it from arch_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Remove CONFIG_PPC_MM_SLICES (Chris von Recklinghausen) [2120352]
- powerpc/mm: Make slice specific to book3s/64 (Chris von Recklinghausen) [2120352]
- powerpc/mm: Move vma_mmu_pagesize() (Chris von Recklinghausen) [2120352]
- mm: Add len and flags parameters to arch_get_mmap_end() (Chris von Recklinghausen) [2120352]
- mm, hugetlbfs: Allow an arch to always use generic versions of get_unmapped_area functions (Chris von Recklinghausen) [2120352]
- mm: Allow arch specific arch_randomize_brk() with CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT (Chris von Recklinghausen) [2120352]
- arm64: mm: Cleanup useless parameters in zone_sizes_init() (Chris von Recklinghausen) [2120352]
- arm64: fix types in copy_highpage() (Chris von Recklinghausen) [2120352]
- x86: Fix return value of __setup handlers (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix sparse report in mm/nohash/fsl_book3e.c (Chris von Recklinghausen) [2120352]
- powerpc/mm: Switch from __FUNCTION__ to __func__ (Chris von Recklinghausen) [2120352]
- mm: use for_each_online_node and node_online instead of open coding (Chris von Recklinghausen) [2120352]
- hugetlb: fix return value of __setup handlers (Chris von Recklinghausen) [2120352]
- hugetlb: fix hugepages_setup when deal with pernode (Chris von Recklinghausen) [2120352]
- hugetlb: fix wrong use of nr_online_nodes (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup CONFIG_HUGETLB_PAGE_FREE_VMEMMAP* (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup hugetlb_free_vmemmap_enabled* (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup hugetlb_vmemmap related functions (Chris von Recklinghausen) [2120352]
- x86/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- sparc/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- arm64/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- powerpc/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- mm/mmap: add new config ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- mm/mmap: clarify protection_map[] indices (Chris von Recklinghausen) [2120352]
- arm64: mm: hugetlb: enable HUGETLB_PAGE_FREE_VMEMMAP for arm64 (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: introduce ARCH_WANT_HUGETLB_PAGE_FREE_VMEMMAP (Chris von Recklinghausen) [2120352]
- mm, hugetlb: allow for "high" userspace addresses (Chris von Recklinghausen) [2120352]
- hugetlb: do not demote poisoned hugetlb pages (Chris von Recklinghausen) [2120352]
- x86/mm: Replace nodes_weight() with nodes_empty() where appropriate (Chris von Recklinghausen) [2120352]
- x86: Replace cpumask_weight() with cpumask_empty() where appropriate (Chris von Recklinghausen) [2120352]
- Revert "powerpc: Set max_mapnr correctly" (Chris von Recklinghausen) [2120352]
- powerpc: Fix virt_addr_valid() for 64-bit Book3E & 32-bit (Chris von Recklinghausen) [2120352]
- x86/fault: Cast an argument to the proper address space in prefetch() (Chris von Recklinghausen) [2120352]
- x86/mm/tlb: Revert retpoline avoidance approach (Chris von Recklinghausen) [2120352]
- arm64: fix typos in comments (Chris von Recklinghausen) [2120352]
- powerpc/numa: Handle partially initialized numa nodes (Chris von Recklinghausen) [2120352]
- mm: generalize ARCH_HAS_FILTER_PGPROT (Chris von Recklinghausen) [2120352]
- mm/migration: add trace events for THP migrations (Chris von Recklinghausen) [2120352]
- hugetlb: clean up potential spectre issue warnings (Chris von Recklinghausen) [2120352]
- mm: sparsemem: move vmemmap related to HugeTLB to CONFIG_HUGETLB_PAGE_FREE_VMEMMAP (Chris von Recklinghausen) [2120352]
- mm: sparsemem: use page table lock to protect kernel pmd operations (Chris von Recklinghausen) [2120352]
- mm: hugetlb: replace hugetlb_free_vmemmap_enabled with a static_key (Chris von Recklinghausen) [2120352]
- mm: hugetlb: free the 2nd vmemmap page associated with each HugeTLB page (Chris von Recklinghausen) [2120352]
- arch/x86/mm/numa: Do not initialize nodes twice (Chris von Recklinghausen) [2120352]
- mm: merge pte_mkhuge() call into arch_make_huge_pte() (Chris von Recklinghausen) [2120352]
- x86/boot: Add setup_indirect support in early_memremap_is_setup_data() (Chris von Recklinghausen) [2120352]
- x86/boot: Fix memremap of setup_indirect structures (Chris von Recklinghausen) [2120352]
- powerpc/64s: Don't use DSISR for SLB faults (Chris von Recklinghausen) [2120352]
- powerpc/64s: Fix build failure when CONFIG_PPC_64S_HASH_MMU is not set (Chris von Recklinghausen) [2120352]
- s390/mm: convert pte_val()/pXd_val() into functions (Chris von Recklinghausen) [2120352]
- s390/mm,gmap: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,hugetlb: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,pageattr: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,pgtable: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm: use set_pXd()/set_pte() helper functions everywhere (Chris von Recklinghausen) [2120352]
- s390/mm: add set_pte_bit()/clear_pte_bit() helper functions (Chris von Recklinghausen) [2120352]
- s390/mm: add set_pXd()/set_pte() helper functions (Chris von Recklinghausen) [2120352]
- s390/setup: preserve memory at OLDMEM_BASE and OLDMEM_SIZE (Chris von Recklinghausen) [2120352]
- powerpc/mm/numa: skip NUMA_NO_NODE onlining in parse_numa_properties() (Chris von Recklinghausen) [2120352]
- hugetlbfs: fix a truncation issue in hugepages parameter (Chris von Recklinghausen) [2120352]
- x86/pat: Remove the unused set_pages_array_wt() function (Chris von Recklinghausen) [2120352]
- powerpc/mm: Update default hugetlb size early (Chris von Recklinghausen) [2120352]
- powerpc/32s: Enable STRICT_MODULE_RWX for the 603 core (Chris von Recklinghausen) [2120352]
- powerpc: Add set_memory_{p/np}() and remove set_memory_attr() (Chris von Recklinghausen) [2120352]
- powerpc/set_memory: Avoid spinlock recursion in change_page_attr() (Chris von Recklinghausen) [2120352]
- s390/mm: use CRST_ALLOC_ORDER instead of number (Chris von Recklinghausen) [2120352]
- s390/maccess: fix semantics of memcpy_real() and its callers (Chris von Recklinghausen) [2120352]
- s390/dump: fix old lowcore virtual vs physical address confusion (Chris von Recklinghausen) [2120352]
- s390/maccess: fix absolute lowcore virtual vs physical address confusion (Chris von Recklinghausen) [2120352]
- s390: remove invalid email address of Heiko Carstens (Chris von Recklinghausen) [2120352]
- mm/page_table_check: check entries at pmd levels (Chris von Recklinghausen) [2120352]
- mm/khugepaged: unify collapse pmd clear, flush and free (Chris von Recklinghausen) [2120352]
- powerpc/kasan: Fix early region not updated correctly (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix sparse warning in hashpagetable.c (Chris von Recklinghausen) [2120352]
- ia64: make IA64_MCA_RECOVERY bool instead of tristate (Chris von Recklinghausen) [2120352]
- docs/vm: Fix typo in *harden* (Chris von Recklinghausen) [2120352]
- powerpc/fixmap: Fix VM debug warning on unmap (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix kasan_init_region() for KASAN (Chris von Recklinghausen) [2120352]
- mm/thp: drop unused trace events hugepage_[invalidate|splitting] (Chris von Recklinghausen) [2120352]
- x86: mm: add x86_64 support for page table check (Chris von Recklinghausen) [2120352]
- mm: page table check (Chris von Recklinghausen) [2120352]
- mm: ptep_clear() page table helper (Chris von Recklinghausen) [2120352]
- mm: change page type prior to adding page table entry (Chris von Recklinghausen) [2120352]
- mm: remove redundant check about FAULT_FLAG_ALLOW_RETRY bit (Chris von Recklinghausen) [2120352]
- powerpc/mm: Add __init attribute to eligible functions (Chris von Recklinghausen) [2120352]
- x86/mm: Prevent early boot triple-faults with instrumentation (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix DEBUG_WX since generic ptdump conversion (Chris von Recklinghausen) [2120352]
- s390/crash_dump: fix virtual vs physical address handling (Chris von Recklinghausen) [2120352]
- powerpc/64s/radix: Fix huge vmap false positive (Chris von Recklinghausen) [2120352]
- s390/sclp: release SCLP early buffer after kernel initialization (Chris von Recklinghausen) [2120352]
- hugetlbfs: fix issue of preallocation of gigantic pages can't work (Chris von Recklinghausen) [2120352]
- s390/pgalloc: use pointers instead of unsigned long values (Chris von Recklinghausen) [2120352]
- s390/pgalloc: add virt/phys address handling to base asce functions (Chris von Recklinghausen) [2120352]
- s390/cmm: add missing virt_to_phys() conversion (Chris von Recklinghausen) [2120352]
- s390/diag: use pfn_to_phys() instead of open coding (Chris von Recklinghausen) [2120352]
- s390/mm: add missing phys_to_virt translation to page table dumper (Chris von Recklinghausen) [2120352]
- powerpc/32s: Allocate one 256k IBAT instead of two consecutives 128k IBATs (Chris von Recklinghausen) [2120352]
- powerpc: Remove CONFIG_PPC_HAVE_KUAP and CONFIG_PPC_HAVE_KUEP (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on book3e/64 (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 85xx in 32 bits mode. (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 40x (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 44x (Chris von Recklinghausen) [2120352]
- powerpc: Add KUAP support for BOOKE and 40x (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Make PPC_KUAP_DEBUG depend on PPC_KUAP only (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Prepare for supporting KUAP on BOOK3E/64 (Chris von Recklinghausen) [2120352]
- powerpc/config: Add CONFIG_BOOKE_OR_40x (Chris von Recklinghausen) [2120352]
- powerpc/nohash: Move setup_kuap out of 8xx.c (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Add kuap_lock() (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Remove __kuap_assert_locked() (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Check KUAP activation in generic functions (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Add a generic intermediate layer (Chris von Recklinghausen) [2120352]
- powerpc/kuep: Remove 'nosmep' boot time parameter except for book3s/64 (Chris von Recklinghausen) [2120352]
- powerpc/32s: Save content of sr0 to avoid 'mfsr' (Chris von Recklinghausen) [2120352]
- powerpc/32s: Do kuep_lock() and kuep_unlock() in assembly (Chris von Recklinghausen) [2120352]
- powerpc/32s: Remove capability to disable KUEP at boottime (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- powerpc/44x: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- Revert "powerpc: Inline setup_kup()" (Chris von Recklinghausen) [2120352]
- powerpc/microwatt: add POWER9_CPU, clear PPC_64S_HASH_MMU (Chris von Recklinghausen) [2120352]
- powerpc/64s: Move hash MMU support code under CONFIG_PPC_64S_HASH_MMU (Chris von Recklinghausen) [2120352]
- powerpc/64s: Make hash MMU support configurable (Chris von Recklinghausen) [2120352]
- powerpc/64s: Always define arch unmapped area calls (Chris von Recklinghausen) [2120352]
- powerpc/64s: Fix radix MMU when MMU_FTR_HPTE_TABLE is clear (Chris von Recklinghausen) [2120352]
- powerpc/64e: remove mmu_linear_psize (Chris von Recklinghausen) [2120352]
- x86/mm/64: Flush global TLB on boot and AP bringup (Chris von Recklinghausen) [2120352]
- x86/realmode: Add comment for Global bit usage in trampoline_pgd (Chris von Recklinghausen) [2120352]
- powerpc: make memremap_compat_align 64s-only (Chris von Recklinghausen) [2120352]
- powerpc/64: pcpu setup avoid reading mmu_linear_psize on 64e or radix (Chris von Recklinghausen) [2120352]
- powerpc/64s: Rename hash_hugetlbpage.c to hugetlbpage.c (Chris von Recklinghausen) [2120352]
- powerpc/64s: move page size definitions from hash specific file (Chris von Recklinghausen) [2120352]
- powerpc/64s: Make flush_and_reload_slb a no-op when radix is enabled (Chris von Recklinghausen) [2120352]
- powerpc/64s: move THP trace point creation out of hash specific file (Chris von Recklinghausen) [2120352]
- powerpc/pseries: lparcfg don't include slb_size line in radix mode (Chris von Recklinghausen) [2120352]
- powerpc/pseries: move process table registration away from hash-specific code (Chris von Recklinghausen) [2120352]
- powerpc/64s: Move and rename do_bad_slb_fault as it is not hash specific (Chris von Recklinghausen) [2120352]
- powerpc/pseries: Stop selecting PPC_HASH_MMU_NATIVE (Chris von Recklinghausen) [2120352]
- powerpc: Rename PPC_NATIVE to PPC_HASH_MMU_NATIVE (Chris von Recklinghausen) [2120352]
- powerpc: Remove unused FW_FEATURE_NATIVE references (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix shift-out-of-bounds in KASAN init (Chris von Recklinghausen) [2120352]
- powerpc/64s: Get LPID bit width from device tree (Chris von Recklinghausen) [2120352]
- powerpc: flexible GPR range save/restore macros (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix display a BAT's size unit (Chris von Recklinghausen) [2120352]
- Revert "powerpc/code-patching: Improve verification of patchability" (Chris von Recklinghausen) [2120352]
- powerpc/code-patching: Improve verification of patchability (Chris von Recklinghausen) [2120352]
- s390/dump: fix copying to user-space of swapped kdump oldmem (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix TLBCAM preset at boot (Chris von Recklinghausen) [2120352]
- powerpc/pseries: Fix numa FORM2 parsing fallback code (Chris von Recklinghausen) [2120352]
- powerpc/pseries: rename numa_dist_table to form2_distances (Chris von Recklinghausen) [2120352]
- kasan: add kasan mode messages when kasan init (Chris von Recklinghausen) [2120352]
- arm64/bpf: Remove 128MB limit for BPF JIT programs (Chris von Recklinghausen) [2120352]
- hugetlbfs: extend the definition of hugepages parameter to support node allocation (Chris von Recklinghausen) [2120352]
- memblock: stop aliasing __memblock_free_late with memblock_free_late (Chris von Recklinghausen) [2120352]
- hugetlb: support node specified when using cma for gigantic hugepages (Chris von Recklinghausen) [2120352]
- hugetlb: add hugetlb demote page support (Chris von Recklinghausen) [2120352]
- hugetlb: add demote bool to gigantic page routines (Chris von Recklinghausen) [2120352]
- hugetlb: be sure to free demoted CMA pages to CMA (Chris von Recklinghausen) [2120352]
- mm/cma: add cma_pages_valid to determine if pages are in CMA (Chris von Recklinghausen) [2120352]
- hugetlb: add demote hugetlb page sysfs interfaces (Chris von Recklinghausen) [2120352]
- s390: use generic version of arch_is_kernel_initmem_freed() (Chris von Recklinghausen) [2120352]
- powerpc: use generic version of arch_is_kernel_initmem_freed() (Chris von Recklinghausen) [2120352]
- mm: remove redundant smp_wmb() (Chris von Recklinghausen) [2120352]
- mm: introduce pmd_install() helper (Chris von Recklinghausen) [2120352]
- powerpc: Don't provide __kernel_map_pages() without ARCH_SUPPORTS_DEBUG_PAGEALLOC (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Fix setting of exec flag when setting TLBCAMs (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix set_memory_x() and set_memory_nx() (Chris von Recklinghausen) [2120352]
- powerpc/nohash: Fix __ptep_set_access_flags() and ptep_set_wrprotect() (Chris von Recklinghausen) [2120352]
- powerpc/64s: Default to 64K pages for 64 bit book3s (Chris von Recklinghausen) [2120352]
- s390: make command line configurable (Chris von Recklinghausen) [2120352]
- s390: support command lines longer than 896 bytes (Chris von Recklinghausen) [2120352]
- s390/kexec_file: move kernel image size check (Chris von Recklinghausen) [2120352]
- s390/setup: use physical pointers for memblock_reserve() (Chris von Recklinghausen) [2120352]
- s390/pgtable: use physical address for Page-Table Origin (Chris von Recklinghausen) [2120352]
- s390/mm: optimize reset_guest_reference_bit() (Chris von Recklinghausen) [2120352]
- s390/mm: optimize set_guest_storage_key() (Chris von Recklinghausen) [2120352]
- s390/mm: no need for pte_alloc_map_lock() if we know the pmd is present (Chris von Recklinghausen) [2120352]
- s390/mm: fix VMA and page table handling code in storage key handling functions (Chris von Recklinghausen) [2120352]
- s390/mm: validate VMA in PGSTE manipulation functions (Chris von Recklinghausen) [2120352]
- powerpc/32: Don't use a struct based type for pte_t (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Simplify TLB handling (Chris von Recklinghausen) [2120352]
- powerpc/32: Don't use lmw/stmw for saving/restoring non volatile regs (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Enable STRICT_KERNEL_RWX (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Update of TLBCAMs after init (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Allocate separate TLBCAMs for readonly memory (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Tell map_mem_in_cams() if init is done (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Enable reloading of TLBCAM without switching to AS1 (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Take exec flag into account when setting TLBCAMs (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Rename fsl_booke.c to fsl_book3e.c (Chris von Recklinghausen) [2120352]
- powerpc/booke: Disable STRICT_KERNEL_RWX, DEBUG_PAGEALLOC and KFENCE (Chris von Recklinghausen) [2120352]
- powerpc/s64: Clarify that radix lacks DEBUG_PAGEALLOC (Chris von Recklinghausen) [2120352]
- signal/sparc32: Remove unreachable do_exit in do_sparc_fault (Chris von Recklinghausen) [2120352]
- reboot: Remove the unreachable panic after do_exit in reboot(2) (Chris von Recklinghausen) [2120352]
- exit: Remove calls of do_exit after noreturn versions of die (Chris von Recklinghausen) [2120352]
- exit/doublefault: Remove apparently bogus comment about rewind_stack_do_exit (Chris von Recklinghausen) [2120352]
- powerpc: Set max_mapnr correctly (Chris von Recklinghausen) [2120352]
- s390/cmm: use string_upper() instead of open coded variant (Chris von Recklinghausen) [2120352]
- powerpc/mem: Fix arch/powerpc/mm/mem.c:53:12: error: no previous prototype for 'create_section_mapping' (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix kuap_kernel_restore() (Chris von Recklinghausen) [2120352]
- s390/boot: allocate amode31 section in decompressor (Chris von Recklinghausen) [2120352]
- s390/boot: initialize control registers in decompressor (Chris von Recklinghausen) [2120352]
- x86/mm/64: Improve stack overflow warnings (Chris von Recklinghausen) [2120352]
- x86/fault: Fix wrong signal when vsyscall fails with pkey (Chris von Recklinghausen) [2120352]
- x86/mm: Fix kern_addr_valid() to cope with existing but not present entries (Chris von Recklinghausen) [2120352]
- x86/pat: Pass valid address to sanitize_phys() (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix generic ptdump for 64-bit (Chris von Recklinghausen) [2120352]
- powerpc/numa: Update cpu_cpu_map on CPU online/offline (Chris von Recklinghausen) [2120352]
- powerpc/numa: Print debug statements only when required (Chris von Recklinghausen) [2120352]
- powerpc/numa: convert printk to pr_xxx (Chris von Recklinghausen) [2120352]
- powerpc/numa: Drop dbg in favour of pr_debug (Chris von Recklinghausen) [2120352]
- powerpc/smp: Enable CACHE domain for shared processor (Chris von Recklinghausen) [2120352]
- powerpc/smp: Fix a crash while booting kvm guest with nr_cpus=2 (Chris von Recklinghausen) [2120352]
- powerpc: Refactor verification of MSR_RI (Chris von Recklinghausen) [2120352]
- powerpc: Remove MSR_PR check in interrupt_exit_{user/kernel}_prepare() (Chris von Recklinghausen) [2120352]
- s390/mm,pageattr: fix walk_pte_level() early exit (Chris von Recklinghausen) [2120352]
- s390: fix typo in linker script (Chris von Recklinghausen) [2120352]
- s390/boot: factor out offset_vmlinux_info() function (Chris von Recklinghausen) [2120352]
- s390/kasan: fix large PMD pages address alignment check (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Convert powerpc to GENERIC_PTDUMP (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Reduce level numbers by 1 in note_page() and add p4d level (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Remove unused 'page_size' parameter (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Use DEFINE_SHOW_ATTRIBUTE() (Chris von Recklinghausen) [2120352]
- powerpc: Avoid link stack corruption in misc asm functions (Chris von Recklinghausen) [2120352]
- powerpc/booke: Avoid link stack corruption in several places (Chris von Recklinghausen) [2120352]
- s390/sclp: reserve memory occupied by sclp early buffer (Chris von Recklinghausen) [2120352]
- s390/mm: remove unused cmma functions (Chris von Recklinghausen) [2120352]
- powerpc: rename powerpc_debugfs_root to arch_debugfs_dir (Chris von Recklinghausen) [2120352]
- powerpc/book3s64/radix: make tlb_single_page_flush_ceiling a debugfs entry (Chris von Recklinghausen) [2120352]
- s390: rename dma section to amode31 (Chris von Recklinghausen) [2120352]
- s390/mm: use page_to_virt() in __kernel_map_pages() (Chris von Recklinghausen) [2120352]
- s390: add kfence region to pagetable dumper (Chris von Recklinghausen) [2120352]
- s390: add support for KFENCE (Chris von Recklinghausen) [2120352]
- s390/mm: implement set_memory_4k() (Chris von Recklinghausen) [2120352]
- s390/boot: get rid of arithmetics on function pointers (Chris von Recklinghausen) [2120352]
- s390/setup: don't reserve memory that occupied decompressor's head (Chris von Recklinghausen) [2120352]
- s390/boot: move dma sections from decompressor to decompressed kernel (Chris von Recklinghausen) [2120352]
- s390/ctl_reg: add ctlreg5 and ctlreg15 unions (Chris von Recklinghausen) [2120352]
- s390/boot: make _diag308_reset_dma() position-independent (Chris von Recklinghausen) [2120352]
- s390/boot: move EP_OFFSET and EP_STRING to head.S (Chris von Recklinghausen) [2120352]
- s390/setup: generate asm offsets from struct parmarea (Chris von Recklinghausen) [2120352]
- s390/setup: drop _OFFSET macros (Chris von Recklinghausen) [2120352]
- s390/setup: remove unused symbolic constants for C code from setup.h (Chris von Recklinghausen) [2120352]
- s390/dump: introduce boot data 'oldmem_data' (Chris von Recklinghausen) [2120352]
- s390/boot: introduce boot data 'initrd_data' (Chris von Recklinghausen) [2120352]
- s390/boot: move sclp early buffer from fixed address in asm to C (Chris von Recklinghausen) [2120352]
- s390/boot: get rid of magic numbers for startup offsets (Chris von Recklinghausen) [2120352]
- s390/mm: don't print hashed values for pte_ERROR() & friends (Chris von Recklinghausen) [2120352]
- s390/mm: use pr_err() instead of printk() for pte_ERROR & friends (Chris von Recklinghausen) [2120352]
- s390/sclp: use only one sclp early buffer to send commands (Chris von Recklinghausen) [2120352]
- s390/boot: make stacks part of the decompressor's image (Chris von Recklinghausen) [2120352]
- powerpc/kexec: blacklist functions called in real mode for kprobe (Chris von Recklinghausen) [2120352]
- Revert "s390/mm: do not trigger write fault when vma does not allow VM_WRITE" (Chris von Recklinghausen) [2120352]
- Revert "s390/boot: move sclp early buffer from fixed address in asm to C" (Chris von Recklinghausen) [2120352]
- Revert "s390/kexec_file: move kernel image size check" (Chris von Recklinghausen) [2120352]
- Revert "s390: support command lines longer than 896 bytes" (Rafael Aquini) [2120352]
- Revert "s390: make command line configurable" (Chris von Recklinghausen) [2120352]
- Revert "s390/sclp: reserve memory occupied by sclp early buffer" (Chris von Recklinghausen) [2120352]
- Revert "rhel: configs: add config option CONFIG_COMMAND_LINE_SIZE" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: consolidate mapcount logic on THP split" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: make the THP mapcount atomic with a seqlock" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: introduce page_trans_huge_anon_shared" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: COR: copy-on-read fault" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: gup_must_unshare()" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_UNSHARE" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_NOUNSHARE: optimize follow_page" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_UNSHARE RHEL" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: COR: copy-on-read fault" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: FOLL_FAULT_UNSHARE" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: gup_must_unshare() use can_read_pin_swap_page()" (Chris von Recklinghausen) [2120352]
- Revert "mm: COW: skip the page lock in the COW copy path" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: replace the page lock with the seqlock for the THP mapcount" (Chris von Recklinghausen) [2120352]
- Revert "mm: COW: restore full accuracy in page reuse" (Chris von Recklinghausen) [2120352]
- selftest/vm: uninitialized variable in main() (Chris von Recklinghausen) [2120352]
- selftest/vm: add skip support to mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: support xfail in mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: verify remap destination address in mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: verify mmap addr in mremap_test (Chris von Recklinghausen) [2120352]
- selftests/vm: cleanup hugetlb file after mremap test (Chris von Recklinghausen) [2120352]
- mm, hugepages: make memory size variable in hugepage-mremap selftest (Chris von Recklinghausen) [2120352]
- mm: remove duplicate include in hugepage-mremap.c (Chris von Recklinghausen) [2120352]
- mm, hugepages: add hugetlb vma mremap() test (Chris von Recklinghausen) [2120352]

* Fri Oct 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-178.el9]
- s390/dasd: Establish DMA alignment (Ming Lei) [2118511]
- md/raid10: Fix the data type of an r10_sync_page_io() argument (Ming Lei) [2118511]
- blk-lib: fix blkdev_issue_secure_erase (Ming Lei) [2118511]
- block: blk_queue_enter() / __bio_queue_enter() must return -EAGAIN for nowait (Ming Lei) [2118511]
- block: add missing request flags to debugfs code (Ming Lei) [2118511]
- block: don't add partitions if GD_SUPPRESS_PART_SCAN is set (Ming Lei) [2118511]
- loop: Check for overflow while configuring loop (Ming Lei) [2118511]
- blk-mq: fix io hung due to missing commit_rqs (Ming Lei) [2118511]
- blk-mq: run queue no matter whether the request is the last request (Ming Lei) [2118511]
- blk-mq: remove unused function blk_mq_queue_stopped() (Ming Lei) [2118511]
- block: Do not call blk_put_queue() if gendisk allocation fails (Ming Lei) [2118511]
- block: fix leaking page ref on truncated direct io (Ming Lei) [2118511]
- block: ensure bio_iov_add_page can't fail (Ming Lei) [2118511]
- block: ensure iov_iter advances for added pages (Ming Lei) [2118511]
- block: pass struct queue_limits to the bio splitting helpers (Ming Lei) [2118511]
- block: move bio_allowed_max_sectors to blk-merge.c (Ming Lei) [2118511]
- block: move the call to get_max_io_size out of blk_bio_segment_split (Ming Lei) [2118511]
- block: move ->bio_split to the gendisk (Ming Lei) [2118511]
- block: change the blk_queue_bounce calling convention (Ming Lei) [2118511]
- block: change the blk_queue_split calling convention (Ming Lei) [2118511]
- remove the sx8 block driver (Ming Lei) [2118511]
- nbd: add missing definition of pr_fmt (Ming Lei) [2118511]
- null_blk: fix ida error handling in null_add_dev() (Ming Lei) [2118511]
- null_blk: add configfs variables for 2 options (Ming Lei) [2118511]
- null_blk: add module parameters for 4 options (Ming Lei) [2118511]
- block/rnbd-srv: Replace sess_dev_list with index_idr (Ming Lei) [2118511]
- block/rnbd-srv: Set keep_id to true after mutex_trylock (Ming Lei) [2118511]
- rnbd-clt: make rnbd_clt_change_capacity return void (Ming Lei) [2118511]
- rnbd-clt: pass sector_t type for resize capacity (Ming Lei) [2118511]
- rnbd-clt: check capacity inside rnbd_clt_change_capacity (Ming Lei) [2118511]
- rnbd-clt: adjust the layout of struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: reduce the size of struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: kill read_only from struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: don't free rsp in msg_open_conf for map scenario (Ming Lei) [2118511]
- rnbd-clt: open code send_msg_open in rnbd_clt_map_device (Ming Lei) [2118511]
- block: null_blk: Use the bitmap API to allocate bitmaps (Ming Lei) [2118511]
- drbd: bm_page_async_io: fix spurious bitmap "IO error" on large volumes (Ming Lei) [2118511]
- block: remove __blk_get_queue (Ming Lei) [2118511]
- block: call blk_mq_exit_queue from disk_release for never added disks (Ming Lei) [2118511]
- blk-mq: fix error handling in __blk_mq_alloc_disk (Ming Lei) [2118511]
- block: don't allow the same type rq_qos add more than once (Ming Lei) [2118511]
- mmc: fix disk/queue leak in case of adding disk failure (Ming Lei) [2118511]
- blktrace: Fix the blk_fill_rwbs() kernel-doc header (Ming Lei) [2118511]
- fs/buffer: Fix the ll_rw_block() kernel-doc header (Ming Lei) [2118511]
- fs/zonefs: Use the enum req_op type for tracing request operations (Ming Lei) [2118511]
- fs/xfs: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- PM: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/ocfs2: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/nfs: Use enum req_op where appropriate (Ming Lei) [2118511]
- fs/jbd2: Fix the documentation of the jbd2_write_superblock() callers (Ming Lei) [2118511]
- fs/hfsplus: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/gfs2: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/ext4: Use the new blk_opf_t type (Ming Lei) [2118511]
- fs/mpage: Use the new blk_opf_t type (Ming Lei) [2118511]
- fs/direct-io: Reduce the size of struct dio (Ming Lei) [2118511]
- fs/buffer: Combine two submit_bh() and ll_rw_block() arguments (Ming Lei) [2118511]
- fs/buffer: Use the new blk_opf_t type (Ming Lei) [2118511]
- mm: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/target: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/device_handlers: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/core: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/core: Change the return type of scsi_noretry_cmd() into bool (Ming Lei) [2118511]
- scsi/core: Improve static type checking (Ming Lei) [2118511]
- nvme/target: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/raid5: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- md/raid10: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/raid1: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/bcache: Combine two prio_io() arguments (Ming Lei) [2118511]
- md/bcache: Combine two uuid_io() arguments (Ming Lei) [2118511]
- md/core: Combine two sync_page_io() arguments (Ming Lei) [2118511]
- dm/dm-zoned: Use the enum req_op type (Ming Lei) [2118511]
- dm/zone: Use the enum req_op type (Ming Lei) [2118511]
- dm-snap: Combine request operation type and flags (Ming Lei) [2118511]
- dm mirror log: Use the new blk_opf_t type (Ming Lei) [2118511]
- dm/dm-integrity: Combine request operation and flags (Ming Lei) [2118511]
- dm/dm-flakey: Use the new blk_opf_t type (Ming Lei) [2118511]
- dm/ebs: Change 'int rw' into 'enum req_op op' (Ming Lei) [2118511]
- dm/core: Combine request operation type and flags (Ming Lei) [2118511]
- dm/core: Rename kcopyd_job.rw into kcopyd.op (Ming Lei) [2118511]
- dm/core: Reduce the size of struct dm_io_request (Ming Lei) [2118511]
- um: Use enum req_op where appropriate (Ming Lei) [2118511]
- nvdimm-btt: Use the enum req_op type (Ming Lei) [2118511]
- block/zram: Use enum req_op where appropriate (Ming Lei) [2118511]
- xen-blkback: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- block/rnbd: Use blk_opf_t where appropriate (Ming Lei) [2118511]
- block/floppy: Fix a sparse warning (Ming Lei) [2118511]
- block/drbd: Combine two drbd_submit_peer_request() arguments (Ming Lei) [2118511]
- block/drbd: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- block/brd: Use the enum req_op type (Ming Lei) [2118511]
- blktrace: Use the new blk_opf_t type (Ming Lei) [2118511]
- blktrace: Trace remapped requests correctly (Ming Lei) [2118511]
- block/kyber: Use the new blk_opf_t type (Ming Lei) [2118511]
- block/mq-deadline: Use the new blk_opf_t type (Ming Lei) [2118511]
- block/bfq: Use the new blk_opf_t type (Ming Lei) [2118511]
- block: Use the new blk_opf_t type (Ming Lei) [2118511]
- block: Introduce the type blk_opf_t (Ming Lei) [2118511]
- block: Change the type of req_op() and bio_op() into enum req_op (Ming Lei) [2118511]
- block: Change the type of the last .rw_page() argument (Ming Lei) [2118511]
- block: Use enum req_op where appropriate (Ming Lei) [2118511]
- treewide: Rename enum req_opf into enum req_op (Ming Lei) [2118511]
- block: remove bdevname (Ming Lei) [2118511]
- ext4: only initialize mmp_bdevname once (Ming Lei) [2118511]
- ocfs2/cluster: remove the hr_dev_name field from struct o2hb_region (Ming Lei) [2118511]
- rnbd-srv: remove the name field from struct rnbd_dev (Ming Lei) [2118511]
- pktcdvd: stop using bdevname in pkt_new_dev (Ming Lei) [2118511]
- pktcdvd: stop using bdevname in pkt_seq_show (Ming Lei) [2118511]
- drbd: stop using bdevname in drbd_report_io_error (Ming Lei) [2118511]
- block: stop using bdevname in __blkdev_issue_discard (Ming Lei) [2118511]
- block: stop using bdevname in bdev_write_inode (Ming Lei) [2118511]
- blk-cgroup: Use atomic{,64}_try_cmpxchg (Ming Lei) [2118511]
- blk-iolatency: Use atomic{,64}_try_cmpxchg (Ming Lei) [2118511]
- block: Use try_cmpxchg in update_io_ticks (Ming Lei) [2118511]
- block/rq_qos: Use atomic_try_cmpxchg in atomic_inc_below (Ming Lei) [2118511]
- block: move zone related fields to struct gendisk (Ming Lei) [2118511]
- block: remove blk_queue_zone_sectors (Ming Lei) [2118511]
- dm-zoned: cleanup dmz_fixup_devices (Ming Lei) [2118511]
- nvmet:: use bdev based helpers in nvmet_bdev_zone_mgmt_emulate_all (Ming Lei) [2118511]
- block: use bdev based helpers in blkdev_zone_mgmt{,all} (Ming Lei) [2118511]
- block: replace blkdev_nr_zones with bdev_nr_zones (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_max_open_zones and blk_queue_max_active_zones (Ming Lei) [2118511]
- block: remove queue_max_open_zones and queue_max_active_zones (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_free_zone_bitmaps (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_clear_zone_settings (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_set_zoned (Ming Lei) [2118511]
- block: simplify blk_check_zone_append (Ming Lei) [2118511]
- block: simplify blk_mq_plug (Ming Lei) [2118511]
- block: use bdev_is_zoned instead of open coding it (Ming Lei) [2118511]
- block: call blk_queue_free_zone_bitmaps from disk_release (Ming Lei) [2118511]
- block: remove a superflous ifdef in blkdev.h (Ming Lei) [2118511]
- blk-mq: Drop local variable for reserved tag (Ming Lei) [2118511]
- blk-mq: Drop 'reserved' arg of busy_tag_iter_fn (Ming Lei) [2118511]
- scsi: fnic: Drop reserved request handling (Ming Lei) [2118511]
- blk-mq: Drop blk_mq_ops.timeout 'reserved' arg (Ming Lei) [2118511]
- blk-mq: Add a flag for reserved requests (Ming Lei) [2118511]
- scsi: core: Remove reserved request time-out handling (Ming Lei) [2118511]
- blk-cgroup: factor out blkcg_free_all_cpd() (Ming Lei) [2118511]
- blk-cgroup: factor out blkcg_iostat_update() (Ming Lei) [2118511]
- block: simplify disk_set_independent_access_ranges (Ming Lei) [2118511]
- block: move ->ia_ranges from the request_queue to the gendisk (Ming Lei) [2118511]
- block: remove "select BLK_RQ_IO_DATA_LEN" from BLK_CGROUP_IOCOST dependency (Ming Lei) [2118511]
- blk-mq: cleanup disk sysfs registration (Ming Lei) [2118511]
- blk-mq: rename blk_mq_sysfs_{,un}register (Ming Lei) [2118511]
- block: remove the extra gendisk reference in __blk_mq_register_dev (Ming Lei) [2118511]
- block: use default groups to register the queue attributes (Ming Lei) [2118511]
- block: remove a superflous queue kobject reference (Ming Lei) [2118511]
- block: simplify blktrace sysfs attribute creation (Ming Lei) [2118511]
- block: remove blk_cleanup_disk (Ming Lei) [2118511]
- block: simplify disk shutdown (Ming Lei) [2118511]
- block: stop setting the nomerges flags in blk_cleanup_queue (Ming Lei) [2118511]
- block: remove QUEUE_FLAG_DEAD (Ming Lei) [2118511]
- mtip32xx: fix device removal (Ming Lei) [2118511]
- mtip32xx: remove the device_status debugfs file (Ming Lei) [2118511]
- blk-mq: blk_mq_tag_busy is no need to return a value (Ming Lei) [2118511]
- block: Always initialize bio IO priority on submit (Ming Lei) [2118511]
- block: Initialize bio priority earlier (Ming Lei) [2118511]
- blk-ioprio: Convert from rqos policy to direct call (Ming Lei) [2118511]
- blk-ioprio: Remove unneeded field (Ming Lei) [2118511]
- block: Fix handling of tasks without ioprio in ioprio_get(2) (Ming Lei) [2118511]
- block: Make ioprio_best() static (Ming Lei) [2118511]
- block: Generalize get_current_ioprio() for any task (Ming Lei) [2118511]
- block: Return effective IO priority from get_current_ioprio() (Ming Lei) [2118511]
- block: fix default IO priority handling again (Ming Lei) [2118511]
- blk-mq: Don't disable preemption around __blk_mq_run_hw_queue(). (Ming Lei) [2118511]
- block: bfq: Fix kernel-doc headers (Ming Lei) [2118511]
- block: bfq: Remove an unused function definition (Ming Lei) [2118511]
- bfq: Remove useless code in bfq_lookup_next_entity (Ming Lei) [2118511]
- block: move blk_queue_get_max_sectors to blk.h (Ming Lei) [2118511]
- block: fold blk_max_size_offset into get_max_io_size (Ming Lei) [2118511]
- block: cleanup variable naming in get_max_io_size (Ming Lei) [2118511]
- block: open code blk_max_size_offset in blk_rq_get_max_sectors (Ming Lei) [2118511]
- dm: open code blk_max_size_offset in max_io_len (Ming Lei) [2118511]
- block: factor out a chunk_size_left helper (Ming Lei) [2118511]
- block: Make blk_mq_get_sq_hctx() select the proper hardware queue type (Ming Lei) [2118511]
- block: Rename a blk_mq_map_queue() argument (Ming Lei) [2118511]
- blk-iocost: Simplify ioc_rqos_done() (Ming Lei) [2118511]
- block: Directly use ida_alloc()/free() (Ming Lei) [2118511]
- iomap: add support for dma aligned direct-io (Ming Lei) [2118511]
- block: relax direct io memory alignment (Ming Lei) [2118511]
- block: introduce bdev_iter_is_aligned helper (Ming Lei) [2118511]
- iov: introduce iov_iter_aligned (Ming Lei) [2118511]
- block/bounce: count bytes instead of sectors (Ming Lei) [2118511]
- block/merge: count bytes instead of sectors (Ming Lei) [2118511]
- block: add a helper function for dio alignment (Ming Lei) [2118511]
- block: introduce bdev_dma_alignment helper (Ming Lei) [2118511]
- block: export dma_alignment attribute (Ming Lei) [2118511]
- block/bio: remove duplicate append pages code (Ming Lei) [2118511]
- block: fix infinite loop for invalid zone append (Ming Lei) [2118511]
- block: fix missing blkcg_bio_issue_init (Ming Lei) [2118511]
- lib/sbitmap: Fix invalid loop in __sbitmap_queue_get_batch() (Ming Lei) [2118511]
- btrfs: simplify ->flush_bio handling (Ming Lei) [2118511]
- cdrom: remove obsolete TODO list (Ming Lei) [2118511]
- block: remove last remaining traces of IDE documentation (Ming Lei) [2118511]
- cdrom: mark CDROMGETSPINDOWN/CDROMSETSPINDOWN obsolete (Ming Lei) [2118511]
- cdrom: remove the unused driver specific disc change ioctl (Ming Lei) [2118511]
- cdrom: make EXPORT_SYMBOL follow exported function (Ming Lei) [2118511]
- fs-writeback: writeback_sb_inodes：Recalculate 'wrote' according skipped pages (Ming Lei) [2118511]
- fs: remove fs.f_write_hint (Ming Lei) [2118511]
- fs: remove kiocb.ki_hint (Ming Lei) [2118511]
- block: remove the per-bio/request write hint (Ming Lei) [2118511]
- nvme: remove support or stream based temperature hint (Ming Lei) [2118511]
- btrfs: check-integrity: stop storing the block device name in btrfsic_dev_state (Ming Lei) [2118511]
- loadpin: stop using bdevname (Ming Lei) [2118511]
- dax: remove bdev_dax_supported (Ming Lei) [2118511]
- dax: stub out dax_supported for !CONFIG_FS_DAX (Ming Lei) [2118511]
- dax: remove __generic_fsdax_supported (Ming Lei) [2118511]
- dax: move the dax_read_lock() locking into dax_supported (Ming Lei) [2118511]
- dax: mark dax_get_by_host static (Ming Lei) [2118511]
- dm: use fs_dax_get_by_bdev instead of dax_get_by_host (Ming Lei) [2118511]
- fsdax: improve the FS_DAX Kconfig description and help text (Ming Lei) [2118511]
- io_uring: apply worker limits to previous users (Jeff Moyer) [2107656]
- io_uring: fix ltimeout unprep (Jeff Moyer) [2107656]
- io_uring: apply max_workers limit to all future users (Jeff Moyer) [2107656]
- io_uring: utilize the io batching infrastructure for more efficient polled IO (Jeff Moyer) [2107656]
- io_uring: fix wrong condition to grab uring lock (Jeff Moyer) [2107656]
- io_uring: kill fasync (Jeff Moyer) [2107656]
- io-wq: exclusively gate signal based exit on get_signal() return (Jeff Moyer) [2107656]
- io_uring: make OP_CLOSE consistent with direct open (Jeff Moyer) [2107656]
- io_uring: kill extra checks in io_write() (Jeff Moyer) [2107656]
- io_uring: don't punt files update to io-wq unconditionally (Jeff Moyer) [2107656]
- io_uring: put provided buffer meta data under memcg accounting (Jeff Moyer) [2107656]
- io_uring: allow conditional reschedule for intensive iterators (Jeff Moyer) [2107656]
- io_uring: fix potential req refcount underflow (Jeff Moyer) [2107656]
- io_uring: fix missing set of EPOLLONESHOT for CQ ring overflow (Jeff Moyer) [2107656]
- io_uring: fix race between poll completion and cancel_hash insertion (Jeff Moyer) [2107656]
- io-wq: ensure we exit if thread group is exiting (Jeff Moyer) [2107656]
- io_uring: convert io_uring to the secure anon inode interface (Jeff Moyer) [2107656]
- fs: add anon_inode_getfile_secure() similar to anon_inode_getfd_secure() (Jeff Moyer) [2107656]
- io_uring: move iopoll reissue into regular IO path (Jeff Moyer) [2107656]
- Revert "iov_iter: track truncated size" (Jeff Moyer) [2107656]
- io_uring: use iov_iter state save/restore helpers (Jeff Moyer) [2107656]
- iov_iter: add helper to save iov_iter state (Jeff Moyer) [2107656]
- io_uring: allow retry for O_NONBLOCK if async is supported (Jeff Moyer) [2107656]
- io_uring: auto-removal for direct open/accept (Jeff Moyer) [2107656]
- io_uring: fix missing sigmask restore in io_cqring_wait() (Jeff Moyer) [2107656]
- io_uring: pin SQPOLL data before unlocking ring lock (Jeff Moyer) [2107656]
- io-wq: provide IO_WQ_* constants for IORING_REGISTER_IOWQ_MAX_WORKERS arg items (Jeff Moyer) [2107656]
- io-wq: fix potential race of acct->nr_workers (Jeff Moyer) [2107656]
- io-wq: code clean of io_wqe_create_worker() (Jeff Moyer) [2107656]
- io_uring: ensure symmetry in handling iter types in loop_rw_iter() (Jeff Moyer) [2107656]
- io_uring: fix off-by-one in BUILD_BUG_ON check of __REQ_F_LAST_BIT (Jeff Moyer) [2107656]
- io_uring: fail links of cancelled timeouts (Jeff Moyer) [2107656]
- io-wq: fix memory leak in create_io_worker() (Jeff Moyer) [2107656]
- io-wq: fix silly logic error in io_task_work_match() (Jeff Moyer) [2107656]
- io_uring: drop ctx->uring_lock before acquiring sqd->lock (Jeff Moyer) [2107656]
- io_uring: fix missing mb() before waitqueue_active (Jeff Moyer) [2107656]
- io-wq: fix cancellation on create-worker failure (Jeff Moyer) [2107656]
- namei: Fix use after free in kern_path_locked (Jeff Moyer) [2107656]
- io_uring: reexpand under-reexpanded iters (Jeff Moyer) [2107656]
- iov_iter: track truncated size (Jeff Moyer) [2107656]
- io_uring: io_uring_complete() trace should take an integer (Jeff Moyer) [2107656]
- io_uring: fix possible poll event lost in multi shot mode (Jeff Moyer) [2107656]
- io_uring: prolong tctx_task_work() with flushing (Jeff Moyer) [2107656]
- io_uring: don't disable kiocb_done() CQE batching (Jeff Moyer) [2107656]
- io_uring: ensure IORING_REGISTER_IOWQ_MAX_WORKERS works with SQPOLL (Jeff Moyer) [2107656]
- io-wq: make worker creation resilient against signals (Jeff Moyer) [2107656]
- io-wq: get rid of FIXED worker flag (Jeff Moyer) [2107656]
- io-wq: only exit on fatal signals (Jeff Moyer) [2107656]
- io-wq: split bounded and unbounded work into separate lists (Jeff Moyer) [2107656]
- io-wq: fix queue stalling race (Jeff Moyer) [2107656]
- io_uring: don't submit half-prepared drain request (Jeff Moyer) [2107656]
- io_uring: fix queueing half-created requests (Jeff Moyer) [2107656]
- io-wq: ensure that hash wait lock is IRQ disabling (Jeff Moyer) [2107656]
- io_uring: retry in case of short read on block device (Jeff Moyer) [2107656]
- io_uring: IORING_OP_WRITE needs hash_reg_file set (Jeff Moyer) [2107656]
- io-wq: fix race between adding work and activating a free worker (Jeff Moyer) [2107656]
- io-wq: fix wakeup race when adding new work (Jeff Moyer) [2107656]
- io-wq: wqe and worker locks no longer need to be IRQ safe (Jeff Moyer) [2107656]
- io-wq: check max_worker limits if a worker transitions bound state (Jeff Moyer) [2107656]
- io_uring: allow updating linked timeouts (Jeff Moyer) [2107656]
- io_uring: keep ltimeouts in a list (Jeff Moyer) [2107656]
- io_uring: support CLOCK_BOOTTIME/REALTIME for timeouts (Jeff Moyer) [2107656]
- io-wq: provide a way to limit max number of workers (Jeff Moyer) [2107656]
- io_uring: add build check for buf_index overflows (Jeff Moyer) [2107656]
- io_uring: clarify io_req_task_cancel() locking (Jeff Moyer) [2107656]
- io_uring: add task-refs-get helper (Jeff Moyer) [2107656]
- io_uring: fix failed linkchain code logic (Jeff Moyer) [2107656]
- io_uring: remove redundant req_set_fail() (Jeff Moyer) [2107656]
- io_uring: don't free request to slab (Jeff Moyer) [2107656]
- io_uring: accept directly into fixed file table (Jeff Moyer) [2107656]
- io_uring: hand code io_accept() fd installing (Jeff Moyer) [2107656]
- io_uring: openat directly into fixed fd table (Jeff Moyer) [2107656]
- net: add accept helper not installing fd (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_LINKAT (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_SYMLINKAT (Jeff Moyer) [2107656]
- io_uring: fix io_try_cancel_userdata race for iowq (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_MKDIRAT (Jeff Moyer) [2107656]
- namei: update do_*() helpers to return ints (Jeff Moyer) [2107656]
- namei: make do_linkat() take struct filename (Jeff Moyer) [2107656]
- namei: add getname_uflags() (Jeff Moyer) [2107656]
- namei: make do_symlinkat() take struct filename (Jeff Moyer) [2107656]
- namei: make do_mknodat() take struct filename (Jeff Moyer) [2107656]
- namei: make do_mkdirat() take struct filename (Jeff Moyer) [2107656]
- namei: change filename_parentat() calling conventions (Jeff Moyer) [2107656]
- namei: ignore ERR/NULL names in putname() (Jeff Moyer) [2107656]
- io_uring: IRQ rw completion batching (Jeff Moyer) [2107656]
- io_uring: batch task work locking (Jeff Moyer) [2107656]
- io_uring: flush completions for fallbacks (Jeff Moyer) [2107656]
- io_uring: add ->splice_fd_in checks (Jeff Moyer) [2107656]
- io_uring: add clarifying comment for io_cqring_ev_posted() (Jeff Moyer) [2107656]
- io_uring: place fixed tables under memcg limits (Jeff Moyer) [2107656]
- io_uring: limit fixed table size by RLIMIT_NOFILE (Jeff Moyer) [2107656]
- io_uring: fix lack of protection for compl_nr (Jeff Moyer) [2107656]
- io_uring: Add register support for non-4k PAGE_SIZE (Jeff Moyer) [2107656]
- io_uring: extend task put optimisations (Jeff Moyer) [2107656]
- io_uring: add comments on why PF_EXITING checking is safe (Jeff Moyer) [2107656]
- io-wq: move nr_running and worker_refs out of wqe->lock protection (Jeff Moyer) [2107656]
- io_uring: fix io_timeout_remove locking (Jeff Moyer) [2107656]
- io_uring: improve same wq polling (Jeff Moyer) [2107656]
- io_uring: reuse io_req_complete_post() (Jeff Moyer) [2107656]
- io_uring: better encapsulate buffer select for rw (Jeff Moyer) [2107656]
- io_uring: optimise io_prep_linked_timeout() (Jeff Moyer) [2107656]
- io_uring: cancel not-armed linked touts separately (Jeff Moyer) [2107656]
- io_uring: simplify io_prep_linked_timeout (Jeff Moyer) [2107656]
- io_uring: kill REQ_F_LTIMEOUT_ACTIVE (Jeff Moyer) [2107656]
- io_uring: deduplicate cancellation code (Jeff Moyer) [2107656]
- io_uring: kill not necessary resubmit switch (Jeff Moyer) [2107656]
- io_uring: optimise initial ltimeout refcounting (Jeff Moyer) [2107656]
- io_uring: don't inflight-track linked timeouts (Jeff Moyer) [2107656]
- io_uring: optimise iowq refcounting (Jeff Moyer) [2107656]
- io_uring: correct __must_hold annotation (Jeff Moyer) [2107656]
- io_uring: code clean for completion_lock in io_arm_poll_handler() (Jeff Moyer) [2107656]
- io_uring: remove files pointer in cancellation functions (Jeff Moyer) [2107656]
- io_uring: extract io_uring_files_cancel() in io_uring_task_cancel() (Jeff Moyer) [2107656]
- io_uring: optimise hot path of ltimeout prep (Jeff Moyer) [2107656]
- io_uring: skip request refcounting (Jeff Moyer) [2107656]
- io_uring: remove submission references (Jeff Moyer) [2107656]
- io_uring: remove req_ref_sub_and_test() (Jeff Moyer) [2107656]
- io_uring: move req_ref_get() and friends (Jeff Moyer) [2107656]
- io_uring: remove IRQ aspect of io_ring_ctx completion lock (Jeff Moyer) [2107656]
- io_uring: run regular file completions from task_work (Jeff Moyer) [2107656]
- io_uring: run linked timeouts from task_work (Jeff Moyer) [2107656]
- io_uring: run timeouts from task_work (Jeff Moyer) [2107656]
- io_uring: remove file batch-get optimisation (Jeff Moyer) [2107656]
- io_uring: clean up tctx_task_work() (Jeff Moyer) [2107656]
- io_uring: inline io_poll_remove_waitqs (Jeff Moyer) [2107656]
- io_uring: remove extra argument for overflow flush (Jeff Moyer) [2107656]
- io_uring: inline struct io_comp_state (Jeff Moyer) [2107656]
- io_uring: use inflight_entry instead of compl.list (Jeff Moyer) [2107656]
- io_uring: remove redundant args from cache_free (Jeff Moyer) [2107656]
- io_uring: cache __io_free_req()'d requests (Jeff Moyer) [2107656]
- io_uring: move io_fallback_req_func() (Jeff Moyer) [2107656]
- io_uring: optimise putting task struct (Jeff Moyer) [2107656]
- io_uring: drop exec checks from io_req_task_submit (Jeff Moyer) [2107656]
- io_uring: kill unused IO_IOPOLL_BATCH (Jeff Moyer) [2107656]
- io_uring: improve ctx hang handling (Jeff Moyer) [2107656]
- io_uring: deduplicate open iopoll check (Jeff Moyer) [2107656]
- io_uring: inline io_free_req_deferred (Jeff Moyer) [2107656]
- io_uring: move io_rsrc_node_alloc() definition (Jeff Moyer) [2107656]
- io_uring: move io_put_task() definition (Jeff Moyer) [2107656]
- io_uring: extract a helper for ctx quiesce (Jeff Moyer) [2107656]
- io_uring: optimise io_cqring_wait() hot path (Jeff Moyer) [2107656]
- io_uring: add more locking annotations for submit (Jeff Moyer) [2107656]
- io_uring: refactor io_alloc_req (Jeff Moyer) [2107656]
- io-wq: improve wq_list_add_tail() (Jeff Moyer) [2107656]
- io_uring: remove unnecessary PF_EXITING check (Jeff Moyer) [2107656]
- io_uring: clean io-wq callbacks (Jeff Moyer) [2107656]
- io_uring: avoid touching inode in rw prep (Jeff Moyer) [2107656]
- io_uring: rename io_file_supports_async() (Jeff Moyer) [2107656]
- io_uring: inline fixed part of io_file_get() (Jeff Moyer) [2107656]
- io_uring: use kvmalloc for fixed files (Jeff Moyer) [2107656]
- io_uring: be smarter about waking multiple CQ ring waiters (Jeff Moyer) [2107656]
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Jeff Moyer) [2107656]
- arm64: kexec_file: use more system keyrings to verify kernel image signature (Coiby Xu) [2004384]
- kexec, KEYS: make the code in bzImage64_verify_sig generic (Coiby Xu) [2004384]
- kexec: clean up arch_kexec_kernel_verify_sig (Coiby Xu) [2004384]
- kexec_file: drop weak attribute from functions (Coiby Xu) [2004384]
- kexec_file: drop weak attribute from arch_kexec_apply_relocations[_add] (Coiby Xu) [2004384]
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on PTRACE_SEIZE (Oleg Nesterov) [2121271] {CVE-2022-30594}
- intel_idle: make SPR C1 and C1E be independent (David Arcari) [2125352]
- notifier: Remove atomic_notifier_call_chain_robust() (David Arcari) [2117508]
- PM: cpu: Make notifier chain use a raw_spinlock_t (David Arcari) [2117508]
- mailmap: remove my redhat.com address from RHEL9's .mailmap file (Jeffrey Layton) [2094072]
- NFSD: fix regression with setting ACLs. (Jeffrey Layton) [2094072]
- NFSD: discard fh_locked flag and fh_lock/fh_unlock (Jeffrey Layton) [2094072]
- NFSD: use (un)lock_inode instead of fh_(un)lock for file operations (Jeffrey Layton) [2094072]
- NFSD: use explicit lock/unlock for directory ops (Jeffrey Layton) [2094072]
- NFSD: reduce locking in nfsd_lookup() (Jeffrey Layton) [2094072]
- NFSD: only call fh_unlock() once in nfsd_link() (Jeffrey Layton) [2094072]
- NFSD: always drop directory lock in nfsd_unlink() (Jeffrey Layton) [2094072]
- NFSD: change nfsd_create()/nfsd_symlink() to unlock directory before returning. (Jeffrey Layton) [2094072]
- NFSD: add posix ACLs to struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: add security label to struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: set attributes when creating symlinks (Jeffrey Layton) [2094072]
- NFSD: introduce struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: verify the opened dentry after setting a delegation (Jeffrey Layton) [2094072]
- NFSD: drop fh argument from alloc_init_deleg (Jeffrey Layton) [2094072]
- NFSD: Move copy offload callback arguments into a separate structure (Jeffrey Layton) [2094072]
- NFSD: Add nfsd4_send_cb_offload() (Jeffrey Layton) [2094072]
- NFSD: Remove kmalloc from nfsd4_do_async_copy() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_do_copy() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_cleanup_inter_ssc() (2/2) (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_cleanup_inter_ssc() (1/2) (Jeffrey Layton) [2094072]
- NFSD: Replace boolean fields in struct nfsd4_copy (Jeffrey Layton) [2094072]
- NFSD: Make nfs4_put_copy() static (Jeffrey Layton) [2094072]
- NFSD: Reorder the fields in struct nfsd4_op (Jeffrey Layton) [2094072]
- NFSD: Shrink size of struct nfsd4_copy (Jeffrey Layton) [2094072]
- NFSD: Shrink size of struct nfsd4_copy_notify (Jeffrey Layton) [2094072]
- NFSD: nfserrno(-ENOMEM) is nfserr_jukebox (Jeffrey Layton) [2094072]
- NFSD: Fix strncpy() fortify warning (Jeffrey Layton) [2094072]
- NFSD: Clean up nfsd4_encode_readlink() (Jeffrey Layton) [2094072]
- NFSD: Use xdr_pad_size() (Jeffrey Layton) [2094072]
- NFSD: Simplify starting_len (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_readv() (Jeffrey Layton) [2094072]
- NFSD: Add an nfsd4_read::rd_eof field (Jeffrey Layton) [2094072]
- NFSD: Clean up SPLICE_OK in nfsd4_encode_read() (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_fattr() (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_operation() (Jeffrey Layton) [2094072]
- nfsd: silence extraneous printk on nfsd.ko insertion (Jeffrey Layton) [2094072]
- NFSD: refactoring v4 specific code to a helper in nfs4state.c (Jeffrey Layton) [2094072]
- NFSD: Ensure nf_inode is never dereferenced (Jeffrey Layton) [2094072]
- NFSD: NFSv4 CLOSE should release an nfsd_file immediately (Jeffrey Layton) [2094072]
- NFSD: Move nfsd_file_trace_alloc() tracepoint (Jeffrey Layton) [2094072]
- NFSD: Separate tracepoints for acquire and create (Jeffrey Layton) [2094072]
- NFSD: Clean up unused code after rhashtable conversion (Jeffrey Layton) [2094072]
- NFSD: Convert the filecache to use rhashtable (Jeffrey Layton) [2094072]
- NFSD: Set up an rhashtable for the filecache (Jeffrey Layton) [2094072]
- NFSD: Replace the "init once" mechanism (Jeffrey Layton) [2094072]
- NFSD: Remove nfsd_file::nf_hashval (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_hash_remove can compute hashval (Jeffrey Layton) [2094072]
- NFSD: Refactor __nfsd_file_close_inode() (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_unhash can compute hashval from nf->nf_inode (Jeffrey Layton) [2094072]
- NFSD: Remove lockdep assertion from unhash_and_release_locked() (Jeffrey Layton) [2094072]
- NFSD: No longer record nf_hashval in the trace log (Jeffrey Layton) [2094072]
- NFSD: Never call nfsd_file_gc() in foreground paths (Jeffrey Layton) [2094072]
- NFSD: Fix the filecache LRU shrinker (Jeffrey Layton) [2094072]
- NFSD: Leave open files out of the filecache LRU (Jeffrey Layton) [2094072]
- NFSD: Trace filecache LRU activity (Jeffrey Layton) [2094072]
- NFSD: WARN when freeing an item still linked via nf_lru (Jeffrey Layton) [2094072]
- NFSD: Hook up the filecache stat file (Jeffrey Layton) [2094072]
- NFSD: Zero counters when the filecache is re-initialized (Jeffrey Layton) [2094072]
- NFSD: Record number of flush calls (Jeffrey Layton) [2094072]
- NFSD: Report the number of items evicted by the LRU walk (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd_file_lru_scan() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd_file_gc() (Jeffrey Layton) [2094072]
- NFSD: Add nfsd_file_lru_dispose_list() helper (Jeffrey Layton) [2094072]
- NFSD: Report average age of filecache items (Jeffrey Layton) [2094072]
- NFSD: Report count of freed filecache items (Jeffrey Layton) [2094072]
- NFSD: Report count of calls to nfsd_file_acquire() (Jeffrey Layton) [2094072]
- NFSD: Report filecache LRU size (Jeffrey Layton) [2094072]
- NFSD: Demote a WARN to a pr_warn() (Jeffrey Layton) [2094072]
- nfsd: remove redundant assignment to variable len (Jeffrey Layton) [2094072]
- NFSD: Fix space and spelling mistake (Jeffrey Layton) [2094072]
- NFSD: Instrument fh_verify() (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_put() can sleep (Jeffrey Layton) [2094072]
- NFSD: Add documenting comment for nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- NFSD: Modernize nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- NFSD: Fix possible sleep during nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- SUNRPC: Use RMW bitops in single-threaded hot paths (Jeffrey Layton) [2094072]
- NFSD: Trace filecache opens (Jeffrey Layton) [2094072]
- NFSD: Move documenting comment for nfsd4_process_open2() (Jeffrey Layton) [2094072]
- NFSD: Fix whitespace (Jeffrey Layton) [2094072]
- NFSD: Remove dprintk call sites from tail of nfsd4_open() (Jeffrey Layton) [2094072]
- NFSD: Clean up nfsd_splice_actor() (Jeffrey Layton) [2094072]
- Revert "SUNRPC: Remove unreachable error condition" (Benjamin Coddington) [2094072]
- NFSv4.2: Update mode bits after ALLOCATE and DEALLOCATE (Benjamin Coddington) [2094072]
- NFSv4: Turn off open-by-filehandle and NFS re-export for NFSv4.0 (Benjamin Coddington) [2094072]
- SUNRPC: RPC level errors should set task->tk_rpc_status (Benjamin Coddington) [2094072]
- NFSv4.2 fix problems with __nfs42_ssc_open (Benjamin Coddington) [2094072]
- NFS: Fix another fsync() issue after a server reboot (Benjamin Coddington) [2094072]
- net/sunrpc: fix potential memory leaks in rpc_sysfs_xprt_state_change() (Benjamin Coddington) [2094072]
- SUNRPC: Fix xdr_encode_bool() (Benjamin Coddington) [2094072]
- SUNRPC: Reinitialise the backchannel request buffers before reuse (Benjamin Coddington) [2094072]
- NFSv4.1: RECLAIM_COMPLETE must handle EACCES (Benjamin Coddington) [2094072]
- NFSv4: Fix races in the legacy idmapper upcall (Benjamin Coddington) [2094072]
- sunrpc: fix expiry of auth creds (Benjamin Coddington) [2094072]
- NFSv4.1: Handle NFS4ERR_DELAY replies to OP_SEQUENCE correctly (Benjamin Coddington) [2094072]
- NFSv4.1: Don't decrease the value of seq_nr_highest_sent (Benjamin Coddington) [2094072]
- pNFS/flexfiles: Report RDMA connection errors to the server (Benjamin Coddington) [2094072]
- Revert "pNFS: nfs3_set_ds_client should set NFS_CS_NOPING" (Benjamin Coddington) [2094072]
- SUNRPC: Fix the calculation of xdr->end in xdr_get_next_encode_buffer() (Benjamin Coddington) [2094072]
- pNFS: Avoid a live lock condition in pnfs_update_layout() (Benjamin Coddington) [2094072]
- pNFS: Don't keep retrying if the server replied NFS4ERR_LAYOUTUNAVAILABLE (Benjamin Coddington) [2094072]
- SUNRPC: Trap RDMA segment overflows (Benjamin Coddington) [2094072]
- nfsd: Fix null-ptr-deref in nfsd_fill_super() (Benjamin Coddington) [2094072]
- nfsd: Unregister the cld notifier when laundry_wq create failed (Benjamin Coddington) [2094072]
- NFSD: move create/destroy of laundry_wq to init_nfsd and exit_nfsd (Benjamin Coddington) [2094072]
- NFS: Further fixes to the writeback error handling (Benjamin Coddington) [2094072]
- NFSv4/pNFS: Do not fail I/O when we fail to allocate the pNFS layout (Benjamin Coddington) [2094072]
- NFS: Memory allocation failures are not server fatal errors (Benjamin Coddington) [2094072]
- NFS: Don't report errors from nfs_pageio_complete() more than once (Benjamin Coddington) [2094072]
- NFS: Do not report flush errors in nfs_write_end() (Benjamin Coddington) [2094072]
- NFS: Don't report ENOSPC write errors twice (Benjamin Coddington) [2094072]
- NFS: fsync() should report filesystem errors over EINTR/ERESTARTSYS (Benjamin Coddington) [2094072]
- NFS: Do not report EINTR/ERESTARTSYS as mapping errors (Benjamin Coddington) [2094072]
- SUNRPC: Fix call completion races with call_decode() (Benjamin Coddington) [2094072]
- SUNRPC: Don't reuse bvec on retransmission of the request (Benjamin Coddington) [2094072]
- NFSD: Decode NFSv4 birth time attribute (Benjamin Coddington) [2094072]
- NFS: restore module put when manager exits. (Benjamin Coddington) [2094072]
- NFSD: restore EINVAL error translation in nfsd_commit() (Benjamin Coddington) [2094072]
- NFSD: Fix potential use-after-free in nfsd_file_put() (Benjamin Coddington) [2094072]
- SUNRPC: Ensure that the gssproxy client can start in a connected state (Benjamin Coddington) [2094072]
- Revert "SUNRPC: Ensure gss-proxy connects on setup" (Benjamin Coddington) [2094072]
- Revert "SUNRPC: attempt AF_LOCAL connect on setup" (Benjamin Coddington) [2094072]
- SUNRPC: Ensure gss-proxy connects on setup (Benjamin Coddington) [2094072]
- SUNRPC: Ensure timely close of disconnected AF_LOCAL sockets (Benjamin Coddington) [2094072]
- NFSv4: Don't invalidate inode attributes on delegation return (Benjamin Coddington) [2094072]
- SUNRPC: Move the call to xprt_send_pagedata() out of xprt_sock_sendmsg() (Benjamin Coddington) [2094072]
- SUNRPC: svc_tcp_sendmsg() should handle errors from xdr_alloc_bvec() (Benjamin Coddington) [2094072]
- SUNRPC: Handle allocation failure in rpc_new_task() (Benjamin Coddington) [2094072]
- NFS: Ensure rpc_run_task() cannot fail in nfs_async_rename() (Benjamin Coddington) [2094072]
- NFSv4/pnfs: Handle RPC allocation errors in nfs4_proc_layoutget (Benjamin Coddington) [2094072]
- SUNRPC: Handle low memory situations in call_status() (Benjamin Coddington) [2094072]
- SUNRPC: Handle ENOMEM in call_transmit_status() (Benjamin Coddington) [2094072]
- NFS: Replace readdir's use of xxhash() with hash_64() (Benjamin Coddington) [2094072]
- SUNRPC: Fix the svc_deferred_event trace class (Benjamin Coddington) [2094072]
- SUNRPC: Fix NFSD's request deferral on RDMA transports (Benjamin Coddington) [2094072]
- nfsd: Clean up nfsd_file_put() (Benjamin Coddington) [2094072]
- nfsd: Fix a write performance regression (Benjamin Coddington) [2094072]
- SUNRPC: handle malloc failure in ->request_prepare (Benjamin Coddington) [2094072]
- NFSv4: fix open failure with O_ACCMODE flag (Benjamin Coddington) [2094072]
- Revert "NFSv4: Handle the special Linux file open access mode" (Benjamin Coddington) [2094072]
- NFSv4/pNFS: Fix another issue with a list iterator pointing to the head (Benjamin Coddington) [2094072]
- SUNRPC: Return true/false (not 1/0) from bool functions (Benjamin Coddington) [2094072]
- SUNRPC: Don't return error values in sysfs read of closed files (Benjamin Coddington) [2094072]
- SUNRPC: Do not dereference non-socket transports in sysfs (Benjamin Coddington) [2094072]
- NFSv4.1: don't retry BIND_CONN_TO_SESSION on session error (Benjamin Coddington) [2094072]
- NFS: replace usage of found with dedicated list iterator variable (Benjamin Coddington) [2094072]
- SUNRPC: avoid race between mod_timer() and del_timer_sync() (Benjamin Coddington) [2094072]
- nfs: remove reliance on bdi congestion (Benjamin Coddington) [2094072]
- pNFS/files: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- pNFS/flexfiles: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- NFSv4/pnfs: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- NFS: Avoid writeback threads getting stuck in mempool_alloc() (Benjamin Coddington) [2094072]
- NFS: nfsiod should not block forever in mempool_alloc() (Benjamin Coddington) [2094072]
- SUNRPC: Make the rpciod and xprtiod slab allocation modes consistent (Benjamin Coddington) [2094072]
- SUNRPC: Fix unx_lookup_cred() allocation (Benjamin Coddington) [2094072]
- NFS: Fix memory allocation in rpc_alloc_task() (Benjamin Coddington) [2094072]
- NFS: Fix memory allocation in rpc_malloc() (Benjamin Coddington) [2094072]
- SUNRPC: Improve accuracy of socket ENOBUFS determination (Benjamin Coddington) [2094072]
- SUNRPC: Replace internal use of SOCKWQ_ASYNC_NOSPACE (Benjamin Coddington) [2094072]
- SUNRPC: Fix socket waits for write buffer space (Benjamin Coddington) [2094072]
- SUNRPC: Only save the TCP source port after the connection is complete (Benjamin Coddington) [2094072]
- NFS: Fix revalidation of empty readdir pages (Benjamin Coddington) [2094072]
- NFS: Don't deadlock when cookie hashes collide (Benjamin Coddington) [2094072]
- nfsd: fix using the correct variable for sizeof() (Benjamin Coddington) [2094072]
- nfsd: use correct format characters (Benjamin Coddington) [2094072]
- NFSD: prevent integer overflow on 32 bit systems (Benjamin Coddington) [2094072]
- NFSD: prevent underflow in nfssvc_decode_writeargs() (Benjamin Coddington) [2094072]
- SUNRPC: change locking for xs_swap_enable/disable (Benjamin Coddington) [2094072]
- NFS: swap-out must always use STABLE writes. (Benjamin Coddington) [2094072]
- NFS: swap IO handling is slightly different for O_DIRECT IO (Benjamin Coddington) [2094072]
- NFSv4: keep state manager thread active if swap is enabled (Benjamin Coddington) [2094072]
- SUNRPC: improve 'swap' handling: scheduling and PF_MEMALLOC (Benjamin Coddington) [2094072]
- NFS: discard NFS_RPC_SWAPFLAGS and RPC_TASK_ROOTCREDS (Benjamin Coddington) [2094072]
- SUNRPC: remove scheduling boost for "SWAPPER" tasks. (Benjamin Coddington) [2094072]
- SUNRPC/xprt: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- SUNRPC/auth: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- SUNRPC/call_alloc: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- NFS: remove IS_SWAPFILE hack (Benjamin Coddington) [2094072]
- NFS: remove unneeded check in decode_devicenotify_args() (Benjamin Coddington) [2094072]
- NFSD: Fix nfsd_breaker_owns_lease() return values (Benjamin Coddington) [2094072]
- NFSD: Clean up _lm_ operation names (Benjamin Coddington) [2094072]
- NFSD: Remove CONFIG_NFSD_V3 Conflicts: Two hunks of the upstream version of this patch has been removed here because we've already removed do_nfsd_create() in a previous backport of upstream 1c388f27759c5d9271d4fca081f7ee138986eb7d. (Benjamin Coddington) [2094072]
- NFS: Cache all entries in the readdirplus reply (Benjamin Coddington) [2094072]
- NFS: Optimise away the previous cookie field (Benjamin Coddington) [2094072]
- NFS: Fix up forced readdirplus (Benjamin Coddington) [2094072]
- NFS: Convert readdir page cache to use a cookie based index (Benjamin Coddington) [2094072]
- NFS: Clean up page array initialisation/free (Benjamin Coddington) [2094072]
- NFS: Trace effects of the readdirplus heuristic (Benjamin Coddington) [2094072]
- NFS: Trace effects of readdirplus on the dcache (Benjamin Coddington) [2094072]
- NFS: Add basic readdir tracing (Benjamin Coddington) [2094072]
- NFS: Don't request readdirplus when revalidation was forced (Benjamin Coddington) [2094072]
- NFS: Readdirplus can't help lookup for case insensitive filesystems (Benjamin Coddington) [2094072]
- NFSv4: Ask for a full XDR buffer of readdir goodness (Benjamin Coddington) [2094072]
- NFS: Don't ask for readdirplus unless it can help nfs_getattr() (Benjamin Coddington) [2094072]
- NFS: Improve heuristic for readdirplus (Benjamin Coddington) [2094072]
- NFS: Reduce use of uncached readdir (Benjamin Coddington) [2094072]
- NFS: Simplify nfs_readdir_xdr_to_array() (Benjamin Coddington) [2094072]
- NFS: If the cookie verifier changes, we must invalidate the page cache (Benjamin Coddington) [2094072]
- NFS: Adjust the amount of readahead performed by NFS readdir (Benjamin Coddington) [2094072]
- NFS: Don't advance the page pointer unless the page is full (Benjamin Coddington) [2094072]
- NFS: Don't re-read the entire page cache to find the next cookie (Benjamin Coddington) [2094072]
- NFS: Store the change attribute in the directory page cache (Benjamin Coddington) [2094072]
- nfsd: more robust allocation failure handling in nfsd_file_cache_init (Benjamin Coddington) [2094072]
- SUNRPC: Teach server to recognize RPC_AUTH_TLS (Benjamin Coddington) [2094072]
- NFSD: Move svc_serv_ops::svo_function into struct svc_serv (Benjamin Coddington) [2094072]
- NFSD: Remove svc_serv_ops::svo_module (Benjamin Coddington) [2094072]
- SUNRPC: Remove svc_shutdown_net() (Benjamin Coddington) [2094072]
- SUNRPC: Rename svc_close_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Rename svc_create_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Remove svo_shutdown method (Benjamin Coddington) [2094072]
- SUNRPC: Merge svc_do_enqueue_xprt() into svc_enqueue_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Remove the .svo_enqueue_xprt method (Benjamin Coddington) [2094072]
- SUNRPC: Record endpoint information in trace log (Benjamin Coddington) [2094072]
- SUNRPC: Same as SVC_RQST_ENDPOINT, but without the xid (Benjamin Coddington) [2094072]
- SUNRPC: Improve sockaddr handling in the svc_xprt_create_error trace point (Benjamin Coddington) [2094072]
- tracing: Have event format check not flag %%p* on __get_dynamic_array() (Benjamin Coddington) [2094072]
- tracing: Update print fmt check to handle new __get_sockaddr() macro (Benjamin Coddington) [2094072]
- NFSD: Remove NFSD_PROC_ARGS_* macros (Benjamin Coddington) [2094072]
- NFSD: Use __sockaddr field to store socket addresses (Benjamin Coddington) [2094072]
- NFSD: Streamline the rare "found" case (Benjamin Coddington) [2094072]
- NFSD: Skip extra computation for RC_NOCACHE case (Benjamin Coddington) [2094072]
- NFSD: De-duplicate hash bucket indexing (Benjamin Coddington) [2094072]
- nfsd: Add support for the birth time attribute (Benjamin Coddington) [2094072]
- NFS: Calculate page offsets algorithmically (Benjamin Coddington) [2094072]
- NFS: Use kzalloc() to avoid initialising the nfs_open_dir_context (Benjamin Coddington) [2094072]
- NFS: Initialise the readdir verifier as best we can in nfs_opendir() (Benjamin Coddington) [2094072]
- NFS: Trace lookup revalidation failure (Benjamin Coddington) [2094072]
- NFS: constify nfs_server_capable() and nfs_have_writebacks() (Benjamin Coddington) [2094072]
- NFS: Return valid errors from nfs2/3_decode_dirent() (Benjamin Coddington) [2094072]
- Revert "NFSv4: use unique client identifiers in network namespaces" (Benjamin Coddington) [2094072]
- NFS: Use of mapping_set_error() results in spurious errors (Benjamin Coddington) [2094072]
- NFS: Clean up NFSv4.2 xattrs (Benjamin Coddington) [2094072]
- NFS: Remove unnecessary XATTR cache invalidation in nfs_fhget() (Benjamin Coddington) [2094072]
- NFS: NFSv2/v3 clients should never be setting NFS_CAP_XATTR (Benjamin Coddington) [2094072]
- NFS: Remove unused flag NFS_INO_REVAL_PAGECACHE (Benjamin Coddington) [2094072]
- NFS: Replace last uses of NFS_INO_REVAL_PAGECACHE (Benjamin Coddington) [2094072]
- NFSv4: use unique client identifiers in network namespaces (Benjamin Coddington) [2094072]
- SUNRPC/xprtrdma: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- SUNRPC/auth_gss: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- SUNRPC: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4.2/copyoffload: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4/flexfiles: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFS: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4: Charge NFSv4 open state trackers to kmemcg (Benjamin Coddington) [2094072]
- NFS: Charge open/lock file contexts to kmemcg (Benjamin Coddington) [2094072]
- NFSv4: Protect the state recovery thread against direct reclaim (Benjamin Coddington) [2094072]
- SUNRPC: remove redundant pointer plainhdr (Benjamin Coddington) [2094072]
- NFSv4.2: fix reference count leaks in _nfs42_proc_copy_notify() (Benjamin Coddington) [2094072]
- Convert NFS from readpages to readahead (Benjamin Coddington) [2094072]
- NFS: simplify check for freeing cn_resp (Benjamin Coddington) [2094072]
- tracing: Introduce helpers to safely handle dynamic-sized sockaddrs (Benjamin Coddington) [2094072]
- NFS: Do not report writeback errors in nfs_getattr() (Benjamin Coddington) [2094072]
- NFS: Remove an incorrect revalidation in nfs4_update_changeattr_locked() (Benjamin Coddington) [2094072]
- NFSD: Deprecate NFS_OFFSET_MAX (Benjamin Coddington) [2094072]
- SUNRPC: lock against ->sock changing during sysfs read (Benjamin Coddington) [2094072]
- NFS: Fix nfs4_proc_get_locations() kernel-doc comment (Benjamin Coddington) [2094072]
- xprtrdma: fix pointer derefs in error cases of rpcrdma_ep_create (Benjamin Coddington) [2094072]
- NFS: Avoid duplicate uncached readdir calls on eof (Benjamin Coddington) [2094072]
- NFS: Don't skip directory entries when doing uncached readdir (Benjamin Coddington) [2094072]
- NFS: Don't overfill uncached readdir pages (Benjamin Coddington) [2094072]
- nfsd: nfsd4_setclientid_confirm mistakenly expires confirmed client. (Benjamin Coddington) [2094072]
- fsnotify: fix fsnotify hooks in pseudo filesystems (Benjamin Coddington) [2094072]
- xprtrdma: Remove definitions of RPCDBG_FACILITY (Benjamin Coddington) [2094072]
- xprtrdma: Remove final dprintk call sites from xprtrdma (Benjamin Coddington) [2094072]
- sunrpc: Fix potential race conditions in rpc_sysfs_xprt_state_change() (Benjamin Coddington) [2094072]
- net/sunrpc: fix reference count leaks in rpc_sysfs_xprt_state_change (Benjamin Coddington) [2094072]
- SUNRPC: Fix sockaddr handling in svcsock_accept_class trace points (Benjamin Coddington) [2094072]
- SUNRPC: Fix sockaddr handling in the svc_xprt_create_error trace point (Benjamin Coddington) [2094072]
- nfsd: fix crash on COPY_NOTIFY with special stateid (Benjamin Coddington) [2094072]
- NFSD: Trace boot verifier resets (Benjamin Coddington) [2094072]
- NFSD: Rename boot verifier functions (Benjamin Coddington) [2094072]
- NFSD: Clean up the nfsd_net::nfssvc_boot field (Benjamin Coddington) [2094072]
- NFSD: Write verifier might go backwards (Benjamin Coddington) [2094072]
- nfsd: Add a tracepoint for errors in nfsd4_clone_file_range() (Benjamin Coddington) [2094072]
- NFSD: De-duplicate net_generic(nf->nf_net, nfsd_net_id) (Benjamin Coddington) [2094072]
- NFSD: De-duplicate net_generic(SVC_NET(rqstp), nfsd_net_id) (Benjamin Coddington) [2094072]
- NFSD: Clean up nfsd_vfs_write() (Benjamin Coddington) [2094072]
- nfsd: Replace use of rwsem with errseq_t (Benjamin Coddington) [2094072]
- NFSD: Fix verifier returned in stable WRITEs (Benjamin Coddington) [2094072]
- nfsd: Retry once in nfsd_open on an -EOPENSTALE return (Benjamin Coddington) [2094072]
- nfsd: Add errno mapping for EREMOTEIO (Benjamin Coddington) [2094072]
- nfsd: map EBADF (Benjamin Coddington) [2094072]
- NFSD: Fix zero-length NFSv3 WRITEs (Benjamin Coddington) [2094072]
- nfsd4: add refcount for nfsd4_blocked_lock (Benjamin Coddington) [2094072]
- NFSD: De-duplicate nfsd4_decode_bitmap4() (Benjamin Coddington) [2094072]
- nfsd: improve stateid access bitmask documentation (Benjamin Coddington) [2094072]
- NFSD: Combine XDR error tracepoints (Benjamin Coddington) [2094072]
- NFSv42: Fallocate and clone should also request 'blocks used' (Benjamin Coddington) [2094072]
- NFSv4: Allow writebacks to request 'blocks used' (Benjamin Coddington) [2094072]
- SUNRPC: use default_groups in kobj_type (Benjamin Coddington) [2094072]
- NFS: use default_groups in kobj_type (Benjamin Coddington) [2094072]
- NFS: Fix the verifier for case sensitive filesystem in nfs_atomic_open() (Benjamin Coddington) [2094072]
- NFS: Add a helper to remove case-insensitive aliases (Benjamin Coddington) [2094072]
- NFS: Invalidate negative dentries on all case insensitive directory changes (Benjamin Coddington) [2094072]
- NFSv4: Just don't cache negative dentries on case insensitive servers (Benjamin Coddington) [2094072]
- NFSv4: Add some support for case insensitive filesystems (Benjamin Coddington) [2094072]
- NFSv4.1: Fix uninitialised variable in devicenotify (Benjamin Coddington) [2094072]
- nfs: nfs4clinet: check the return value of kstrdup() (Benjamin Coddington) [2094072]
- sunrpc: Remove unneeded null check (Benjamin Coddington) [2094072]
- nfs41: pnfs: filelayout: Replace one-element array with flexible-array member (Benjamin Coddington) [2094072]
- SUNRPC: Add source address/port to rpc_socket* traces (Benjamin Coddington) [2094072]
- NFS: Ensure the server has an up to date ctime before renaming (Benjamin Coddington) [2094072]
- NFS: Ensure the server has an up to date ctime before hardlinking (Benjamin Coddington) [2094072]
- NFS: don't store 'struct cred *' in struct nfs_access_entry (Benjamin Coddington) [2094072]
- NFS: pass cred explicitly for access tests (Benjamin Coddington) [2094072]
- NFS: change nfs_access_get_cached to only report the mask (Benjamin Coddington) [2094072]
- SUNRPC: Remove low signal-to-noise tracepoints (Benjamin Coddington) [2094072]
- NFSD: simplify per-net file cache management (Benjamin Coddington) [2094072]
- NFSD: Fix inconsistent indenting (Benjamin Coddington) [2094072]
- NFSD: Remove be32_to_cpu() from DRC hash function (Benjamin Coddington) [2094072]
- NFS: switch the callback service back to non-pooled. (Benjamin Coddington) [2094072]
- lockd: use svc_set_num_threads() for thread start and stop (Benjamin Coddington) [2094072]
- SUNRPC: always treat sv_nrpools==1 as "not pooled" (Benjamin Coddington) [2094072]
- SUNRPC: move the pool_map definitions (back) into svc.c (Benjamin Coddington) [2094072]
- lockd: rename lockd_create_svc() to lockd_get() (Benjamin Coddington) [2094072]
- lockd: introduce lockd_put() (Benjamin Coddington) [2094072]
- lockd: move svc_exit_thread() into the thread (Benjamin Coddington) [2094072]
- lockd: move lockd_start_svc() call into lockd_create_svc() (Benjamin Coddington) [2094072]
- lockd: simplify management of network status notifiers (Benjamin Coddington) [2094072]
- lockd: introduce nlmsvc_serv (Benjamin Coddington) [2094072]
- NFSD: simplify locking for network notifier. (Benjamin Coddington) [2094072]
- SUNRPC: discard svo_setup and rename svc_set_num_threads_sync() (Benjamin Coddington) [2094072]
- NFSD: Make it possible to use svc_set_num_threads_sync (Benjamin Coddington) [2094072]
- NFSD: narrow nfsd_mutex protection in nfsd thread (Benjamin Coddington) [2094072]
- SUNRPC: use sv_lock to protect updates to sv_nrthreads. (Benjamin Coddington) [2094072]
- nfsd: make nfsd_stats.th_cnt atomic_t (Benjamin Coddington) [2094072]
- SUNRPC: stop using ->sv_nrthreads as a refcount (Benjamin Coddington) [2094072]
- SUNRPC/NFSD: clean up get/put functions. (Benjamin Coddington) [2094072]
- SUNRPC: change svc_get() to return the svc. (Benjamin Coddington) [2094072]
- NFSD: handle errors better in write_ports_addfd() (Benjamin Coddington) [2094072]
- NFSD: Fix sparse warning (Benjamin Coddington) [2094072]
- redhat/Makefile: Remove hardcoded BUILD_TARGET entries (Prarit Bhargava)
- tty: use new tty_insert_flip_string_and_push_buffer() in pty_write() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: extract tty_flip_buffer_commit() from tty_flip_buffer_push() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: drop tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: the rest, stop using tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: drivers/tty/, stop using tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- iommu: Fix false ownership failure on AMD systems with PASID activated (Alex Williamson) [2124620]
- iommu/virtio: Fix interaction with VFIO (Alex Williamson) [2124620]
- vfio: Move vfio.c to vfio_main.c (Alex Williamson) [2124620]
- vfio: do not set FMODE_LSEEK flag (Alex Williamson) [2124620]
- drm/i915/gvt: Fix Comet Lake (Alex Williamson) [2124620]
- vfio/pci: fix the wrong word (Alex Williamson) [2124620]
- vfio/ccw: Check return code from subchannel quiesce (Alex Williamson) [2124620]
- vfio/ccw: Remove FSM Close from remove handlers (Alex Williamson) [2124620]
- vfio/ccw: Add length to DMA_UNMAP checks (Alex Williamson) [2124620]
- vfio: Replace phys_pfn with pages for vfio_pin_pages() (Alex Williamson) [2124620]
- vfio/ccw: Add kmap_local_page() for memcpy (Alex Williamson) [2124620]
- vfio: Rename user_iova of vfio_dma_rw() (Alex Williamson) [2124620]
- vfio/ccw: Change pa_pfn list to pa_iova list (Alex Williamson) [2124620]
- vfio/ap: Change saved_pfn to saved_iova (Alex Williamson) [2124620]
- vfio: Pass in starting IOVA to vfio_pin/unpin_pages API (Alex Williamson) [2124620]
- vfio/ccw: Only pass in contiguous pages (Alex Williamson) [2124620]
- vfio/ap: Pass in physical address of ind to ap_aqic() (Alex Williamson) [2124620]
- s390/ap: add missing virt_to_phys address conversion (Alex Williamson) [2124620]
- drm/i915/gvt: Replace roundup with DIV_ROUND_UP (Alex Williamson) [2124620]
- vfio: Make vfio_unpin_pages() return void (Alex Williamson) [2124620]
- vfio/spapr_tce: Fix the comment (Alex Williamson) [2124620]
- vfio: Replace the iommu notifier with a device list (Alex Williamson) [2124620]
- vfio: Replace the DMA unmapping notifier with a callback (Alex Williamson) [2124620]
- vfio/ccw: Move FSM open/close to MDEV open/close (Alex Williamson) [2124620]
- vfio/ccw: Refactor vfio_ccw_mdev_reset (Alex Williamson) [2124620]
- vfio/ccw: Create a CLOSE FSM event (Alex Williamson) [2124620]
- vfio/ccw: Create an OPEN FSM Event (Alex Williamson) [2124620]
- vfio/ccw: Update trace data for not operational event (Alex Williamson) [2124620]
- vfio/ccw: Flatten MDEV device (un)register (Alex Williamson) [2124620]
- vfio/ccw: Pass enum to FSM event jumptable (Alex Williamson) [2124620]
- vfio/ccw: Remove private->mdev (Alex Williamson) [2124620]
- vfio/ccw: Do not change FSM state in subchannel event (Alex Williamson) [2124620]
- vfio/ccw: Fix FSM state if mdev probe fails (Alex Williamson) [2124620]
- vfio/ccw: Remove UUID from s390 debug log (Alex Williamson) [2124620]
- vfio/pci: fix the wrong word (Alex Williamson) [2124620]
- vfio/spapr_tce: Remove the unused parameters container (Alex Williamson) [2124620]
- vfio: Move "device->open_count--" out of group_rwsem in vfio_device_open() (Alex Williamson) [2124620]
- vfio: remove useless judgement (Alex Williamson) [2124620]
- vfio: Clear the caps->buf to NULL after free (Alex Williamson) [2124620]
- vfio: check iommu_group_set_name() return value (Alex Williamson) [2124620]
- vfio: check vfio_register_iommu_driver() return value (Alex Williamson) [2124620]
- vfio: Use device_iommu_capable() (Alex Williamson) [2124620]
- vfio/type1: Simplify bus_type determination (Alex Williamson) [2124620]
- vfio: Split migration ops from main device ops (Alex Williamson) [2124620]
- vfio: de-extern-ify function prototypes (Alex Williamson) [2124620]
- vfio: Move IOMMU_CAP_CACHE_COHERENCY test to after we know we have a group (Alex Williamson) [2124620]
- vfio: remove VFIO_GROUP_NOTIFY_SET_KVM (Alex Williamson) [2124620]
- vfio: Do not manipulate iommu dma_owner for fake iommu groups (Alex Williamson) [2124620]
- vfio/pci: Move the unused device into low power state with runtime PM (Alex Williamson) [2124620]
- vfio/pci: Virtualize PME related registers bits and initialize to zero (Alex Williamson) [2124620]
- vfio/pci: Change the PF power state to D0 before enabling VFs (Alex Williamson) [2124620]
- vfio/pci: Invalidate mmaps and block the access in D3hot power state (Alex Williamson) [2124620]
- vfio: Change struct vfio_group::container_users to a non-atomic int (Alex Williamson) [2124620]
- vfio: Simplify the life cycle of the group FD (Alex Williamson) [2124620]
- vfio: Fully lock struct vfio_group::container (Alex Williamson) [2124620]
- vfio: Split up vfio_group_get_device_fd() (Alex Williamson) [2124620]
- vfio: Change struct vfio_group::opened from an atomic to bool (Alex Williamson) [2124620]
- vfio: Add missing locking for struct vfio_group::kvm (Alex Williamson) [2124620]
- kvm/vfio: Fix potential deadlock problem in vfio (Alex Williamson) [2124620]
- include/uapi/linux/vfio.h: Fix trivial typo - _IORW should be _IOWR instead (Alex Williamson) [2124620]
- vfio/pci: Use the struct file as the handle not the vfio_group (Alex Williamson) [2124620]
- kvm/vfio: Remove vfio_group from kvm (Alex Williamson) [2124620]
- vfio: Change vfio_group_set_kvm() to vfio_file_set_kvm() (Alex Williamson) [2124620]
- vfio: Change vfio_external_check_extension() to vfio_file_enforced_coherent() (Alex Williamson) [2124620]
- vfio: Remove vfio_external_group_match_file() (Alex Williamson) [2124620]
- vfio: Change vfio_external_user_iommu_id() to vfio_file_iommu_group() (Alex Williamson) [2124620]
- kvm/vfio: Store the struct file in the kvm_vfio_group (Alex Williamson) [2124620]
- kvm/vfio: Move KVM_DEV_VFIO_GROUP_* ioctls into functions (Alex Williamson) [2124620]
- vfio: Delete container_q (Alex Williamson) [2124620]
- vfio/pci: Remove vfio_device_get_from_dev() (Alex Williamson) [2124620]
- vfio/pci: Have all VFIO PCI drivers store the vfio_pci_core_device in drvdata (Alex Williamson) [2124620]
- vfio: Remove calls to vfio_group_add_container_user() (Alex Williamson) [2124620]
- vfio: Remove dead code (Alex Williamson) [2124620]
- drm/i915/gvt: Change from vfio_group_(un)pin_pages to vfio_(un)pin_pages (Alex Williamson) [2124620]
- vfio/mdev: Pass in a struct vfio_device * to vfio_dma_rw() (Alex Williamson) [2124620]
- vfio/mdev: Pass in a struct vfio_device * to vfio_pin/unpin_pages() (Alex Williamson) [2124620]
- vfio/ccw: Remove mdev from struct channel_program (Alex Williamson) [2124620]
- vfio: Make vfio_(un)register_notifier accept a vfio_device (Alex Williamson) [2124620]
- vfio: Stop using iommu_present() (Alex Williamson) [2124620]
- iommu/s390: Tolerate repeat attach_dev calls (Alex Williamson) [2124620]
- iommu: iommu_group_claim_dma_owner() must always assign a domain (Alex Williamson) [2124620]
- iommu: Remove iommu group changes notifier (Alex Williamson) [2124620]
- vfio: Remove iommu group notifier (Alex Williamson) [2124620]
- vfio: Delete the unbound_list (Alex Williamson) [2124620]
- vfio: Remove use of vfio_group_viable() (Alex Williamson) [2124620]
- vfio: Set DMA ownership for VFIO devices (Alex Williamson) [2124620]
- PCI: portdrv: Set driver_managed_dma (Alex Williamson) [2124620]
- PCI: pci_stub: Set driver_managed_dma (Alex Williamson) [2124620]
- bus: platform,amba,fsl-mc,PCI: Add device DMA ownership management (Alex Williamson) [2124620]
- amba: Stop sharing platform_dma_configure() (Alex Williamson) [2124620]
- driver core: Add dma_cleanup callback in bus_type (Alex Williamson) [2124620]
- iommu: Add DMA ownership management interfaces (Alex Williamson) [2124620]
- vfio: Require that devices support DMA cache coherence (Alex Williamson) [2124620]
- iommu: Redefine IOMMU_CAP_CACHE_COHERENCY as the cap flag for IOMMU_CACHE (Alex Williamson) [2124620]
- vfio: Move the Intel no-snoop control off of IOMMU_CACHE (Alex Williamson) [2124620]
- iommu: Introduce the domain op enforce_cache_coherency() (Alex Williamson) [2124620]
- i915/gvt: Fix NULL pointer dereference in init_mmio_block_handlers (Alex Williamson) [2124620]
- drm/i915/gvt: Fix the compiling error when CONFIG_DRM_I915_DEBUG_RUNTIME_PM=n (Alex Williamson) [2124620]
- drm/i915/gvt: Make intel_gvt_match_device() static (Alex Williamson) [2124620]
- drm/i915/gvt: Add missing symbol export. (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev drvdata (Alex Williamson) [2124620]
- vfio/mdev: Use the driver core to create the 'remove' file (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev_parent_ops (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev_parent_ops dev_attr_groups (Alex Williamson) [2124620]
- vfio/mdev: Remove vfio_mdev.c (Alex Williamson) [2124620]
- drm/i915/gvt: merge gvt.c into kvmgvt.c (Alex Williamson) [2124620]
- drm/i915/gvt: convert to use vfio_register_emulated_iommu_dev (Alex Williamson) [2124620]
- drm/i915/gvt: remove kvmgt_guest_{init,exit} (Alex Williamson) [2124620]
- drm/i915/gvt: pass a struct intel_vgpu to the vfio read/write helpers (Alex Williamson) [2124620]
- drm/i915/gvt: streamline intel_vgpu_create (Alex Williamson) [2124620]
- drm/i915/gvt: remove the extra vfio_device refcounting for dmabufs (Alex Williamson) [2124620]
- drm/i915/gvt: remove struct intel_gvt_mpt (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize dma_pin_guest_page (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->dma_{,un}map_guest_page (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{enable,disable}_page_track (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->gfn_to_mfn (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->is_valid_gfn (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->inject_msi (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->detach_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->set_edid and ->set_opregion (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{get,put}_vfio_device (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{read,write}_gpa (Alex Williamson) [2124620]
- drm/i915/gvt: remove vgpu->handle (Alex Williamson) [2124620]
- drm/i915/gvt: merge struct kvmgt_guest_info into strut intel_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: merge struct kvmgt_vdev into struct intel_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: remove the unused from_virt_to_mfn op (Alex Williamson) [2124620]
- drm/i915/gvt: remove the map_gfn_to_mfn and set_trap_area ops (Alex Williamson) [2124620]
- drm/i915/gvt: remove intel_gvt_ops (Alex Williamson) [2124620]
- drm/i915/gvt: move the gvt code into kvmgt.ko (Alex Williamson) [2124620]
- drm/i915/gvt: rename intel_vgpu_ops to intel_vgpu_mdev_ops (Alex Williamson) [2124620]
- drm/i915/gvt: remove enum hypervisor_type (Alex Williamson) [2124620]
- drm/i915/gvt: remove module refcounting in intel_gvt_{,un}register_hypervisor (Alex Williamson) [2124620]
- drm/i915/gvt: better align the Makefile with i915 Makefile (Alex Williamson) [2124620]
- drm/i915/gvt: fix trace TRACE_INCLUDE_PATH (Alex Williamson) [2124620]
- i915/gvt: Use the initial HW state snapshot saved in i915 (Alex Williamson) [2124620]
- i915/gvt: Save the initial HW state snapshot in i915 (Alex Williamson) [2124620]
- i915/gvt: Separate the MMIO tracking table from GVT-g (Alex Williamson) [2124620]
- s390/vfio-ap: remove superfluous MODULE_DEVICE_TABLE declaration (Alex Williamson) [2124620]
- MAINTAINERS: update file path for S390 VFIO AP DRIVER (Alex Williamson) [2124620]
- vfio-ccw: step down as maintainer (Alex Williamson) [2124620]
- skmsg: Fix wrong last sg check in sk_msg_recvmsg() (Paolo Abeni) [2134161]
- skmsg: Schedule psock work if the cached skb exists on the psock (Paolo Abeni) [2134161]
- net: core: fix flow symmetric hash (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_somaxconn. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_unregister_timeout_secs. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_devconf_inherit_init_net. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_fb_tunnels_only_for_init_net. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_budget_usecs. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_budget. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_net_busy_read. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_net_busy_poll. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_tstamp_allow_data. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_optmem_max. (Paolo Abeni) [2134161]
- net: Fix data-races around netdev_tstamp_prequeue. (Paolo Abeni) [2134161]
- net: Fix data-races around netdev_max_backlog. (Paolo Abeni) [2134161]
- net: Fix data-races around weight_p and dev_weight_[rt]x_bias. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_[rw]mem_(max|default). (Paolo Abeni) [2134161]
- net: sched: fix misuse of qcpu->backlog in gnet_stats_add_queue_cpu (Paolo Abeni) [2134161]
- devlink: Fix use-after-free after a failed reload (Paolo Abeni) [2134161]
- skmsg: Fix invalid last sg check in sk_msg_recvmsg() (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_[rw]mem(_offset)?. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_mem. (Paolo Abeni) [2134161]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Al Stone) [2071841]
- perf/core: Add a new read format to get a number of lost samples (Al Stone) [2071841]
- drivers/perf: arm_pmu: Handle 47 bit counters (Al Stone) [2071841]
- mm: prevent page_frag_alloc() from corrupting the memory (Izabela Bakollari) [2104445]
- crypto: cryptd - Protect per-CPU resource by disabling BH. (Vladis Dronov) [2117509]
- RDMA: Handle the return code from dma_resv_wait_timeout() properly (Kamal Heib) [2120665]
- RDMA/irdma: Report RNR NAK generation in device caps (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Use s/g array in post send only when its valid (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Return correct WC error for bind operation failure (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Return error on MR deregister CQP failure (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Report the correct max cqes from query device (Kamal Heib) [2104474 2120665]
- IB/core: Fix a nested dead lock as part of ODP flow (Kamal Heib) [2120665]
- RDMA/siw: Pass a pointer to virt_to_page() (Kamal Heib) [2120665]
- RDMA/srp: Set scmnd->result only when scmnd is not NULL (Kamal Heib) [2120665]
- RDMA/cma: Fix arguments order in net device validation (Kamal Heib) [2120665]
- RDMA/irdma: Fix drain SQ hang with no completion (Kamal Heib) [2033131 2104474 2120665]
- IB/iser: Fix login with authentication (Kamal Heib) [2120665]
- RDMA/ib_srpt: Unify checking rdma_cm_id condition in srpt_cm_req_recv() (Kamal Heib) [2120665]
- RDMA/srpt: Fix a use-after-free (Kamal Heib) [2120665]
- RDMA/srpt: Introduce a reference count in struct srpt_device (Kamal Heib) [2120665]
- RDMA/srpt: Duplicate port name members (Kamal Heib) [2120665]
- RDMA: Fix comment typo (Kamal Heib) [2120665]
- IB: Fix repeated words 'the the' comments (Kamal Heib) [2120665]
- RDMA/hfi1: fix potential memory leak in setup_base_ctxt() (Kamal Heib) [2120665]
- RDMA/siw: Fix duplicated reported IW_CM_EVENT_CONNECT_REPLY event (Kamal Heib) [2120665]
- RDMA/hfi1: Depend on !UML (Kamal Heib) [2120665]
- RDMA/irdma: Use the bitmap API to allocate bitmaps (Kamal Heib) [2104474 2120665]
- RDMA: remove useless condition in siw_create_cq() (Kamal Heib) [2120665]
- RDMA/irdma: Fix setting of QP context err_rq_idx_valid field (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Fix VLAN connection with wildcard address (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Fix a window for use-after-free (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Make resource distribution algorithm more QP oriented (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Make CQP invalid state error non-critical (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Add AE source to error log (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Add 2 level PBLE support for FMR (Kamal Heib) [2104474 2120665]
- RDMA: Correct duplicated words in comments (Kamal Heib) [2120665]
- IB/iser: Drain the entire QP during destruction flow (Kamal Heib) [2120665]
- RDMA/usnic: Use device_iommu_capable() (Kamal Heib) [2120665]
- RDMA/core: Add a netevent notifier to cma (Kamal Heib) [2117911 2120665]
- RDMA/core: Add an rb_tree that stores cm_ids sorted by ifindex and remote IP (Kamal Heib) [2117911 2120665]
- RDMA/hfi1: Fix typo in comment (Kamal Heib) [2120665]
- RDMA/hfi1: Remove all traces of diagpkt support (Kamal Heib) [2120662]
- RDMA/hfi1: Consolidate software versions (Kamal Heib) [2120662]
- RDMA/hfi1: Remove pointless driver version (Kamal Heib) [2120662]
- RDMA/hfi1: Prevent panic when SDMA is disabled (Kamal Heib) [2120662]
- IB/core: Fix typo in comment (Kamal Heib) [2120662]
- RDMA/core: Fix typo in comment (Kamal Heib) [2120662]
- IB/hf1: Fix typo in comment (Kamal Heib) [2120662]
- IB/iser: Fix typo in comment (Kamal Heib) [2120662]
- IB/isert: Avoid flush_scheduled_work() usage (Kamal Heib) [2120662]
- RDMA/siw: Enable siw on tunnel devices (Kamal Heib) [2120662]
- RDMA/core: Avoid flush_workqueue(system_unbound_wq) usage (Kamal Heib) [2120662]
- RDMA/usnic: Refactor usnic_uiom_alloc_pd() (Kamal Heib) [2120662]
- RDMA/usnic: Stop using iommu_present() (Kamal Heib) [2120662]
- IB/SA: Replace usage of found with dedicated list iterator variable (Kamal Heib) [2120662]
- RDMA: Split kernel-only global device caps from uverbs device caps (Kamal Heib) [2120662]
- IB/rdmavt: add missing locks in rvt_ruc_loopback (Kamal Heib) [2120662]
- IB/uverbs: Move part of enum ib_device_cap_flags to uapi (Kamal Heib) [2120662]
- IB/uverbs: Move enum ib_raw_packet_caps to uapi (Kamal Heib) [2120662]
- RDMA: use dma_resv_wait() instead of extracting the fence (Kamal Heib) [2120662]
- RDMA/siw: make use of the helper function kthread_run_on_cpu() (Kamal Heib) [2120662]
- scsi: ib_srp: Call scsi_done() directly (Kamal Heib) [2120662]
- scsi: target: srpt: Replace enable attr with ops.enable (Kamal Heib) [2120662]
- scsi: RDMA/srp: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120662]
- scsi: RDMA/iser: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120662]
- scsi: iser: Use scsi_get_sector() instead of scsi_get_lba() (Kamal Heib) [2120662]
- EDAC/amd64: Add new register offset support and related changes (Aristeu Rozanski) [2048800]
- EDAC/amd64: Set memory type per DIMM (Aristeu Rozanski) [2048800]
- redhat/configs: enable UINPUT on aarch64 (Benjamin Tissoires) [2119170]
- exfat: use updated exfat_chain directly during renaming (Pavel Reichl) [2115894]
- exfat: fix i_blocks for files truncated over 4 GiB (Pavel Reichl) [2115894]
- exfat: fix incorrect loading of i_blocks for large files (Pavel Reichl) [2115894]
- exfat: fix referencing wrong parent directory information after renaming (Pavel Reichl) [2115894]
- exfat: check if cluster num is valid (Pavel Reichl) [2115894]
- exfat: simplify is_valid_cluster() (Pavel Reichl) [2115894]
- arm64: dts: imx8mm: Reverse CPLD_Dn GPIO label mapping on MX8Menlo (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix CAN STBY polarity (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix ksz9477 cpu port (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix port/phy validation (Al Stone) [2121508]
- arm64: dts: freescale: verdin-imx8mp: fix atmel_mxt_ts reset polarity (Al Stone) [2121508]
- arm64: dts: verdin-imx8mm: add otg2 pd to usbphy (Al Stone) [2121508]
- arm64: dts: freescale: verdin-imx8mm: fix atmel_mxt_ts reset polarity (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: extend pmic voltages (Al Stone) [2121508]
- arm64: dts: tqma8mqml: Include phy-imx8-pcie.h header (Al Stone) [2121508]
- arm64: dts: imx8mn: remove GPU power domain reset (Al Stone) [2121508]
- arm64: dts: imx8ulp: add #reset-cells for pcc (Al Stone) [2121508]
- dt-bindings: soc: imx8mp-media-blk-ctrl: Fix DT example (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix sai2 pin settings (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: use level interrupt for mcp251xfd (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update CAN clock to 40MHz (Al Stone) [2121508]
- arm64: dts: imx8m{m,p}-verdin: use IT temperatures (Al Stone) [2121508]
- arm64: dts: freescale: align gpio-key node names with dtschema (Al Stone) [2121508]
- arm64: dts: ls1028a-qds-65bb: don't use in-band autoneg for 2500base-x (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: Remove superfluous interrupt-names (Al Stone) [2121508]
- arm64: dts: ls1028a: Update SFP node to include clock (Al Stone) [2121508]
- arm64: dts: imx8mp-icore-mx8mp-edim2.2: correct pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct i2c2 & mmc settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct eqos pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct uart pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: correct pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C3 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C1 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C5 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct vbus pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct eqos pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct vbus pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct gpio-led pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct the uart2 pinctl value (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct mmc pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp: correct clock of pgc_ispdwp (Al Stone) [2121508]
- dt-bindings: tegra186-hsp: add type for shared mailboxes (Al Stone) [2121508]
- dt-bindings: mailbox: tegra: Document Tegra234 HSP (Al Stone) [2121508]
- dt-bindings: mailbox: tegra: Convert to json-schema (Al Stone) [2121508]
- arm64: dt: imx8mp: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mn: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mm: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mq: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: remove unnecessary cpu temp override (Al Stone) [2121508]
- arm64: dts: imx8m*venice: add missing clock-names to pcie_phy (Al Stone) [2121508]
- arm64: dts: freescale: reduce the interrup-map-mask (Al Stone) [2121508]
- arm64: dts: imx8mn-beacon: Enable RTS-CTS on UART3 (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable RTS-CTS on UART3 (Al Stone) [2121508]
- arm64: dts: imx8mm: Use 100 kHz I2C2 on Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mm: Disable USB2 OC on Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mm: Add CPLD on MX8Menlo board (Al Stone) [2121508]
- arm64: dts: imx8mq-kontron-pitx-imx8m: Use the standard 'uart-has-rtscts' (Al Stone) [2121508]
- arm64: dts: imx8mp-verdin: Use the standard 'uart-has-rtscts' (Al Stone) [2121508]
- arm64: dts: imx8mp: Add MEDIA_BLK_CTRL (Al Stone) [2121508]
- arm64: dts: imx8mp: Add MEDIAMIX power domains (Al Stone) [2121508]
- arm64: dts: imx8mp: add HSIO power-domains (Al Stone) [2121508]
- dt-bindings: power: imx8mp: add defines for HDMI blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: soc: Add i.MX8MP media block control DT bindings (Al Stone) [2121508]
- arm64: dts: imx8mp: Add Engicam i.Core MX8M Plus EDIMM2.2 Starter Kit (Al Stone) [2121508]
- arm64: dts: imx8mp: Add Engicam i.Core MX8M Plus SoM (Al Stone) [2121508]
- arm64: dts: freescale: update ifc node name to be memory-controller (Al Stone) [2121508]
- arm64: dts: remove "simple-bus" compatible from ifc node (Al Stone) [2121508]
- clk: imx8mp: add clkout1/2 support (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: Add UART3 support (Al Stone) [2121508]
- arm64: dts: imx8mn-ddr4-evk: Describe the 32.768 kHz PMIC clock (Al Stone) [2121508]
- arm64: dts: imx8mm: Add i.MX8M Mini Toradex Verdin based Menlo board (Al Stone) [2121508]
- dt-bindings: clock: gcc-msm8998: Add definitions of SSC-related clocks (Al Stone) [2121508]
- arm64: dts: imx: Add i.MX8M Plus Gateworks gw7400 dts support (Al Stone) [2121508]
- arm64: dts: imx8mm-evk: add pwm1/backlight support (Al Stone) [2121508]
- arm64: dts: imx8mn: add 8MNANOD3L-EVK device tree (Al Stone) [2121508]
- clk: imx8mp: Add DISP2 pixel clock (Al Stone) [2121508]
- arm64: dts: freescale: imx8q: add imx vpu codec entries (Al Stone) [2121508]
- arm64: dts: imx8mp: Enable HS400-ES (Al Stone) [2121508]
- arm64: dts: imx8mn: Enable HS400-ES (Al Stone) [2121508]
- dt-bindings: imx: add clock bindings for i.MX8MN GPT (Al Stone) [2121508]
- arm64: dts: freescale: add initial support for verdin imx8m plus (Al Stone) [2121508]
- arm64: dts: imx8mp: add uart2 dma (Al Stone) [2121508]
- arm64: dts: freescale: align SPI NOR node name with dtschema (Al Stone) [2121508]
- arm64: dts: imx8m: Pass a label to the soc node (Al Stone) [2121508]
- arm64: dts: fsl: adjust whitespace around '=' (Al Stone) [2121508]
- arm64: dts: lx2160a: Update can node property (Al Stone) [2121508]
- arm64: dts: ls1028a: default to OTG mode for USB (Al Stone) [2121508]
- arm64: dts: ls1028a: sl28: use ocelot-8021q tagging by default (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: add sd1 sleep pinctrl (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: note about disabled sd1 pull-ups (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: capitalisation of verdin comments (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: re-order pinctrl groups (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update iomux configuration (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: comment about i2c level shifter (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: only dashes in node names (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: alphabetically re-order nodes (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: multi-line comment style (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update regulator names (Al Stone) [2121508]
- arm64: dts: imx8mp: add ddr controller node to support EDAC on imx8mp (Al Stone) [2121508]
- arm64: dts: imx8mp: Add cpu-freq support (Al Stone) [2121508]
- arm64: dts: imx8mp: Add missing speed grade phandle (Al Stone) [2121508]
- ARM: dts: imx8mm-venice-gw{71xx,72xx,73xx}: fix OTG controller OC mode (Al Stone) [2121508]
- arm64: dts: imx8mn: Fix SAI nodes (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: change the spi-nor tx (Al Stone) [2121508]
- arm64: dts: imx8qm: Correct SCU clock controller's compatible property (Al Stone) [2121508]
- arm64: dts: imx8mp: add GPU nodes (Al Stone) [2121508]
- arm64: dts: imx8mp: add GPC node with GPU power domains (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: add QSPI flash (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5-r4: add the correct panel (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add a RO firmware partition (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: higher boost regulation current (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: remove description of CHG_STATUS_B (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: make the volume buttons a wakeup source (Al Stone) [2121508]
- arm64: dts: imx: Fix imx8*-var-som touchscreen property sizes (Al Stone) [2121508]
- arm64: dts: imx8mm-venice: fix spi2 pin configuration (Al Stone) [2121508]
- arm64: tegra: Add QSPI controllers on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add HDA device tree node for Tegra234 (Al Stone) [2121508]
- arm64: tegra: APE sound card for Jetson AGX Orin (Al Stone) [2121508]
- arm64: tegra: Add audio devices on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 IOMMUs (Al Stone) [2121508]
- arm64: tegra: Enable gpio-keys on Jetson AGX Orin Developer Kit (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 PWM devicetree nodes (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 I2C devicetree nodes (Al Stone) [2121508]
- arm64: tegra: Hook up MMC and BPMP to memory controller (Al Stone) [2121508]
- arm64: tegra: Add memory controller on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Describe Tegra234 CPU hierarchy (Al Stone) [2121508]
- arm64: tegra: Add main and AON GPIO controllers on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 TCU device (Al Stone) [2121508]
- arm64: tegra: Fill in properties for Tegra234 eMMC (Al Stone) [2121508]
- arm64: tegra: Update Tegra234 BPMP channel addresses (Al Stone) [2121508]
- arm64: tegra: Add clock for Tegra234 RTC (Al Stone) [2121508]
- arm64: tegra: Fixup SYSRAM references (Al Stone) [2121508]
- arm64: tegra: Remove unused only-1-8-v properties (Al Stone) [2121508]
- arm64: tegra: Add NVIDIA Jetson AGX Orin Developer Kit support (Al Stone) [2121508]
- arm64: dts: imx8mq: add hdmi phy 27m clock (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: fix the min/max voltages of the PMIC (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: use proper names for PMIC outputs (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: fix ethernet node name (Al Stone) [2121508]
- arm64: dts: imx8mm: Add support for Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mn-bsh-smm-s2pro: Add tlv320aic31xx audio card node (Al Stone) [2121508]
- arm64: dts: ls1046a: Update i2c node dma properties (Al Stone) [2121508]
- arm64: dts: ls1043a: Update i2c dma properties (Al Stone) [2121508]
- Revert "arm64: dts: freescale: Fix 'interrupt-map' parent address cells" (Al Stone) [2121508]
- arm64: dts: imx8mp: Add memory for USB3 glue layer to usb3 nodes (Al Stone) [2121508]
- arch: arm64: dts: lx2160a: describe the SerDes block #1 (Al Stone) [2121508]
- dt-bindings: clock: add i.MX93 clock definition (Al Stone) [2121508]
- dt-bindings: memory: Add Tegra234 PCIe memory (Al Stone) [2121508]
- dt-bindings: power: Add Tegra234 PCIe power domains (Al Stone) [2121508]
- dt-bindings: Add Tegra234 PCIe clocks and resets (Al Stone) [2121508]
- dt-bindings: Add HDA support for Tegra234 (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set usdhc root clock for eMMC (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: LDO5 needs to be enabled instead of LDO4 (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set VDD_ARM run and standby voltage (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Update WDOG muxing (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Reduce drive strength for fec tx lines (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Adapt eMMC drive strength (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set minimum output impedance for eth phy (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw72xx-0x: add dt overlay for imx219 rpi v2 camera (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw73xx-0x: add dt overlay for imx219 rpi v2 camera (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw72xx-0x: add dt overlays for serial modes (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw73xx-0x: add dt overlays for serial modes (Al Stone) [2121508]
- arm64: dts: imx: Add i.mx8mm Gateworks gw7903 dts support (Al Stone) [2121508]
- arm64: dts: ls1028a: add efuse node (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add support for I2C5 (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add PCA6416 gpio line names (Al Stone) [2121508]
- arm64: dts: imx8qm: added more serial alias to dts (Al Stone) [2121508]
- arm64: dts: imx8qm: add compatible string for usdhc3 (Al Stone) [2121508]
- dt-bindings: Add Tegra234 APE support (Al Stone) [2121508]
- dt-bindings: memory: tegra: Add Tegra234 support (Al Stone) [2121508]
- arm64: dts: imx8mm: Fix VPU Hanging (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: Add second PCIe port support (Al Stone) [2121508]
- dt-bindings: power: imx8mp: add defines for HSIO blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: power: add defines for i.MX8MP power domain (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable PCIe (Al Stone) [2121508]
- arm64: dts: freescale: add initial support for verdin imx8m mini (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add PCA6416 interrupt controller mode (Al Stone) [2121508]
- arm64: dts: freescale: Use overlay target for simplicity (Al Stone) [2121508]
- arm64: dts: fsl-ls1028a-qds: Drop overlay syntax hard coding (Al Stone) [2121508]
- arm64: dts: imx8mm: fix strange hex notation (Al Stone) [2121508]
- arm64: dts: imx8mm: Add support for emtrion emCON-MX8M Mini (Al Stone) [2121508]
- arm64: dts: tqma8mqml: add PCIe support (Al Stone) [2121508]
- arm64: dts: imx8mm: Enable Hantro G1 and G2 video decoders (Al Stone) [2121508]
- arm64: dts: imx8mq: Enable both G1 and G2 VPU's with vpu-blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: Remove redundant vpu reference (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: define mdio slots for networking options (Al Stone) [2121508]
- arm64: dts: imx8m{m,n}_venice*: add gpio-line-names (Al Stone) [2121508]
- arm64: dts: imx8m{m,n}-venice-*: add missing uart-has-rtscts property to UARTs (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7902: fix pcie bindings (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7902: add vdd_5p0 ADC channel (Al Stone) [2121508]
- arm64: dts: imx8mm: Add missing MX8MM_IOMUXC_NAND_READY_B_SD3_RESET_B (Al Stone) [2121508]
- arm64: dts: imx8mp: disable usb3_phy1 (Al Stone) [2121508]
- arm64: dts: imx8qxp-ss-adma: Drop fsl,imx7ulp-lpuart comaptible (Al Stone) [2121508]
- arm64: dts: imx8: add mu5/6 node (Al Stone) [2121508]
- arm64: dts: imx8qm: Add SCU RTC node (Al Stone) [2121508]
- arm64: dts: imx8mn-venice-gw7902: disable gpu (Al Stone) [2121508]
- arm64: dts: imx8mq: disable DDRC node by default (Al Stone) [2121508]
- arm64: dts: imx8qm: Drop CPU 'arm,armv8' compatible (Al Stone) [2121508]
- arm64: dts: imx8mm-venice*: add PCIe support (Al Stone) [2121508]
- arm64: dts: imx8mn: Enable GPU (Al Stone) [2121508]
- arm64: dts: imx8mn: add DISP blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mn: put USB controller into power-domains (Al Stone) [2121508]
- arm64: dts: imx8mn: add GPC node (Al Stone) [2121508]
- arm64: dts: imx8mm-evk: Add the pcie support on imx8mm evk board (Al Stone) [2121508]
- arm64: dts: imx8mm: Add the pcie support (Al Stone) [2121508]
- arm64: dts: imx8mm: Add the pcie phy support (Al Stone) [2121508]
- dt-bindings: power: imx8mq: add defines for VPU blk-ctrl domains (Al Stone) [2121508]
- Revert "arm64: dts: imx8mn-venice-gw7902: disable gpu" (Al Stone) [2121508]
- dt-bindings: Add headers for Tegra234 PWM (Al Stone) [2121508]
- dt-bindings: Add headers for Tegra234 I2C (Al Stone) [2121508]
- dt-bindings: imx: Add clock binding for i.MXRT1050 (Al Stone) [2121508]
- arm64: dts: imx8mq: fix lcdif port node (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: fix mipi_csi1 port number to sensor (Al Stone) [2121508]
- arm64: dts: imx8mq: fix mipi_csi bidirectional port numbers (Al Stone) [2121508]
- arm64: dts: ls1028a: sl28: re-enable ftm_alarm0 (Al Stone) [2121508]
- arm64: dts: freescale: Fix sound card model for MBa8Mx (Al Stone) [2121508]
- arm64: dts: imx8mn-venice-gw7902: disable gpu (Al Stone) [2121508]
- dt-bindings: power: imx8mn: add defines for DISP blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: memory: tegra: Update for Tegra194 (Al Stone) [2121508]
- dt-bindings: Update headers for Tegra234 (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: configure multiple queues on eqos (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: add overlays for various serdes protocols (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: enable lpuart1 (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: move rtc node to the correct i2c bus (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: enable pwm0 (Al Stone) [2121508]
- arm64: dts: ls1028a: add flextimer based pwm nodes (Al Stone) [2121508]
- arm64: dts: ls1028a: add ftm_alarm1 node to be used as wakeup source (Al Stone) [2121508]
- arm64: dts: ls1028a: Add PCIe EP nodes (Al Stone) [2121508]
- arm64: dts: lx2162a-qds: add interrupt line for RTC node (Al Stone) [2121508]
- arm64: dts: lx2162a-qds: support SD UHS-I and eMMC HS400 modes (Al Stone) [2121508]
- arm64: dts: lx2160a: enable usb3-lpm-capable for usb3 nodes (Al Stone) [2121508]
- arm64: dts: lx2160a-qds: Add mdio mux nodes (Al Stone) [2121508]
- arm64: dts: lx2160a: add optee-tz node (Al Stone) [2121508]
- arm64: dts: lx2160a-rdb: Add Inphi PHY node (Al Stone) [2121508]
- arm64: dts: lx2160a: fix scl-gpios property name (Al Stone) [2121508]
- arm64: dts: imx8mm: don't assign PLL2 in SoC dtsi (Al Stone) [2121508]
- dt-bindings: phy: phy-imx8-pcie: Add binding for the pad modes of imx8 pcie phy (Al Stone) [2121508]
- arm64: dts: imx8mn-bsh-smm-s2/pro: Add iMX8MN BSH SMM S2 boards (Al Stone) [2121508]
- arm64: dts: imx8mm/n: Remove the 'pm-ignore-notify' property (Al Stone) [2121508]
- dt-bindings: power: imx8ulp: add power domain header file (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: link regulator to VPU domain (Al Stone) [2121508]
- arm64: dts: ls1088a: add snps incr burst type adjustment for usb1 (Al Stone) [2121508]
- arm64: dts: ls1088a: Add reboot nodes (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: update copyright (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: add aliases for the Ethernet ports (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: add an alias for the FlexSPI controller (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: sort nodes alphabetically by label (Al Stone) [2121508]
- arm64: dts: imx8mp: add mac address for EQOS (Al Stone) [2121508]
- arm64: dts: imx8m: remove unused "nvmem_macaddr_swap" property for FEC (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: disable CLKOUT clock for ENET PHY (Al Stone) [2121508]
- arm64: dts: imx8m: configure FEC PHY VDDIO voltage (Al Stone) [2121508]
- arm64: dts: imx8m: disable smart eee for FEC PHY (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add hardware reset for EQOS PHY (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: add hardware reset for FEC PHY (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8Mx with i.MX8M (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8MQNL with i.MX8MN (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8MQML with i.MX8MM (Al Stone) [2121508]
- arm64: dts: imx8ulp: address build warning (Al Stone) [2121508]
- arm64: dts: imx8ulp: Set #thermal-sensor-cells to 1 as required (Al Stone) [2121508]
- arm64: dts: imx8ulp: add power domain entry for usdhc (Al Stone) [2121508]
- arm64: dts: imx8ulp: add scmi firmware node (Al Stone) [2121508]
- arm64: dts: imx8ulp: Add the basic dtsi file for imx8ulp (Al Stone) [2121508]
- arm64: dts: imx8ulp: Add the basic dts for imx8ulp evk board (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable OV5640 Camera (Al Stone) [2121508]
- arm64: dts: imx8mm: Add CSI nodes (Al Stone) [2121508]
- arm64: dts: imx8mq: fix the schema check errors for fsl,tmu-calibration (Al Stone) [2121508]
- arm64: dts: lx2162a: Add CAN nodes for LX2162A-QDS (Al Stone) [2121508]
- arm64: dts: imx8mq: remove interconnect property from lcdif (Al Stone) [2121508]
- arm64: dts: ten64: remove redundant interrupt declaration for gpio-keys (Al Stone) [2121508]
- arm64: dts: imx8qxp: add cache info (Al Stone) [2121508]
- arm64: dts: imx8qm: add cache info (Al Stone) [2121508]
- arm64: dts: imx8m: add cache info (Al Stone) [2121508]
- clk: imx8mp: Remove IPG_AUDIO_ROOT from imx8mp-clock.h (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5-r3.dtsi: describe selfie cam XSHUTDOWN pin (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: describe the selfie cam (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: describe power supply for cameras (Al Stone) [2121508]
- arm64: dts: split out a shared imx8mq-librem5-r3.dtsi description (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable USB Controllers (Al Stone) [2121508]
- arm64: dts: fsl-ls1043a-rdb: add delay between CS and CLK signal for flash device (Al Stone) [2121508]
- arm64: dts: lx2160abluebox3: update RGMII delays for sja1105 switch (Al Stone) [2121508]
- arm64: dts: imx: imx8mn-beacon: Drop undocumented clock-names reference (Al Stone) [2121508]
- arm64: dts: mnt-reform2: correct i2c3 pad-ctrl (Al Stone) [2121508]
- arm64: dts: mnt-reform2: add internal display support (Al Stone) [2121508]
- arm64: dts: freescale: add 'chassis-type' property (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix connection type for VSC8531 RGMII PHY (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix CAN SPI clock frequency (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix polarity of reg_rst_eth2 (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Set lower limit of VDD_SNVS to 800 mV (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Make sure SOC and DRAM supply voltages are correct (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Add support for ultra high speed modes on SD card (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901.dts: disable pgc_gpumix (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: set debounce interval of volume buttons to 50ms (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: Limit the max sdio frequency (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add power sequencing for M.2 cards (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: delay the startup of the SDIO (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: wire up the wifi regulator (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: Fix led_r and led_g pinctrl assignments (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add reset gpio to mantix panel description (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix reset delays for ethernet PHY (Al Stone) [2121508]
- arm64: dts: imx8mm: add DISP blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mm: add VPU blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mm: Add GPU nodes for 2D and 3D core (Al Stone) [2121508]
- arm64: dts: imx8mm: put USB controllers into power-domains (Al Stone) [2121508]
- arm64: dts: imx8mm: add GPC node (Al Stone) [2121508]
- dt-bindings: power: imx8mm: add defines for DISP blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: power: imx8mm: add defines for VPU blk-ctrl domains (Al Stone) [2121508]
- arm64: dts: imx8m*-venice-gw7902: fix M2_RST# gpio (Al Stone) [2121508]
- arm64: dts: ls1028a: mark internal links between Felix and ENETC as capable of flow control (Al Stone) [2121508]
- arm64: dts: freescale: Fix 'interrupt-map' parent address cells (Al Stone) [2121508]
- arm64: dts: ls1028a: use phy-mode instead of phy-connection-type (Al Stone) [2121508]
- arm64: dts: ls1028a: move PHY nodes to MDIO controller (Al Stone) [2121508]
- arm64: dts: ls1028a: disable usb controller by default (Al Stone) [2121508]
- arm64: dts: ls1028a: add Vivante GPU node (Al Stone) [2121508]
- arm64: dts: ls1028a: move Mali DP500 node into /soc (Al Stone) [2121508]
- arm64: dts: ls1028a: move pixel clock pll into /soc (Al Stone) [2121508]
- arm64: dts: ls1028a: fix eSDHC2 node (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron-n801x-som: do not allow to switch off buck2 (Al Stone) [2121508]
- arm64: dts: s32g2: add memory nodes for evb and rdb2 (Al Stone) [2121508]
- arm64: dts: s32g2: add VNP-EVB and VNP-RDB2 support (Al Stone) [2121508]
- arm64: dts: add device tree for the LX2160A on the NXP BlueBox3 board (Al Stone) [2121508]
- arm64: dts: imx8: change the spi-nor tx (Al Stone) [2121508]
- dt-bindings: clock: Add imx8ulp clock support (Al Stone) [2121508]
- arm64: dts: ls1012a: Add serial alias for ls1012a-rdb (Al Stone) [2121508]
- arm64: dts: imx8mp: Reorder flexspi clock-names entry (Al Stone) [2121508]
- arm64: dts: imx8mq: fix the schema check errors (Al Stone) [2121508]
- arm64: dts: freescale: fix arm,sp805 compatible string (Al Stone) [2121508]
- arm64: dts: zii-ultra: add PCIe PHY supply (Al Stone) [2121508]
- arm64: dts: freescale: imx8mq-librem5: align operating-points table name with dtschema (Al Stone) [2121508]
- arm64: dts: imx8mm-venice: Fix the SPI chipselect polarity (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron-n801x-som: Fix the SPI chipselect polarity (Al Stone) [2121508]
- clk: imx8mn: Add M7 core clock (Al Stone) [2121508]
- arm64: dts: add device tree for Traverse Ten64 (LS1088A) (Al Stone) [2121508]
- arm64: dts: ls1088a: add missing PMU node (Al Stone) [2121508]
- arm64: dts: ls1088a: add internal PCS for DPMAC1 node (Al Stone) [2121508]
- arm64: dts: imx8m: drop interrupt-affinity for pmu (Al Stone) [2121508]
- arm64: dts: imx8qxp: update pmu compatible (Al Stone) [2121508]
- arm64: dts: imx8mm: update pmu compatible (Al Stone) [2121508]
- arm64: dts: ls1046a: fix eeprom entries (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: enable pull-down on gpio outputs (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: add support for USB hub subload (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw71xx: fix USB OTG VBUS (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw700x: fix invalid pmic pin config (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw700x: fix mp5416 pmic config (Al Stone) [2121508]
- arm64: dts: imx8mq: add mipi csi phy and csi bridge descriptions (Al Stone) [2121508]
- arm64: dts: imx: Add i.mx8mm/imx8mn Gateworks gw7902 dts support (Al Stone) [2121508]
- arm64: dts: imx8mp: Add dsp node (Al Stone) [2121508]
- arm64: dts: imx8m: Replace deprecated fsl,usbphy DT props with phys (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: Remove unnecessary blank lines (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: add CD pinctrl for usdhc2 (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: Remove unnecessary #address-cells/#size-cells (Al Stone) [2121508]
- arm64: dts: imx8: Add jpeg encoder/decoder nodes (Al Stone) [2121508]
- arm64: dts: imx8qxp-ai_ml: Fix checkpatch warnings (Al Stone) [2121508]
- arm64: dts: ls1088ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: ls2088ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: lx2160ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: imx8qxp: add "fsl,imx8qm-fec" compatible string for FEC (Al Stone) [2121508]
- arm64: dts: imx8m: add "fsl,imx8mq-fec" compatible string for FEC (Al Stone) [2121508]
- arm64: dts: imx8mq-reform2: add uSDHC2 CD pinctrl (Al Stone) [2121508]
- arm64: dts: imx8mq-reform2: add sound support (Al Stone) [2121508]
- arm64: dts: imx8mq: add support for MNT Reform2 (Al Stone) [2121508]
- arm64: dts: nitrogen8-som: correct i2c1 pad-ctrl (Al Stone) [2121508]
- arm64: dts: nitrogen8-som: correct network PHY reset (Al Stone) [2121508]
- arm64: dts: imx8mq: add Nitrogen8 SoM (Al Stone) [2121508]
- ACPI: processor idle: Practically limit "Dummy wait" workaround to old Intel systems (Wei Huang) [2130652]

* Mon Oct 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-177.el9]
- cpufreq: intel_pstate: Support Sapphire Rapids OOB mode (David Arcari) [2117768]
- watchdog: sbsa: only use 32-bit accessors (Mark Salter) [2046672]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [2117770]
- tools/power turbostat: version 2022.07.28 (David Arcari) [2117770]
- tools/power turbostat: do not decode ACC for ICX and SPR (David Arcari) [2117770]
- tools/power turbostat: fix SPR PC6 limits (David Arcari) [2117770]
- tools/power turbostat: cleanup 'automatic_cstate_conversion_probe()' (David Arcari) [2117770]
- tools/power turbostat: separate SPR from ICX (David Arcari) [2117770]
- tools/power turbosstat: fix comment (David Arcari) [2117770]
- tools/power turbostat: Support RAPTORLAKE P (David Arcari) [2117770]
- tools/power turbostat: add support for ALDERLAKE_N (David Arcari) [2117770]
- tools/power turbostat: dump secondary Turbo-Ratio-Limit (David Arcari) [2117770]
- tools/power turbostat: simplify dump_turbo_ratio_limits() (David Arcari) [2117770]
- tools/power turbostat: dump CPUID.7.EDX.Hybrid (David Arcari) [2117770]
- tools/power turbostat: Show uncore frequency (David Arcari) [2117770]
- tools/power turbostat: Fix file pointer leak (David Arcari) [2117770]
- tools/power turbostat: replace strncmp with single character compare (David Arcari) [2117770]
- tools/power turbostat: print the kernel boot commandline (David Arcari) [2117770]
- tools/power turbostat: Introduce support for RaptorLake (David Arcari) [2117770]
- tools/power turbostat: version 2022.04.16 (David Arcari) [2117770]
- tools/power turbostat: No build warnings with -Wextra (David Arcari) [2117770]
- tools/power turbostat: be more useful as non-root (David Arcari) [2117770]
- tools/power turbostat: fix ICX DRAM power numbers (David Arcari) [2117770]
- tools/power turbostat: Support thermal throttle count print (David Arcari) [2117770]
- tools/power turbostat: Allow printing header every N iterations (David Arcari) [2117770]
- tools/power turbostat: Allow -e for all names. (David Arcari) [2117770]
- tools/power turbostat: print power values upto three decimal (David Arcari) [2117770]
- tools/power turbostat: Add Power Limit4 support (David Arcari) [2117770]
- tools/power turbostat: fix dump for AMD cpus (David Arcari) [2117770]
- tools/power turbostat: tweak --show and --hide capability (David Arcari) [2117770]
- crypto: ecdh - disallow plain "ecdh" usage in FIPS mode (Vladis Dronov) [2126683]
- crypto: dh - disallow plain "dh" usage in FIPS mode (Vladis Dronov) [2126683]

* Wed Oct 12 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-176.el9]
- docs: translations: zn_CN: irq-affinity.rst: add a missing extension (David Arcari) [2117494]
- docs/zh_CN: core-api: Update the translation of printk-basics.rst to 5.19-rc3 (David Arcari) [2117494]
- docs/zh_CN: Modify the translator tag and fix the wrong word (David Arcari) [2117494]
- MIPS/asm/printk: Fix build failure caused by printk (David Arcari) [2117494]
- printk: do not wait for consoles when suspended (David Arcari) [2117494]
- Revert "printk: add functions to prefer direct printing" (David Arcari) [2117494]
- Revert "printk: add kthread console printers" (David Arcari) [2117494]
- Revert "printk: extend console_lock for per-console locking" (David Arcari) [2117494]
- Revert "printk: remove @console_locked" (David Arcari) [2117494]
- Revert "printk: Block console kthreads when direct printing will be required" (David Arcari) [2117494]
- Revert "printk: Wait for the global console lock when the system is going down" (David Arcari) [2117494]
- printk: Wait for the global console lock when the system is going down (David Arcari) [2117494]
- printk: Block console kthreads when direct printing will be required (David Arcari) [2117494]
- Revert "printk: wake up all waiters" (David Arcari) [2117494]
- printk, tracing: fix console tracepoint (David Arcari) [2117494]
- printk: remove @console_locked (David Arcari) [2117494]
- printk: extend console_lock for per-console locking (David Arcari) [2117494]
- printk: add kthread console printers (David Arcari) [2117494]
- printk: add functions to prefer direct printing (David Arcari) [2117494]
- printk: add pr_flush() (David Arcari) [2117494]
- printk: move buffer definitions into console_emit_next_record() caller (David Arcari) [2117494]
- printk: refactor and rework printing logic (David Arcari) [2117494]
- serial: core: Fix initializing and restoring termios speed (David Arcari) [2117494]
- printk: add con_printk() macro for console details (David Arcari) [2117494]
- printk: call boot_delay_msec() in printk_delay() (David Arcari) [2117494]
- printk: get caller_id/timestamp after migration disable (David Arcari) [2117494]
- printk: wake waiters for safe and NMI contexts (David Arcari) [2117494]
- printk: wake up all waiters (David Arcari) [2117494]
- printk: add missing memory barrier to wake_up_klogd() (David Arcari) [2117494]
- printk: rename cpulock functions (David Arcari) [2117494]
- printk: fix return value of printk.devkmsg __setup handler (David Arcari) [2117494]
- printk: make suppress_panic_printk static (David Arcari) [2117494]
- printk: Set console_set_on_cmdline=1 when __add_preferred_console() is called with user_specified == true (David Arcari) [2117494]
- printk: Drop console_sem during panic (David Arcari) [2117494]
- printk: Avoid livelock with heavy printk during panic (David Arcari) [2117494]
- printk: disable optimistic spin during panic (David Arcari) [2117494]
- printk: Add panic_in_progress helper (David Arcari) [2117494]
- printk: Fix incorrect __user type in proc_dointvec_minmax_sysadmin() (David Arcari) [2117494]
- printk: ringbuffer: Improve prb_next_seq() performance (David Arcari) [2117494]
- printk: fix build warning when CONFIG_PRINTK=n (David Arcari) [2117494]
- printk: move printk sysctl to printk/sysctl.c (David Arcari) [2117494]
- printk/console: Clean up boot console handling in register_console() (David Arcari) [2117494]
- printk/console: Remove need_default_console variable (David Arcari) [2117494]
- printk/console: Remove unnecessary need_default_console manipulation (David Arcari) [2117494]
- printk/console: Rename has_preferred_console to need_default_console (David Arcari) [2117494]
- printk/console: Split out code that enables default console (David Arcari) [2117494]
- printk: use gnu_printf format attribute for printk_sprint() (David Arcari) [2117494]
- printk: avoid -Wsometimes-uninitialized warning (David Arcari) [2117494]
- printk: use kvmalloc instead of kmalloc for devkmsg_user (David Arcari) [2117494]
- printk/index: Fix -Wunused-function warning (David Arcari) [2117494]
- printk: Add printk.console_no_auto_verbose boot parameter (David Arcari) [2117494]
- printk: Move the printk() kerneldoc comment to its new home (David Arcari) [2117494]
- printk/index: Fix warning about missing prototypes (David Arcari) [2117494]
- redhat/configs: enable CONFIG_PRINTK_INDEX (David Arcari) [2117494]
- printk: Userspace format indexing support (David Arcari) [2117494]
- printk: Rework parse_prefix into printk_parse_prefix (David Arcari) [2117494]
- printk: Straighten out log_flags into printk_info_flags (David Arcari) [2117494]
- printk/console: Check consistent sequence number when handling race in console_unlock() (David Arcari) [2117494]
- serial/8250: Use fifo in 8250 console driver (David Arcari) [2117494]
- serial: 8250_omap: Handle optional overrun-throttle-ms property (David Arcari) [2117494]
- serial: omap: Disable PM runtime autoidle to remove pm_runtime_irq_safe() (David Arcari) [2117494]
- rhel: Enable imx8 pinctrl devices (Al Stone) [2071845]
- pinctrl: Don't allow PINCTRL_AMD to be a module (Al Stone) [2071845]
- pinctrl: imx: Add the zero base flag for imx93 (Al Stone) [2071845]
- pinctrl: intel: Fix kernel doc format, i.e. add return sections (Al Stone) [2071845]
- pinctrl: freescale: Add i.MXRT1170 pinctrl driver support (Al Stone) [2071845]
- pinctrl: intel: Drop unused irqchip member in struct intel_pinctrl (Al Stone) [2071845]
- pinctrl: intel: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: cherryview: Use GPIO chip pointer in chv_gpio_irq_mask_unmask() (Al Stone) [2071845]
- pinctrl: lynxpoint: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: cherryview: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: baytrail: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: broxton: Add module alias for Intel Apollo Lake (Al Stone) [2071845]
- pinctrl: tegra: tegra194: drop unused pin groups (Al Stone) [2071845]
- pinctrl: thunderbay: Use devm_platform_ioremap_resource() (Al Stone) [2071845]
- pinctrl: amd: Make the irqchip immutable (Al Stone) [2071845]
- pinctrl: imx: Reduce printk message level for empty nodes (Al Stone) [2071845]
- pinctrl: pinconf-generic: Print arguments for bias-pull-* (Al Stone) [2071845]
- pinctrl: imx93: Add pinctrl driver support (Al Stone) [2071845]
- pinctrl: baytrail: Add pinconf group + function for the pmu_clk (Al Stone) [2071845]
- pinctrl: icelake: Add Ice Lake-N PCH pin controller support (Al Stone) [2071845]
- pinctrl: baytrail: Clear direct_irq_en flag on broken configs (Al Stone) [2071845]
- pinctrl: cherryview: Trigger hwirq0 for interrupt-lines without a mapping (Al Stone) [2071845]
- pinctrl: thunderbay: rework loops looking for groups names (Al Stone) [2071845]
- pinctrl: thunderbay: comment process of building functions a bit (Al Stone) [2071845]
- pinctrl: imx: fix assigning groups names (Al Stone) [2071845]
- pinctrl: imx: fix allocation result check (Al Stone) [2071845]
- pinctrl: add one more "const" for generic function groups (Al Stone) [2071845]
- pinctrl: keembay: rework loops looking for groups names (Al Stone) [2071845]
- pinctrl: keembay: comment process of building functions a bit (Al Stone) [2071845]
- pinctrl: imx: prepare for making "group_names" in "function_desc" const (Al Stone) [2071845]
- pinctrl: Add Intel Thunder Bay pinctrl driver (Al Stone) [2071845]
- pinctrl: freescale: Add i.MXRT1050 pinctrl driver support (Al Stone) [2071845]
- pinctrl: cherryview: Use temporary variable for struct device (Al Stone) [2071845]
- pinctrl: cherryview: Do not allow the same interrupt line to be used by 2 pins (Al Stone) [2071845]
- pinctrl: cherryview: Don't use selection 0 to mark an interrupt line as unused (Al Stone) [2071845]
- pinctrl: baytrail: Set IRQCHIP_SET_TYPE_MASKED flag on the irqchip (Al Stone) [2071845]
- pinctrl: tegra194: remove duplicate initializer again (Al Stone) [2071845]
- pinctrl: tegra: Return const pointer from tegra_pinctrl_get_group() (Al Stone) [2071845]
- pinctrl: pinconf-generic: Add support for "output-impedance-ohms" to be extracted from DT files (Al Stone) [2071845]
- pinctrl: tegra: Fix warnings and error (Al Stone) [2071845]
- pinctrl: tegra: Use correct offset for pin group (Al Stone) [2071845]
- pinctrl: core: fix possible memory leak in pinctrl_enable() (Al Stone) [2071845]
- pinctrl: tegra: Add pinmux support for Tegra194 (Al Stone) [2071845]
- pinctrl: tegra: include lpdr pin properties (Al Stone) [2071845]
- pinctrl: amd: disable and mask interrupts on probe (Al Stone) [2071845]
- pinctrl: Fix spelling mistake "atleast" -> "at least" (Al Stone) [2071845]
- pinctrl: core: Remove duplicated word from devm_pinctrl_unregister() (Al Stone) [2071845]
- pinctrl: Add Intel Keem Bay pinctrl driver (Al Stone) [2071845]
- pinctrl: single: Move test PCS_HAS_PINCONF in pcs_parse_bits_in_pinctrl_entry() to the beginning (Al Stone) [2071845]
- pinctrl: single: Fix error return code in pcs_parse_bits_in_pinctrl_entry() (Al Stone) [2071845]
- pinctrl: imx8dxl: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8qxp: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8mn: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8ulp: Initialize pin_reg (Al Stone) [2071845]
- pinctrl: imx8ulp: Add pinctrl driver support (Al Stone) [2071845]
- inotify: show inotify mask flags in proc fdinfo (Andrey Albershteyn) [2125133]
- fsnotify: fix fsnotify hooks in pseudo filesystems (Andrey Albershteyn) [2090079]
- fsnotify: invalidate dcache before IN_DELETE event (Andrey Albershteyn) [2090079]
- scsi: target: core: De-RCU of se_lun and se_lun acl (Maurizio Lombardi) [2129900]
- scsi: target: core: Fix race during ACL removal (Maurizio Lombardi) [2129900]
- scsi: target: Remove XDWRITEREAD emulated support (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Do not require target authentication (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Allow AuthMethod=None (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Support base64 in CHAP (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Add support for extended CDB AHS (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Fix clang -Wformat warnings (Maurizio Lombardi) [2129900]
- scsi: target: Detect UNMAP support post configuration (Maurizio Lombardi) [2129900]
- scsi: target: Add file configure_unmap callout (Maurizio Lombardi) [2129900]
- scsi: target: Add iblock configure_unmap callout (Maurizio Lombardi) [2129900]
- scsi: target: Add callout to configure UNMAP settings (Maurizio Lombardi) [2129900]
- scsi: target: Remove incorrect zero blocks WRITE_SAME check (Maurizio Lombardi) [2129900]
- scsi: target: Remove duplicate "the" (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Fix NULL pointer dereference in iscsi_conn_auth_required() (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Control authentication per ACL (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Extract auth functions (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Add upcast helpers (Maurizio Lombardi) [2129900]
- scsi: target: Fix WRITE_SAME No Data Buffer crash (Maurizio Lombardi) [2129900]
- scsi: target: tcmu: Avoid holding XArray lock when calling lock_page (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_session to iscsit_session (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_conn to iscsit_conn (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_cmd to iscsit_cmd (Maurizio Lombardi) [2129900]
- scsi: target: tcmu: Fix possible data corruption (Maurizio Lombardi) [2129900]
- scsi: target: core: Silence the message about unknown VPD pages (Maurizio Lombardi) [2129900]
- scsi: target: Fix incorrect use of cpumask_t (Maurizio Lombardi) [2129900]
- scsi: target: Add iscsi/cpus_allowed_list in configfs (Maurizio Lombardi) [2129900]
- random: trigger reseeding DRBG on more occasions (Daiki Ueno) [2131988]

* Tue Oct 11 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-175.el9]
- x86,config: Enable straight-line-speculation fix (Wander Lairson Costa) [2062177] {CVE-2021-26341}
- nvme-rdma: handle number of queue changes (John Meneghini) [2112025]
- nvme-tcp: handle number of queue changes (John Meneghini) [2112025]
- nvmet: expose max queues to configfs (John Meneghini) [2112025]
- nvme-fabrics: parse nvme connect Linux error codes (John Meneghini) [2112025]
- xfs: flush inode gc workqueue before clearing agi bucket (Brian Foster) [2083143]
- xfs: use invalidate_lock to check the state of mmap_lock (Brian Foster) [2083143]
- xfs: introduce xfs_inodegc_push() (Brian Foster) [2083143]
- xfs: bound maximum wait time for inodegc work (Brian Foster) [2083143]
- xfs: flush inodegc workqueue tasks before cancel (Brian Foster) [2083143]
- xfs: xfs_is_shutdown vs xlog_is_shutdown cage fight (Brian Foster) [2083143]
- xfs: log items should have a xlog pointer, not a mount (Brian Foster) [2083143]
- xfs: async CIL flushes need pending pushes to be made stable (Brian Foster) [2083143]
- xfs: run callbacks before waking waiters in xlog_state_shutdown_callbacks (Brian Foster) [2083143]
- xfs: remove xfs_inew_wait (Brian Foster) [2083143]
- xfs: factor out a xfs_buftarg_is_dax helper (Brian Foster) [2083143]
- xfs: only set IOMAP_F_SHARED when providing a srcmap to a write (Brian Foster) [2083143]
- xfs: fix perag structure refcounting error when scrub fails (Brian Foster) [2083143]
- xfs: rename buffer cache index variable b_bn (Brian Foster) [2083143]
- xfs: convert bp->b_bn references to xfs_buf_daddr() (Brian Foster) [2083143]
- xfs: introduce xfs_buf_daddr() (Brian Foster) [2083143]
- xfs: kill xfs_sb_version_has_v3inode() (Brian Foster) [2083143]
- xfs: introduce xfs_sb_is_v5 helper (Brian Foster) [2083143]
- xfs: remove unused xfs_sb_version_has wrappers (Brian Foster) [2083143]
- xfs: convert xfs_sb_version_has checks to use mount features (Brian Foster) [2083143]
- xfs: convert scrub to use mount-based feature checks (Brian Foster) [2083143]
- xfs: open code sb verifier feature checks (Brian Foster) [2083143]
- xfs: convert xfs_fs_geometry to use mount feature checks (Brian Foster) [2083143]
- xfs: replace XFS_FORCED_SHUTDOWN with xfs_is_shutdown (Brian Foster) [2083143]
- xfs: convert remaining mount flags to state flags (Brian Foster) [2083143]
- xfs: convert mount flags to features (Brian Foster) [2083143]
- xfs: consolidate mount option features in m_features (Brian Foster) [2083143]
- xfs: replace xfs_sb_version checks with feature flag checks (Brian Foster) [2083143]
- xfs: reflect sb features in xfs_mount (Brian Foster) [2083143]
- xfs: rework attr2 feature and mount options (Brian Foster) [2083143]
- xfs: rename xfs_has_attr() (Brian Foster) [2083143]
- xfs: sb verifier doesn't handle uncached sb buffer (Brian Foster) [2083143]
- xfs: start documenting common units and tags used in tracepoints (Brian Foster) [2083143]
- xfs: decode scrub flags in ftrace output (Brian Foster) [2083143]
- xfs: standardize inode generation formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize remaining xfs_buf length tracepoints (Brian Foster) [2083143]
- xfs: resolve fork names in trace output (Brian Foster) [2083143]
- xfs: rename i_disk_size fields in ftrace output (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "count" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "len" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "offset" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "blkno", "block", or "bno" (Brian Foster) [2083143]
- xfs: standardize daddr formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize rmap owner number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize AG block number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize AG number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize inode number formatting in ftrace output (Brian Foster) [2083143]
- xfs: remove support for untagged lookups in xfs_icwalk* (Brian Foster) [2083143]
- xfs: constify btree function parameters that are not modified (Brian Foster) [2083143]
- xfs: make the start pointer passed to btree update_lastrec functions const (Brian Foster) [2083143]
- xfs: make the start pointer passed to btree alloc_block functions const (Brian Foster) [2083143]
- xfs: make the pointer passed to btree set_root functions const (Brian Foster) [2083143]
- xfs: mark the record passed into xchk_btree functions as const (Brian Foster) [2083143]
- xfs: make the keys and records passed to btree inorder functions const (Brian Foster) [2083143]
- xfs: mark the record passed into btree init_key functions as const (Brian Foster) [2083143]
- xfs: make the record pointer passed to query_range functions const (Brian Foster) [2083143]
- xfs: make the key parameters to all btree query range functions const (Brian Foster) [2083143]
- xfs: make the key parameters to all btree key comparison functions const (Brian Foster) [2083143]
- xfs: add trace point for fs shutdown (Brian Foster) [2083143]
- xfs: remove unnecessary agno variable from struct xchk_ag (Brian Foster) [2083143]
- xfs: make fsmap backend function key parameters const (Brian Foster) [2083143]
- xfs: fix off-by-one error when the last rt extent is in use (Brian Foster) [2083143]
- xfs: make xfs_rtalloc_query_range input parameters const (Brian Foster) [2083143]
- xfs: drop ->writepage completely (Brian Foster) [2083143]
- xfs: move the CIL workqueue to the CIL (Brian Foster) [2083143]
- xfs: CIL work is serialised, not pipelined (Brian Foster) [2083143]
- xfs: AIL needs asynchronous CIL forcing (Brian Foster) [2083143]
- xfs: order CIL checkpoint start records (Brian Foster) [2083143]
- xfs: attach iclog callbacks in xlog_cil_set_ctx_write_state() (Brian Foster) [2083143]
- xfs: factor out log write ordering from xlog_cil_push_work() (Brian Foster) [2083143]
- xfs: pass a CIL context to xlog_write() (Brian Foster) [2083143]
- xfs: move xlog_commit_record to xfs_log_cil.c (Brian Foster) [2083143]
- xfs: log head and tail aren't reliable during shutdown (Brian Foster) [2083143]
- xfs: don't run shutdown callbacks on active iclogs (Brian Foster) [2083143]
- xfs: separate out log shutdown callback processing (Brian Foster) [2083143]
- xfs: rework xlog_state_do_callback() (Brian Foster) [2083143]
- xfs: make forced shutdown processing atomic (Brian Foster) [2083143]
- xfs: convert log flags to an operational state field (Brian Foster) [2083143]
- xfs: move recovery needed state updates to xfs_log_mount_finish (Brian Foster) [2083143]
- xfs: XLOG_STATE_IOERROR must die (Brian Foster) [2083143]
- xfs: convert XLOG_FORCED_SHUTDOWN() to xlog_is_shutdown() (Brian Foster) [2083143]
- xfs: cleanup __FUNCTION__ usage (Brian Foster) [2083143]
- xfs: Rename __xfs_attr_rmtval_remove (Brian Foster) [2083143]
- xfs: add attr state machine tracepoints (Brian Foster) [2083143]
- xfs: refactor xfs_iget calls from log intent recovery (Brian Foster) [2083143]
- xfs: clear log incompat feature bits when the log is idle (Brian Foster) [2083143]
- xfs: allow setting and clearing of log incompat feature flags (Brian Foster) [2083143]
- xfs: replace kmem_alloc_large() with kvmalloc() (Brian Foster) [2083143]
- xfs: remove kmem_alloc_io() (Brian Foster) [2083143]
- xfs: dump log intent items that cannot be recovered due to corruption (Brian Foster) [2083143]
- xfs: grab active perag ref when reading AG headers (Brian Foster) [2083143]
- xfs: fix silly whitespace problems with kernel libxfs (Brian Foster) [2083143]
- xfs: throttle inode inactivation queuing on memory reclaim (Brian Foster) [2083143]
- xfs: avoid buffer deadlocks when walking fs inodes (Brian Foster) [2083143]
- xfs: use background worker pool when transactions can't get free space (Brian Foster) [2083143]
- xfs: don't run speculative preallocation gc when fs is frozen (Brian Foster) [2083143]
- xfs: flush inode inactivation work when compiling usage statistics (Brian Foster) [2083143]
- xfs: inactivate inodes any time we try to free speculative preallocations (Brian Foster) [2083143]
- xfs: queue inactivation immediately when free realtime extents are tight (Brian Foster) [2083143]
- xfs: queue inactivation immediately when quota is nearing enforcement (Brian Foster) [2083143]
- xfs: queue inactivation immediately when free space is tight (Brian Foster) [2083143]
- xfs: per-cpu deferred inode inactivation queues (Brian Foster) [2083143]
- xfs: detach dquots from inode if we don't need to inactivate it (Brian Foster) [2083143]
- xfs: move xfs_inactive call to xfs_inode_mark_reclaimable (Brian Foster) [2083143]
- xfs: introduce all-mounts list for cpu hotplug notifications (Brian Foster) [2083143]
- xfs: introduce CPU hotplug infrastructure (Brian Foster) [2083143]
- xfs: remove the active vs running quota differentiation (Brian Foster) [2083143]
- xfs: remove the flags argument to xfs_qm_dquot_walk (Brian Foster) [2083143]
- xfs: remove xfs_dqrele_all_inodes (Brian Foster) [2083143]
- xfs: remove support for disabling quota accounting on a mounted file system (Brian Foster) [2083143]
- xfs: Convert double locking of MMAPLOCK to use VFS helpers (Brian Foster) [2083143]
- xfs: Convert to use invalidate_lock (Brian Foster) [2083143]
- xfs: Refactor xfs_isilocked() (Brian Foster) [2083143]
- s390/pai: Fix multiple concurrent event installation (Tobias Huschle) [2110299]
- s390/pai: Prevent invalid event number for pai_crypto PMU (Tobias Huschle) [2110299]
- s390/pai: add support for cryptography counters (Tobias Huschle) [2110299]
- entry: Rename arch_check_user_regs() to arch_enter_from_user_mode() (Tobias Huschle) [2110299]
- irq: remove handle_domain_{irq,nmi}() (Adrien Thierry) [2123744]
- crypto: qat - add limit to linked list parsing (Vladis Dronov) [2122112]
- crypto: qat - use reference to structure in dma_map_single() (Vladis Dronov) [2122112]
- Revert "crypto: qat - reduce size of mapped region" (Vladis Dronov) [2122112]
- crypto: qat - fix DMA transfer direction (Vladis Dronov) [2122112]
- crypto: qat - fix default value of WDT timer (Vladis Dronov) [2122112]
- crypto: drivers - move from strlcpy with unused retval to strscpy (Vladis Dronov) [2122112]
- crypto: qat - add check to validate firmware images (Vladis Dronov) [2122112]
- Documentation: qat: rewrite description (Vladis Dronov) [2122112]
- Documentation: qat: Use code block for qat sysfs example (Vladis Dronov) [2122112]
- thermal: int340x: Add Meteor Lake PCI device ID (David Arcari) [2072653]
- ACPI: DPTF: Support Meteor Lake (David Arcari) [2072653]
- thermal: int340x: Mode setting with new OS handshake (David Arcari) [2072653]
- thermal: int340x: Fix attr.show callback prototype (David Arcari) [2072653]
- thermal: int340x: Clean up _OSC context init (David Arcari) [2072653]
- thermal: int340x: Consolidate freeing of acpi_buffer pointer (David Arcari) [2072653]
- thermal: int340x: Clean up unnecessary acpi_buffer pointer freeing (David Arcari) [2072653]
- gfs2: Use TRY lock in gfs2_inode_lookup for UNLINKED inodes (Bob Peterson) [2121570]
- bpf: Use bpf_capable() instead of CAP_SYS_ADMIN for blinding decision (Yauheni Kaliuta) [2063058]

* Fri Oct 07 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-174.el9]
- kabi: add symbol yield to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_spec_ctrl_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vprintk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_zone_stat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_event_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol try_wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol this_cpu_off to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_unlock_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_freezing_cnt to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sme_me_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_freezable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_current_groups to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_sb_eat_lsm_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_free_mnt_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scsi_command_size_tbl to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rtnl_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol revert_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol recalc_sigpending to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rcu_read_unlock_strict to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol radix_tree_delete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol put_unused_fd to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_to_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_from_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol override_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memparse to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol lookup_bdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_coarse_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kmalloc_order_trace to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_end to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_begin_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies_64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_group_p to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_aton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in6_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in4_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol groups_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_zeroed_page to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_unused_fd_flags to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol fortify_panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol flush_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol efi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dev_base_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol del_timer_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpumask_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_number to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol congestion_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete_and_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol commit_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol clear_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_find_free_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol avenrun to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_unregister to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_register to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full_domain to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol abort_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _totalram_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_cred to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __preempt_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_del_entry_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_add_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __kmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cond_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __alloc_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: re-enable build-time kabi-checks (Čestmír Kalina) [2120321]
- sfc: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2129287]
- sfc: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2129287]
- redhat: change default dist suffix for RHEL 9.1 (Patrick Talbert)
- netfilter: nf_tables: clean up hook list when offload flags check fails (Florian Westphal) [2121393]
- netfilter: nfnetlink_osf: fix possible bogus match in nf_osf_find() (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Fix forged IP logic (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Tighten matching on DCC message (Florian Westphal) [2121393]
- netfilter: br_netfilter: Drop dst references before setting. (Florian Westphal) [2121393]
- netfilter: flowtable: fix stuck flows on cleanup due to pending work (Florian Westphal) [2121393]
- netfilter: flowtable: add function to invoke garbage collection immediately (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow binding to already bound chain (Florian Westphal) [2121393]
- netfilter: nft_tunnel: restrict it to netdev family (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow updates of implicit chain (Florian Westphal) [2121393]
- netfilter: nft_tproxy: restrict to prerouting hook (Florian Westphal) [2121393]
- netfilter: ebtables: reject blobs that don't provide all entry points (Florian Westphal) [2121393]
- netfilter: nf_tables: check NFT_SET_CONCAT flag if field_count is specified (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFT_SET_ELEM_CATCHALL and NFT_SET_ELEM_INTERVAL_END (Florian Westphal) [2121393]
- netfilter: nf_tables: NFTA_SET_ELEM_KEY_END requires concat and interval flags (Florian Westphal) [2121393]
- netfilter: nf_tables: validate NFTA_SET_ELEM_OBJREF based on NFT_SET_OBJECT flag (Florian Westphal) [2121393]
- netfilter: nf_tables: possible module reference underflow in error path (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFTA_SET_ELEM_KEY_END with NFT_SET_ELEM_INTERVAL_END flag (Florian Westphal) [2121393]
- netfilter: nf_tables: use READ_ONCE and WRITE_ONCE for shared generation id access (Florian Westphal) [2121393]
- netfilter: nf_tables: fix null deref due to zeroed list head (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow jump to implicit chain from set element (Florian Westphal) [2121393]
- netfilter: nfnetlink: re-enable conntrack expectation events (Florian Westphal) [2121393]

* Thu Oct 06 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-173.el9]
- redhat: fix elf got hardening for vm tools (Frantisek Hrbata)
- ipmi:ipmb: Fix refcount leak in ipmi_ipmb_probe (Tony Camuso) [2130241]
- ipmi: remove unnecessary type castings (Tony Camuso) [2130241]
- ipmi: Make two logs unique (Tony Camuso) [2130241]
- ipmi:si: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130241]
- ipmi: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130241]
- ipmi: Fix pr_fmt to avoid compilation issues (Tony Camuso) [2130241]
- ipmi: Add an intializer for ipmi_recv_msg struct (Tony Camuso) [2130241]
- ipmi: Add an intializer for ipmi_smi_msg struct (Tony Camuso) [2130241]
- ipmi:ssif: Check for NULL msg when handling events and messages (Tony Camuso) [2130241]
- ipmi: use simple i2c probe function (Tony Camuso) [2130241]
- ipmi: Add a sysfs count of total outstanding messages for an interface (Tony Camuso) [2130241]
- ipmi: Add a sysfs interface to view the number of users (Tony Camuso) [2130241]
- ipmi: Limit the number of message a user may have outstanding (Tony Camuso) [2130241]
- ipmi: Add a limit on the number of users that may use IPMI (Tony Camuso) [2130241]
- ipmi:ipmi_ipmb: Fix null-ptr-deref in ipmi_unregister_smi() (Tony Camuso) [2130241]

* Mon Oct 03 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-172.el9]
- redhat/Makefile: Add DIST to git tags for RHEL (Prarit Bhargava)
- Revert "Split partner modules into a sub-package" (Prarit Bhargava)
- redhat: Remove filter-i686.sh.rhel (Prarit Bhargava)
- redhat/Makefile: Add RHEL specific message for BUILDID deprecation (Prarit Bhargava)
- redhat/Makefile: Set PATCHLIST_URL to none for RHEL/cs9 (Prarit Bhargava)
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Prarit Bhargava)
- redhat/Makefile: Always set UPSTREAM (Prarit Bhargava)
- redhat/Makefile.variables: Add ADD_COMMITID_TO_VERSION (Prarit Bhargava)
- kernel.spec: disable vmlinux.h generation for s390 zfcpdump config (Prarit Bhargava)
- Revert "Add rtla subpackage for kernel-tools" (Prarit Bhargava)
- Enable KUNIT tests for redhat kernel-modules-internal (Prarit Bhargava)
- Makefile: add kabi targets (Prarit Bhargava)
- kabi: add stablelist helpers (Prarit Bhargava)
- perf: Require libbpf 0.6.0 or newer (Prarit Bhargava)
- kabi: add support for symbol namespaces into check-kabi (Prarit Bhargava)
- kabi: ignore new stablelist metadata in show-kabi (Prarit Bhargava)
- Makefile: add dist-assert-tree-clean target (Prarit Bhargava)
- redhat: Use redhatsecureboot701 for ppc64le (Prarit Bhargava)
- redhat: workaround CKI cross compilation for scripts (Prarit Bhargava)
- crypto: fips - make proc files report fips module name and version (Prarit Bhargava)
- redhat/configs: Enable Marvell OcteonTX2 crypto device (Prarit Bhargava)
- redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf (Prarit Bhargava)
- spec: Fix separate tools build (Prarit Bhargava)
- redhat: drop the RELEASED_KERNEL switch (Prarit Bhargava)
- redhat: switch the kernel package to use certs from system-sb-certs (Prarit Bhargava)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- redhat/kernel.spec.template: enable dependencies generation (Prarit Bhargava)
- redhat: build and include memfd to kernel-selftests-internal (Prarit Bhargava)
- redhat/kernel.spec.template: Link perf with --export-dynamic (Prarit Bhargava)
- cifs: enable SMB_DIRECT in RHEL9 (Prarit Bhargava)
- redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0 (Prarit Bhargava)
- redhat: Remove fedora configs directories and files. (Prarit Bhargava)
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Prarit Bhargava)
- redhat: switch secureboot kernel image signing to release keys (Prarit Bhargava)
- redhat: kernel.spec: selftests: abort on build failure (Prarit Bhargava)
- redhat: fix chronological order in the changelog file (Prarit Bhargava)
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Prarit Bhargava)
- redhat: define _rhel variable because pesign macro now needs it (Prarit Bhargava)
- redhat: update branches/targets after 9 Beta fork (Prarit Bhargava)
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Prarit Bhargava)
- redhat: correct file name of redhatsecurebootca1 (Prarit Bhargava)
- redhat: align file names with names of signing keys for ppc and s390 (Prarit Bhargava)
- redhat: update Makefile.variables for centos/rhel9 fork (Prarit Bhargava)
- redhat: make DIST default to .el9 (Prarit Bhargava)
- redhat/self-test: Fix shellcheck errors (Prarit Bhargava)
- redhat: change the changelog item for upstream merges (Prarit Bhargava)
- redhat/docs: Add dist-brew BUILD_FLAGS information (Prarit Bhargava)
- redhat: fix dist-release build number test (Prarit Bhargava)
- redhat: fix release number bump when dist-release-changed runs (Prarit Bhargava)
- redhat: use new genlog.sh script to detect changes for dist-release (Prarit Bhargava)
- redhat: move changelog addition to the spec file back into genspec.sh (Prarit Bhargava)
- redhat: always add a rebase entry when ark merges from upstream (Prarit Bhargava)
- redhat: drop merge ark patches hack (Prarit Bhargava)
- redhat: don't hardcode temporary changelog file (Prarit Bhargava)
- redhat: split changelog generation from genspec.sh (Prarit Bhargava)
- Add python3-setuptools buildreq for perf (Prarit Bhargava)
- Add cros_kunit to mod-internal.list (Prarit Bhargava)
- Add new tests to mod-internal.list (Prarit Bhargava)
- redhat/Makefile: Clean linux tarballs (Prarit Bhargava)
- redhat: properly handle binary files in patches (Prarit Bhargava)
- spec: add cpupower daemon reload on install/upgrade (Prarit Bhargava)
- redhat/configs: Fix rm warning on config warnings (Prarit Bhargava)
- redhat/Makefile: Deprecate PREBUILD_GIT_ONLY variable (Prarit Bhargava)
- redhat/Makefile: Deprecate SINGLE_TARBALL variable (Prarit Bhargava)
- redhat/Makefile: Deprecate GIT variable (Prarit Bhargava)
- omit unused Provides (Prarit Bhargava)
- self-test: Add test for DIST=".eln" (Prarit Bhargava)
- redhat/docs: Add information on build dependencies (Prarit Bhargava)
- redhat/Makefile: Add better pass message for dist-get-buildreqs (Prarit Bhargava)
- redhat/Makefile: Provide a better message for system-sb-certs (Prarit Bhargava)
- redhat/Makefile: Change dist-buildreq-check to a non-blocking target (Prarit Bhargava)
- create-data: Parallelize spec file data (Prarit Bhargava)
- create-data.sh: Store SOURCES Makefile variable (Prarit Bhargava)
- redhat/Makefile: Split up setup-source target (Prarit Bhargava)
- create-data.sh: Redefine varfilename (Prarit Bhargava)
- create-data.sh: Parallelize variable file creation (Prarit Bhargava)
- redhat/docs: Update brew information (Prarit Bhargava)
- redhat/Makefile: Fix eln BUILD_TARGET (Prarit Bhargava)
- redhat/Makefile: Set BUILD_TARGET for dist-brew (Prarit Bhargava)
- kernel.spec.template: update (s390x) expoline.o path (Prarit Bhargava)
- redhat/Makefile: Change fedora BUILD_TARGET (Prarit Bhargava)
- redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel (Prarit Bhargava)
- redhat: Exclude cpufreq.h from kernel-headers (Prarit Bhargava)
- Add rtla subpackage for kernel-tools (Prarit Bhargava)
- redhat/Makefile: Deprecate BUILD_SCRATCH_TARGET (Prarit Bhargava)
- redhat/Makefile: Remove deprecated variables and targets (Prarit Bhargava)
- Split partner modules into a sub-package (Prarit Bhargava)
- Enable Marvell OcteonTX2 crypto device in ARK (Prarit Bhargava)
- redhat/Makefile: Remove --scratch from BUILD_TARGET (Prarit Bhargava)
- redhat/Makefile: Fix dist-brew and distg-brew targets (Prarit Bhargava)
- redhat/Makefile: Add SPECKABIVERSION variable (Prarit Bhargava)
- redhat/self-test: Provide better failure output (Prarit Bhargava)
- redhat/self-test: Reformat tests to kernel standard (Prarit Bhargava)
- redhat/self-test: Add purpose and header to each test (Prarit Bhargava)
- redhat/self-test: Update data set (Prarit Bhargava)
- create-data.sh: Reduce specfile data output (Prarit Bhargava)
- self-test: Fixup Makefile contents test (Prarit Bhargava)
- redhat/self-test: self-test data update (Prarit Bhargava)
- redhat/self-test: Fix up create-data.sh to not report local variables (Prarit Bhargava)
- redhat: change tools_make macro to avoid full override of variables in Makefile (Prarit Bhargava)
- Fix typo in Makefile for Fedora Stable Versioning (Prarit Bhargava)
- redhat/configs/README: Update the README (Prarit Bhargava)
- redhat/docs: fix hyperlink typo (Prarit Bhargava)
- redhat/docs: Add a description of kernel naming (Prarit Bhargava)
- redhat/kernel.spec.template: update selftest data via "make dist-self-test-data" (Prarit Bhargava)
- redhat/kernel.spec.template: remove stray *.hardlink-temporary files, if any (Prarit Bhargava)
- Fix versioning on stable Fedora (Prarit Bhargava)
- Revert "Merge branch 'fix-ci-20220523' into 'os-build'" (Prarit Bhargava)
- redhat/Makefile: Drop quotation marks around string definitions (Prarit Bhargava)
- redhat/self-test/data: Update data set (Prarit Bhargava)
- Revert variable switch for lasttag (Prarit Bhargava)
- redhat/self-test: Update data (Prarit Bhargava)
- redhat/self-test: Unset Makefile variables (Prarit Bhargava)
- redhat/self-test: Omit SHELL variable from test data (Prarit Bhargava)
- Update filter-modules for mlx5-vfio-pci (Prarit Bhargava)
- self-test/data/create-data.sh: Avoid SINGLE_TARBALL warning (Prarit Bhargava)
- redhat/Makefile: Rename PREBUILD to UPSTREAMBUILD (Prarit Bhargava)
- redhat/Makefile: Rename BUILDID to LOCALVERSION (Prarit Bhargava)
- redhat/Makefile: Fix dist-brew & distg-brew targets (Prarit Bhargava)
- redhat/Makefile: Reorganize MARKER code (Prarit Bhargava)
- redhat/scripts/new_release.sh: Use Makefile variables (Prarit Bhargava)
- redhat/Makefile: Rename __YSTREAM and __ZSTREAM (Prarit Bhargava)
- redhat/genspec.sh: Add comment about SPECBUILDID variable (Prarit Bhargava)
- redhat/kernel.spec.template: Move genspec variables into one section (Prarit Bhargava)
- redhat/kernel.spec.template: Remove kversion (Prarit Bhargava)
- redhat/Makefile: Add SPECTARFILE_RELEASE comment (Prarit Bhargava)
- redhat/Makefile: Rename RPMVERSION to BASEVERSION (Prarit Bhargava)
- redhat/Makefile: Target whitespace cleanup (Prarit Bhargava)
- redhat/Makefile: Move SPECRELEASE to genspec.sh (Prarit Bhargava)
- redhat/Makefile: Add kernel-NVR comment (Prarit Bhargava)
- redhat/Makefile: Use SPECFILE variable (Prarit Bhargava)
- redhat/Makefile: Remove KEXTRAVERSION (Prarit Bhargava)
- redhat: Enable VM kselftests (Prarit Bhargava)
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Prarit Bhargava)
- redhat: Enable HMM test to be used by the kselftest test suite (Prarit Bhargava)
- redhat/Makefile.variables: Change git hash length to default (Prarit Bhargava)
- redhat/Makefile: Drop quotation marks around string definitions (Prarit Bhargava)
- redhat/configs: Fix rm warning on error (Prarit Bhargava)
- redhat/kernel.spec.template: fix standalone tools build (Prarit Bhargava)
- Add system-sb-certs for RHEL-9 (Prarit Bhargava)
- Fix dist-buildcheck-reqs (Prarit Bhargava)
- redhat: indicate HEAD state in tarball/rpm name (Prarit Bhargava)
- redhat/self-test: Add test to verify Makefile declarations. (Prarit Bhargava)
- redhat/Makefile: Add RHTEST (Prarit Bhargava)
- redhat: shellcheck cleanup (Prarit Bhargava)
- redhat/self-test/data: Cleanup data (Prarit Bhargava)
- redhat/self-test: Add test to verify SPEC variables (Prarit Bhargava)
- redhat/Makefile: Add 'duplicate' SPEC entries for user set variables (Prarit Bhargava)
- redhat/Makefile: Rename TARFILE_RELEASE to SPECTARFILE_RELEASE (Prarit Bhargava)
- redhat/genspec: Rename PATCHLIST_CHANGELOG to SPECPATCHLIST_CHANGELOG (Prarit Bhargava)
- redhat/genspec: Rename DEBUG_BUILDS_ENABLED to SPECDEBUG_BUILDS_ENABLED (Prarit Bhargava)
- redhat/Makefile: Rename PKGRELEASE to SPECBUILD (Prarit Bhargava)
- redhat/genspec: Rename BUILDID_DEFINE to SPECBUILDID (Prarit Bhargava)
- redhat/Makefile: Rename CHANGELOG to SPECCHANGELOG (Prarit Bhargava)
- redhat/Makefile: Rename RPMKEXTRAVERSION to SPECKEXTRAVERSION (Prarit Bhargava)
- redhat/Makefile: Rename RPMKSUBLEVEL to SPECKSUBLEVEL (Prarit Bhargava)
- redhat/Makefile: Rename RPMKPATCHLEVEL to SPECKPATCHLEVEL (Prarit Bhargava)
- redhat/Makefile: Rename RPMKVERSION to SPECKVERSION (Prarit Bhargava)
- redhat/Makefile: Rename KVERSION to SPECVERSION (Prarit Bhargava)
- redhat/Makefile: Deprecate some simple targets (Prarit Bhargava)
- redhat/Makefile: Use KVERSION (Prarit Bhargava)
- enable DAMON configs (Prarit Bhargava)
- redhat: change kabi tarballs to use the package release (Prarit Bhargava)
- redhat: generate distgit changelog in genspec.sh as well (Prarit Bhargava)
- redhat: make genspec prefer metadata from git notes (Prarit Bhargava)
- redhat: use tags from git notes for zstream to generate changelog (Prarit Bhargava)
- redhat/self-test: Clean up data set (Prarit Bhargava)
- redhat/Makefile.rhpkg: Remove quotes for RHDISTGIT (Prarit Bhargava)
- redhat/scripts/create-tarball.sh: Use Makefile variables (Prarit Bhargava)
- redhat/Makefile: Deprecate SINGLE_TARBALL (Prarit Bhargava)
- redhat/Makefile: Move SINGLE_TARBALL to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Use RPMVERSION (Prarit Bhargava)
- redhat/scripts/rh-dist-git.sh: Use Makefile variables (Prarit Bhargava)
- redhat/configs/build_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat/kernel.spec.template: Use RPM_BUILD_NCPUS (Prarit Bhargava)
- redhat/configs/generate_all_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat: ignore known empty patches on the patches rpminspect test (Prarit Bhargava)
- spec: keep .BTF section in modules for s390 (Prarit Bhargava)
- kernel.spec.template: Ship arch/s390/lib/expoline.o in kernel-devel (Prarit Bhargava)
- redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY (Prarit Bhargava)
- Build intel_sdsi with %%{tools_make} (Prarit Bhargava)
- spec: make HMAC file encode relative path (Prarit Bhargava)
- redhat/kernel.spec.template: Add intel_sdsi utility (Prarit Bhargava)
- Spec fixes for intel-speed-select (Prarit Bhargava)
- Add clk_test and clk-gate_test to mod-internal.list (Prarit Bhargava)
- redhat/self-tests: Ignore UPSTREAM (Prarit Bhargava)
- redhat/self-tests: Ignore RHGITURL (Prarit Bhargava)
- redhat/Makefile.variables: Extend git hash length to 15 (Prarit Bhargava)
- redhat/self-test: Remove changelog from spec files (Prarit Bhargava)
- redhat/genspec.sh: Rearrange genspec.sh (Prarit Bhargava)
- redhat/self-test: Add spec file data (Prarit Bhargava)
- redhat/self-test: Add better dist-dump-variables test (Prarit Bhargava)
- redhat/self-test: Add variable test data (Prarit Bhargava)
- Avoid creating files in $RPM_SOURCE_DIR (Prarit Bhargava)
- redhat/configs/process_configs.sh: Avoid race with find (Prarit Bhargava)
- redhat/configs/process_configs.sh: Remove CONTINUEONERROR (Prarit Bhargava)
- Remove i686 configs and filters (Prarit Bhargava)
- redhat: Fix release tagging (Prarit Bhargava)
- redhat/self-test: Fix version tag test (Prarit Bhargava)
- redhat/self-test: Fix BUILD verification test (Prarit Bhargava)
- redhat/self-test: Cleanup SRPM related self-tests (Prarit Bhargava)
- redhat/self-test: Fix shellcheck test (Prarit Bhargava)
- redhat/README.Makefile: Add a Makefile README file (Prarit Bhargava)
- redhat/Makefile: Remove duplicated code (Prarit Bhargava)
- Add BuildRequires libnl3-devel for intel-speed-select (Prarit Bhargava)
- Add new kunit tests for 5.18 to mod-internal.list (Prarit Bhargava)
- Fix RHDISTGIT for Fedora (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix race with tools generation (Prarit Bhargava)
- Define SNAPSHOT correctly when VERSION_ON_UPSTREAM is 0 (Prarit Bhargava)
- redhat/Makefile: Fix dist-git (Prarit Bhargava)
- redhat/Makefile: Reorganize variables (Prarit Bhargava)
- redhat/Makefile: Add some descriptions (Prarit Bhargava)
- redhat/Makefile: Move SNAPSHOT check (Prarit Bhargava)
- redhat/Makefile: Deprecate BREW_FLAGS, KOJI_FLAGS, and TEST_FLAGS (Prarit Bhargava)
- redhat/genspec.sh: Rework RPMVERSION variable (Prarit Bhargava)
- redhat/Makefile: Remove dead comment (Prarit Bhargava)
- redhat/Makefile: Cleanup KABI* variables. (Prarit Bhargava)
- redhat/Makefile.variables: Default RHGITCOMMIT to HEAD (Prarit Bhargava)
- redhat/scripts/create-tarball.sh: Use Makefile TARBALL variable (Prarit Bhargava)
- redhat/Makefile: Remove extra DIST_BRANCH (Prarit Bhargava)
- redhat/Makefile: Remove STAMP_VERSION (Prarit Bhargava)
- redhat/Makefile: Move NO_CONFIGCHECKS to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move RHJOBS to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move RHGIT* variables to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move PREBUILD_GIT_ONLY to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD_FLAGS to Makefile.variables. (Prarit Bhargava)
- redhat/Makefile: Move BUILD_PROFILE to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD_TARGET and BUILD_SCRATCH_TARGET to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Remove RHPRODUCT variable (Prarit Bhargava)
- redhat/Makefile: Cleanup DISTRO variable (Prarit Bhargava)
- redhat/Makefile: Move HEAD to Makefile.variables. (Prarit Bhargava)
- redhat: Combine Makefile and Makefile.common (Prarit Bhargava)
- redhat/koji/Makefile: Decouple koji Makefile from Makefile.common (Prarit Bhargava)
- Add asus_wmi_sensors modules to filters for Fedora (Prarit Bhargava)
- Update scripts to put new configs under ark-common (Prarit Bhargava)
- redhat: spec: trigger dracut when modules are installed separately (Prarit Bhargava)
- redhat/Makefile: Silence dist-clean-configs output (Prarit Bhargava)
- Print arch with process_configs errors (Prarit Bhargava)
- Pass RHJOBS to process_configs for dist-configs-check as well (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix issue with old error files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/build_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/build_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Add local variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/process_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/process_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add processing config function (Prarit Bhargava)
- redhat: Unify genspec.sh and kernel.spec variable names (Prarit Bhargava)
- redhat/genspec.sh: Remove options and use Makefile variables (Prarit Bhargava)
- Add rebase note for 5.17 on Fedora stable (Prarit Bhargava)
- redhat: Fix "make dist-release-finish" to use the correct NVR variables (Prarit Bhargava)
- Build CROS_EC Modules (Prarit Bhargava)
- redhat/Makefile: Fix dist-dump-variables target (Prarit Bhargava)
- configs/process_configs.sh: Remove orig files (Prarit Bhargava)
- redhat: fix make {distg-brew,distg-koji} (Prarit Bhargava)
- redhat/configs: Enable CONFIG_TEST_BPF (Prarit Bhargava)
- Enable KUNIT tests for testing (Prarit Bhargava)
- Makefile: Check PKGRELEASE size on dist-brew targets (Prarit Bhargava)
- kernel.spec: Add glibc-static build requirement (Prarit Bhargava)
- spec: don't overwrite auto.conf with .config (Prarit Bhargava)
- Add test_hash to the mod-internal.list (Prarit Bhargava)
- spec: speed up "cp -r" when it overwrites existing files. (Prarit Bhargava)
- redhat: use centos x509.genkey file if building under centos (Prarit Bhargava)
- Revert "[redhat] Generate a crashkernel.default for each kernel build" (Prarit Bhargava)
- spec: make linux-firmware weak(er) dependency (Prarit Bhargava)
- Add packaged but empty /lib/modules/<kver>/systemtap/ (Prarit Bhargava)
- filter-modules.sh.rhel: Add ntc_thermistor to singlemods (Prarit Bhargava)
- Add dev_addr_lists_test to mod-internal.list (Prarit Bhargava)
- redhat: ignore ksamples and kselftests on the badfuncs rpminspect test (Prarit Bhargava)
- redhat: disable upstream check for rpminspect (Prarit Bhargava)
- redhat: Pull in openssl-devel as a build dependency correctly (Prarit Bhargava)
- Update rebase-notes with dracut 5.17 information (Prarit Bhargava)
- Enable CONFIG_CIFS_SMB_DIRECT for ARK (Prarit Bhargava)
- redhat: make Patchlist.changelog generation conditional (Prarit Bhargava)
- redhat/configs/evaluate_configs: Add find dead configs option (Prarit Bhargava)
- Add more rebase notes for Fedora 5.16 (Prarit Bhargava)
- spec: Keep .BTF section in modules (Prarit Bhargava)
- spec: add bpf_testmod.ko to kselftests/bpf (Prarit Bhargava)
- redhat/docs/index.rst: Add local build information. (Prarit Bhargava)
- Turn on CONFIG_HID_NINTENDO for controller support (Prarit Bhargava)
- Add rebase notes to check for PCI patches (Prarit Bhargava)
- Filter updates for hid-playstation on Fedora (Prarit Bhargava)
- Add nct6775 to filter-modules.sh.rhel (Prarit Bhargava)
- Add memcpy_kunit to mod-internal.list (Prarit Bhargava)
- Add nct6775 to Fedora filter-modules.sh (Prarit Bhargava)
- redhat/kernel.spec.template: don't hardcode gcov arches (Prarit Bhargava)
- redhat/configs: create a separate config for gcov options (Prarit Bhargava)
- Update documentation with FAQ and update frequency (Prarit Bhargava)
- Document force pull option for mirroring (Prarit Bhargava)
- Ignore the rhel9 kabi files (Prarit Bhargava)
- Remove legacy elrdy cruft (Prarit Bhargava)
- redhat/configs/evaluate_configs: walk cfgvariants line by line (Prarit Bhargava)
- redhat/configs/evaluate_configs: insert EMPTY tags at correct place (Prarit Bhargava)
- redhat: make dist-srpm-gcov add to BUILDOPTS (Prarit Bhargava)
- spec: Don't fail spec build if ksamples fails (Prarit Bhargava)
- redhat: Disable clang's integrated assembler on ppc64le and s390x (Prarit Bhargava)
- Fix dist-srpm-gcov (Prarit Bhargava)
- Add kfence_test to mod-internal.list (Prarit Bhargava)
- Enable KUNIT tests for redhat kernel-modules-internal (Prarit Bhargava)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Prarit Bhargava)
- redhat: fix typo and make the output more silent for dist-git sync (Prarit Bhargava)
- Fix ordering in genspec args (Prarit Bhargava)
- redhat/docs: update Koji link to avoid redirect (Prarit Bhargava)
- redhat: add support for different profiles with dist*-brew (Prarit Bhargava)
- redhat: move the DIST variable setting to Makefile.variables (Prarit Bhargava)
- redhat/kernel.spec.template: Cleanup source numbering (Prarit Bhargava)
- redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files (Prarit Bhargava)
- redhat/kernel.spec.template: Add include_fedora and include_rhel variables (Prarit Bhargava)
- redhat/Makefile: Make kernel-local global (Prarit Bhargava)
- redhat/Makefile: Use flavors file (Prarit Bhargava)
- redhat: rename usage of .rhel8git.mk to .rhpkg.mk (Prarit Bhargava)
- redhat: remove kernel.changelog-8.99 file (Prarit Bhargava)
- redhat: add documentation about the os-build rebase process (Prarit Bhargava)
- Build kernel-doc for Fedora (Prarit Bhargava)
- Revert "redhat: set default values in Makefiles for RHEL 9 Beta" (Prarit Bhargava)
- Revert "redhat: make DIST default to .el9" (Prarit Bhargava)
- Revert "redhat: add support for stream profile in koji/brew" (Prarit Bhargava)
- Revert "redhat: update Makefile.variables for centos/rhel9 fork" (Prarit Bhargava)
- Revert "redhat: drop Patchlist.changelog for RHEL" (Prarit Bhargava)
- Revert "redhat: align file names with names of signing keys for ppc and s390" (Prarit Bhargava)
- Revert "redhat: correct file name of redhatsecurebootca1" (Prarit Bhargava)
- Revert "redhat: drop certificates that were deprecated after GRUB's BootHole flaw" (Prarit Bhargava)
- Revert "redhat: update branches/targets after 9 Beta fork" (Prarit Bhargava)
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Prarit Bhargava)
- Revert "redhat: replace redhatsecureboot303 signing key with redhatsecureboot601" (Prarit Bhargava)
- Revert "redhat: add *-matched meta packages to rpminspect emptyrpm config" (Prarit Bhargava)
- Revert "redhat: add option to use DIST tag in sources" (Prarit Bhargava)
- Revert "redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta" (Prarit Bhargava)
- Revert "redhat: fix chronological order in the changelog file" (Prarit Bhargava)
- Revert "redhat: restore sublevel in changelog" (Prarit Bhargava)
- Revert "redhat: kernel.spec: selftests: abort on build failure" (Prarit Bhargava)
- Revert "redhat/.gitignore: Add rhel9 KABI files" (Prarit Bhargava)
- Revert "Revert "redhat: define _rhel variable because pesign macro now needs it"" (Prarit Bhargava)
- Revert "redhat/Makefile: Use flavors file" (Prarit Bhargava)
- Revert "redhat/Makefile: Make kernel-local global" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Add include_fedora and include_rhel variables" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Cleanup source numbering" (Prarit Bhargava)
- Revert "redhat: Remove fedora configs directories and files." (Prarit Bhargava)
- Revert "redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0" (Prarit Bhargava)
- Revert "redhat: BUILDID parameter must come last in genspec.sh" (Prarit Bhargava)
- Revert "kernel.spec: add bpf_testmod.ko to kselftests/bpf" (Prarit Bhargava)
- Revert "cifs: enable SMB_DIRECT in RHEL9" (Prarit Bhargava)
- Revert "redhat: Fix dist-srpm-gcov" (Prarit Bhargava)
- Revert "redhat: make dist-srpm-gcov add to BUILDOPTS" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: don't hardcode gcov arches" (Prarit Bhargava)
- Revert "redhat/configs: create a separate config for gcov options" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: walk cfgvariants line by line" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: insert EMPTY tags at correct place" (Prarit Bhargava)
- Revert "redhat: fix typo and make the output more silent for dist-git sync" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Link perf with --export-dynamic" (Prarit Bhargava)
- Revert "redhat: build and include memfd to kernel-selftests-internal" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: enable dependencies generation" (Prarit Bhargava)
- Revert "redhat: disable upstream check for rpminspect" (Prarit Bhargava)
- Revert "redhat: ignore ksamples and kselftests on the badfuncs rpminspect test" (Prarit Bhargava)
- Revert "redhat: Pull in openssl-devel as a build dependency correctly" (Prarit Bhargava)
- Revert "Revert "[redhat] Generate a crashkernel.default for each kernel build"" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: Add find dead configs option" (Prarit Bhargava)
- Revert "redhat/scripts: Update merge-subtrees.sh with new subtree location" (Prarit Bhargava)
- Revert "redhat: make pathspec exclusion compatible with old git versions" (Prarit Bhargava)
- Revert "Add packaged but empty /lib/modules/<kver>/systemtap" (Prarit Bhargava)
- Revert "redhat: use centos x509.genkey file if building under centos" (Prarit Bhargava)
- Revert "redhat: fix the exclusion of rhdocs changes entries in the changelog" (Prarit Bhargava)
- Revert "redhat: switch the kernel package to use certs from system-sb-certs" (Prarit Bhargava)
- Revert "redhat: drop the RELEASED_KERNEL switch" (Prarit Bhargava)
- Revert "Enable KUNIT tests for redhat kernel-modules-internal" (Prarit Bhargava)
- Revert "redhat/configs: Enable CONFIG_TEST_BPF" (Prarit Bhargava)
- Revert "spec: Fix separate tools build" (Prarit Bhargava)
- Revert "kernel.spec: Add glibc-static build requirement" (Prarit Bhargava)
- Revert "spec: make linux-firmware weak(er) dependency" (Prarit Bhargava)
- Revert "redhat: use tags from git notes for zstream to generate changelog" (Prarit Bhargava)
- Revert "redhat: make genspec prefer metadata from git notes" (Prarit Bhargava)
- Revert "redhat: generate distgit changelog in genspec.sh as well" (Prarit Bhargava)
- Revert "redhat: change kabi tarballs to use the package release" (Prarit Bhargava)
- Revert "redhat: rpminspect: disable 'patches' check for known empty patch files" (Prarit Bhargava)
- Revert "redhat: spec: trigger dracut when modules are installed separately" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Add processing config function" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Create unique output files" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Provide better messages" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Parallelize execution" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Add local variables" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Create unique output files" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Provide better messages" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Parallelize execution" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Fix issue with old error files" (Prarit Bhargava)
- Revert "Pass RHJOBS to process_configs for dist-configs-check as well" (Prarit Bhargava)
- Revert "Print arch with process_configs errors" (Prarit Bhargava)
- Revert "redhat/Makefile: Silence dist-clean-configs output" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Fix race with tools generation" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Remove CONTINUEONERROR" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Avoid race with find" (Prarit Bhargava)
- Revert "redhat/Makefile: Fix dist-dump-variables target" (Prarit Bhargava)
- Revert "redhat: fix make {distg-brew,distg-koji}" (Prarit Bhargava)
- Revert "redhat/koji/Makefile: Decouple koji Makefile from Makefile.common" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Add intel_sdsi utility" (Prarit Bhargava)
- Revert "Build intel_sdsi with %%{tools_make}" (Prarit Bhargava)
- Revert "Add BuildRequires libnl3-devel for intel-speed-select" (Prarit Bhargava)
- Revert "Spec fixes for intel-speed-select" (Prarit Bhargava)
- Revert "redhat: enable CONFIG_TEST_VMALLOC for vm selftests" (Prarit Bhargava)
- Revert "redhat: Enable HMM test to be used by the kselftest test suite" (Prarit Bhargava)
- Revert "redhat: Enable VM kselftests" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: fix standalone tools build" (Prarit Bhargava)
- Revert "redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY" (Prarit Bhargava)
- Revert "redhat: Exclude cpufreq.h from kernel-headers" (Prarit Bhargava)
- Revert "kernel.spec: disable vmlinux.h generation for s390 zfcpdump config" (Prarit Bhargava)
- Revert "spec: Keep .BTF section in modules" (Prarit Bhargava)
- Revert "redhat/configs: Enable Marvell OcteonTX2 crypto device" (Prarit Bhargava)
- Revert "redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel" (Prarit Bhargava)
- Revert "crypto: fips - make proc files report fips module name and version" (Prarit Bhargava)
- Revert "redhat: fix kernel_variant_package option definition" (Prarit Bhargava)
- Revert "redhat: workaround CKI cross compilation for scripts" (Prarit Bhargava)
- Revert "redhat: Use redhatsecureboot701 for ppc64le" (Prarit Bhargava)
- Revert "[redhat] Makefile: add dist-assert-tree-clean target" (Prarit Bhargava)
- Revert "[redhat] Makefile.common: export REDHAT variable" (Prarit Bhargava)
- Revert "[redhat] kabi: ignore new stablelist metadata in show-kabi" (Prarit Bhargava)
- Revert "[redhat] kabi: add support for symbol namespaces into check-kabi" (Prarit Bhargava)
- Revert "[redhat] perf: Require libbpf 0.6.0 or newer" (Prarit Bhargava)
- Revert "[redhat] kabi: add stablelist helpers" (Prarit Bhargava)
- Revert "[redhat] Makefile: add kabi targets" (Prarit Bhargava)
- Revert "redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning" (Prarit Bhargava)

* Sat Oct 01 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-171.el9]
- irqchip/qcom-pdc: Drop open coded version of __assign_bit() (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Fix broken locking (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill qcom_pdc_translate helper (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill non-wakeup irqdomain (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill PDC_NO_PARENT_IRQ (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Trim unused levels of the interrupt hierarchy (Eric Chanudet) [2105098]
- drm/bochs: fix blanking (Michel Dänzer) [2124193]
- opp: use list iterator only inside the loop (Eric Chanudet) [2112113]
- opp: replace usage of found with dedicated list iterator variable (Eric Chanudet) [2112113]
- PM: opp: simplify with dev_err_probe() (Eric Chanudet) [2112113]
- OPP: call of_node_put() on error path in _bandwidth_supported() (Eric Chanudet) [2112113]
- OPP: Add support of "opp-microwatt" for EM registration (Eric Chanudet) [2112113]
- PM: EM: add macro to set .active_power() callback conditionally (Eric Chanudet) [2112113]
- OPP: Add "opp-microwatt" supporting code (Eric Chanudet) [2112113]
- dt-bindings: opp: Add "opp-microwatt" entry in the OPP (Eric Chanudet) [2112113]
- dt-bindings: opp: Allow multi-worded OPP entry name (Eric Chanudet) [2112113]
- dt-bindings: opp: Convert to DT schema (Eric Chanudet) [2112113]
- opp: Expose of-node's name in debugfs (Eric Chanudet) [2112113]
- opp: Fix return in _opp_add_static_v2() (Eric Chanudet) [2112113]
- opp: Add more resource-managed variants of dev_pm_opp_of_add_table() (Eric Chanudet) [2112113]
- opp: Change type of dev_pm_opp_attach_genpd(names) argument (Eric Chanudet) [2112113]
- opp: Fix required-opps phandle array count check (Eric Chanudet) [2112113]
- opp: Don't print an error if required-opps is missing (Eric Chanudet) [2112113]
- thunderbolt: Add support for Intel Raptor Lake (Torez Smith) [2040039]
- bonding: accept unsolicited NA message (Jonathan Toppins) [2115631]
- bonding: add all node mcast address when slave up (Jonathan Toppins) [2115631]
- bonding: use unspecified address if no available link local address (Jonathan Toppins) [2115631]
- bonding: 3ad: make ad_ticks_per_sec a const (Jonathan Toppins) [2126214]
- bonding: 802.3ad: fix no transmission of LACPDUs (Jonathan Toppins) [2126214]

* Thu Sep 29 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-170.el9]
- NFSv4.1 restrict GETATTR fs_location query to the main transport (Scott Mayhew) [2066372]
- NFSv4: Add an fattr allocation to _nfs4_discover_trunking() (Scott Mayhew) [2066372]
- sunrpc: set cl_max_connect when cloning an rpc_clnt (Scott Mayhew) [2066372]
- NFSv4.1 mark qualified async operations as MOVEABLE tasks (Scott Mayhew) [2066372]
- NFSv4.1 provide mount option to toggle trunking discovery (Scott Mayhew) [2066372]
- NFSv4.1 test and add 4.1 trunking transport (Scott Mayhew) [2066372]
- SUNRPC allow for unspecified transport time in rpc_clnt_add_xprt (Scott Mayhew) [2066372]
- NFSv4 handle port presence in fs_location server string (Scott Mayhew) [2066372]
- NFSv4 expose nfs_parse_server_name function (Scott Mayhew) [2066372]
- NFSv4.1 query for fs_location attr on a new file system (Scott Mayhew) [2066372]
- NFSv4 store server support for fs_location attribute (Scott Mayhew) [2066372]
- NFSv4 remove zero number of fs_locations entries error check (Scott Mayhew) [2066372]
- iwlwifi: limit fw version for AC9560 to avoid fw crash (Íñigo Huguet) [2096128]
- configs: enable CONFIG_HP_ILO for aarch64 (Mark Salter) [2126153]

* Tue Sep 27 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-169.el9]
- bonding: fix NULL deref in bond_rr_gen_slave_id (Jonathan Toppins) [2001260]
- CI: Add automotive-check for rt branches (Veronika Kabatova)
- smp: Make softirq handling RT safe in flush_smp_call_function_queue() (Phil Auld) [2120671]
- smp: Rename flush_smp_call_function_from_idle() (Phil Auld) [2120671]
- sched: Fix missing prototype warnings (Phil Auld) [2120671]
- signal: In get_signal test for signal_group_exit every time through the loop (Phil Auld) [2120671]
- KVM: s390: pv: don't present the ecall interrupt twice (Tobias Huschle) [2125209]
- s390/mm: do not trigger write fault when vma does not allow VM_WRITE (Tobias Huschle) [2125208]
- s390/hugetlb: fix prepare_hugepage_range() check for 2 GB hugepages (Tobias Huschle) [2125207]

* Fri Sep 23 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-168.el9]
- xdp: check prog type before updating BPF link (Felix Maurer) [2071620]
- net: bpf: Handle return value of BPF_CGROUP_RUN_PROG_INET{4,6}_POST_BIND() (Felix Maurer) [2071620]
- tools: Fix unavoidable GCC call in Clang builds (Artem Savkov) [2069046]
- tools: Help cross-building with clang (Artem Savkov) [2069046]
- libbpf: Initialize err in probe_map_create (Artem Savkov) [2069046]
- tracing/perf: Avoid -Warray-bounds warning for __rel_loc macro (Artem Savkov) [2069046]
- tracing: Add '__rel_loc' using trace event macros (Artem Savkov) [2069046]
- xdp: xdp_mem_allocator can be NULL in trace_mem_connect(). (Felix Maurer) [2071620]
- bpf, sockmap: Do not ignore orig_len parameter (Felix Maurer) [2071620]
- page_pool: remove spinlock in page_pool_refill_alloc_cache() (Felix Maurer) [2071620]
- xdp: Add xdp_do_redirect_frame() for pre-computed xdp_frames (Felix Maurer) [2071620]
- xdp: Move conversion to xdp_frame out of map functions (Felix Maurer) [2071620]
- page_pool: Store the XDP mem id (Felix Maurer) [2071620]
- page_pool: Add callback to init pages when they are allocated (Felix Maurer) [2071620]
- xdp: Allow registering memory model without rxq reference (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add timestamp for Tx-only operation (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add time-out for cleaning Tx (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add sched policy and priority support (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add cyclic TX operation capability (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add clockid selection support (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add Dest and Src MAC setting for Tx-only operation (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add VLAN support for Tx-only operation (Felix Maurer) [2071620]
- xdp: move the if dev statements to the first (Felix Maurer) [2071620]
- xsk: Wipe out dead zero_copy_allocator declarations (Felix Maurer) [2071620]
- skbuff: Move conditional preprocessor directives out of struct sk_buff (Felix Maurer) [2071620]
- bpf, docs: Add a missing colon in verifier.rst (Artem Savkov) [2069046]
- bpf: Fix usage of trace RCU in local storage. (Artem Savkov) [2069046]
- bpf: Check PTR_TO_MEM | MEM_RDONLY in check_helper_mem_access (Artem Savkov) [2069046]
- libbpf: Fix libbpf.map inheritance chain for LIBBPF_0.7.0 (Artem Savkov) [2069046]
- perf/bpf_counter: Use bpf_map_create instead of bpf_create_map (Artem Savkov) [2069046]
- bpftool: Fix pretty print dump for maps without BTF loaded (Artem Savkov) [2069046]
- bpftool: Fix the error when lookup in no-btf maps (Artem Savkov) [2069046]
- add includes masked by cgroup -> bpf dependency (Artem Savkov) [2069046]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Artem Savkov) [2069046]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Artem Savkov) [2069046]
- net: Add includes masked by netdevice.h including uapi/bpf.h (Artem Savkov) [2069046]
- bpf: Add schedule points in batch ops (Artem Savkov) [2069046]
- bpf: Fix crash due to out of bounds access into reg2btf_ids. (Artem Savkov) [2069046]
- selftests: bpf: Check bpf_msg_push_data return value (Artem Savkov) [2069046]
- bpf: Emit bpf_timer in vmlinux BTF (Artem Savkov) [2069046]
- selftests/bpf: Add test for bpf_timer overwriting crash (Artem Savkov) [2069046]
- bpf: Do not try bpf_msg_push_data with len 0 (Artem Savkov) [2069046]
- tools/resolve_btfids: Do not print any commands when building silently (Artem Savkov) [2069046]
- bpf: Use VM_MAP instead of VM_ALLOC for ringbuf (Artem Savkov) [2069046]
- tools headers UAPI: remove stale lirc.h (Artem Savkov) [2069046]
- tools/testing/selftests/bpf: replace open-coded 16 with TASK_COMM_LEN (Artem Savkov) [2069046]
- tools/bpf/bpftool/skeleton: replace bpf_probe_read_kernel with bpf_probe_read_kernel_str to get task comm (Artem Savkov) [2069046]
- samples/bpf/test_overhead_kprobe_kern: replace bpf_probe_read_kernel with bpf_probe_read_kernel_str to get task comm (Artem Savkov) [2069046]
- bpf, selftests: Add ringbuf memory type confusion test (Artem Savkov) [2069046]
- bpf, selftests: Add various ringbuf tests with invalid offset (Artem Savkov) [2069046]
- bpf: Fix ringbuf memory type confusion when passing to helpers (Artem Savkov) [2069046]
- bpf: Fix out of bounds access for ringbuf helpers (Artem Savkov) [2069046]
- bpf: Generally fix helper register offset check (Artem Savkov) [2069046]
- bpf: Mark PTR_TO_FUNC register initially with zero offset (Artem Savkov) [2069046]
- bpf: Generalize check_ctx_reg for reuse with other types (Artem Savkov) [2069046]
- powerpc64/bpf: Limit 'ldbrx' to processors compliant with ISA v2.06 (Artem Savkov) [2069046]
- tools/bpf: Rename 'struct event' to avoid naming conflict (Artem Savkov) [2069046]
- bpf: Guard against accessing NULL pt_regs in bpf_get_task_stack() (Artem Savkov) [2069046]
- bpf: Fix incorrect integer literal used for marking scratched stack. (Artem Savkov) [2069046]
- bpf/selftests: Add check for updating XDP bpf_link with wrong program type (Artem Savkov) [2069046]
- bpf/selftests: convert xdp_link test to ASSERT_* macros (Artem Savkov) [2069046]
- bpf: Fix mount source show for bpffs (Artem Savkov) [2069046]
- bpf: selftests: Add bind retry for post_bind{4, 6} (Artem Savkov) [2069046]
- bpf: selftests: Use C99 initializers in test_sock.c (Artem Savkov) [2069046]
- bpf/selftests: Test bpf_d_path on rdonly_mem. (Artem Savkov) [2069046]
- libbpf: Add documentation for bpf_map batch operations (Artem Savkov) [2069046]
- selftests/bpf: Don't rely on preserving volatile in PT_REGS macros in loop3 (Artem Savkov) [2069046]
- libbpf 1.0: Deprecate bpf_object__find_map_by_offset() API (Artem Savkov) [2069046]
- libbpf 1.0: Deprecate bpf_map__is_offload_neutral() (Artem Savkov) [2069046]
- libbpf: Support repeated legacy kprobes on same function (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_perf_event_read_simple() API (Artem Savkov) [2069046]
- bpf: Add SO_RCVBUF/SO_SNDBUF in _bpf_getsockopt(). (Artem Savkov) [2069046]
- bpf: Fix SO_RCVBUF/SO_SNDBUF handling in _bpf_setsockopt(). (Artem Savkov) [2069046]
- bpf, docs: Fully document the JMP mode modifiers (Artem Savkov) [2069046]
- bpf, docs: Fully document the JMP opcodes (Artem Savkov) [2069046]
- bpf, docs: Fully document the ALU opcodes (Artem Savkov) [2069046]
- bpf, docs: Document the opcode classes (Artem Savkov) [2069046]
- bpf, docs: Add subsections for ALU and JMP instructions (Artem Savkov) [2069046]
- bpf, docs: Add a setion to explain the basic instruction encoding (Artem Savkov) [2069046]
- bpf: Don't promote bogus looking registers after null check. (Artem Savkov) [2069046]
- bpf, selftests: Add verifier test for mem_or_null register with offset. (Artem Savkov) [2069046]
- bpftool: Probe for instruction set extensions (Artem Savkov) [2069046]
- bpftool: Probe for bounded loop support (Artem Savkov) [2069046]
- bpftool: Refactor misc. feature probe (Artem Savkov) [2069046]
- bpf: Fix typo in a comment in bpf lpm_trie. (Artem Savkov) [2069046]
- bpf, docs: Move the packet access instructions last in instruction-set.rst (Artem Savkov) [2069046]
- bpf, docs: Generate nicer tables for instruction encodings (Artem Savkov) [2069046]
- bpf, docs: Split the comparism to classic BPF from instruction-set.rst (Artem Savkov) [2069046]
- bpf, docs: Fix verifier references (Artem Savkov) [2069046]
- bpf: Invert the dependency between bpf-netns.h and netns/bpf.h (Artem Savkov) [2069046]
- bpf/selftests: Update local storage selftest for sleepable programs (Artem Savkov) [2069046]
- bpf: Allow bpf_local_storage to be used by sleepable programs (Artem Savkov) [2069046]
- libbpf: Improve LINUX_VERSION_CODE detection (Artem Savkov) [2069046]
- libbpf: Use 100-character limit to make bpf_tracing.h easier to read (Artem Savkov) [2069046]
- libbpf: Normalize PT_REGS_xxx() macro definitions (Artem Savkov) [2069046]
- selftests/bpf: Add btf_dump__new to test_cpp (Artem Savkov) [2069046]
- libbpf: Do not use btf_dump__new() macro in C++ mode (Artem Savkov) [2069046]
- bpftool: Enable line buffering for stdout (Artem Savkov) [2069046]
- bpf: Use struct_size() helper (Artem Savkov) [2069046]
- selftests/bpf: Correct the INDEX address in vmtest.sh (Artem Savkov) [2069046]
- bpf: Extend kfunc with PTR_TO_CTX, PTR_TO_MEM argument support (Artem Savkov) [2069046]
- bpf/selftests: Test PTR_TO_RDONLY_MEM (Artem Savkov) [2069046]
- bpf: Add MEM_RDONLY for helper args that are pointers to rdonly mem. (Artem Savkov) [2069046]
- bpf: Make per_cpu_ptr return rdonly PTR_TO_MEM. (Artem Savkov) [2069046]
- bpf: Convert PTR_TO_MEM_OR_NULL to composable types. (Artem Savkov) [2069046]
- bpf: Introduce MEM_RDONLY flag (Artem Savkov) [2069046]
- bpf: Replace PTR_TO_XXX_OR_NULL with PTR_TO_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Replace RET_XXX_OR_NULL with RET_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Replace ARG_XXX_OR_NULL with ARG_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Introduce composable reg, ret and arg types. (Artem Savkov) [2069046]
- bpftool: Reimplement large insn size limit feature probing (Artem Savkov) [2069046]
- selftests/bpf: Add libbpf feature-probing API selftests (Artem Savkov) [2069046]
- libbpf: Rework feature-probing APIs (Artem Savkov) [2069046]
- Only output backtracking information in log level 2 (Artem Savkov) [2069046]
- bpf: Right align verifier states in verifier logs. (Artem Savkov) [2069046]
- bpf: Only print scratched registers and stack slots to verifier logs. (Artem Savkov) [2069046]
- bpf: Remove the cgroup -> bpf header dependecy (Artem Savkov) [2069046]
- add missing bpf-cgroup.h includes (Artem Savkov) [2069046]
- selftests/bpf: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/runqslower: Enable cross-building with clang (Artem Savkov) [2069046]
- bpftool: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/libbpf: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/resolve_btfids: Support cross-building the kernel with clang (Artem Savkov) [2069046]
- libbpf: Avoid reading past ELF data section end when copying license (Artem Savkov) [2069046]
- libbpf: Mark bpf_object__find_program_by_title API deprecated. (Artem Savkov) [2069046]
- samples/bpf: Stop using bpf_object__find_program_by_title API. (Artem Savkov) [2069046]
- selftests/bpf: Stop using bpf_object__find_program_by_title API. (Artem Savkov) [2069046]
- selftests/bpf: Remove explicit setrlimit(RLIMIT_MEMLOCK) in main selftests (Artem Savkov) [2069046]
- libbpf: Auto-bump RLIMIT_MEMLOCK if kernel needs it for BPF (Artem Savkov) [2069046]
- libbpf: Add sane strncpy alternative and use it internally (Artem Savkov) [2069046]
- libbpf: Fix potential uninit memory read (Artem Savkov) [2069046]
- libbpf: Add doc comments for bpf_program__(un)pin() (Artem Savkov) [2069046]
- selftests/bpf: Fix segfault in bpf_tcp_ca (Artem Savkov) [2069046]
- selftests/bpf: Add tests for get_func_[arg|ret|arg_cnt] helpers (Artem Savkov) [2069046]
- bpf: Add get_func_[arg|ret|arg_cnt] helpers (Artem Savkov) [2069046]
- bpf, x64: Replace some stack_size usage with offset variables (Artem Savkov) [2069046]
- selftests/bpf: Add test to access int ptr argument in tracing program (Artem Savkov) [2069046]
- bpf: Allow access to int pointer arguments in tracing programs (Artem Savkov) [2069046]
- libbpf: Don't validate TYPE_ID relo's original imm value (Artem Savkov) [2069046]
- selftests/bpf: Remove last bpf_create_map_xattr from test_verifier (Artem Savkov) [2069046]
- bpf: Silence coverity false positive warning. (Artem Savkov) [2069046]
- bpf: Use kmemdup() to replace kmalloc + memcpy (Artem Savkov) [2069046]
- selftests/bpf: Add test cases for bpf_strncmp() (Artem Savkov) [2069046]
- selftests/bpf: Add benchmark for bpf_strncmp() helper (Artem Savkov) [2069046]
- selftests/bpf: Fix checkpatch error on empty function parameter (Artem Savkov) [2069046]
- bpf: Add bpf_strncmp helper (Artem Savkov) [2069046]
- libbpf: Fix typo in btf__dedup@LIBBPF_0.0.2 definition (Artem Savkov) [2069046]
- bpftool: Switch bpf_object__load_xattr() to bpf_object__load() (Artem Savkov) [2069046]
- selftests/bpf: Remove the only use of deprecated bpf_object__load_xattr() (Artem Savkov) [2069046]
- selftests/bpf: Add test for libbpf's custom log_buf behavior (Artem Savkov) [2069046]
- selftests/bpf: Replace all uses of bpf_load_btf() with bpf_btf_load() (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_object__load_xattr() (Artem Savkov) [2069046]
- libbpf: Add per-program log buffer setter and getter (Artem Savkov) [2069046]
- libbpf: Preserve kernel error code and remove kprobe prog type guessing (Artem Savkov) [2069046]
- libbpf: Improve logging around BPF program loading (Artem Savkov) [2069046]
- libbpf: Allow passing user log setting through bpf_object_open_opts (Artem Savkov) [2069046]
- libbpf: Allow passing preallocated log_buf when loading BTF into kernel (Artem Savkov) [2069046]
- libbpf: Add OPTS-based bpf_btf_load() API (Artem Savkov) [2069046]
- libbpf: Fix bpf_prog_load() log_buf logic for log_level 0 (Artem Savkov) [2069046]
- samples/bpf: Remove unneeded variable (Artem Savkov) [2069046]
- bpf: Remove redundant assignment to pointer t (Artem Savkov) [2069046]
- selftests/bpf: Fix a compilation warning (Artem Savkov) [2069046]
- bpf: Silence purge_cand_cache build warning. (Artem Savkov) [2069046]
- libbpf: Add doc comments in libbpf.h (Artem Savkov) [2069046]
- libbpf: Fix trivial typo (Artem Savkov) [2069046]
- bpftool: Add debug mode for gen_loader. (Artem Savkov) [2069046]
- bpf: Disallow BPF_LOG_KERNEL log level for bpf(BPF_BTF_LOAD) (Artem Savkov) [2069046]
- bpf: Fix the test_task_vma selftest to support output shorter than 1 kB (Artem Savkov) [2069046]
- libbpf: Reduce bpf_core_apply_relo_insn() stack usage. (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_prog_load_xattr() API (Artem Savkov) [2069046]
- samples/bpf: Get rid of deprecated libbpf API uses (Artem Savkov) [2069046]
- samples/bpf: Clean up samples/bpf build failes (Artem Savkov) [2069046]
- selftests/bpf: Remove all the uses of deprecated bpf_prog_load_xattr() (Artem Savkov) [2069046]
- selftests/bpf: Mute xdpxceiver.c's deprecation warnings (Artem Savkov) [2069046]
- selftests/bpf: Remove recently reintroduced legacy btf__dedup() use (Artem Savkov) [2069046]
- bpftool: Migrate off of deprecated bpf_create_map_xattr() API (Artem Savkov) [2069046]
- libbpf: Add API to get/set log_level at per-program level (Artem Savkov) [2069046]
- libbpf: Use __u32 fields in bpf_map_create_opts (Artem Savkov) [2069046]
- selftests/bpf: Update test names for xchg and cmpxchg (Artem Savkov) [2069046]
- selftests/bpf: Build testing_helpers.o out of tree (Artem Savkov) [2069046]
- selftests/bpf: Add CO-RE relocations to verifier scale test. (Artem Savkov) [2069046]
- selftests/bpf: Revert CO-RE removal in test_ksyms_weak. (Artem Savkov) [2069046]
- selftests/bpf: Additional test for CO-RE in the kernel. (Artem Savkov) [2069046]
- selftests/bpf: Convert map_ptr_kern test to use light skeleton. (Artem Savkov) [2069046]
- selftests/bpf: Improve inner_map test coverage. (Artem Savkov) [2069046]
- selftests/bpf: Add lskel version of kfunc test. (Artem Savkov) [2069046]
- libbpf: Clean gen_loader's attach kind. (Artem Savkov) [2069046]
- libbpf: Support init of inner maps in light skeleton. (Artem Savkov) [2069046]
- libbpf: Use CO-RE in the kernel in light skeleton. (Artem Savkov) [2069046]
- bpf: Add bpf_core_add_cands() and wire it into bpf_core_apply_relo_insn(). (Artem Savkov) [2069046]
- libbpf: Cleanup struct bpf_core_cand. (Artem Savkov) [2069046]
- bpf: Adjust BTF log size limit. (Artem Savkov) [2069046]
- bpf: Pass a set of bpf_core_relo-s to prog_load command. (Artem Savkov) [2069046]
- bpf: Define enum bpf_core_relo_kind as uapi. (Artem Savkov) [2069046]
- bpf: Prepare relo_core.c for kernel duty. (Artem Savkov) [2069046]
- bpf: Rename btf_member accessors. (Artem Savkov) [2069046]
- libbpf: Replace btf__type_by_id() with btf_type_by_id(). (Artem Savkov) [2069046]
- samples: bpf: Fix conflicting types in fds_example (Artem Savkov) [2069046]
- bpf: Clean-up bpf_verifier_vlog() for BPF_LOG_KERNEL log level (Artem Savkov) [2069046]
- libbpf: Avoid reload of imm for weak, unresolved, repeating ksym (Artem Savkov) [2069046]
- libbpf: Avoid double stores for success/failure case of ksym relocations (Artem Savkov) [2069046]
- bpf: Change bpf_kallsyms_lookup_name size type to ARG_CONST_SIZE_OR_ZERO (Artem Savkov) [2069046]
- selftest/bpf/benchs: Add bpf_loop benchmark (Artem Savkov) [2069046]
- selftests/bpf: Measure bpf_loop verifier performance (Artem Savkov) [2069046]
- selftests/bpf: Add bpf_loop test (Artem Savkov) [2069046]
- bpf: Add bpf_loop helper (Artem Savkov) [2069046]
- bpf, docs: Split general purpose eBPF documentation out of filter.rst (Artem Savkov) [2069046]
- bpf, docs: Move handling of maps to Documentation/bpf/maps.rst (Artem Savkov) [2069046]
- bpf, docs: Prune all references to "internal BPF" (Artem Savkov) [2069046]
- bpf: Remove a redundant comment on bpf_prog_free (Artem Savkov) [2069046]
- x86, bpf: Cleanup the top of file header in bpf_jit_comp.c (Artem Savkov) [2069046]
- libbpf: Remove duplicate assignments (Artem Savkov) [2069046]
- selftests/bpf: Test BPF_MAP_TYPE_PROG_ARRAY static initialization (Artem Savkov) [2069046]
- libbpf: Support static initialization of BPF_MAP_TYPE_PROG_ARRAY (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned accesses in xdp and xdp_bpf2bpf tests (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned memory accesses in xdp_bonding test (Artem Savkov) [2069046]
- selftests/bpf: Prevent out-of-bounds stack access in test_bpffs (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned memory access in queue_stack_map test (Artem Savkov) [2069046]
- selftests/bpf: Prevent misaligned memory access in get_stack_raw_tp test (Artem Savkov) [2069046]
- selftests/bpf: Fix possible NULL passed to memcpy() with zero size (Artem Savkov) [2069046]
- selftests/bpf: Fix UBSan complaint about signed __int128 overflow (Artem Savkov) [2069046]
- libbpf: Fix using invalidated memory in bpf_linker (Artem Savkov) [2069046]
- libbpf: Fix glob_syms memory leak in bpf_linker (Artem Savkov) [2069046]
- libbpf: Don't call libc APIs with NULL pointers (Artem Savkov) [2069046]
- libbpf: Fix potential misaligned memory access in btf_ext__new() (Artem Savkov) [2069046]
- tools/resolve_btf_ids: Close ELF file on error (Artem Savkov) [2069046]
- selftests/bpf: Migrate selftests to bpf_map_create() (Artem Savkov) [2069046]
- libbpf: Prevent deprecation warnings in xsk.c (Artem Savkov) [2069046]
- libbpf: Use bpf_map_create() consistently internally (Artem Savkov) [2069046]
- libbpf: Unify low-level map creation APIs w/ new bpf_map_create() (Artem Savkov) [2069046]
- selftests/bpf: Mix legacy (maps) and modern (vars) BPF in one test (Artem Savkov) [2069046]
- bpf ppc64: Access only if addr is kernel address (Artem Savkov) [2069046]
- bpf ppc64: Add BPF_PROBE_MEM support for JIT (Artem Savkov) [2069046]
- powerpc/ppc-opcode: introduce PPC_RAW_BRANCH() macro (Artem Savkov) [2069046]
- bpf powerpc: refactor JIT compiler code (Artem Savkov) [2069046]
- bpf powerpc: Remove extra_pass from bpf_jit_build_body() (Artem Savkov) [2069046]
- bpf powerpc: Remove unused SEEN_STACK (Artem Savkov) [2069046]
- selftests/bpf: Fix trivial typo (Artem Savkov) [2069046]
- libbpf: Change bpf_program__set_extra_flags to bpf_program__set_flags (Artem Savkov) [2069046]
- selftests/bpf: Add btf_dedup case with duplicated structs within CU (Artem Savkov) [2069046]
- libbpf: Accommodate DWARF/compiler bug with duplicated structs (Artem Savkov) [2069046]
- libbpf: Add runtime APIs to query libbpf version (Artem Savkov) [2069046]
- selfetests/bpf: Adapt vmtest.sh to s390 libbpf CI changes (Artem Savkov) [2069046]
- bpf, docs: Fix ordering of bpf documentation (Artem Savkov) [2069046]
- bpf, docs: Rename bpf_lsm.rst to prog_lsm.rst (Artem Savkov) [2069046]
- bpf, docs: Change underline in btf to match style guide (Artem Savkov) [2069046]
- selftests/bpf: Mark variable as static (Artem Savkov) [2069046]
- selftests/bpf: Variable naming fix (Artem Savkov) [2069046]
- selftests/bpf: Move summary line after the error logs (Artem Savkov) [2069046]
- selftests/bpf: Add uprobe triggering overhead benchmarks (Artem Savkov) [2069046]
- selftests/bpf: Configure dir paths via env in test_bpftool_synctypes.py (Artem Savkov) [2069046]
- bpftool: Update doc (use susbtitutions) and test_bpftool_synctypes.py (Artem Savkov) [2069046]
- bpftool: Add SPDX tags to RST documentation files (Artem Savkov) [2069046]
- selftests/bpf: Add a dedup selftest with equivalent structure types (Artem Savkov) [2069046]
- libbpf: Fix a couple of missed btf_type_tag handling in btf.c (Artem Savkov) [2069046]
- bpftool: Add current libbpf_strict mode to version output (Artem Savkov) [2069046]
- bpftool: Use libbpf_get_error() to check error (Artem Savkov) [2069046]
- bpftool: Fix mixed indentation in documentation (Artem Savkov) [2069046]
- bpftool: Update the lists of names for maps and prog-attach types (Artem Savkov) [2069046]
- bpftool: Remove inclusion of utilities.mak from Makefiles (Artem Savkov) [2069046]
- bpftool: Fix memory leak in prog_dump() (Artem Savkov) [2069046]
- selftests/bpf: Fix a tautological-constant-out-of-range-compare compiler warning (Artem Savkov) [2069046]
- selftests/bpf: Fix an unused-but-set-variable compiler warning (Artem Savkov) [2069046]
- bpf: Introduce btf_tracing_ids (Artem Savkov) [2069046]
- bpf: Extend BTF_ID_LIST_GLOBAL with parameter for number of IDs (Artem Savkov) [2069046]
- docs/bpf: Update documentation for BTF_KIND_TYPE_TAG support (Artem Savkov) [2069046]
- selftests/bpf: Clarify llvm dependency with btf_tag selftest (Artem Savkov) [2069046]
- selftests/bpf: Add a C test for btf_type_tag (Artem Savkov) [2069046]
- selftests/bpf: Rename progs/tag.c to progs/btf_decl_tag.c (Artem Savkov) [2069046]
- selftests/bpf: Test BTF_KIND_DECL_TAG for deduplication (Artem Savkov) [2069046]
- selftests/bpf: Add BTF_KIND_TYPE_TAG unit tests (Artem Savkov) [2069046]
- selftests/bpf: Test libbpf API function btf__add_type_tag() (Artem Savkov) [2069046]
- bpftool: Support BTF_KIND_TYPE_TAG (Artem Savkov) [2069046]
- libbpf: Support BTF_KIND_TYPE_TAG (Artem Savkov) [2069046]
- bpf: Support BTF_KIND_TYPE_TAG for btf_type_tag attributes (Artem Savkov) [2069046]
- bpftool: Update btf_dump__new() and perf_buffer__new_raw() calls (Artem Savkov) [2069046]
- tools/runqslower: Update perf_buffer__new() calls (Artem Savkov) [2069046]
- selftests/bpf: Update btf_dump__new() uses to v1.0+ variant (Artem Savkov) [2069046]
- selftests/bpf: Migrate all deprecated perf_buffer uses (Artem Savkov) [2069046]
- libbpf: Make perf_buffer__new() use OPTS-based interface (Artem Savkov) [2069046]
- libbpf: Ensure btf_dump__new() and btf_dump_opts are future-proof (Artem Savkov) [2069046]
- libbpf: Turn btf_dedup_opts into OPTS-based struct (Artem Savkov) [2069046]
- selftests/bpf: Minor cleanups and normalization of Makefile (Artem Savkov) [2069046]
- bpftool: Normalize compile rules to specify output file last (Artem Savkov) [2069046]
- selftests/bpf: Fix bpf_prog_test_load() logic to pass extra log level (Artem Savkov) [2069046]
- libbpf: Add ability to get/set per-program load flags (Artem Savkov) [2069046]
- selftests/bpf: Add tests for accessing ingress_ifindex in bpf_sk_lookup (Artem Savkov) [2069046]
- bpf: Add ingress_ifindex to bpf_sk_lookup (Artem Savkov) [2069046]
- bpftool: Fix SPDX tag for Makefiles and .gitignore (Artem Savkov) [2069046]
- libbpf: Compile using -std=gnu89 (Artem Savkov) [2069046]
- selftests/bpf: Add exception handling selftests for tp_bpf program (Artem Savkov) [2069046]
- selftests/bpf: Add tests for bpf_find_vma (Artem Savkov) [2069046]
- bpf: Introduce helper bpf_find_vma (Artem Savkov) [2069046]
- selftests/bpf: Fix bpf_object leak in skb_ctx selftest (Artem Savkov) [2069046]
- selftests/bpf: Destroy XDP link correctly (Artem Savkov) [2069046]
- selftests/bpf: Avoid duplicate btf__parse() call (Artem Savkov) [2069046]
- selftests/bpf: Clean up btf and btf_dump in dump_datasec test (Artem Savkov) [2069046]
- selftests/bpf: Free inner strings index in btf selftest (Artem Savkov) [2069046]
- selftests/bpf: Free per-cpu values array in bpf_iter selftest (Artem Savkov) [2069046]
- selftests/bpf: Fix memory leaks in btf_type_c_dump() helper (Artem Savkov) [2069046]
- libbpf: Free up resources used by inner map definition (Artem Savkov) [2069046]
- selftests/bpf: Pass sanitizer flags to linker through LDFLAGS (Artem Savkov) [2069046]
- selftests/bpf: Use explicit bpf_test_load_program() helper calls (Artem Savkov) [2069046]
- selftests/bpf: Use explicit bpf_prog_test_load() calls everywhere (Artem Savkov) [2069046]
- selftests/bpf: Merge test_stub.c into testing_helpers.c (Artem Savkov) [2069046]
- selftests/bpf: Convert legacy prog load APIs to bpf_prog_load() (Artem Savkov) [2069046]
- selftests/bpf: Fix non-strict SEC() program sections (Artem Savkov) [2069046]
- bpftool: Stop using deprecated bpf_load_program() (Artem Savkov) [2069046]
- libbpf: Stop using to-be-deprecated APIs (Artem Savkov) [2069046]
- libbpf: Remove internal use of deprecated bpf_prog_load() variants (Artem Savkov) [2069046]
- libbpf: Unify low-level BPF_PROG_LOAD APIs into bpf_prog_load() (Artem Savkov) [2069046]
- libbpf: Pass number of prog load attempts explicitly (Artem Savkov) [2069046]
- libbpf: Rename DECLARE_LIBBPF_OPTS into LIBBPF_OPTS (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_program__load() API (Artem Savkov) [2069046]
- libbpf: Improve ELF relo sanitization (Artem Savkov) [2069046]
- libbpf: Validate that .BTF and .BTF.ext sections contain data (Artem Savkov) [2069046]
- libbpf: Improve sanity checking during BTF fix up (Artem Savkov) [2069046]
- libbpf: Detect corrupted ELF symbols section (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_program__get_prog_info_linear (Artem Savkov) [2069046]
- bpftool: Use bpf_obj_get_info_by_fd directly (Artem Savkov) [2069046]
- bpftool: Migrate -1 err checks of libbpf fn calls (Artem Savkov) [2069046]
- redhat: configs: add CONFIG_SERIAL_MULTI_INSTANTIATE=m for x86_64 (Jaroslav Kysela) [2123651]
- ACPI: scan: Add CLSA0101 Laptop Support (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Add CLSA0101 Laptop (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Sort ACPI IDs by HID (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Get rid of redundant 'else' (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Use while (i--) pattern to clean up (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Improve dev_err_probe() messaging (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Drop duplicate check (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Improve autodetection (Jaroslav Kysela) [2123651]
- ACPI / scan: Create platform device for CS35L41 (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Add SPI support (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Reorganize I2C functions (Jaroslav Kysela) [2123651]
- platform/x86: i2c-multi-instantiate: Rename it for a generic serial driver name (Jaroslav Kysela) [2123651]
- Revert "platform/x86: i2c-multi-instantiate: Don't create platform device for INT3515 ACPI nodes" (Jaroslav Kysela) [2123651]
- platform/x86: i2c-multi-instantiate: Use the new i2c_acpi_client_count() helper (Jaroslav Kysela) [2123651]
- spi: Return deferred probe error when controller isn't yet available (Jaroslav Kysela) [2123651]
- spi: Add API to count spi acpi resources (Jaroslav Kysela) [2123651]
- spi: Support selection of the index of the ACPI Spi Resource before alloc (Jaroslav Kysela) [2123651]
- spi: Create helper API to lookup ACPI info for spi device (Jaroslav Kysela) [2123651]
- i2c: acpi: Add an i2c_acpi_client_count() helper function (Jaroslav Kysela) [2123651]

* Thu Sep 22 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-167.el9]
- powerpc/perf: Optimize clearing the pending PMI and remove WARN_ON for PMI check in power_pmu_disable (Steve Best) [2116680]
- assoc_array: Fix BUG_ON during garbage collect (Dave Wysochanski) [2117318]
- cpufreq: intel_pstate: Handle no_turbo in frequency invariance (Phil Auld) [2100595]
- sched/fair: Introduce SIS_UTIL to search idle CPU based on sum of util_avg (Phil Auld) [2100595]
- sched/fair: Consider CPU affinity when allowing NUMA imbalance in find_idlest_group() (Phil Auld) [2110021]
- sched/numa: Adjust imb_numa_nr to a better approximation of memory channels (Phil Auld) [2110021]
- sched/numa: Apply imbalance limitations consistently (Phil Auld) [2110021]
- sched/numa: Do not swap tasks between nodes when spare capacity is available (Phil Auld) [2110021]
- sched/numa: Initialise numa_migrate_retry (Phil Auld) [2110021]
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM (Steve Best) [2122830]
- powerpc/watchdog: introduce a NMI watchdog's factor (Steve Best) [2122830]
- watchdog: export lockup_detector_reconfigure (Steve Best) [2122830]
- powerpc/mobility: wait for memory transfer to complete (Steve Best) [2122830]
- srcu: Make expedited RCU grace periods block even less frequently (Waiman Long) [2117491]
- srcu: Block less aggressively for expedited grace periods (Waiman Long) [2117491]
- rcu: Move expedited grace period (GP) work to RT kthread_worker (Waiman Long) [2117491]
- redhat/configs: Introduce CONFIG_RCU_EXP_CPU_STALL_TIMEOUT (Waiman Long) [2117491]
- rcu: Introduce CONFIG_RCU_EXP_CPU_STALL_TIMEOUT (Waiman Long) [2117491]
- srcu: Drop needless initialization of sdp in srcu_gp_start() (Waiman Long) [2117491]
- srcu: Prevent expedited GPs and blocking readers from consuming CPU (Waiman Long) [2117491]
- srcu: Add contention check to call_srcu() srcu_data ->lock acquisition (Waiman Long) [2117491]
- srcu: Automatically determine size-transition strategy at boot (Waiman Long) [2117491]
- rcutorture: Make torture.sh allow for --kasan (Waiman Long) [2117491]
- rcutorture: Make torture.sh refscale and rcuscale specify Tasks Trace RCU (Waiman Long) [2117491]
- rcutorture: Make kvm.sh allow more memory for --kasan runs (Waiman Long) [2117491]
- torture: Save "make allmodconfig" .config file (Waiman Long) [2117491]
- scftorture: Remove extraneous "scf" from per_version_boot_params (Waiman Long) [2117491]
- rcutorture: Adjust scenarios' Kconfig options for CONFIG_PREEMPT_DYNAMIC (Waiman Long) [2117491]
- torture: Enable CSD-lock stall reports for scftorture (Waiman Long) [2117491]
- torture: Skip vmlinux check for kvm-again.sh runs (Waiman Long) [2117491]
- scftorture: Adjust for TASKS_RCU Kconfig option being selected (Waiman Long) [2117491]
- rcuscale: Allow rcuscale without RCU Tasks Rude/Trace (Waiman Long) [2117491]
- rcuscale: Allow rcuscale without RCU Tasks (Waiman Long) [2117491]
- refscale: Allow refscale without RCU Tasks Rude/Trace (Waiman Long) [2117491]
- refscale: Allow refscale without RCU Tasks (Waiman Long) [2117491]
- rcutorture: Allow specifying per-scenario stat_interval (Waiman Long) [2117491]
- rcutorture: Add CONFIG_PREEMPT_DYNAMIC=n to TASKS02 scenario (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks Rude (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks Trace (Waiman Long) [2117491]
- rcu: Make the TASKS_RCU Kconfig option be selected (Waiman Long) [2117491]
- rcu: Use IRQ_WORK_INIT_HARD() to avoid rcu_read_unlock() hangs (Waiman Long) [2117491]
- rcu_sync: Fix comment to properly reflect rcu_sync_exit() behavior (Waiman Long) [2117491]
- rcu: Check for successful spawn of ->boost_kthread_task (Waiman Long) [2117491]
- rcu: Fix preemption mode check on synchronize_rcu[_expedited]() (Waiman Long) [2117491]
- rcu: Print number of online CPUs in RCU CPU stall-warning messages (Waiman Long) [2117491]
- rcu: Add comments to final rcu_gp_cleanup() "if" statement (Waiman Long) [2117491]
- kernel/smp: Provide boot-time timeout for CSD lock diagnostics (Waiman Long) [2117491]
- docs: Update RCU cross-references as suggested in doc-guide (Waiman Long) [2117491]
- docs: Add documentation for rude and trace RCU flavors (Waiman Long) [2117491]
- rcu: Check for jiffies going backwards (Waiman Long) [2117491]
- rcu: Fix rcu_preempt_deferred_qs_irqrestore() strict QS reporting (Waiman Long) [2117491]
- rcu: Clarify fill-the-gap comment in rcu_segcblist_advance() (Waiman Long) [2117491]
- torture: Make thread detection more robust by using lspcu (Waiman Long) [2117491]
- torture: Permit running of experimental torture types (Waiman Long) [2117491]
- torture: Use "-o Batchmode=yes" to disable ssh password requests (Waiman Long) [2117491]
- torture: Reposition so that $? collects ssh code in torture.sh (Waiman Long) [2117491]
- rcu: Make TASKS_RUDE_RCU select IRQ_WORK (Waiman Long) [2117491]
- rcutorture: Call preempt_schedule() through static call/key (Waiman Long) [2117491]
- rcutorture: Add missing return and use __func__ in warning (Waiman Long) [2117491]
- rcutorture: Avoid corner-case #DE with nsynctypes check (Waiman Long) [2117491]
- scftorture: Fix distribution of short handler delays (Waiman Long) [2117491]
- rcutorture: Suppress debugging grace period delays during flooding (Waiman Long) [2117491]
- torture: Add rcu_normal and rcu_expedited runs to torture.sh (Waiman Long) [2117491]
- rcu-tasks: Handle sparse cpu_possible_mask in rcu_tasks_invoke_cbs() (Waiman Long) [2117491]
- rcu-tasks: Handle sparse cpu_possible_mask (Waiman Long) [2117491]
- rcu-tasks: Make show_rcu_tasks_generic_gp_kthread() check all CPUs (Waiman Long) [2117491]
- rcu-tasks: Restore use of timers for non-RT kernels (Waiman Long) [2117491]
- rcu-tasks: Use schedule_hrtimeout_range() to wait for grace periods (Waiman Long) [2117491]
- rcu-tasks: Make Tasks RCU account for userspace execution (Waiman Long) [2117491]
- rcu-tasks: Use rcuwait for the rcu_tasks_kthread() (Waiman Long) [2117491]
- rcu-tasks: Print pre-stall-warning informational messages (Waiman Long) [2117491]
- rcu-tasks: Fix race in schedule and flush work (Waiman Long) [2117491]
- rcu/nocb: Initialize nocb kthreads only for boot CPU prior SMP initialization (Waiman Long) [2117491]
- rcu: Initialize boost kthread only for boot node prior SMP initialization (Waiman Long) [2117491]
- rcu: Assume rcu_init() is called before smp (Waiman Long) [2117491]
- rcu/nocb: Move rcu_nocb_is_setup to rcu_state (Waiman Long) [2117491]
- rcu: Remove rcu_is_nocb_cpu() (Waiman Long) [2117491]
- srcu: Add contention-triggered addition of srcu_node tree (Waiman Long) [2117491]
- srcu: Create concurrency-safe helper for initiating size transition (Waiman Long) [2117491]
- srcu: Explain srcu_funnel_gp_start() call to list_add() is safe (Waiman Long) [2117491]
- srcu: Prevent cleanup_srcu_struct() from freeing non-dynamic ->sda (Waiman Long) [2117491]
- srcu: Avoid NULL dereference in srcu_torture_stats_print() (Waiman Long) [2117491]
- srcu: Use export for srcu_struct defined by DEFINE_STATIC_SRCU() (Waiman Long) [2117491]
- srcu: Add boot-time control over srcu_node array allocation (Waiman Long) [2117491]
- srcu: Ensure snp nodes tree is fully initialized before traversal (Waiman Long) [2117491]
- srcu: Use invalid initial value for srcu_node GP sequence numbers (Waiman Long) [2117491]
- srcu: Compute snp_seq earlier in srcu_funnel_gp_start() (Waiman Long) [2117491]
- srcu: Make rcutorture dump the SRCU size state (Waiman Long) [2117491]
- srcu: Add size-state transitioning code (Waiman Long) [2117491]
- srcu: Dynamically allocate srcu_node array (Waiman Long) [2117491]
- srcu: Make Tree SRCU able to operate without snp_node array (Waiman Long) [2117491]
- srcu: Make srcu_funnel_gp_start() cache ->mynode in snp_leaf (Waiman Long) [2117491]
- srcu: Fix s/is/if/ typo in srcu_node comment (Waiman Long) [2117491]
- srcu: Tighten cleanup_srcu_struct() GP checks (Waiman Long) [2117491]
- preempt/dynamic: Introduce preemption model accessors (Waiman Long) [2117491]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Waiman Long) [2117491]

* Wed Sep 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-166.el9]
- scsi: restore setting of scmd->scsi_done() in EH and reset ioctl paths (Ewan D. Milne) [2120469]
- x86/boot: Don't propagate uninitialized boot_params->cc_blob_address (Terry Bowman) [2124644]
- ice: Allow operation with reduced device MSI-X (Petr Oros) [2107719]
- ixgbe: Add locking to prevent panic when setting sriov_numvfs to zero (Ken Cox) [2109871]
- drm/hyperv : Removing the restruction of VRAM allocation with PCI bar size (Vitaly Kuznetsov) [2030922]
- drm/nouveau/kms/nv140-: Disable interlacing (Lyude Paul) [2122068]
- drm/amdgpu: Only disable prefer_shadow on hawaii (Lyude Paul) [2120670]
- i40e: Fix kernel crash during module removal (Ivan Vecera) [2070375]
- Revert "net: macsec: update SCI upon MAC address change." (Sabrina Dubroca) [2118139]
- redhat: enable zstream release numbering for rhel 9.1 (Patrick Talbert)

* Sat Sep 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-165.el9]
- sysctl: returns -EINVAL when a negative value is passed to proc_doulongvec_minmax (Vratislav Bendel) [2121392]
- nvme-fc: fix the fc_appid_store return value (Ewan D. Milne) [2113035]
- i2c: ismt: prevent memory corruption in ismt_access() (David Arcari) [2125582] {CVE-2022-3077}
- scsi: zfcp: Fix missing auto port scan and thus missing target ports (Tobias Huschle) [2121088]
- s390/mmap: increase stack/mmap gap to 128MB (Tobias Huschle) [2080165]
- s390/vdso: add vdso randomization (Tobias Huschle) [2080165]
- s390/vdso: map vdso above stack (Tobias Huschle) [2080165]
- s390/vdso: move vdso mapping to its own function (Tobias Huschle) [2080165]
- netfs: do not unlock and put the folio twice (Jeffrey Layton) [1229736]
- netfs: Rename the netfs_io_request cleanup op and give it an op pointer (Jeffrey Layton) [1229736]
- ceph: call netfs_subreq_terminated with was_async == false (Jeffrey Layton) [1229736]
- ceph: fix decoding of client session messages flags (Jeffrey Layton) [1229736]
- netfs: Fix gcc-12 warning by embedding vfs inode in netfs_i_context (Jeffrey Layton) [1229736]
- netfs: Eliminate Clang randstruct warning (Jeffrey Layton) [1229736]
- ceph: replace usage of found with dedicated list iterator variable (Jeffrey Layton) [1229736]
- Invalidate fscache cookie only when inode attributes are changed. (Jeffrey Layton) [1229736]
- fscache: add tracepoint when failing cookie (Jeffrey Layton) [1229736]
- fscache: don't leak cookie access refs if invalidation is in progress or failed (Jeffrey Layton) [1229736]
- vfs: Check the truncate maximum size in inode_newsize_ok() (Jeffrey Layton) [1229736]
- fscache: Fix invalidation/lookup race (Jeffrey Layton) [1229736]
- cachefiles: narrow the scope of flushed requests when releasing fd (Jeffrey Layton) [1229736]
- fscache: Introduce fscache_cookie_is_dropped() (Jeffrey Layton) [1229736]
- fscache: Fix if condition in fscache_wait_on_volume_collision() (Jeffrey Layton) [1229736]
- NFS: Pass i_size to fscache_unuse_cookie() when a file is released (Jeffrey Layton) [1229736]
- NFS: Remove remaining dfprintks related to fscache and remove NFSDBG_FSCACHE (Jeffrey Layton) [1229736]
- NFS: Replace dfprintks with tracepoints in fscache read and write page functions (Jeffrey Layton) [1229736]
- NFS: Rename fscache read and write pages functions (Jeffrey Layton) [1229736]
- NFS: Cleanup usage of nfs_inode in fscache interface (Jeffrey Layton) [1229736]
- config: disable CONFIG_CACHEFILES_ERROR_INJECTION and CONFIG_CACHEFILES_ONDEMAND (Jeffrey Layton) [1229736]
- afs: Fix afs_getattr() to refetch file status if callback break occurred (Jeffrey Layton) [1229736]
- cachefiles: add tracepoints for on-demand read mode (Jeffrey Layton) [1229736]
- cachefiles: enable on-demand read mode (Jeffrey Layton) [1229736]
- cachefiles: implement on-demand read (Jeffrey Layton) [1229736]
- cachefiles: notify the user daemon when withdrawing cookie (Jeffrey Layton) [1229736]
- cachefiles: unbind cachefiles gracefully in on-demand mode (Jeffrey Layton) [1229736]
- cachefiles: notify the user daemon when looking up cookie (Jeffrey Layton) [1229736]
- cachefiles: extract write routine (Jeffrey Layton) [1229736]
- fscache: remove FSCACHE_OLD_API Kconfig option (Jeffrey Layton) [1229736]
- fscache: Use wrapper fscache_set_cache_state() directly when relinquishing (Jeffrey Layton) [1229736]
- fscache: Move fscache_cookies_seq_ops specific code under CONFIG_PROC_FS (Jeffrey Layton) [1229736]
- fscache: Remove the cookie parameter from fscache_clear_page_bits() (Jeffrey Layton) [1229736]
- cachefiles: Fix KASAN slab-out-of-bounds in cachefiles_set_volume_xattr (Jeffrey Layton) [1229736]
- cachefiles: unmark inode in use in error path (Jeffrey Layton) [1229736]
- ceph: uninitialized variable in debug output (Jeffrey Layton) [1229736]
- afs: Maintain netfs_i_context::remote_i_size (Jeffrey Layton) [1229736]
- netfs: Split some core bits out into their own file (Jeffrey Layton) [1229736]
- netfs: Split fs/netfs/read_helper.c (Jeffrey Layton) [1229736]
- netfs: Rename read_helper.c to io.c (Jeffrey Layton) [1229736]
- netfs: Prepare to split read_helper.c (Jeffrey Layton) [1229736]
- netfs: Add a function to consolidate beginning a read (Jeffrey Layton) [1229736]
- netfs: Keep track of the actual remote file size (Jeffrey Layton) [1229736]
- netfs: Add a netfs inode context (Jeffrey Layton) [1229736]
- ceph: Make ceph_init_request() check caps on readahead (Jeffrey Layton) [1229736]
- netfs: Change ->init_request() to return an error code (Jeffrey Layton) [1229736]
- netfs: Refactor arguments for netfs_alloc_read_request (Jeffrey Layton) [1229736]
- netfs: Adjust the netfs_failure tracepoint to indicate non-subreq lines (Jeffrey Layton) [1229736]
- netfs: Trace refcounting on the netfs_io_subrequest struct (Jeffrey Layton) [1229736]
- netfs: Trace refcounting on the netfs_io_request struct (Jeffrey Layton) [1229736]
- netfs: Adjust the netfs_rreq tracepoint slightly (Jeffrey Layton) [1229736]
- netfs: Split netfs_io_* object handling out (Jeffrey Layton) [1229736]
- netfs: Finish off rename of netfs_read_request to netfs_io_request (Jeffrey Layton) [1229736]
- netfs: Rename netfs_read_*request to netfs_io_*request (Jeffrey Layton) [1229736]
- netfs: Generate enums from trace symbol mapping lists (Jeffrey Layton) [1229736]
- fscache: export fscache_end_operation() (Jeffrey Layton) [1229736]
- cachefiles: Fix volume coherency attribute (Jeffrey Layton) [1229736]
- afs: Fix potential thrashing in afs writeback (Jeffrey Layton) [1229736]
- cachefiles: Fix incorrect length to fallocate() (Jeffrey Layton) [1229736]
- ceph: uninline the data on a file opened for writing (Jeffrey Layton) [1229736]
- ceph: make ceph_netfs_issue_op() handle inlined data (Jeffrey Layton) [1229736]
- cifs: Implement cache I/O by accessing the cache directly (Jeffrey Layton) [1229736]
- cifs: Transition from ->readpages() to ->readahead() (Jeffrey Layton) [1229736]
- netfs, cachefiles: Add a method to query presence of data in the cache (Jeffrey Layton) [1229736]
- Revert "fs/9p: search open fids first" (Jeffrey Layton) [1229736]
- netfs: Make ops->init_rreq() optional (Jeffrey Layton) [1229736]
- fscache: Add a comment explaining how page-release optimisation works (Jeffrey Layton) [1229736]
- cachefiles: Check that the backing filesystem supports tmpfiles (Jeffrey Layton) [1229736]
- cachefiles: Explain checks in a comment (Jeffrey Layton) [1229736]
- cachefiles: Trace active-mark failure (Jeffrey Layton) [1229736]
- cachefiles: Make some tracepoint adjustments (Jeffrey Layton) [1229736]
- cachefiles: set default tag name if it's unspecified (Jeffrey Layton) [1229736]
- cachefiles: Calculate the blockshift in terms of bytes, not pages (Jeffrey Layton) [1229736]
- fscache: Fix the volume collision wait condition (Jeffrey Layton) [1229736]
- cifs: Support fscache indexing rewrite (Jeffrey Layton) [1229736]
- 9p, afs, ceph, nfs: Use current_is_kswapd() rather than gfpflags_allow_blocking() (Jeffrey Layton) [1229736]
- fscache: Add a tracepoint for cookie use/unuse (Jeffrey Layton) [1229736]
- ceph: add fscache writeback support (Jeffrey Layton) [1229736]
- ceph: conversion to new fscache API (Jeffrey Layton) [1229736]
- 9p: fix enodata when reading growing file (Jeffrey Layton) [1229736]
- nfs: Implement cache I/O by accessing the cache directly (Jeffrey Layton) [1229736]
- nfs: Convert to new fscache volume/cookie API (Jeffrey Layton) [1229736]
- 9p: Copy local writes to the cache when writing to the server (Jeffrey Layton) [1229736]
- 9p: Use fscache indexing rewrite and reenable caching (Jeffrey Layton) [1229736]
- 9p: only copy valid iattrs in 9P2000.L setattr implementation (Jeffrey Layton) [1229736]
- 9p: Use BUG_ON instead of if condition followed by BUG. (Jeffrey Layton) [1229736]
- afs: Skip truncation on the server of data we haven't written yet (Jeffrey Layton) [1229736]
- afs: Copy local writes to the cache when writing to the server (Jeffrey Layton) [1229736]
- afs: Convert afs to use the new fscache API (Jeffrey Layton) [1229736]
- fscache, cachefiles: Display stat of culling events (Jeffrey Layton) [1229736]
- fscache, cachefiles: Display stats of no-space events (Jeffrey Layton) [1229736]
- cachefiles: Allow cachefiles to actually function (Jeffrey Layton) [1229736]
- fscache, cachefiles: Store the volume coherency data (Jeffrey Layton) [1229736]
- cachefiles: Implement the I/O routines (Jeffrey Layton) [1229736]
- cachefiles: Implement cookie resize for truncate (Jeffrey Layton) [1229736]
- cachefiles: Implement begin and end I/O operation (Jeffrey Layton) [1229736]
- cachefiles: Implement backing file wrangling (Jeffrey Layton) [1229736]
- cachefiles: Implement culling daemon commands (Jeffrey Layton) [1229736]
- cachefiles: Mark a backing file in use with an inode flag (Jeffrey Layton) [1229736]
- cachefiles: Implement metadata/coherency data storage in xattrs (Jeffrey Layton) [1229736]
- cachefiles: Implement key to filename encoding (Jeffrey Layton) [1229736]
- cachefiles: Implement object lifecycle funcs (Jeffrey Layton) [1229736]
- cachefiles: Add tracepoints for calls to the VFS (Jeffrey Layton) [1229736]
- cachefiles: Implement volume support (Jeffrey Layton) [1229736]
- cachefiles: Implement cache registration and withdrawal (Jeffrey Layton) [1229736]
- cachefiles: Implement a function to get/create a directory in the cache (Jeffrey Layton) [1229736]
- vfs, cachefiles: Mark a backing file in use with an inode flag (Jeffrey Layton) [1229736]
- cachefiles: Provide a function to check how much space there is (Jeffrey Layton) [1229736]
- cachefiles: Register a miscdev and parse commands over it (Jeffrey Layton) [1229736]
- cachefiles: Add security derivation (Jeffrey Layton) [1229736]
- cachefiles: Add cache error reporting macro (Jeffrey Layton) [1229736]
- cachefiles: Add a couple of tracepoints for logging errors (Jeffrey Layton) [1229736]
- cachefiles: Add some error injection support (Jeffrey Layton) [1229736]
- cachefiles: Define structs (Jeffrey Layton) [1229736]
- cachefiles: Introduce rewritten driver (Jeffrey Layton) [1229736]
- fscache: Provide a function to resize a cookie (Jeffrey Layton) [1229736]
- fscache: Provide a function to note the release of a page (Jeffrey Layton) [1229736]
- vfs, fscache: Implement pinning of cache usage for writeback (Jeffrey Layton) [1229736]
- fscache: Implement higher-level write I/O interface (Jeffrey Layton) [1229736]
- fscache: Implement raw I/O interface (Jeffrey Layton) [1229736]
- netfs: Pass more information on how to deal with a hole in the cache (Jeffrey Layton) [1229736]
- fscache: Provide a function to let the netfs update its coherency data (Jeffrey Layton) [1229736]
- fscache: Provide read/write stat counters for the cache (Jeffrey Layton) [1229736]
- fscache: Count data storage objects in a cache (Jeffrey Layton) [1229736]
- fscache: Provide a means to begin an operation (Jeffrey Layton) [1229736]
- fscache: Implement cookie invalidation (Jeffrey Layton) [1229736]
- fscache: Implement cookie user counting and resource pinning (Jeffrey Layton) [1229736]
- fscache: Implement simple cookie state machine (Jeffrey Layton) [1229736]
- fscache: Add a function for a cache backend to note an I/O error (Jeffrey Layton) [1229736]
- fscache: Provide and use cache methods to lookup/create/free a volume (Jeffrey Layton) [1229736]
- fscache: Implement functions add/remove a cache (Jeffrey Layton) [1229736]
- fscache: Implement cookie-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement volume-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement cache-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement cookie registration (Jeffrey Layton) [1229736]
- fscache: Implement volume registration (Jeffrey Layton) [1229736]
- fscache: Implement cache registration (Jeffrey Layton) [1229736]
- fscache: Implement a hash function (Jeffrey Layton) [1229736]
- fscache: Introduce new driver (Jeffrey Layton) [1229736]
- netfs: Pass a flag to ->prepare_write() to say if there's no alloc'd space (Jeffrey Layton) [1229736]
- netfs: Display the netfs inode number in the netfs_read tracepoint (Jeffrey Layton) [1229736]
- fscache: Remove the contents of the fscache driver, pending rewrite (Jeffrey Layton) [1229736]
- cachefiles: Delete the cachefiles driver pending rewrite (Jeffrey Layton) [1229736]
- fscache, cachefiles: Disable configuration (Jeffrey Layton) [1229736]
- fs: 9p: remove unneeded variable (Jeffrey Layton) [1229736]
- afs: Fix mmap (Jeffrey Layton) [1229736]
- netfs: fix parameter of cleanup() (Jeffrey Layton) [1229736]
- netfs: Fix lockdep warning from taking sb_writers whilst holding mmap_lock (Jeffrey Layton) [1229736]
- fs: add is_idmapped_mnt() helper (Jeffrey Layton) [1229736]
- netfs: Adjust docs after foliation (Jeffrey Layton) [1229736]
- afs: Use folios in directory handling (Jeffrey Layton) [1229736]
- netfs, 9p, afs, ceph: Use folios (Jeffrey Layton) [1229736]
- fs/netfs: Add folio fscache functions (Jeffrey Layton) [1229736]
- 9p: fix a bunch of checkpatch warnings (Jeffrey Layton) [1229736]
- 9p: set readahead and io size according to maxsize (Jeffrey Layton) [1229736]
- 9p p9mode2perm: remove useless strlcpy and check sscanf return code (Jeffrey Layton) [1229736]
- 9p v9fs_parse_options: replace simple_strtoul with kstrtouint (Jeffrey Layton) [1229736]
- 9p: fix file headers (Jeffrey Layton) [1229736]
- fs/9p: fix indentation and Add missing a blank line after declaration (Jeffrey Layton) [1229736]
- fs/9p: fix warnings found by checkpatch.pl (Jeffrey Layton) [1229736]
- 9p: fix minor indentation and codestyle (Jeffrey Layton) [1229736]
- fs/9p: cleanup: opening brace at the beginning of the next line (Jeffrey Layton) [1229736]
- 9p: Convert to using the netfs helper lib to do reads and caching (Jeffrey Layton) [1229736]
- fscache_cookie_enabled: check cookie is valid before accessing it (Jeffrey Layton) [1229736]
- afs: Set mtime from the client for yfs create operations (Jeffrey Layton) [1229736]
- afs: Sort out symlink reading (Jeffrey Layton) [1229736]
- afs: Fix afs_launder_page() to set correct start file position (Jeffrey Layton) [1229736]
- netfs: Fix READ/WRITE confusion when calling iov_iter_xarray() (Jeffrey Layton) [1229736]
- cachefiles: Fix oops with cachefiles_cull() due to NULL object (Jeffrey Layton) [1229736]
- fscache: Remove an unused static variable (Jeffrey Layton) [1229736]
- fscache: Fix some kerneldoc warnings shown up by W=1 (Jeffrey Layton) [1229736]
- 9p: Fix a bunch of kerneldoc warnings shown up by W=1 (Jeffrey Layton) [1229736]
- afs: Fix kerneldoc warning shown up by W=1 (Jeffrey Layton) [1229736]
- cachefiles: Fix oops in trace_cachefiles_mark_buried due to NULL object (Jeffrey Layton) [1229736]
- afs: Fix updating of i_blocks on file/dir extension (Jeffrey Layton) [1229736]
- afs: Fix corruption in reads at fpos 2G-4G from an OpenAFS server (Jeffrey Layton) [1229736]
- afs: Try to avoid taking RCU read lock when checking vnode validity (Jeffrey Layton) [1229736]
- afs: Fix mmap coherency vs 3rd-party changes (Jeffrey Layton) [1229736]
- afs: Fix incorrect triggering of sillyrename on 3rd-party invalidation (Jeffrey Layton) [1229736]
- afs: Add missing vnode validation checks (Jeffrey Layton) [1229736]
- afs: Fix page leak (Jeffrey Layton) [1229736]
- afs: Fix missing put on afs_read objects and missing get on the key therein (Jeffrey Layton) [1229736]
- fscache: Use refcount_t for the cookie refcount instead of atomic_t (Jeffrey Layton) [1229736]
- fscache: Fix fscache_cookie_put() to not deref after dec (Jeffrey Layton) [1229736]
- fscache: Fix cookie key hashing (Jeffrey Layton) [1229736]
- cachefiles: Change %%p in format strings to something else (Jeffrey Layton) [1229736]
- fscache: Change %%p in format strings to something else (Jeffrey Layton) [1229736]
- fscache: Remove the object list procfile (Jeffrey Layton) [1229736]
- fscache, cachefiles: Remove the histogram stuff (Jeffrey Layton) [1229736]
- fscache: Procfile to display cookies (Jeffrey Layton) [1229736]
- fscache: Add a cookie debug ID and use that in traces (Jeffrey Layton) [1229736]
- cachefiles: Use file_inode() rather than accessing ->f_inode (Jeffrey Layton) [1229736]
- netfs: Move cookie debug ID to struct netfs_cache_resources (Jeffrey Layton) [1229736]
- fscache: Select netfs stats if fscache stats are enabled (Jeffrey Layton) [1229736]
- ceph: Fix race between hole punch and page fault (Jeffrey Layton) [1229736]
- nohz/full, sched/rt: Fix missed tick-reenabling bug in dequeue_task_rt() (Phil Auld) [2107236]
- igmp: Add ip_mc_list lock in ip_check_mc_rcu (Hangbin Liu) [2114950] {CVE-2022-20141}

* Wed Sep 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-164.el9]
- nvmem: core: Check input parameter for NULL in nvmem_unregister() (David Arcari) [2124820]
- dt-bindings: PCI: qcom: Fix reset conditional (Myron Stowe) [2118429]
- PCI/ASPM: Remove pcie_aspm_pm_state_change() (Myron Stowe) [2118429]
- x86/PCI: Revert "x86/PCI: Clip only host bridge windows for E820 regions" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Split brcm_pcie_setup() into two funcs" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Add mechanism to turn on subdev regulators" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Add control of subdevice voltage regulators" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Do not turn off WOL regulators on suspend" (Myron Stowe) [2118429]
- PCI: versatile: Remove redundant variable retval (Myron Stowe) [2118429]
- PCI: rockchip: Fix find_first_zero_bit() limit (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Add schema for sc7280 chipset (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Specify reg-names explicitly (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Do not require resets on msm8996 platforms (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Convert to YAML (Myron Stowe) [2118429]
- dt-bindings: PCI: update references to Designware schema (Myron Stowe) [2118429]
- PCI: qcom: Fix unbalanced PHY init on probe errors (Myron Stowe) [2118429]
- PCI: qcom: Fix runtime PM imbalance on probe errors (Myron Stowe) [2118429]
- PCI: qcom: Fix pipe clock imbalance (Myron Stowe) [2118429]
- PCI: qcom: Add SM8150 SoC support (Myron Stowe) [2118429]
- dt-bindings: pci: qcom: Document PCIe bindings for SM8150 SoC (Myron Stowe) [2118429]
- PCI: mvebu: Add support for sending Set_Slot_Power_Limit message (Myron Stowe) [2118429]
- PCI: Add function for parsing 'slot-power-limit-milliwatt' DT property (Myron Stowe) [2118429]
- PCI: Add PCI_EXP_SLTCTL_ASPL_DISABLE macro (Myron Stowe) [2118429]
- PCI: microchip: Fix potential race in interrupt handling (Myron Stowe) [2118429]
- PCI: microchip: Add missing chained_irq_enter()/exit() calls (Myron Stowe) [2118429]
- PCI: microchip: Add a missing semicolon (Myron Stowe) [2118429]
- PCI: mediatek-gen3: Assert resets to ensure expected init state (Myron Stowe) [2118429]
- PCI: mediatek: Fix refcount leak in mtk_pcie_subsys_powerup() (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: define AER/PME interrupts (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Add EP mode compatible strings for ls1028a (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Update the description of SCFG property (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Add a optional property big-endian (Myron Stowe) [2118429]
- PCI: imx6: Fix PERST# start-up sequence (Myron Stowe) [2118429]
- PCI: rockchip-dwc: Add legacy interrupt support (Myron Stowe) [2118429]
- PCI: rockchip-dwc: Reset core at driver probe (Myron Stowe) [2118429]
- dt-bindings: PCI: Remove fallback from Rockchip DesignWare binding (Myron Stowe) [2118429]
- PCI: qcom-ep: Move enable/disable resources code to common functions (Myron Stowe) [2118429]
- PCI: tegra194: Remove unnecessary MSI enable reg save and restore (Myron Stowe) [2118429]
- PCI: dwc: Fix setting error return on MSI DMA mapping failure (Myron Stowe) [2118429]
- PCI: cadence: Clear FLR in device capabilities register (Myron Stowe) [2118429]
- PCI: cadence: Allow PTM Responder to be enabled (Myron Stowe) [2118429]
- PCI: cadence: Fix find_first_zero_bit() limit (Myron Stowe) [2118429]
- PCI: Avoid pci_dev_lock() AB/BA deadlock with sriov_numvfs_store() (Myron Stowe) [2118429]
- x86/PCI: Disable E820 reserved region clipping starting in 2023 (Myron Stowe) [2118429]
- x86/PCI: Disable E820 reserved region clipping via quirks (Myron Stowe) [2118429]
- x86/PCI: Add kernel cmdline options to use/ignore E820 reserved regions (Myron Stowe) [2118429]
- x86/PCI: Clip only host bridge windows for E820 regions (Myron Stowe) [2118429]
- x86: Log resource clipping for E820 regions (Myron Stowe) [2118429]
- x86/PCI: Eliminate remove_e820_regions() common subexpressions (Myron Stowe) [2118429]
- PCI/PM: Replace pci_set_power_state() in pci_pm_thaw_noirq() (Myron Stowe) [2118429]
- PCI/PM: Rearrange pci_set_power_state() (Myron Stowe) [2118429]
- PCI/PM: Clean up pci_set_low_power_state() (Myron Stowe) [2118429]
- PCI/PM: Do not restore BARs if device is not in D0 (Myron Stowe) [2118429]
- PCI/PM: Split pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Write 0 to PMCSR in pci_power_up() in all cases (Myron Stowe) [2118429]
- PCI/PM: Do not call pci_update_current_state() from pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Unfold pci_platform_power_transition() in pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Set current_state to D3cold if the device is not accessible (Myron Stowe) [2118429]
- PCI/PM: Relocate pci_set_low_power_state() (Myron Stowe) [2118429]
- PCI/PM: Split pci_raw_set_power_state() (Myron Stowe) [2118429]
- PCI/PM: Rearrange pci_update_current_state() (Myron Stowe) [2118429]
- PCI/PM: Drop the runtime_d3cold device flag (Myron Stowe) [2118429]
- PCI/PM: Resume subordinate bus in bus type callbacks (Myron Stowe) [2118429]
- PCI/PM: Power up all devices during runtime resume (Myron Stowe) [2118429]
- PCI/PM: Define pci_restore_standard_config() only for CONFIG_PM_SLEEP (Myron Stowe) [2118429]
- PCI/P2PDMA: Whitelist Intel Skylake-E Root Ports at any devfn (Myron Stowe) [2118429]
- PCI/doc: Update obsolete pci_set_dma_mask() references (Myron Stowe) [2118429]
- PCI/doc: cleanup references to the legacy PCI DMA API (Myron Stowe) [2118429]
- PCI: hotplug: Clean up include files (Myron Stowe) [2118429]
- PCI/AER: Clear MULTI_ERR_COR/UNCOR_RCV bits (Myron Stowe) [2118429]
- PCI/ASPM: Make Intel DG2 L1 acceptable latency unlimited (Myron Stowe) [2118429]
- PCI: Export pci_dev_lock() (Myron Stowe) [2118429]
- vfio/type1: Unpin zero pages (Alex Williamson) [2121855]
- platform/x86/intel/vsec: Fix wrong type for local status variables (David Arcari) [2076745]
- platform/x86/intel/vsec: Add PCI error recovery support to Intel PMT (David Arcari) [2076745]
- platform/x86/intel/pmt: telemetry: Fix fixed region handling (David Arcari) [2076745]
- platform/x86/intel/vsec: Add support for Raptor Lake (David Arcari) [2076745]
- platform/x86/intel/vsec: Rework early hardware code (David Arcari) [2076745]
- platform/x86/intel: Fix pmt_crashlog array reference (David Arcari) [2076745]
- platform/x86: intel/pmc: Add Alder Lake N support to PMC core driver (David Arcari) [2072655]
- platform/x86/intel: pmc: Support Intel Raptorlake P (David Arcari) [2072655]
- platform/x86/intel: pmc/core: Use kobj_to_dev() (David Arcari) [2072655]
- platform/x86/intel: pmc/core: change pmc_lpm_modes to static (David Arcari) [2072655]
- platform/x86: intel_pmc_core: fix memleak on registration failure (David Arcari) [2072655]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED default 1024 (Jerry Snitselaar) [2120411]
- Revert "iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting" (Jerry Snitselaar) [2120411]
- Revert "rhel config: Set DMAR_UNITS_SUPPORTED" (Jerry Snitselaar) [2120411]
- iavf: Fix reset error handling (Petr Oros) [2119712]
- iavf: Fix NULL pointer dereference in iavf_get_link_ksettings (Petr Oros) [2119712]
- iavf: Fix missing state logs (Petr Oros) [2119712]

* Thu Sep 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-163.el9]
- x86/cpu: Add new Raptor Lake CPU model number (David Arcari) [2120362]
- rhel: configs: add config option CONFIG_COMMAND_LINE_SIZE (Mete Durlu) [2060827]
- s390/sclp: reserve memory occupied by sclp early buffer (Mete Durlu) [2060827]
- s390: make command line configurable (Mete Durlu) [2060827]
- s390: support command lines longer than 896 bytes (Mete Durlu) [2060827]
- s390/kexec_file: move kernel image size check (Mete Durlu) [2060827]
- s390/boot: move sclp early buffer from fixed address in asm to C (Mete Durlu) [2060827]
- rhel: set previously unused GPIO config items (Al Stone) [2071835]
- gpio: sim: fix hogs with custom chip labels (Al Stone) [2071835]
- gpio: sim: check the label length when setting up device properties (Al Stone) [2071835]
- gpio: sim: Declare gpio_sim_hog_config_item_ops static (Al Stone) [2071835]
- gpio: sim: fix a typo (Al Stone) [2071835]
- gpio: sim: fix setting and getting multiple lines (Al Stone) [2071835]
- gpio: sim: Use correct order for the parameters of devm_kcalloc() (Al Stone) [2071835]
- gpio: sim: fix the chip_name configfs item (Al Stone) [2071835]
- gpio: xlp: Fix build errors from Netlogic XLP removal (Al Stone) [2071835]
- gpio: virtio: Add IRQ support (Al Stone) [2071835]
- gpio: virtio: remove timeout (Al Stone) [2071835]
- gpiolib: cdev: fix null pointer dereference in linereq_free() (Al Stone) [2071835]
- gpio: mxs: Fix header comment (Al Stone) [2071835]
- gpio: Fix kernel-doc comments to nested union (Al Stone) [2071835]
- gpio: grgpio: Fix device removing (Al Stone) [2071835]
- gpiolib: cdev: Fix kernel doc for struct line (Al Stone) [2071835]
- gpio: dwapb: Don't print error on -EPROBE_DEFER (Al Stone) [2071835]
- gpio: sch: make irq_chip immutable (Al Stone) [2071835]
- gpio: dwapb: Make the irqchip immutable (Al Stone) [2071835]
- gpiolib: cdev: Add hardware timestamp clock type (Al Stone) [2071835]
- drivers: Add hardware timestamp engine (HTE) subsystem (Al Stone) [2071835]
- gpio: tegra186: Add HTE support (Al Stone) [2071835]
- gpiolib: Add HTE support (Al Stone) [2071835]
- hte: Uninitialized variable in hte_ts_get() (Al Stone) [2071835]
- hte: Fix off by one in hte_push_ts_ns() (Al Stone) [2071835]
- hte: Add Tegra HTE test driver (Al Stone) [2071835]
- hte: Add Tegra194 HTE kernel provider (Al Stone) [2071835]
- drivers: Add hardware timestamp engine (HTE) subsystem (Al Stone) [2071835]
- gpiolib: of: fix bounds check for 'gpio-reserved-ranges' (Al Stone) [2071835]
- gpio: syscon: Remove usage of syscon_regmap_lookup_by_compatible (Al Stone) [2071835]
- gpio: use raw spinlock for gpio chip shadowed data (Al Stone) [2071835]
- gpio: Request interrupts after IRQ is initialized (Al Stone) [2071835]
- gpiolib: of: Introduce hook for missing gpio-ranges (Al Stone) [2071835]
- gpio: Update TODO to mention immutable irq_chip structures (Al Stone) [2071835]
- gpio: pl061: Make the irqchip immutable (Al Stone) [2071835]
- gpio: tegra186: Make the irqchip immutable (Al Stone) [2071835]
- gpio: Add helpers to ease the transition towards immutable irq_chip (Al Stone) [2071835]
- gpio: Expose the gpiochip_irq_re[ql]res helpers (Al Stone) [2071835]
- gpio: Don't fiddle with irqchips marked as immutable (Al Stone) [2071835]
- gpiolib: Introduce a helper to get first GPIO controller node (Al Stone) [2071835]
- gpiolib: Extract gpio_chip_get_value() wrapper (Al Stone) [2071835]
- gpiolib: Refactor gpiolib_dbg_show() with help of for_each_gpio_desc() (Al Stone) [2071835]
- gpiolib: Split out for_each_gpio_desc() macro (Al Stone) [2071835]
- gpiolib: Embed iterator variable into for_each_gpio_desc_with_flag() (Al Stone) [2071835]
- gpiolib: Move error message out of a spinlock (Al Stone) [2071835]
- gpiolib: Introduce gpiochip_node_count() helper (Al Stone) [2071835]
- gpiolib: Introduce for_each_gpiochip_node() loop helper (Al Stone) [2071835]
- gpiolib: acpi: Convert type for pin to be unsigned (Al Stone) [2071835]
- gpiolib: acpi: use correct format characters (Al Stone) [2071835]
- gpiolib: Get rid of redundant 'else' (Al Stone) [2071835]
- gpio: Restrict usage of GPIO chip irq members before initialization (Al Stone) [2071835]
- gpio: Properly document parent data union (Al Stone) [2071835]
- gpiolib: Use list_first_entry()/list_last_entry() (Al Stone) [2071835]
- gpiolib: acpi: Convert ACPI value of debounce to microseconds (Al Stone) [2071835]
- gpio: tegra186: Add IRQ per bank for Tegra241 (Al Stone) [2071835]
- gpio: Return EPROBE_DEFER if gc->to_irq is NULL (Al Stone) [2071835]
- gpio: tegra186: Fix chip_data type confusion (Al Stone) [2071835]
- gpiolib: sysfs: Simplify edge handling in the code (Al Stone) [2071835]
- gpiolib: sysfs: Move kstrtox() calls outside of the mutex lock (Al Stone) [2071835]
- gpiolib: sysfs: Move sysfs_emit() calls outside of the mutex lock (Al Stone) [2071835]
- gpiolib: make struct comments into real kernel docs (Al Stone) [2071835]
- gpiolib: Simplify error path in gpiod_get_index() when requesting GPIO (Al Stone) [2071835]
- gpiolib: Use short form of ternary operator in gpiod_get_index() (Al Stone) [2071835]
- gpiolib: Introduce for_each_gpio_desc_with_flag() macro (Al Stone) [2071835]
- gpiolib: Never return internal error codes to user space (Al Stone) [2071835]
- gpio: aggregator: Fix calling into sleeping GPIO controllers (Al Stone) [2071835]
- gpio: tegra: Get rid of duplicate of_node assignment (Al Stone) [2071835]
- gpio: dwapb: Switch to use fwnode instead of of_node (Al Stone) [2071835]
- gpiolib: acpi: make fwnode take precedence in struct gpio_chip (Al Stone) [2071835]
- gpio: regmap: Switch to use fwnode instead of of_node (Al Stone) [2071835]
- gpio: tegra186: Add support for Tegra241 (Al Stone) [2071835]
- dt-bindings: gpio: Add Tegra241 support (Al Stone) [2071835]
- gpio: Remove unused local OF node pointers (Al Stone) [2071835]
- gpio: Propagate firmware node from a parent device (Al Stone) [2071835]
- gpio: Setup parent device and get rid of unnecessary of_node assignment (Al Stone) [2071835]
- gpio: Get rid of duplicate of_node assignment in the drivers (Al Stone) [2071835]
- gpiolib: allow line names from device props to override driver names (Al Stone) [2071835]
- gpio: amdpt: add new device ID and 24-pin support (Al Stone) [2071835]
- gpio: tegra186: Add support for Tegra234 (Al Stone) [2071835]
- gpio: sim: new testing module (Al Stone) [2071835]
- gpiolib: of: make fwnode take precedence in struct gpio_chip (Al Stone) [2071835]
- gpiolib: allow to specify the firmware node in struct gpio_chip (Al Stone) [2071835]
- gpiolib: provide gpiod_remove_hogs() (Al Stone) [2071835]
- gpio: sch: fix typo in a comment (Al Stone) [2071835]
- gpiolib: check the 'ngpios' property in core gpiolib code (Al Stone) [2071835]
- gpiolib: improve coding style for local variables (Al Stone) [2071835]
- gpio: aggregator: Add interrupt support (Al Stone) [2071835]
- gpiolib: Let gpiod_add_lookup_table() call gpiod_add_lookup_tables() (Al Stone) [2071835]
- gpio: dwapb: clarify usage of the register file version (Al Stone) [2071835]
- gpio: pch: Cache &pdev->dev to reduce repetition (Al Stone) [2071835]
- gpio: pch: Use .driver_data instead of checking Device IDs again (Al Stone) [2071835]
- gpio: bd70528 Drop BD70528 support (Al Stone) [2071835]
- gpiolib: acpi: Unify debug and other messages format (Al Stone) [2071835]
- gpiolib: acpi: Do not set the IRQ type if the IRQ is already in use (Al Stone) [2071835]
- gpio: mockup: Switch to use kasprintf_strarray() (Al Stone) [2071835]
- gpiolib: acpi: shrink devm_acpi_dev_add_driver_gpios() (Al Stone) [2071835]
- gpiolib: acpi: Remove never used devm_acpi_dev_remove_driver_gpios() (Al Stone) [2071835]
- gpio: xlp: Remove Netlogic XLP variants (Al Stone) [2071835]
- gpio: virtio: Fix sparse warnings (Al Stone) [2071835]
- gpio: clean up Kconfig file (Al Stone) [2071835]
- gpio: Allow per-parent interrupt data (Al Stone) [2071835]
- gpio-amdpt: ACPI: Use the ACPI_COMPANION() macro directly (Al Stone) [2071835]
- gpiolib: acpi: Replace custom code with device_match_acpi_handle() (Al Stone) [2071835]
- gpio: mc33880: Drop if with an always false condition (Al Stone) [2071835]
- gpio: aggregator: Wrap access to gpiochip_fwd.tmp[] (Al Stone) [2071835]
- gpio: tps65218: drop unneeded MODULE_ALIAS (Al Stone) [2071835]
- gpio: max77620: drop unneeded MODULE_ALIAS (Al Stone) [2071835]
- gpio: tegra186: Support multiple interrupts per bank (Al Stone) [2071835]
- gpio: tegra186: Force one interrupt per bank (Al Stone) [2071835]
- gpiolib: acpi: Make set-debounce-timeout failures non fatal (Al Stone) [2071835]
- gpio: remove the obsolete MX35 3DS BOARD MC9S08DZ60 GPIO functions (Al Stone) [2071835]
- gpio: Add virtio-gpio driver (Al Stone) [2071835]
- gpio: Bulk conversion to generic_handle_domain_irq() (Al Stone) [2071835]
- gpio: dwapb: Get rid of legacy platform data (Al Stone) [2071835]
- gpio: dwapb: Read GPIO base from gpio-base property (Al Stone) [2071835]
- gpio: dwapb: Unify ACPI enumeration checks in get_irq() and configure_irqs() (Al Stone) [2071835]
- gpiolib: Deduplicate forward declaration in the consumer.h header (Al Stone) [2071835]
- gpio: tegra186: Add ACPI support (Al Stone) [2071835]
- dt-bindings: gpio: Add Tegra234 support (Al Stone) [2071835]
- dt-bindings: gpio: tegra186: Convert to json-schema (Al Stone) [2071835]
- gpiolib: of: constify few local device_node variables (Al Stone) [2071835]
- gpiolib: convert 'devprop_gpiochip_set_names' to support multiple gpiochip banks per device (Al Stone) [2071835]
- devlink: hold the instance lock during eswitch_mode callbacks (Petr Oros) [2101713]
- netdevsim: replace vfs_lock with devlink instance lock (Petr Oros) [2101713]
- netdevsim: replace port_list_lock with devlink instance lock (Petr Oros) [2101713]
- devlink: add explicitly locked flavor of the rate node APIs (Petr Oros) [2101713]
- bnxt: use the devlink instance lock to protect sriov (Petr Oros) [2101713]
- devlink: pass devlink_port to port_split / port_unsplit callbacks (Petr Oros) [2101713]
- devlink: hold the instance lock in port_split / port_unsplit callbacks (Petr Oros) [2101713]
- eth: mlxsw: switch to explicit locking for port registration (Petr Oros) [2101713]
- eth: nfp: replace driver's "pf" lock with devlink instance lock (Petr Oros) [2101713]
- eth: nfp: wrap locking assertions in helpers (Petr Oros) [2101713]
- devlink: expose instance locking and add locked port registering (Petr Oros) [2101713]
- mlxsw: reg: Remove PMTM register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Use PMTDB register to obtain split info (Ivan Vecera) [2101713]
- mlxsw: reg: Add Port Module To local DataBase Register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Use PLLP to get front panel number and split number (Ivan Vecera) [2101713]
- mlxsw: reg: Add Port Local port to Label Port mapping Register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Move port SWID set before core port init (Ivan Vecera) [2101713]
- mlxsw: spectrum: Move port module mapping before core port init (Ivan Vecera) [2101713]
- mlxsw: spectrum: Bump minimum FW version to xx.2008.3326 (Ivan Vecera) [2101713]
- vdpa/mlx5: Initialize CVQ vringh only once (Eugenio Pérez) [2119809]
- vdpa/mlx5: Update Control VQ callback information (Eugenio Pérez) [2119809]
- intel_th: pci: Add Raptor Lake-S CPU support (Michael Petlan) [2040036]
- intel_th: pci: Add Raptor Lake-S PCH support (Michael Petlan) [2040036]
- rhel: usb: remove Conflicts for gadget_unbind_drivers() (Al Stone) [2071830]
- soc: ti: fix wkup_m3_rproc_boot_thread return type (Al Stone) [2071830]
- fbdev: Prevent probing generic drivers if a FB is already registered (Al Stone) [2071830]
- rhel: Enable EFI DXE memory attributes (Al Stone) [2071830]
- rhel: Enable EFI COCO secret (Al Stone) [2071830]
- firmware: arm_scmi: Fix SENSOR_AXIS_NAME_GET behaviour when unsupported (Al Stone) [2071830]
- firmware: arm_scmi: Remove all the unused local variables (Al Stone) [2071830]
- efi/x86: libstub: Fix typo in __efi64_argmap* name (Al Stone) [2071830]
- powerpc/64: Include cache.h directly in paca.h (Al Stone) [2071830]
- firmware: arm_scmi: Relax CLOCK_DESCRIBE_RATES out-of-spec checks (Al Stone) [2071830]
- firmware: arm_scmi: Avoid using extended string-buffers sizes if not necessary (Al Stone) [2071830]
- video: vga16fb: Only probe for EGA and VGA 16 color graphic cards (Al Stone) [2071830]
- efi: clean up Kconfig dependencies on CONFIG_EFI (Al Stone) [2071830]
- efi/x86: libstub: Make DXE calls mixed mode safe (Al Stone) [2071830]
- edd: simplify the check of 'attr->test' in edd_populate_dir() (Al Stone) [2071830]
- firmware: dmi-sysfs: Fix memory leak in dmi_sysfs_register_handle (Al Stone) [2071830]
- printk: stop including cache.h from printk.h (Al Stone) [2071830]
- efi: stub: prefer mirrored memory for randomized allocations (Al Stone) [2071830]
- efi/arm64: libstub: run image in place if randomized by the loader (Al Stone) [2071830]
- efi: libstub: pass image handle to handle_kernel_image() (Al Stone) [2071830]
- efi: libstub: ensure allocated memory to be executable (Al Stone) [2071830]
- efi: libstub: declare DXE services table (Al Stone) [2071830]
- firmware: arm_scmi: Fix late checks on pointer dereference (Al Stone) [2071830]
- firmware: arm_ffa: Remove incorrect assignment of driver_data (Al Stone) [2071830]
- firmware: arm_ffa: Fix uuid parameter to ffa_partition_probe (Al Stone) [2071830]
- firmware: arm_scmi: Support optee shared memory in the optee transport (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 VOLTAGE_LEVEL_SET_COMPLETE (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 clock notifications (Al Stone) [2071830]
- firmware: arm_scmi: Add checks for min/max limits in PERFORMANCE_LIMITS_SET (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 perf power-cost in microwatts (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the perf protocol (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the voltage protocol (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the clock protocol (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 SENSOR_AXIS_NAME_GET support (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the sensor protocol (Al Stone) [2071830]
- firmware: arm_scmi: Add iterators for multi-part commands (Al Stone) [2071830]
- firmware: arm_scmi: Parse clock_enable_latency conditionally (Al Stone) [2071830]
- firmware: arm_scmi: Set clock latency to U32_MAX if it is not supported (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 protocol extended names support (Al Stone) [2071830]
- firmware: arm_scmi: Introduce a common SCMI v3.1 .extended_name_get helper (Al Stone) [2071830]
- firmware: arm_scmi: Split protocol specific definitions in a dedicated header (Al Stone) [2071830]
- firmware: arm_scmi: Remove unneeded NULL termination of clk name (Al Stone) [2071830]
- firmware: arm_scmi: Check CLOCK_RATE_SET_COMPLETE async response (Al Stone) [2071830]
- firmware: arm_scmi: Make name_get operations return a const (Al Stone) [2071830]
- firmware: arm_scmi: Dynamically allocate implemented protocols array (Al Stone) [2071830]
- firmware: arm_scmi: Validate BASE_DISCOVER_LIST_PROTOCOLS response (Al Stone) [2071830]
- firmware: arm_scmi: Fix list protocols enumeration in the base protocol (Al Stone) [2071830]
- firmware: arm_scmi: Make protocols initialisation fail on basic errors (Al Stone) [2071830]
- firmware: arm_ffa: Fix handling of fragmented memory descriptors (Al Stone) [2071830]
- efi: Register efi_secret platform device if EFI secret area is declared (Al Stone) [2071830]
- efi: Save location of EFI confidential computing area (Al Stone) [2071830]
- efi: Move efifb_setup_from_dmi() prototype from arch headers (Al Stone) [2071830]
- efi/cper: Reformat CPER memory error location to more readable (Al Stone) [2071830]
- EDAC/ghes: Unify CPER memory error location reporting (Al Stone) [2071830]
- efi/cper: Add a cper_mem_err_status_str() to decode error description (Al Stone) [2071830]
- firmware: arm_scmi: Fix sparse warnings in OPTEE transport driver (Al Stone) [2071830]
- firmware: arm_scmi: Replace zero-length array with flexible-array member (Al Stone) [2071830]
- firmware: arm_scmi: Fix sorting of retrieved clock rates (Al Stone) [2071830]
- firmware: arm_scmi: Remove clear channel call on the TX channel (Al Stone) [2071830]
- rhel: Configure ARM SCMI SMC transport AtomicEnable (Al Stone) [2071830]
- firmware: sysfb: fix platform-device leak in error path (Al Stone) [2071830]
- pstore: Don't use semaphores in always-atomic-context code (Al Stone) [2071830]
- efi/mokvar: move up init order (Al Stone) [2071830]
- sysfb: Enable boot time VESA graphic mode selection (Al Stone) [2071830]
- sysfb: Make config option dependencies explicit (Al Stone) [2071830]
- efi: fix return value of __setup handlers (Al Stone) [2071830]
- efivars: Respect "block" flag in efivar_entry_set_safe() (Al Stone) [2071830]
- firmware: arm_scmi: Add support for clock_enable_latency (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic support to clock protocol (Al Stone) [2071830]
- firmware: arm_scmi: Support optional system wide atomic-threshold-us (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic mode support to virtio transport (Al Stone) [2071830]
- firmware: arm_scmi: Review virtio free_list handling (Al Stone) [2071830]
- firmware: arm_scmi: Add a virtio channel refcount (Al Stone) [2071830]
- firmware: imx: scu-pd: imx8q: add vpu mu resources (Al Stone) [2071830]
- firmware: imx: add get resource owner api (Al Stone) [2071830]
- firmware: arm_scmi: Remove space in MODULE_ALIAS name (Al Stone) [2071830]
- firmware: arm_scmi: Disable ftrace for Clang Thumb2 builds (Al Stone) [2071830]
- drivers/firmware: Don't mark as busy the simple-framebuffer IO resource (Al Stone) [2071830]
- efi: runtime: avoid EFIv2 runtime services on Apple x86 machines (Al Stone) [2071830]
- efi/libstub: arm64: Fix image check alignment at entry (Al Stone) [2071830]
- virtio: wrap config->reset calls (Al Stone) [2071830]
- efi: use default_groups in kobj_type (Al Stone) [2071830]
- efi/libstub: measure loaded initrd info into the TPM (Al Stone) [2071830]
- efi/libstub: x86/mixed: increase supported argument count (Al Stone) [2071830]
- drivers/firmware: Add missing platform_device_put() in sysfb_create_simplefb (Al Stone) [2071830]
- firmware: edd: remove empty default_attrs array (Al Stone) [2071830]
- firmware: dmi-sysfs: use default_groups in kobj_type (Al Stone) [2071830]
- qemu_fw_cfg: use default_groups in kobj_type (Al Stone) [2071830]
- firmware: memmap: use default_groups in kobj_type (Al Stone) [2071830]
- firmware: arm_scmi: Add new parameter to mark_txdone (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic mode support to smc transport (Al Stone) [2071830]
- firmware: arm_scmi: Add support for atomic transports (Al Stone) [2071830]
- firmware: arm_scmi: Make optee support sync_cmds_completed_on_ret (Al Stone) [2071830]
- firmware: arm_scmi: Make smc support sync_cmds_completed_on_ret (Al Stone) [2071830]
- firmware: arm_scmi: Add sync_cmds_completed_on_ret transport flag (Al Stone) [2071830]
- firmware: arm_scmi: Make smc transport use common completions (Al Stone) [2071830]
- firmware: arm_scmi: Add configurable polling mode for transports (Al Stone) [2071830]
- firmware: qemu_fw_cfg: remove sysfs entries explicitly (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix sysfs information leak (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix kobject leak in probe error path (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix NULL-pointer deref on duplicate entries (Al Stone) [2071830]
- firmware: arm_scmi: Use new trace event scmi_xfer_response_wait (Al Stone) [2071830]
- include: trace: Add new scmi_xfer_response_wait event (Al Stone) [2071830]
- firmware: arm_scmi: Refactor message response path (Al Stone) [2071830]
- firmware: arm_scmi: Set polling timeout to max_rx_timeout_ms (Al Stone) [2071830]
- firmware: arm_scpi: Fix string overflow in SCPI genpd driver (Al Stone) [2071830]
- firmware: arm_scmi: Perform earlier cinfo lookup call in do_xfer (Al Stone) [2071830]
- firmware: arm_scmi: optee: Drop the support for the OPTEE shared dynamic buffer (Al Stone) [2071830]
- firmware: arm_scmi: optee: Fix missing mutex_init() (Al Stone) [2071830]
- efi/libstub: consolidate initrd handling across architectures (Al Stone) [2071830]
- efi/libstub: add prototype of efi_tcg2_protocol::hash_log_extend_event() (Al Stone) [2071830]
- firmware: arm_scmi: Make virtio Version_1 compliance optional (Al Stone) [2071830]
- firmware: arm_scmi: Add optee transport (Al Stone) [2071830]
- firmware: arm_scmi: Fix type error assignment in voltage protocol (Al Stone) [2071830]
- firmware: arm_scmi: Review some virtio log messages (Al Stone) [2071830]
- firmware: arm_scmi: Fix type error in sensor protocol (Al Stone) [2071830]
- firmware: arm_scmi: pm: Propagate return value to caller (Al Stone) [2071830]
- firmware: arm_scmi: Fix base agent discover response (Al Stone) [2071830]
- firmware: arm_scmi: Fix null de-reference on error path (Al Stone) [2071830]
- exit/kthread: Have kernel threads return instead of calling do_exit (Al Stone) [2071830]
- firmware/psci: fix application of sizeof to pointer (Al Stone) [2071830]
- firmware: arm_ffa: Remove unused 'compat_version' variable (Al Stone) [2071830]
- firmware: arm_ffa: Add support for MEM_LEND (Al Stone) [2071830]
- firmware: arm_ffa: Handle compatibility with different firmware versions (Al Stone) [2071830]
- firmware: arm_scmi: Add proper barriers to scmi virtio device (Al Stone) [2071830]
- firmware: arm_scmi: Simplify spinlocks in virtio transport (Al Stone) [2071830]
- efi/cper: use stack buffer for error record decoding (Al Stone) [2071830]
- efi/libstub: Simplify "Exiting bootservices" message (Al Stone) [2071830]
- firmware: arm_ffa: Fix __ffa_devices_unregister (Al Stone) [2071830]
- firmware: arm_ffa: Add missing remove callback to ffa_bus_type (Al Stone) [2071830]
- firmware: arm_scmi: Remove __exit annotation (Al Stone) [2071830]
- firmware: arm_scmi: Fix virtio transport Kconfig dependency (Al Stone) [2071830]
- firmware: dmi: Move product_sku info to the end of the modalias (Al Stone) [2071830]
- efi: cper: check section header more appropriately (Al Stone) [2071830]
- efi: cper: fix scnprintf() use in cper_mem_err_location() (Al Stone) [2071830]
- rhel: Enable Simple FrameBuffer support (Al Stone) [2071830]
- rhel: Enable ARM SCMI transport mechanism (Al Stone) [2071830]
- firmware: arm_scmi: Use WARN_ON() to check configured transports (Al Stone) [2071830]
- firmware: arm_scmi: Fix boolconv.cocci warnings (Al Stone) [2071830]
- firmware: smccc: Register smccc_trng platform device (Al Stone) [2071830]
- firmware: arm_scmi: Free mailbox channels if probe fails (Al Stone) [2071830]
- firmware: arm_scmi: Add virtio transport (Al Stone) [2071830]
- firmware: arm_scmi: Add priv parameter to scmi_rx_callback (Al Stone) [2071830]
- firmware: arm_scmi: Add optional link_supplier() transport op (Al Stone) [2071830]
- firmware: arm_scmi: Add message passing abstractions for transports (Al Stone) [2071830]
- firmware: arm_scmi: Add method to override max message number (Al Stone) [2071830]
- firmware: arm_scmi: Make shmem support optional for transports (Al Stone) [2071830]
- firmware: arm_scmi: Make SCMI transports configurable (Al Stone) [2071830]
- firmware: arm_scmi: Make polling mode optional (Al Stone) [2071830]
- firmware: arm_scmi: Make .clear_channel optional (Al Stone) [2071830]
- firmware: arm_scmi: Handle concurrent and out-of-order messages (Al Stone) [2071830]
- firmware: arm_scmi: Introduce monotonically increasing tokens (Al Stone) [2071830]
- firmware: arm_scmi: Add optional transport_init/exit support (Al Stone) [2071830]
- firmware: arm_scmi: Remove scmi_dump_header_dbg() helper (Al Stone) [2071830]
- firmware: arm_scmi: Add support for type handling in common functions (Al Stone) [2071830]
- efi: sysfb_efi: fix build when EFI is not set (Al Stone) [2071830]
- drivers/firmware: fix SYSFB depends to prevent build failures (Al Stone) [2071830]
- drivers: firmware: Add PDI load API support (Al Stone) [2071830]
- drivers/firmware: consolidate EFI framebuffer setup for all arches (Al Stone) [2071830]
- drivers/firmware: move x86 Generic System Framebuffers support (Al Stone) [2071830]
- bus: Make remove callback return void (Al Stone) [2071830]
- s390/ccwgroup: Drop if with an always false condition (Al Stone) [2071830]
- PCI: endpoint: Make struct pci_epf_driver::remove return void (Al Stone) [2071830]
- s390/scm: Make struct scm_driver::remove return void (Al Stone) [2071830]
- s390/cio: Make struct css_driver::remove return void (Al Stone) [2071830]
- redhat: Bump RHEL_MINOR for 9.2 (Frantisek Hrbata)
- redhat: add missing CVE reference to latest changelog entries (Patrick Talbert)

* Mon Sep 05 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.el9]
- Revert "ixgbevf: Mailbox improvements" (Ken Cox) [2120548]
- Revert "ixgbevf: Add support for new mailbox communication between PF and VF" (Ken Cox) [2120548]
- posix-cpu-timers: Cleanup CPU timers before freeing them during exec (Wander Lairson Costa) [2116968] {CVE-2022-2585}
- fix race between exit_itimers() and /proc/pid/timers (Wander Lairson Costa) [2116968] {CVE-2022-2585}

* Fri Sep 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-161.el9]
- x86/ftrace: Use alternative RET encoding (Joe Lawrence) [2121368]
- x86/ibt,ftrace: Make function-graph play nice (Joe Lawrence) [2121368]
- x86/ibt,paravirt: Use text_gen_insn() for paravirt_patch() (Joe Lawrence) [2121368]
- x86/text-patching: Make text_gen_insn() play nice with ANNOTATE_NOENDBR (Joe Lawrence) [2121368]
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Frantisek Hrbata)
- random: allow reseeding DRBG with getrandom (Daiki Ueno) [2114854]

* Thu Aug 25 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-160.el9]
- iavf: Fix VLAN_V2 addition/rejection (Ivan Vecera) [2119701]
- gve: Recording rx queue before sending to napi (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer queue index check (Jordan Kimbrough) [2022916]
- gve: Fix GFP flags when allocing pages (Jordan Kimbrough) [2022916]
- gve: Add tx|rx-coalesce-usec for DQO (Jordan Kimbrough) [2022916]
- gve: Add consumed counts to ethtool stats (Jordan Kimbrough) [2022916]
- gve: Implement suspend/resume/shutdown (Jordan Kimbrough) [2022916]
- gve: Add optional metadata descriptor type GVE_TXD_MTD (Jordan Kimbrough) [2022916]
- gve: remove memory barrier around seqno (Jordan Kimbrough) [2022916]
- gve: Update gve_free_queue_page_list signature (Jordan Kimbrough) [2022916]
- gve: Move the irq db indexes out of the ntfy block struct (Jordan Kimbrough) [2022916]
- gve: Correct order of processing device options (Jordan Kimbrough) [2022916]
- gve: fix for null pointer dereference. (Jordan Kimbrough) [2022916]
- gve: fix unmatched u64_stats_update_end() (Jordan Kimbrough) [2022916]
- gve: Fix off by one in gve_tx_timeout() (Jordan Kimbrough) [2022916]
- gve: Add a jumbo-frame device option. (Jordan Kimbrough) [2022916]
- gve: Implement packet continuation for RX. (Jordan Kimbrough) [2022916]
- gve: Add RX context. (Jordan Kimbrough) [2022916]
- gve: Track RX buffer allocation failures (Jordan Kimbrough) [2022916]
- gve: Allow pageflips on larger pages (Jordan Kimbrough) [2022916]
- gve: Add netif_set_xps_queue call (Jordan Kimbrough) [2022916]
- gve: Recover from queue stall due to missed IRQ (Jordan Kimbrough) [2022916]
- gve: Do lazy cleanup in TX path (Jordan Kimbrough) [2022916]
- gve: Add rx buffer pagecnt bias (Jordan Kimbrough) [2022916]
- gve: Switch to use napi_complete_done (Jordan Kimbrough) [2022916]
- gve: report 64bit tx_bytes counter from gve_handle_report_stats() (Jordan Kimbrough) [2022916]
- gve: fix gve_get_stats() (Jordan Kimbrough) [2022916]
- gve: Properly handle errors in gve_assign_qpl (Jordan Kimbrough) [2022916]
- gve: Avoid freeing NULL pointer (Jordan Kimbrough) [2022916]
- gve: Correct available tx qpl check (Jordan Kimbrough) [2022916]
- gve: Use kvcalloc() instead of kvzalloc() (Jordan Kimbrough) [2022916]
- gve: DQO: avoid unused variable warnings (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer overflow check (Jordan Kimbrough) [2022916]
- ath9k: htc: clean up statistics macros (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- ath9k: hif_usb: simplify if-if to if-else (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- net: qcom/emac: Fix improper merge resolution in device_get_mac_address (Patrick Talbert) [2108539]
- x86/speculation: Add LFENCE to RSB fill sequence (Waiman Long) [2115086] {CVE-2022-26373}
- x86/speculation: Add RSB VM Exit protections (Waiman Long) [2115086] {CVE-2022-26373}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2115086]
- x86/bugs: Do not enable IBPB at firmware entry when IBPB is not available (Waiman Long) [2115086]
- lkdtm: Disable return thunks in rodata.c (Waiman Long) [2115086]
- x86/amd: Use IBPB for firmware calls (Waiman Long) [2115086]
- x86/bugs: Warn when "ibrs" mitigation is selected on Enhanced IBRS parts (Waiman Long) [2115086]
- x86/alternative: Report missing return thunk details (Waiman Long) [2115086]
- nvme-fc: restart admin queue if the caller needs to restart queue (Ewan D. Milne) [2104461]
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn() (Rahul Lakkireddy) [2109526]
- scsi: csiostor: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Rahul Lakkireddy) [2109526]

* Thu Aug 25 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-159.el9]
- mediatek: mt76: eeprom: fix missing of_node_put() in mt76_find_power_limits_node() (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: consider EHT element size in assoc request (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: switch airtime fairness back to deficit round-robin scheduling (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: fix throughput regression on DFS channels (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix incorrect testmode ipg on band 1 caused by wmm_idx (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: enlarge maximum VHT MPDU length to 11454 (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix aggregation subframes setting to HE max (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211_hwsim: set virtio device ready in probe() (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix possible sdio deadlock in command fail (Jose Ignacio Tornos Martinez) [2103595]
- wifi: rtw89: 8852a: rfk: fix div 0 exception (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: do not update pm states in case of error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: do not update pm stats in case of error (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Avoid REO CMD failed prints during firmware recovery (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Fix incorrect debug_mask mappings (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix missing skb drop on htc_tx_completion error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix firmware download random fail (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix IRQ affinity warning on shutdown (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix netdev open race (Jose Ignacio Tornos Martinez) [2103595]
- iwlwifi: fw: init SAR GEO table only if data is present (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: htt_tx: do not interpret Eth frames as WiFi (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Don't check arvif->is_started before sending management frames (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix twt table_mask to u16 in mt7915_dev (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: reset 11d state in process of recovery (Jose Ignacio Tornos Martinez) [2103595]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on brcmfmac43602 chips (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix tx status related use-after-free race on station removal (Jose Ignacio Tornos Martinez) [2103595]
- mt76: do not attempt to reorder received 802.3 packets without agg session (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix kernel crash at mt7921_pci_remove (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix antenna config missing in 6G cap (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: report rx mode value in mt7915_mac_fill_rx_rate (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: do not pass data pointer to mt7915_mcu_muru_debug_set (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible NULL pointer dereference in mt7915_mac_fill_rx_vector (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible uninitialized pointer dereference in mt7986_wmac_gpio_setup (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: enable napi on RX path for usb (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix the warning of dev_wake in mhi_pm_disable_transition() (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: acquire ab->base_lock in unassign when finding the peer by addr (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix unbounded shift in mt7915_mcu_beacon_mbss (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix DBDC default band selection on MT7915D (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: honor pm user configuration in mt7921_sniffer_interface_iter (Jose Ignacio Tornos Martinez) [2103595]
- crypto: testmgr - disallow plain cbcmac(aes) and ghash in FIPS mode (Vladis Dronov) [2107596]
- crypto: seqiv - flag instantiations as FIPS compliant (Vladis Dronov) [2107596]
- crypto: api - allow algs only in specific constructions in FIPS mode (Vladis Dronov) [2107596]
- i2c: qcom-geni: Fix GPI DMA buffer sync-back (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use the correct return value (Andrew Halaney) [2105390]
- i2c: qcom-geni: Propagate GENI_ABORT_DONE to geni_i2c_abort_xfer() (Andrew Halaney) [2105390]
- i2c: qcom-geni: remove unnecessary conditions (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use dev_err_probe() for GPI DMA error (Andrew Halaney) [2105390]
- i2c: qcom-geni: Add support for GPI DMA (Andrew Halaney) [2105390]
- soc: qcom: geni: Make use of the helper function devm_platform_ioremap_resource() (Andrew Halaney) [2105390]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Andrew Halaney) [2105390]
- soc: qcom: geni: Add support for gpi dma (Andrew Halaney) [2105390]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-158.el9]
- iommu/arm-smmu-qcom: Add SC8280XP support (Eric Chanudet) [2117020]
- dt-bindings: arm-smmu: Add compatible for Qualcomm SC8280XP (Eric Chanudet) [2117020]
- soc: qcom: smem: use correct format characters (Eric Chanudet) [2108804]
- soc: qcom: smem: validate fields of shared structures (Eric Chanudet) [2108804]
- soc: qcom: smem: map only partitions used by local HOST (Eric Chanudet) [2108804]
- soc: qcom: smem: Update max processor count (Eric Chanudet) [2108804]
- dt-bindings: soc: smem: Make indirection optional (Eric Chanudet) [2108804]
- soc: qcom: llcc: Add sc8180x and sc8280xp configurations (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add sc8180x and sc8280xp LLCC compatibles (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add MODULE_DEVICE_TABLE() (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8450 (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8450 SoC (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update register offsets for newer LLCC HW (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add missing llcc configuration data (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add write-cache cacheable support (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update the logic for version info extraction (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add support for 16 ways of allocation (Eric Chanudet) [2108329]
- soc: qcom: llcc: Use devm_bitmap_zalloc() when applicable (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Don't mark LLCC interrupt as required (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC for SM6350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Disable MMUHWT retention (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM6350 (Eric Chanudet) [2108329]
- spi: qcom: geni: Simplify DMA setting (Shawn Doherty) [2106892]
- spi: qcom: geni: handle timeout for gpi mode (Shawn Doherty) [2106892]
- spi: qcom: geni: set the error code for gpi transfer (Shawn Doherty) [2106892]
- spi: qcom: geni: remove unused defines (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: fix error handling in spi_geni_grab_gpi_chan() (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Add support for GPI dma (Shawn Doherty) [2106892]
- soc: qcom: geni: Add support for gpi dma (Shawn Doherty) [2106892]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Remove confusing comment about setting the watermark (Shawn Doherty) [2106892]
- interconnect: qcom: Add SC8280XP interconnect provider (Adrien Thierry) [2105458]
- dt-bindings: interconnect: qcom: Add sc8280xp binding (Adrien Thierry) [2105458]
- soc: qcom: rpmhpd: add sc8280xp & sa8540p rpmh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Don't warn about sparse rpmhpd arrays (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add sc8280xp RPMh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SDX65 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: Add rpm power domain bindings for SDX65 (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add MSM8226 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8226 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Check for null return of devm_kcalloc (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Sort power-domain definitions and lists (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Remove mx/cx relationship on sc7280 (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Rename rpmhpd struct names (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: sm8450: Add the missing .peer for sm8450_cx_ao (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM8450 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM8450 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add support for sm6125 (Adrien Thierry) [2105057]
- dt-bindings: qcom-rpmpd: Add sm6125 power domains (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Drop unused res_name from struct rpmpd (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: fix sm8350_mxc's peer domain (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Make power_on actually enable the domain (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6350 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add power domains for MSM8953 (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8953 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM6350 (Adrien Thierry) [2105057]
- drivers: soc: qcom: rpmpd: Add SM6115 RPM Power Domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6115 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Use corner in power_off (Adrien Thierry) [2105057]
- scsi: ufs: core: Fix referencing invalid rsp field (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up ufshpb_suspend()/resume() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add handing of device reset regions in HPB device mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Change sysfs node hpb_stats/rb_* prefix to start with rcmd_* (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up the handler when device resets HPB information (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove enum initialization value (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Merge ufshpb_reset() and ufshpb_reset_host() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Enable RPM_AUTOSUSPEND for runtime PM (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant wmb() in ufshcd_send_command() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Add a readl() to make sure ref_clk gets enabled (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Simplify handling of devm_phy_get() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix acquiring the optional reset control line (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: Add power-domains (Eric Chanudet) [2102378]
- scsi: ufs: Use pm_runtime_resume_and_get() instead of pm_runtime_get_sync() (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove duplicate include in ufshcd (Eric Chanudet) [2102378]
- scsi: ufs: core: Exclude UECxx from SFR dump list (Eric Chanudet) [2102378]
- scsi: ufs: Move the ufs_is_valid_unit_desc_lun() definition (Eric Chanudet) [2102378]
- scsi: ufs: Move the struct ufs_ref_clk definition (Eric Chanudet) [2102378]
- scsi: ufs: Split the ufshcd.h header file (Eric Chanudet) [2102378]
- scsi: ufs: Minimize #include directives (Eric Chanudet) [2102378]
- scsi: ufs: Fix kernel-doc syntax in ufshcd.h (Eric Chanudet) [2102378]
- scsi: ufs: Remove unnecessary ufshcd-crypto.h include directives (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix ufs_qcom_resume() (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_clkgate_delay_set() (Eric Chanudet) [2102378]
- scsi: ufs: Remove locking from around single register writes (Eric Chanudet) [2102378]
- scsi: ufs: Remove the TRUE and FALSE definitions (Eric Chanudet) [2102378]
- scsi: ufs: Remove paths from source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Use an SPDX license identifier in the Kconfig file (Eric Chanudet) [2102378]
- scsi: ufs: Rename sdev_ufs_device into ufs_device_wlun (Eric Chanudet) [2102378]
- scsi: ufs: Remove the driver version (Eric Chanudet) [2102378]
- scsi: ufs: Make the config_scaling_param calls type safe (Eric Chanudet) [2102378]
- scsi: ufs: Switch to aggregate initialization (Eric Chanudet) [2102378]
- scsi: ufs: Remove unused constants and code (Eric Chanudet) [2102378]
- scsi: ufs: Invert the return value of ufshcd_is_hba_active() (Eric Chanudet) [2102378]
- scsi: ufs: Declare the quirks array const (Eric Chanudet) [2102378]
- scsi: ufs: Rename struct ufs_dev_fix into ufs_dev_quirk (Eric Chanudet) [2102378]
- scsi: ufs: Remove the UFS_FIX() and END_FIX() macros (Eric Chanudet) [2102378]
- scsi: ufs: Use get_unaligned_be16() instead of be16_to_cpup() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_buffer (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_bufflen (Eric Chanudet) [2102378]
- scsi: ufs: Simplify statements that return a boolean (Eric Chanudet) [2102378]
- scsi: ufs: Remove superfluous boolean conversions (Eric Chanudet) [2102378]
- scsi: ufs: Declare ufshcd_wait_for_register() static (Eric Chanudet) [2102378]
- scsi: ufs: Fix a spelling error in a source code comment (Eric Chanudet) [2102378]
- scsi: ufs: core: Increase fDeviceInit poll frequency (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant HPB unmap (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Simplify pdev->dev usage (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix a NULL check on list iterator (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel MTL (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Drop custom Android boot parameters (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove unused field in struct ufs_hba (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom: Add SM6350 compatible string (Eric Chanudet) [2102378]
- scsi: ufs: core: scsi_get_lba() error fix (Eric Chanudet) [2102378]
- dt-bindings: ufs: snps,tc-dwc-g210: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: mediatek,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: hisilicon,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: drop unused/old ufs-qcom PHY bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: samsung,exynos-ufs: use common bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: add common platform bindings (Eric Chanudet) [2102378]
- scsi: ufs: Fix runtime PM messages never-ending cycle (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove wlun_dev_to_hba() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix divide by zero in ufshcd_map_queues() (Eric Chanudet) [2102378]
- block: pass a block_device and opf to bio_alloc (Eric Chanudet) [2102378]
- scsi: ufs: Add checking lifetime attribute for WriteBooster (Eric Chanudet) [2102378]
- scsi: ufs: Treat link loss as fatal error (Eric Chanudet) [2102378]
- scsi: ufs: Use generic error code in ufshcd_set_dev_pwr_mode() (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Check the return value of devm_kstrdup() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix error checking in ufs_mtk_init_va09_pwr_ctrl() (Eric Chanudet) [2102378]
- scsi: ufs: Modify Tactive time setting conditions (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix deadlock issue in ufshcd_wait_for_doorbell_clr() (Eric Chanudet) [2102378]
- scsi: ufs: dt-bindings: Add SM8450 compatible strings (Eric Chanudet) [2102378]
- scsi: ufs: Implement polling support (Eric Chanudet) [2102378]
- scsi: ufs: Optimize the command queueing code (Eric Chanudet) [2102378]
- scsi: ufs: Stop using the clock scaling lock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Fix a kernel crash during shutdown (Eric Chanudet) [2102378]
- scsi: ufs: Improve SCSI abort handling further (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_release_scsi_cmd() (Eric Chanudet) [2102378]
- scsi: ufs: Remove the 'update_scaling' local variable (Eric Chanudet) [2102378]
- scsi: ufs: Remove hba->cmd_queue (Eric Chanudet) [2102378]
- scsi: ufs: Fix a deadlock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Rework ufshcd_change_queue_depth() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_any_tag_in_use() (Eric Chanudet) [2102378]
- scsi: ufs: Fix race conditions related to driver data (Eric Chanudet) [2102378]
- scsi: ufs: Remove dead code (Eric Chanudet) [2102378]
- scsi: ufs: Remove the sdev_rpmb member (Eric Chanudet) [2102378]
- scsi: ufs: Remove is_rpmb_wlun() (Eric Chanudet) [2102378]
- scsi: ufs: Rename a function argument (Eric Chanudet) [2102378]
- scsi: Remove superfluous #include <linux/async.h> directives (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel ADL (Eric Chanudet) [2102378]
- scsi: ufs: Let devices remain runtime suspended during system suspend (Eric Chanudet) [2102378]
- block: remove the gendisk argument to blk_execute_rq (Eric Chanudet) [2102378]
- scsi: ufs: Fix double space in SCSI_UFS_HWMON description (Eric Chanudet) [2102378]
- scsi: ufs: Wrap Universal Flash Storage drivers in SCSI_UFSHCD (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Add put_device() after of_find_device_by_node() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix warning in ufshpb_set_hpb_read_to_upiu() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix another task management completion race (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion timeout race (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve SCSI abort handling (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Properly handle max-single-cmd (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove HPB2.0 flows (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add exynosautov9 compatible (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add io-coherency property (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Introduce ExynosAuto v9 virtual host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Multi-host configuration for ExynosAuto v9 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support ExynosAuto v9 UFS (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add pre/post_hce_enable drv callbacks (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Factor out priv data init (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add EXYNOS_UFS_OPT_SKIP_CONFIG_PHY_ATTR option (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support custom version of ufs_hba_variant_ops (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add setup_clocks callback (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add refclkout_stop control (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Simplify drv_data retrieval (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Change pclk available max value (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to enable host controller without PH configuration (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to handle broken UIC command (Eric Chanudet) [2102378]
- scsi: ufs: core: Micro-optimize ufshcd_map_sg() (Eric Chanudet) [2102378]
- scsi: ufs: core: Add a compile-time structure size check (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove three superfluous casts (Eric Chanudet) [2102378]
- scsi: ufs: core: Add debugfs attributes for triggering the UFS EH (Eric Chanudet) [2102378]
- scsi: ufs: core: Make it easier to add new debugfs attributes (Eric Chanudet) [2102378]
- scsi: ufs: core: Export ufshcd_schedule_eh_work() (Eric Chanudet) [2102378]
- scsi: ufs: core: Log error handler activity (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve static type checking (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Retry aborted SCSI commands instead of completing these successfully" (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Correct timeout value setting registers (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Fix memory leak due to probe defer (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Avoid sched_clock() misuse (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Force a full restore after suspend-to-disk (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix wrong location for ref-clk delay (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix build error caused by use of sched_clock() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Introduce default delay for reference clock (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix synchronization between scsi_unjam_host() and ufshcd_queuecommand() (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Support vops pre suspend to disable auto-hibern8 (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_err_handler() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_reset_and_restore() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Stop clearing UNIT ATTENTIONS (Eric Chanudet) [2102378]
- scsi: ufs: core: Retry START_STOP on UNIT_ATTENTION (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove return statement in void function (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix ufshcd_probe_hba() prototype to match the definition (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix NULL pointer dereference (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Enter and exit hibern8 during clock scaling (Eric Chanudet) [2102378]
- scsi: ufs: core: Export hibern8 entry and exit functions (Eric Chanudet) [2102378]
- scsi: ufs: core: SCSI_UFS_HWMON depends on HWMON=y (Eric Chanudet) [2102378]
- scsi: ufs: exynos: Unify naming (Eric Chanudet) [2102378]
- scsi: ufs: Fix illegal offset in UPIU event trace (Eric Chanudet) [2102378]
- scsi: ufs: core: Add temperature notification exception handling (Eric Chanudet) [2102378]
- scsi: ufs: core: Probe for temperature notification support (Eric Chanudet) [2102378]
- scsi: ufs: core: Unbreak the reset handler (Eric Chanudet) [2102378]
- scsi: ufs: core: Revert "scsi: ufs: Synchronize SCSI and UFS error handling" (Eric Chanudet) [2102378]
- dt-bindings: ufs: Add bindings for Samsung ufs host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Change dbg select by check IP version (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use proper power management API (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Remove unneeded variable 'err' (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Fix Intel LKF link stability (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove unused parameters (Eric Chanudet) [2102378]
- scsi: ufs: Fix ufshcd_request_sense_async() for Samsung KLUFG8RHDA-B2D1 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Fix static checker warning (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix typo in comments (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix possible memory leak (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not report victim error in HCM (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Verify that 'num_inflight_map_req' is non-negative (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use a correct max multi chunk (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Rewind the read timeout on every read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove redundant initialization of variable 'lba' (Eric Chanudet) [2102378]
- scsi: ufshcd: Fix device links when BOOT WLUN fails to probe (Eric Chanudet) [2102378]
- scsi: ufs: Fix unsigned int compared with less than zero (Eric Chanudet) [2102378]
- scsi: ufs: core: Add lu_enable sysfs node (Eric Chanudet) [2102378]
- scsi: ufs: core: Add L2P entry swap quirk for Micron UFS (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant call in ufshcd_add_command_trace() (Eric Chanudet) [2102378]
- scsi: ufs: Add fault injection support (Eric Chanudet) [2102378]
- scsi: ufs: Retry aborted SCSI commands instead of completing these successfully (Eric Chanudet) [2102378]
- scsi: ufs: Synchronize SCSI and UFS error handling (Eric Chanudet) [2102378]
- scsi: ufs: Request sense data asynchronously (Eric Chanudet) [2102378]
- scsi: ufs: Fix the SCSI abort handler (Eric Chanudet) [2102378]
- scsi: ufs: Optimize SCSI command processing (Eric Chanudet) [2102378]
- scsi: ufs: Optimize serialization of setup_xfer_req() calls (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Utilize Transfer Request List Completion Notification Register" (Eric Chanudet) [2102378]
- scsi: ufs: Inline ufshcd_outstanding_req_clear() (Eric Chanudet) [2102378]
- scsi: ufs: Remove several wmb() calls (Eric Chanudet) [2102378]
- scsi: ufs: Improve static type checking for the host controller state (Eric Chanudet) [2102378]
- scsi: ufs: Verify UIC locking requirements at runtime (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_valid_tag() (Eric Chanudet) [2102378]
- scsi: ufs: Use DECLARE_COMPLETION_ONSTACK() where appropriate (Eric Chanudet) [2102378]
- scsi: ufs: Rename the second ufshcd_probe_hba() argument (Eric Chanudet) [2102378]
- scsi: ufs: Only include power management code if necessary (Eric Chanudet) [2102378]
- scsi: ufs: Reduce power management code duplication (Eric Chanudet) [2102378]
- scsi: ufs: Fix memory corruption by ufshcd_read_desc_param() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make host mode parameters configurable (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add support for host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not send umap_all in host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Limit the number of in-flight map requests (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add "cold" regions timer (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB dev reset response (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Region inactivation in host mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make eviction depend on region's reads (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add reads counter (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Transform set_dirty to iterate_rgn (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add host control mode support to rsp_upiu (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Cache HPB Control mode on init (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB 2.0 support (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Prepare HPB read for cached sub-region (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: L2P map management for HPB read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Introduce Host Performance Buffer feature (Eric Chanudet) [2102378]
- scsi: ufs: Allow async suspend/resume callbacks (Eric Chanudet) [2102378]
- scsi: ufs: core: Use scsi_get_lba() to get LBA (Eric Chanudet) [2102378]
- scsi: ufs: Refactor ufshcd_is_intr_aggr_allowed() (Eric Chanudet) [2102378]
- redhat: config: disable qcom eDP phy driver (Eric Chanudet) [2102384]
- phy: qcom-qmp: rename error labels (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix pipe-clock imbalance on power-on failure (Eric Chanudet) [2102384]
- phy: qcom-qmp: switch to explicit reset helpers (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix reset-controller leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix struct clk leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix phy-descriptor kernel-doc typo (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SDX65 QMP PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SDX65 USB PHY binding (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM6350 UFS PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6350 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: add sc8280xp UFS PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: add sc8180x and sc8280xp ufs compatibles (Eric Chanudet) [2102384]
- phy: qcom-snps: Add sc8280xp support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add sc8180x and sc8280xp (Eric Chanudet) [2102384]
- phy: qcom: Program SSC only if supported by sink (Eric Chanudet) [2102384]
- phy: qcom: Add support for eDP PHY on sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: Add eDP PHY compatible for sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: convert Qualcomm USB HS phy to yaml (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for MSM8953 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Document msm8953 compatible (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: conver latch function to pool macro (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: convert to BITFIELD macro (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe1 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe0 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 USB QMP PHYs (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 USB3 PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add bindings for SM8450 (Eric Chanudet) [2102384]
- phy: qcom: use struct_size instead of sizeof (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 UFS QMP Phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 UFS phy compatible (Eric Chanudet) [2102384]
- phy: qcom: Introduce new eDP PHY driver (Eric Chanudet) [2102384]
- dt-bindings: phy: Introduce Qualcomm eDP PHY binding (Eric Chanudet) [2102384]
- phy: qualcomm: ipq806x-usb: Fix kernel-doc style (Eric Chanudet) [2102384]
- phy: qualcomm: usb-hsic: Fix the kernel-doc warn (Eric Chanudet) [2102384]
- phy: qualcomm: qmp: Add missing struct documentation (Eric Chanudet) [2102384]
- phy: qcom-snps: Correct the FSEL_MASK (Eric Chanudet) [2102384]
- phy: qcom-qmp: another fix for the sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: IPQ6018 and IPQ8074 PCIe PHY require no supply (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Fix a memory leak on probe (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add QCM2290 USB3 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add QCM2290 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add missing vdd supply (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add missing vdd-supply (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Drop qcom,mtp (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Document alcatel,idol347 board (Eric Chanudet) [2102384]
- phy: qcom-qmp: Make use of the helper function devm_add_action_or_reset() (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Update maintainer email (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SM6115 UFS phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6115 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qmp: Provide unique clock names for DP clocks (Eric Chanudet) [2102384]
- phy: qcom-qmp: add USB3 PHY support for IPQ6018 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add IPQ6018 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom: qmp: Add SC8180x USB/DP combo (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for sc8180x (Eric Chanudet) [2102384]
- phy: qualcomm: phy-qcom-usb-hs: repair non-kernel-doc comment (Eric Chanudet) [2102384]
- phy: qcom-qmp: Fix sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for SC7280 (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add sc8180x PCIe support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add sc8180x PCIe compatible (Eric Chanudet) [2102384]
- clk: qcom: add sc8280xp GCC driver (Adrien Thierry) [2103761]
- dt-bindings: clock: Add Qualcomm SC8280XP GCC bindings (Adrien Thierry) [2103761]
- redhat: config: qcom_scm download off by default (Eric Chanudet) [2101563]
- redhat: config: disable sm8450 by default (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Update clock voting as optional (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SC7280 lpass pin configuration (Eric Chanudet) [2101563]
- pinctrl: qcom: Extract chip specific LPASS LPI code (Eric Chanudet) [2101563]
- pinctrl: qcom: Update lpi pin group custiom functions with framework generic functions (Eric Chanudet) [2101563]
- pinctrl: qcom: Update macro name to LPI specific (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc7280 lpass lpi pinctrl bindings (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Update lpass lpi file name to SoC specific (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pmx65 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pmx65 support (Eric Chanudet) [2101563]
- pinctrl: qcom: sm6350: fix order of UFS & SDC pins (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8150: Specify PDC map (Eric Chanudet) [2101563]
- dt-bindings: qcom,pdc: Add compatible for SM8150 (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8450 (Eric Chanudet) [2101563]
- pinctrl: qcom: Introduce sc8280xp TLMM driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc8280xp TLMM binding (Eric Chanudet) [2101563]
- pinctrl: qcom: cleanup comments (Eric Chanudet) [2101563]
- pinctrl: qcom: qcm2290: Add GPIO wakeirq map (Eric Chanudet) [2101563]
- pinctrl: qcom: print egpio mode in debugfs (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8450: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: Add PM8226 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Document PM8226 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Return -EINVAL for setting affinity if no IRQ parent (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM8450 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM8450 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: spmi-gpio: Add support for PM2250 (Eric Chanudet) [2101563]
- dt-bindings: qcom,pmic-gpio: Add pm2250 compatible string (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: Add egpio feature support (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8019 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM8019 (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SDX65 pincontrol driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SDX65 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8350: Correct UFS and SDC offsets (Eric Chanudet) [2101563]
- pinctrl: qcom: sdm845: Enable dual edge errata (Eric Chanudet) [2101563]
- pinctrl: qcom: fix unmet dependencies on GPIOLIB for GPIOLIB_IRQCHIP (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: switch to #interrupt-cells (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Convert qcom pmic mpp bindings to YAML (Eric Chanudet) [2101563]
- iommu/arm: fix ARM_SMMU_QCOM compilation (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- qcom_scm: hide Kconfig symbol (Eric Chanudet) [2101563]
- firmware: include drivers/firmware/Kconfig unconditionally (Eric Chanudet) [2101563]
- firmware: qcom_scm: QCOM_SCM should depend on ARCH_QCOM (Eric Chanudet) [2101563]
- firmware: qcom_scm: Allow qcom_scm driver to be loadable as a permenent module (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: add support to enable/disable output (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add output-{enable,disable} properties (Eric Chanudet) [2101563]
- pinctrl: qcom: Add QCM2290 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add QCM2290 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM6350 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6350 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add PM suspend callbacks (Eric Chanudet) [2101563]
- pinctrl: qcom: msm8226: fill in more functions (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: correct parent irqspec translation (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Remove the interrupts property (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Convert qcom pmic gpio bindings to YAML (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pmc8180 & pmc8180c (Eric Chanudet) [2101563]
- drivers: qcom: pinctrl: Add pinctrl driver for sm6115 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6115 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Add compatible for pmic-gpio on SA8155p-adp (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for SA8155p-adp (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- pinctrl: qcom: Add MDM9607 pinctrl driver (Eric Chanudet) [2101563]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-157.el9]
- drm/nouveau: recognise GA103 (Karol Herbst) [2115796]
- drm/aperture: Run fbdev removal before internal helpers (Karol Herbst) [2088409]
- drm/i915/ttm: fix 32b build (Karol Herbst) [2088409]
- drm/amd/display: Ensure valid event timestamp for cursor-only commits (Karol Herbst) [2088409]
- drm/amd/pm: Prevent divide by zero (Karol Herbst) [2088409]
- drm/amd/display: Only use depth 36 bpp linebuffers on DCN display engines. (Karol Herbst) [2088409]
- drm/amdkfd: correct the MEC atomic support firmware checking for GC 10.3.7 (Karol Herbst) [2088409]
- drm/amd/display: Ignore First MST Sideband Message Return Error (Karol Herbst) [2088409]
- drm/i915/selftests: fix subtraction overflow bug (Karol Herbst) [2088409]
- drm/i915/gt: Serialize TLB invalidates with GT resets (Karol Herbst) [2088409]
- drm/i915/gt: Serialize GRDOM access between multiple engine resets (Karol Herbst) [2088409]
- drm/i915/ttm: fix sg_table construction (Karol Herbst) [2088409]
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests (Karol Herbst) [2088409]
- drm/i915/gvt: IS_ERR() vs NULL bug in intel_gvt_update_reg_whitelist() (Karol Herbst) [2088409]
- drm/i915/guc: ADL-N should use the same GuC FW as ADL-S (Karol Herbst) [2088409]
- drm/i915: fix a possible refcount leak in intel_dp_add_mst_connector() (Karol Herbst) [2088409]
- drm/amdgpu/display: disable prefer_shadow for generic fb helpers (Karol Herbst) [2088409]
- drm/amdgpu: keep fbdev buffers pinned during suspend (Karol Herbst) [2088409]
- drm/fourcc: fix integer type usage in uapi header (Karol Herbst) [2088409]
- drm/i915/dgfx: Disable d3cold at gfx root port (Karol Herbst) [2088409]
- drm/i915/gem: add missing else (Karol Herbst) [2088409]
- drm/amdgpu: To flush tlb for MMHUB of RAVEN series (Karol Herbst) [2088409]
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC" (Karol Herbst) [2088409]
- drm/amdgpu: fix adev variable used in amdgpu_device_gpu_recover() (Karol Herbst) [2088409]
- drm/amd: Revert "drm/amd/display: keep eDP Vdd on when eDP stream is already enabled" (Karol Herbst) [2088409]
- udmabuf: add back sanity check (Karol Herbst) [2088409]
- drm/amd/display: Fix typo in override_lane_settings (Karol Herbst) [2088409]
- amd/display/dc: Fix COLOR_ENCODING and COLOR_RANGE doing nothing for DCN20+ (Karol Herbst) [2088409]
- drm/i915: Implement w/a 22010492432 for adl-s (Karol Herbst) [2088409]
- drm/i915/uc: remove accidental static from a local variable (Karol Herbst) [2088409]
- drm/amd/display: Cap OLED brightness per max frame-average luminance (Karol Herbst) [2088409]
- drm/amdgpu: Fix GTT size reporting in amdgpu_ioctl (Karol Herbst) [2088409]
- drm/i915/reset: Fix error_state_read ptr + offset use (Karol Herbst) [2088409]
- drm/amdkfd: add pinned BOs to kfd_bo_list (Karol Herbst) [2088409]
- drm/amdkfd: Use mmget_not_zero in MMU notifier (Karol Herbst) [2088409]
- drm/amdgpu: Resolve RAS GFX error count issue after cold boot on Arcturus (Karol Herbst) [2088409]
- drm/amd/display: Read Golden Settings Table from VBIOS (Karol Herbst) [2088409]
- Revert "drm/amd/display: Fix DCN3 B0 DP Alt Mapping" (Karol Herbst) [2088409]
- drm/amdgpu: update VCN codec support for Yellow Carp (Karol Herbst) [2088409]
- drm/amd/display: remove stale config guards (Karol Herbst) [2088409]
- drm/amdgpu/jpeg2: Add jpeg vmid update under IB submit (Karol Herbst) [2088409]
- drm/atomic: Force bridge self-refresh-exit on CRTC switch (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Support PSR-exit to disable transition (Karol Herbst) [2088409]
- drm/amdkfd:Fix fw version for 10.3.6 (Karol Herbst) [2088409]
- drm/amd/pm: use bitmap_{from,to}_arr32 where appropriate (Karol Herbst) [2088409]
- drm/amd/pm: correct the metrics version for SMU 11.0.11/12/13 (Karol Herbst) [2088409]
- drm/amd/pm: Fix missing thermal throttler status (Karol Herbst) [2088409]
- drm/amd/pm: fix a potential gpu_metrics_table memory leak (Karol Herbst) [2088409]
- drm/radeon: fix a possible null pointer dereference (Karol Herbst) [2088409]
- drm/amd/display: Check zero planes for OTG disable W/A on clock change (Karol Herbst) [2088409]
- drm/amd/display: Check if modulo is 0 before dividing. (Karol Herbst) [2088409]
- drm/amdgpu: fix limiting AV1 to the first instance on VCN3 (Karol Herbst) [2088409]
- drm/bridge: ti-sn65dsi83: Handle dsi_lanes == 0 as invalid (Karol Herbst) [2088409]
- drm/amdgpu: Off by one in dm_dmub_outbox1_low_irq() (Karol Herbst) [2088409]
- gma500: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/i915/dsi: fix VBT send packet port selection for ICL+ (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX (Karol Herbst) [2088409]
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/subdev/bus: Ratelimit logging for fault errors (Karol Herbst) [2088409]
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour. (Karol Herbst) [2088409]
- drm/amdgpu: add beige goby PCI ID (Karol Herbst) [2088409]
- drm/i915: Fix CFI violation with show_dynamic_id() (Karol Herbst) [2088409]
- drm/bridge: it6505: Send DPCD SET_POWER to downstream (Karol Herbst) [2088409]
- drm/panel: panel-simple: Fix proper bpc for AM-1280800N3TZQW-T00H (Karol Herbst) [2088409]
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01 (Karol Herbst) [2088409]
- drm/bridge: Fix it6505 Kconfig DRM_DP_AUX_BUS dependency (Karol Herbst) [2088409]
- drm/bridge: Fix error handling in analogix_dp_probe (Karol Herbst) [2088409]
- drm/bridge: anx7625: Use uint8 for lane-swing arrays (Karol Herbst) [2088409]
- drm/amd/amdgpu: Remove static from variable in RLCG Reg RW (Karol Herbst) [2088409]
- drm/amd/amdgpu: Fix asm/hypervisor.h build error. (Karol Herbst) [2088409]
- drm/amd/amdgpu: Only reserve vram for firmware with vega9 MS_HYPERV host. (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix HFP_HSW_HBP_HI and HFP_MIN handling (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix register layout (Karol Herbst) [2088409]
- drm/bridge: adv7511: clean up CEC adapter when probe fails (Karol Herbst) [2088409]
- drm/bridge: anx7625: add missing destroy_workqueue() in anx7625_i2c_probe() (Karol Herbst) [2088409]
- drm/edid: fix invalid EDID extension block filtering (Karol Herbst) [2088409]
- drm/bridge: it6505: Fix build error (Karol Herbst) [2088409]
- drm: bridge: it66121: Fix the register page length (Karol Herbst) [2088409]
- drm/vmwgfx: Fix an invalid read (Karol Herbst) [2088409]
- drm/ssd130x: Reduce temporary buffer sizes (Karol Herbst) [2088409]
- drm/ssd130x: Fix rectangle updates (Karol Herbst) [2088409]
- drm/format-helper: Fix XRGB888 to monochrome conversion (Karol Herbst) [2088409]
- drm/format-helper: Rename drm_fb_xrgb8888_to_mono_reversed() (Karol Herbst) [2088409]
- drm/solomon: Make DRM_SSD130X depends on MMU (Karol Herbst) [2088409]
- drm: ssd130x: Always apply segment remap setting (Karol Herbst) [2088409]
- drm: ssd130x: Fix COM scan direction register mask (Karol Herbst) [2088409]
- drm/bridge: anx7625: check the return on anx7625_aux_trans (Karol Herbst) [2088409]
- drm/selftests: missing error code in igt_buddy_alloc_smoke() (Karol Herbst) [2088409]
- drm/bridge_connector: enable HPD by default if supported (Karol Herbst) [2088409]
- drm: fix EDID struct for old ARM OABI format (Karol Herbst) [2088409]
- drm/amdgpu: Move mutex_init(&smu->message_lock) to smu_early_init() (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu13 (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu12 (Karol Herbst) [2088409]
- drm/amdgpu/ucode: Remove firmware load type check in amdgpu_ucode_free_bo (Karol Herbst) [2088409]
- drm/amdgpu/psp: move PSP memory alloc from hw_init to sw_init (Karol Herbst) [2088409]
- drm/amd/pm: fix the compile warning (Karol Herbst) [2088409]
- drm/amdkfd: Fix circular lock dependency warning (Karol Herbst) [2088409]
- drm/plane: Move range check for format_count earlier (Karol Herbst) [2088409]
- drm/amdgpu/sdma: Fix incorrect calculations of the wptr of the doorbells (Karol Herbst) [2088409]
- drm/amd/pm: fix double free in si_parse_power_table() (Karol Herbst) [2088409]
- drm/amdgpu/pm: fix the null pointer while the smu is disabled (Karol Herbst) [2088409]
- drm/amd/display: Disabling Z10 on DCN31 (Karol Herbst) [2088409]
- drm/virtio: fix NULL pointer dereference in virtio_gpu_conn_get_modes (Karol Herbst) [2088409]
- drm/vmwgfx: validate the screen formats (Karol Herbst) [2088409]
- drm/selftests: fix a shift-out-of-bounds bug (Karol Herbst) [2088409]
- drm/i915: Fix -Wstringop-overflow warning in call to intel_read_wm_latency() (Karol Herbst) [2088409]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-156.el9]
- net/mlx5: fs, fail conflicting actions (Mohammad Kabat) [2049451]
- net/mlx5: Rearm the FW tracer after each tracer event (Mohammad Kabat) [2049451]
- net/mlx5: correct ECE offset in query qp output (Mohammad Kabat) [2049451]
- net/mlx5e: Disable softirq in mlx5e_activate_rq to avoid race condition (Mohammad Kabat) [2049451]
- net/mlx5: CT: Fix header-rewrite re-use for tupels (Mohammad Kabat) [2049451]
- net/mlx5e: TC NIC mode, fix tc chains miss table (Mohammad Kabat) [2049451]
- net/mlx5: Don't use already freed action pointer (Mohammad Kabat) [2049451]
- net/mlx5: fix typo in comment (Mohammad Kabat) [2049451]
- net/mlx5: Allow future addition of IPsec object modifiers (Mohammad Kabat) [2049451]
- IB/mlx5: Fix undefined behavior due to shift overflowing the constant (Mohammad Kabat) [2049451]
- net/mlx5: Drain fw_reset when removing device (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix setting flow_source for smfs ct tuples (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix support for GRE tuples (Mohammad Kabat) [2049451]
- net/mlx5e: Remove HW-GRO from reported features (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block HW GRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block LRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Block rx-gro-hw feature in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: Wrap mlx5e_trap_napi_poll into rcu_read_lock (Mohammad Kabat) [2049451]
- net/mlx5: DR, Ignore modify TTL on RX if device doesn't support it (Mohammad Kabat) [2049451]
- net/mlx5: Initialize flow steering during driver probe (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix missing flow_source when creating multi-destination FW table (Mohammad Kabat) [2049451]
- net/mlx5: Fix matching on inner TTC (Mohammad Kabat) [2049451]
- net/mlx5: Avoid double clear or set of sync reset requested (Mohammad Kabat) [2049451]
- net/mlx5: Fix deadlock in sync reset flow (Mohammad Kabat) [2049451]
- net/mlx5e: Fix trust state reset in reload (Mohammad Kabat) [2049451]
- net/mlx5e: Avoid checking offload capability in post_parse action (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix queued up restore put() executing after relevant ft release (Mohammad Kabat) [2049451]
- net/mlx5e: TC, fix decap fallback to uplink when int port not supported (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix ct_clear overwriting ct action metadata (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Don't skip fib events on current dst (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix fib_info pointer assignment (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix use-after-free in fib event handler (Mohammad Kabat) [2049451]
- net/mlx5e: Fix the calling of update_buffer_lossy() API (Mohammad Kabat) [2049451]
- net/mlx5e: Don't match double-vlan packets if cvlan is not set (Mohammad Kabat) [2049451]
- net/mlx5: Fix slab-out-of-bounds while reading resource dump menu (Mohammad Kabat) [2049451]
- net/mlx5e: Fix wrong source vport matching on tunnel rule (Mohammad Kabat) [2049451 2049589]
- RDMA/mlx5: Add a missing update of cache->last_add (Mohammad Kabat) [2049451]
- RDMA/mlx5: Don't remove cache MRs when a delay is needed (Mohammad Kabat) [2049451]
- net/mlx5e: HTB, remove unused function declaration (Mohammad Kabat) [2049451]
- net/mlx5e: Statify function mlx5_cmd_trigger_completions (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused fill page array API function (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused exported contiguous coherent buffer allocation API (Mohammad Kabat) [2049451]
- net/mlx5: CT: Remove extra rhashtable remove on tuple entries (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove hw_ste from mlx5dr_ste to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove 4 members from mlx5dr_ste_htbl to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove num_of_entries byte_size from struct mlx5_dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove icm_addr from mlx5dr_icm_chunk to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove mr_addr rkey from struct mlx5dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Adjust structure member to reduce memory hole (Mohammad Kabat) [2049451]
- net/mlx5e: Drop cqe_bcnt32 from mlx5e_skb_from_cqe_mpwrq_linear (Mohammad Kabat) [2049451]
- net/mlx5e: Drop the len output parameter from mlx5e_xdp_handle (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Test the XDP program existence out of the handler (Mohammad Kabat) [2049451]
- net/mlx5e: Build SKB in place over the first fragment in non-linear legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Add headroom only to the first fragment in legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Validate MTU when building non-linear legacy RQ fragments info (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP encap, support action vlan pop_eth explicitly (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP decap, use vlan push_eth instead of pedit (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix memory leak in error flow for subscribe event routine (Mohammad Kabat) [2049451]
- net/mlx5e: Fix use-after-free in mlx5e_stats_grp_sw_update_stats (Mohammad Kabat) [2049451]
- net/mlx5e: Remove overzealous validations in netlink EEPROM query (Mohammad Kabat) [2049451]
- net/mlx5: Parse module mapping using mlx5_ifc (Mohammad Kabat) [2049451]
- net/mlx5: Query the maximum MCIA register read size from firmware (Mohammad Kabat) [2049451]
- net/mlx5: CT: Create smfs dr matchers dynamically (Mohammad Kabat) [2049451]
- net/mlx5: CT: Add software steering ct flow steering provider (Mohammad Kabat) [2049451]
- net/mlx5: Add smfs lib to export direct steering API to CT (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add helper to get backing dr table from a mlx5 flow table (Mohammad Kabat) [2049451]
- net/mlx5: CT: Introduce a platform for multiple flow steering providers (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the doorbell pgdir (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for UAR (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQs (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQ table (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the IRQ table (Mohammad Kabat) [2049451]
- net/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for ConnectX-7 steering (Mohammad Kabat) [2049451]
- net/mlx5: DR, Refactor ste_ctx handling for STE v0/1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Rename action modify fields to reflect naming in HW spec (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix handling of different actions on the same STE in STEv1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove unneeded comments (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for matching on Internet Header Length (IHL) (Mohammad Kabat) [2049451]
- net/mlx5: DR, Align mlx5dv_dr API vport action with FW behavior (Mohammad Kabat) [2049451]
- net/mlx5: Add debugfs counters for page commands failures (Mohammad Kabat) [2049451]
- net/mlx5: Add pages debugfs (Mohammad Kabat) [2049451]
- net/mlx5: Move debugfs entries to separate struct (Mohammad Kabat) [2049451]
- net/mlx5: Change release_all_pages cap bit location (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on reclaim pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant notify fail on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Add command failures data to debugfs (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix use after free in mlx5e_clone_flow_attr_for_post_act() (Mohammad Kabat) [2049451]
- net/mlx5: Support GRE conntrack offload (Mohammad Kabat) [2049451]
- mlx5: add support for page_pool_get_stats (Mohammad Kabat) [2049451]
- net/mlx5: Add migration commands definitions (Mohammad Kabat) [2049451]
- net/mlx5: Introduce migration bits and structures (Mohammad Kabat) [2049451]
- net/mlx5: Expose APIs to get/put the mlx5 core device (Mohammad Kabat) [2049451]
- net/mlx5: Disable SRIOV before PF removal (Mohammad Kabat) [2049451]
- net/mlx5: Reuse exported virtfn index function call (Mohammad Kabat) [2049451]
- net/mlx5: Add clarification on sync reset failure (Mohammad Kabat) [2049451]
- net/mlx5: Add reset_state field to MFRL register (Mohammad Kabat) [2049451]
- RDMA/mlx5: Use new command interface API (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Refactor error handling and reporting of async commands (Mohammad Kabat) [2049451]
- net/mlx5: Use mlx5_cmd_do() in core create_{cq,dct} (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Add new api for command execution (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, cmd_check refactoring (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Return value improvements (Mohammad Kabat) [2049451]
- net/mlx5: Lag, offload active-backup drops to hardware (Mohammad Kabat) [2049451]
- net/mlx5: Lag, record inactive state of bond device (Mohammad Kabat) [2049451]
- net/mlx5: Lag, don't use magic numbers for ports (Mohammad Kabat) [2049451]
- net/mlx5: Lag, use local variable already defined to access E-Switch (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, add drop rule support to ingress ACL (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, remove special uplink ingress ACL handling (Mohammad Kabat) [2049451 2049589]
- net/mlx5: E-Switch, reserve and use same uplink metadata across ports (Mohammad Kabat) [2049451 2049589]
- net/mlx5: Add ability to insert to specific flow group (Mohammad Kabat) [2049451]
- mlx5: remove unused static inlines (Mohammad Kabat) [2049451]
- RDMA/mlx5: Reorder calls to pcie_relaxed_ordering_enabled() (Mohammad Kabat) [2049451]
- RDMA/mlx5: Store ndescs instead of the translation table size (Mohammad Kabat) [2049451]
- RDMA/mlx5: Merge similar flows of allocating MR from the cache (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache ODP MR (Mohammad Kabat) [2049451]
- RDMA/mlx5: Remove redundant work in struct mlx5_cache_ent (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Allow sample action with CT (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Make post_act parse CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Clean redundant counter flag from tc action parsers (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Use multi table support for CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Create new flow attr for multi table actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Add post act offload/unoffload API (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass actions param to actions_match_supported() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move flow hashtable to be per rep (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add support for tx_port_ts in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add PTP counters for uplink representor (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Restrict bulk size for small Striding RQs (Mohammad Kabat) [2049451]
- net/mlx5e: Default to Striding RQ when not conflicting with CQE compression (Mohammad Kabat) [2049451]
- net/mlx5e: Generalize packet merge error message (Mohammad Kabat) [2049451]
- net/mlx5e: Add support for using xdp->data_meta (Mohammad Kabat) [2049451]
- net/mlx5e: Fix spelling mistake "supoported" -> "supported" (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize the common case condition in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize modulo in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Use READ_ONCE/WRITE_ONCE for DCBX trust state (Mohammad Kabat) [2049451]
- net/mlx5e: Move repeating code that gets TC prio into a function (Mohammad Kabat) [2049451]
- net/mlx5e: Use select queue parameters to sync with control flow (Mohammad Kabat) [2049451]
- net/mlx5e: Move mlx5e_select_queue to en/selq.c (Mohammad Kabat) [2049451]
- net/mlx5e: Introduce select queue parameters (Mohammad Kabat) [2049451]
- net/mlx5e: Sync txq2sq updates with mlx5e_xmit for HTB queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use a barrier after updating txq2sq (Mohammad Kabat) [2049451]
- net/mlx5e: Disable TX queues before registering the netdev (Mohammad Kabat) [2049451]
- net/mlx5e: Cleanup of start/stop all queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use FW limitation for max MPW WQEBBs (Mohammad Kabat) [2049451]
- net/mlx5e: Read max WQEBBs on the SQ from firmware (Mohammad Kabat) [2049451]
- net/mlx5e: Remove unused tstamp SQ field (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete get_num_static_uars function (Mohammad Kabat) [2049451]
- net/mlx5: VLAN push on RX, pop on TX (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Introduce software defined steering capabilities (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Remove unused TIR modify bitmask enums (Mohammad Kabat) [2049451]
- net/mlx5e: CT, Remove redundant flow args from tc ct calls (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Store mapped tunnel id on flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Test CT and SAMPLE on flow attr (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: Refactor eswitch attr flags to just attr flags (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: CT, Don't set flow flag CT for ct clear flow (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Hold sample_attr on stack instead of pointer (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: TC, Reject rules with multiple CT actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Refactor mlx5e_tc_add_flow_mod_hdr() to get flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Pass attr to tc_act can_offload() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Split pedit offloads verify from alloc_tc_pedit_action() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move pedit_headers_action to parse_attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move counter creation call to alloc_flow_attr_counter() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass attr arg for attaching/detaching encaps (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move code chunk setting encap dests into its own function (Mohammad Kabat) [2049451 2049666]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-155.el9]
- i40e: Fix tunnel checksum offload with fragmented traffic (Ivan Vecera) [2104734]
- wait: Fix __wait_event_hrtimeout for RT/DL tasks (Prarit Bhargava) [2112265]
- raid1: ensure write behind bio has less than BIO_MAX_VECS sectors (Nigel Croxon) [2117034]
- KVM: nVMX: Inject #UD if VMXON is attempted with incompatible CR0/CR4 (Vitaly Kuznetsov) [2118955]
- iavf: Fix deadlock in initialization (Petr Oros) [2106658]
- netfilter: nf_tables: do not allow RULE_ID to refer to another chain (Florian Westphal) [2116355] {CVE-2022-2586}
- netfilter: nf_tables: do not allow CHAIN_ID to refer to another table (Florian Westphal) [2116355] {CVE-2022-2586}
- netfilter: nf_tables: do not allow SET_ID to refer to another table (Florian Westphal) [2116355] {CVE-2022-2586}
- kbuild: expose explicit .symversions targets (Čestmír Kalina) [2066238]
- selftests: mptcp: make sendfile selftest work (Florian Westphal) [2109043]
- netfilter: nf_queue: do not allow packet truncation below transport header offset (Florian Westphal) [2116161] {CVE-2022-36946}
- ASoC: amd: yc: Update DMI table entries for AMD platforms (Jaroslav Kysela) [2114934]
- ASoC: amd: yc: Update DMI table entries (Jaroslav Kysela) [2114934]
- sfc: fix use after free when disabling sriov (Íñigo Huguet) [2097189]
- mm: Fix PASID use-after-free issue (Jerry Snitselaar) [2113044]
- ice: Fix VF not able to send tagged traffic with no VLAN filters (Petr Oros) [2116964]
- ice: Ignore error message when setting same promiscuous mode (Petr Oros) [2116964]
- ice: Fix clearing of promisc mode with bridge over bond (Petr Oros) [2116964]
- ice: Ignore EEXIST when setting promisc mode (Petr Oros) [2116964]
- ice: Fix double VLAN error when entering promisc mode (Petr Oros) [2116964]
- ice: Fix promiscuous mode not turning off (Petr Oros) [2116964]
- ice: Introduce enabling promiscuous mode on multiple VF's (Petr Oros) [2116964]
- ice: do not setup vlan for loopback VSI (Petr Oros) [2116964]
- ice: check (DD | EOF) bits on Rx descriptor rather than (EOP | RS) (Petr Oros) [2116964]
- ice: Fix VSIs unable to share unicast MAC (Petr Oros) [2116964]
- ice: Fix max VLANs available for VF (Petr Oros) [2116964]
- ice: change devlink code to read NVM in blocks (Petr Oros) [2116964]
- be2net: Remove useless DMA-32 fallback configuration (Petr Oros) [2051280]
- ethernet: constify references to netdev->dev_addr in drivers (Petr Oros) [2051280]
- ethernet: Remove redundant 'flush_workqueue()' calls (Petr Oros) [2051280]
- be2net: Use irq_update_affinity_hint() (Petr Oros) [2051280]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-154.el9]
- Revert "x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV" (John Allen) [2081424]
- virt: sev-guest: Pass the appropriate argument type to iounmap() (John Allen) [2081424]
- x86/boot: Fix the setup data types max limit (John Allen) [2081424]
- x86/compressed/64: Add identity mappings for setup_data entries (John Allen) [2081424]
- x86/Hyper-V: Add SEV negotiate protocol support in Isolation VM (John Allen) [2081424]
- x86/sev: Mark the code returning to user space as syscall gap (John Allen) [2081424]
- x86/sev: Annotate stack change in the #VC handler (John Allen) [2081424]
- x86/sev: Remove duplicated assignment to variable info (John Allen) [2081424]
- x86/sev: Fix address space sparse warning (John Allen) [2081424]
- x86/sev: Get the AP jump table address from secrets page (John Allen) [2081424]
- x86/sev: Add missing __init annotations to SEV init routines (John Allen) [2081424]
- virt: sevguest: Rename the sevguest dir and files to sev-guest (John Allen) [2081424]
- virt: sevguest: Change driver name to reflect generic SEV support (John Allen) [2081424]
- x86/boot: Put globals that are accessed early into the .data section (John Allen) [2081424]
- virt: sevguest: Fix bool function returning negative value (John Allen) [2081424]
- virt: sevguest: Fix return value check in alloc_shared_pages() (John Allen) [2081424]
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO (John Allen) [2081424]
- x86/sev-es: Replace open-coded hlt-loop with sev_es_terminate() (John Allen) [2081424]
- virt: sevguest: Add documentation for SEV-SNP CPUID Enforcement (John Allen) [2081424]
- virt: sevguest: Add support to get extended report (John Allen) [2081424]
- virt: sevguest: Add support to derive key (John Allen) [2081424]
- redhat/configs: enable CONFIG_SEV_GUEST (John Allen) [2081424]
- virt: Add SEV-SNP guest driver (John Allen) [2081424]
- x86/sev: Register SEV-SNP guest request platform device (John Allen) [2081424]
- x86/sev: Provide support for SNP guest request NAEs (John Allen) [2081424]
- x86/sev: Add a sev= cmdline option (John Allen) [2081424]
- x86/sev: Use firmware-validated CPUID for SEV-SNP guests (John Allen) [2081424]
- x86/sev: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/compressed/64: Add identity mapping for Confidential Computing blob (John Allen) [2081424]
- x86/compressed: Export and rename add_identity_map() (John Allen) [2081424]
- x86/compressed: Use firmware-validated CPUID leaves for SEV-SNP guests (John Allen) [2081424]
- x86/compressed: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/boot: Add a pointer to Confidential Computing blob in bootparams (John Allen) [2081424]
- x86/compressed/64: Add support for SEV-SNP CPUID table in #VC handlers (John Allen) [2081424]
- x86/sev: Move MSR-based VMGEXITs for CPUID to helper (John Allen) [2081424]
- KVM: x86: Move lookup of indexed CPUID leafs to helper (John Allen) [2081424]
- x86/boot: Add Confidential Computing type to setup_data (John Allen) [2081424]
- x86/compressed/acpi: Move EFI kexec handling into common code (John Allen) [2081424]
- x86/compressed/acpi: Move EFI vendor table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI config table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI system table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI detection to helper (John Allen) [2081424]
- x86/head/64: Re-enable stack protection (John Allen) [2081424]
- x86/sev: Use SEV-SNP AP creation to start secondary CPUs (John Allen) [2081424]
- x86/mm: Validate memory when changing the C-bit (John Allen) [2081424]
- x86/kernel: Validate ROM memory before accessing when SEV-SNP is active (John Allen) [2081424]
- x86/kernel: Mark the .bss..decrypted section as shared in the RMP table (John Allen) [2081424]
- x86/sev: Add helper for validating pages in early enc attribute changes (John Allen) [2081424]
- x86/sev: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Add helper for validating pages in the decompression stage (John Allen) [2081424]
- x86/sev: Check the VMPL level (John Allen) [2081424]
- x86/sev: Add a helper for the PVALIDATE instruction (John Allen) [2081424]
- x86/sev: Check SEV-SNP features support (John Allen) [2081424]
- x86/sev: Save the negotiated GHCB version (John Allen) [2081424]
- x86/sev: Define the Linux-specific guest termination reasons (John Allen) [2081424]
- x86/mm: Extend cc_attr to include AMD SEV-SNP (John Allen) [2081424]
- x86/sev: Detect/setup SEV/SME features earlier in boot (John Allen) [2081424]
- x86/compressed/64: Detect/setup SEV/SME features earlier during boot (John Allen) [2081424]
- x86/boot: Use MSR read/write helpers instead of inline assembly (John Allen) [2081424]
- x86/boot: Introduce helpers for MSR reads/writes (John Allen) [2081424]
- KVM: SVM: Update the SEV-ES save area mapping (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the GHCB save area (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the SEV-ES save area (John Allen) [2081424]
- KVM: SVM: Define sev_features and vmpl field in the VMSA (John Allen) [2081424]
- x86/mm/cpa: Generalize __set_memory_enc_pgtable() (John Allen) [2081424]
- x86/coco: Add API to handle encryption mask (John Allen) [2081424]
- x86/cc: Move arch/x86/{kernel/cc_platform.c => coco/core.c} (John Allen) [2081424]
- x86/sev: Move common memory encryption code to mem_encrypt.c (John Allen) [2081424]
- x86/sev: Rename mem_encrypt.c to mem_encrypt_amd.c (John Allen) [2081424]
- x86/sev: Remove do_early_exception() forward declarations (John Allen) [2081424]
- x86/head64: Carve out the guest encryption postprocessing into a helper (John Allen) [2081424]
- x86/sev: Get rid of excessive use of defines (John Allen) [2081424]
- x86/sev: Shorten GHCB terminate macro names (John Allen) [2081424]
- x86/sev: Make the #VC exception stacks part of the default stacks storage (John Allen) [2081424]
- tools headers UAPI: Synch KVM's svm.h header with the kernel (John Allen) [2081424]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-153.el9]
- selftests: netfilter: add test case for nf trace infrastructure (Florian Westphal) [2112751]
- netfilter: nf_tables: fix crash when nf_trace is enabled (Florian Westphal) [2112751]
- netfilter: nf_log: incorrect offset to network header (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Consolidate entry checks (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Don't ignore unknown protocols (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Merge MAC header dumpers (Phil Sutter) [2067133]
- net/mlx4_en: use kzalloc (Mohammad Kabat) [2049443]
- net/mlx4: Delete useless moduleparam include (Mohammad Kabat) [2049443]
- RDMA/mlx4: remove redundant assignment to variable nreq (Mohammad Kabat) [2049443]
- RDMA/mlx4: Delete useless module.h include (Mohammad Kabat) [2049443]
- RDMA/mlx4: Don't continue event handler after memory allocation failure (Mohammad Kabat) [2049443]
- net/mlx4: Use irq_update_affinity_hint() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Use bitmap_alloc() when applicable (Mohammad Kabat) [2049443]
- net/mlx4_en: Fix an use-after-free bug in mlx4_en_try_alloc_resources() (Mohammad Kabat) [2049443]
- net/mlx4_en: Update reported link modes for 1/10G (Mohammad Kabat) [2049443]
- RDMA/mlx4: Do not fail the registration on port stats (Mohammad Kabat) [2049443]
- net: convert users of bitmap_foo() to linkmode_foo() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Return missed an error if device doesn't support steering (Mohammad Kabat) [2049443]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049443]
- mlx4: constify args for const dev_addr (Mohammad Kabat) [2049443]
- mlx4: remove custom dev_addr clearing (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_u64_to_mac() with u64_to_ether_addr() (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_mac_to_u64() with ether_addr_to_u64() (Mohammad Kabat) [2049443]
- net/mlx4_en: avoid one cache line miss to ring doorbell (Mohammad Kabat) [2049443]
- net/mlx4_en: Add XDP_REDIRECT statistics (Mohammad Kabat) [2049443]
- net/mlx4: Use array_size() helper in copy_to_user() (Mohammad Kabat) [2049443]
- net: mlx4: Add support for XDP_REDIRECT (Mohammad Kabat) [2049443]
- net/mlx4_en: Don't allow aRFS for encapsulated packets (Mohammad Kabat) [2049443]
- net/mlx4_en: Resolve bad operstate value (Mohammad Kabat) [2049443]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049443]
- net/mlx4: Use ARRAY_SIZE to get an array's size (Mohammad Kabat) [2049443]
- net/mlx4: make the array states static const, makes object smaller (Mohammad Kabat) [2049443]
- redhat: Use redhatsecureboot701 for ppc64le (Patrick Talbert) [2109211]
- device property: Advertise fwnode and device property count API calls (Al Stone) [2102893]
- device property: Fix recent breakage of fwnode_get_next_parent_dev() (Al Stone) [2102893]
- device property: Use multi-connection matchers for single case (Al Stone) [2102893]
- device property: Drop 'test' prefix in parameters of fwnode_is_ancestor_of() (Al Stone) [2102893]
- device property: Introduce fwnode_for_each_parent_node() (Al Stone) [2102893]
- device property: Allow error pointer to be passed to fwnode APIs (Al Stone) [2102893]
- device property: Add irq_get to fwnode operation (Al Stone) [2102893]
- device property: Add iomap to fwnode operations (Al Stone) [2102893]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2102893]
- ARM: tegra: paz00: Handle device properties with software node API (Al Stone) [2102893]

* Mon Aug 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-152.el9]
- net/mlx5e: SHAMPO, reduce TIR indication (Mohammad Kabat) [2049450]
- net/mlx5e: Lag, Only handle events from highest priority multipath entry (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5: Fix a race on command flush flow (Mohammad Kabat) [2049450]
- net/mlx5: Fix size field in bufferx_reg struct (Mohammad Kabat) [2049450]
- net/mlx5e: Fix VF min/max rate parameters interchange mistake (Mohammad Kabat) [2049450]
- net/mlx5e: Add missing increment of count (Mohammad Kabat) [2049450]
- net/mlx5e: MPLSoUDP decap, fix check for unsupported matches (Mohammad Kabat) [2049450]
- net/mlx5e: Fix MPLSoUDP encap to use MPLS action information (Mohammad Kabat) [2049450]
- net/mlx5e: Add feature check for set fec counters (Mohammad Kabat) [2049450 2049713]
- net/mlx5e: TC, Skip redundant ct clear actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded packets (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure (Mohammad Kabat) [2049450]
- net/mlx5: Fix possible deadlock on rule deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049450]
- net/mlx5: Fix wrong limitation of metadata match on ecpf (Mohammad Kabat) [2049450]
- net/mlx5: Update log_max_qp value to be 17 at most (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix the threshold that defines when pool sync is initiated (Mohammad Kabat) [2049450]
- net/mlx5: DR, Don't allow match on IP w/o matching on full ethertype/ip_version (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix slab-out-of-bounds in mlx5_cmd_dr_create_fte (Mohammad Kabat) [2049450]
- net/mlx5: DR, Cache STE shadow memory (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid field-overflowing memcpy() (Mohammad Kabat) [2049450]
- net/mlx5e: Use struct_group() for memcpy() region (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid implicit modify hdr for decap drop rule (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix tunnel mode crypto offload for non TCP/UDP traffic (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix crypto offload for non TCP/UDP encapsulated traffic (Mohammad Kabat) [2049450]
- net/mlx5e: Don't treat small ceil values as unlimited in HTB offload (Mohammad Kabat) [2049450]
- net/mlx5: E-Switch, Fix uninitialized variable modact (Mohammad Kabat) [2049450]
- net/mlx5e: Fix handling of wrong devices during bond netevent (Mohammad Kabat) [2049450]
- net/mlx5e: Fix broken SKB allocation in HW-GRO (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong calculation of header index in HW_GRO (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, Fix devlink deadlock on net namespace deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5: Use del_timer_sync in fw reset flow of halting poll (Mohammad Kabat) [2049450]
- net/mlx5e: Fix module EEPROM query (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, ensure dev_name is null-terminated (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, take rtnl lock in init error handler (Mohammad Kabat) [2049450]
- mlx5: Don't accidentally set RTO_ONLINK before mlx5e_route_lookup_ipv4_get() (Mohammad Kabat) [2049450]
- net/mlx5e: Fix build error in fec_set_block_stats() (Mohammad Kabat) [2049450]
- Revert "net/mlx5: Add retry mechanism to the command entry index allocation" (Mohammad Kabat) [2049450]
- net/mlx5: Set command entry semaphore up once got index free (Mohammad Kabat) [2049450]
- net/mlx5e: Sync VXLAN udp ports during uplink representor profile change (Mohammad Kabat) [2049450]
- net/mlx5: Fix access to sf_dev_table on allocation failure (Mohammad Kabat) [2049450]
- net/mlx5e: Fix matching on modified inner ip_ecn bits (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for GRE tunnel" (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for UDP tunnels" (Mohammad Kabat) [2049450]
- net/mlx5e: Don't block routes with nexthop objects in SW (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix wrong usage of fib_info_nh when routes with nexthop objects are used (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix nullptr on deleting mirroring rule (Mohammad Kabat) [2049450]
- net/mlx5e: Fix page DMA map/unmap attributes (Mohammad Kabat) [2049450]
- net/mlx5e: Add recovery flow in case of error CQE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant error logging (Mohammad Kabat) [2049450]
- net/mlx5e: Refactor set_pflag_cqe_based_moder (Mohammad Kabat) [2049450]
- net/mlx5e: Move HW-GRO and CQE compression check to fix features flow (Mohammad Kabat) [2049450]
- net/mlx5e: Fix feature check per profile (Mohammad Kabat) [2049450]
- net/mlx5e: Unblock setting vid 0 for VF in case PF isn't eswitch manager (Mohammad Kabat) [2049450]
- net/mlx5e: Expose FEC counters via ethtool (Mohammad Kabat) [2049450 2049713]
- net/mlx5: Update log_max_qp value to FW max capability (Mohammad Kabat) [2049450]
- net/mlx5: SF, Use all available cpu for setting cpu affinity (Mohammad Kabat) [2049450]
- net/mlx5: Introduce API for bulk request and release of IRQs (Mohammad Kabat) [2049450]
- net/mlx5: Split irq_pool_affinity logic to new file (Mohammad Kabat) [2049450]
- net/mlx5: Move affinity assignment into irq_request (Mohammad Kabat) [2049450]
- net/mlx5: Introduce control IRQ request API (Mohammad Kabat) [2049450]
- net/mlx5: mlx5e_hv_vhca_stats_create return type to void (Mohammad Kabat) [2049450]
- RDMA/mlx5: Print wc status on CQE error and dump needed (Mohammad Kabat) [2049450]
- net: fixup build after bpf header changes (Mohammad Kabat) [2049450]
- net/mlx5: CT: Set flow source hint from provided tuple device (Mohammad Kabat) [2049450]
- net/mlx5: Set SMFS as a default steering mode if device supports it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Ignore modify TTL if device doesn't support it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Improve steering for empty or RX/TX-only matchers (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for matching on geneve_tlv_option_0_exist field (Mohammad Kabat) [2049450]
- net/mlx5: DR, Support matching on tunnel headers 0 and 1 (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add misc5 to match_param structs (Mohammad Kabat) [2049450]
- net/mlx5: Add misc5 flow table match parameters (Mohammad Kabat) [2049450]
- net/mlx5: DR, Warn on failure to destroy objects due to refcount (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for UPLINK destination type (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for dumping steering info (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add missing reserved fields to dr_match_param (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add check for flex parser ID value (Mohammad Kabat) [2049450]
- net/mlx5: DR, Rename list field in matcher struct to list_node (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Remove unused struct member in matcher (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix lower case macro prefix "mlx5_" to "MLX5_" (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix error flow in creating matcher (Mohammad Kabat) [2049450]
- net/mlx5e: Use auxiliary_device driver data helpers (Mohammad Kabat) [2049450]
- net/mlx5e: Take packet_merge params directly from the RX res struct (Mohammad Kabat) [2049450]
- net/mlx5e: Allocate per-channel stats dynamically at first usage (Mohammad Kabat) [2049450]
- net/mlx5e: Use dynamic per-channel allocations in stats (Mohammad Kabat) [2049450]
- net/mlx5e: Allow profile-specific limitation on max num of channels (Mohammad Kabat) [2049450]
- net/mlx5e: Save memory by using dynamic allocation in netdev priv (Mohammad Kabat) [2049450]
- net/mlx5e: Add profile indications for PTP and QOS HTB features (Mohammad Kabat) [2049450]
- net/mlx5e: Use bitmap field for profile features (Mohammad Kabat) [2049450]
- net/mlx5: Remove the repeated declaration (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure max_macs generic param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Introduce log_max_current_uc_list_wr_supported bit (Mohammad Kabat) [2049450]
- net/mlx5e: Move goto action checks into tc_action goto post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Move vlan action chunk into tc action vlan post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Add post_parse() op to tc action infrastructure (Mohammad Kabat) [2049450]
- net/mlx5e: Move sample attr allocation to tc_action sample parse op (Mohammad Kabat) [2049450]
- net/mlx5e: TC action parsing loop (Mohammad Kabat) [2049450]
- net/mlx5e: Add redirect ingress to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add sample and ptype to tc_action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add ct to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mirred/redirect to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mpls push/pop to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add vlan push/pop/mangle to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add pedit to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add csum to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tunnel encap/decap to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add goto to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tc action infrastructure (Mohammad Kabat) [2049450]
- RDMA/mlx5: Use memset_after() to zero struct mlx5_ib_mr (Mohammad Kabat) [2049450]
- RDMA/mlx5: Add support to multiple priorities for FDB rules (Mohammad Kabat) [2049450]
- net/mlx5: Create more priorities for FDB bypass namespace (Mohammad Kabat) [2049450]
- net/mlx5: Refactor mlx5_get_flow_namespace (Mohammad Kabat) [2049450]
- net/mlx5: Separate FDB namespace (Mohammad Kabat) [2049450]
- net/mlx5: Use irq_set_affinity_and_hint() (Mohammad Kabat) [2049450]
- net/mlx5: Dynamically resize flow counters query buffer (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Set flow attr ip_version earlier (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Move common flow_action checks into function (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from vlan push/pop funcs (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from validate_goto_chain() (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant action stack var (Mohammad Kabat) [2049450]
- net/mlx5e: Hide function mlx5e_num_channels_changed (Mohammad Kabat) [2049450]
- net/mlx5e: SHAMPO, clean MLX5E_MAX_KLM_PER_WQE macro (Mohammad Kabat) [2049450]
- net/mlx5: Print more info on pci error handlers (Mohammad Kabat) [2049450]
- net/mlx5: SF, silence an uninitialized variable warning (Mohammad Kabat) [2049450]
- net/mlx5: Fix error return code in esw_qos_create() (Mohammad Kabat) [2049450]
- mlx5: fix mlx5i_grp_sw_update_stats() stack usage (Mohammad Kabat) [2049450]
- mlx5: fix psample_sample_packet link error (Mohammad Kabat) [2049450]
- net/mlx5: E-switch, Create QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Enable vport QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, move offloads mode callbacks to offloads file (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Reuse mlx5_eswitch_set_vport_mac (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Remove vport enabled check (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Specify out ifindex when looking up decap route (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move comment about mod header flag to correct place (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move kfree() calls after destroying all resources (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Destroy nic flow counter if exists (Mohammad Kabat) [2049450 2049844]
- net/mlx5: TC, using swap() instead of tmp variable (Mohammad Kabat) [2049450 2049844]
- net/mlx5: CT: Allow static allocation of mod headers (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Refactor mod header management API (Mohammad Kabat) [2049450 2049844]
- net/mlx5: Avoid printing health buffer when firmware is unavailable (Mohammad Kabat) [2049450 2049833 2049844]
- net/mlx5: Fix format-security build warnings (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Support ethtool cq mode (Mohammad Kabat) [2049450 2049844]
- Revert "RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow" (Mohammad Kabat) [2049449]
- net/mlx5e: Fix wrong features assignment in case of error (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Fix memory leak with rules with internal port (Mohammad Kabat) [2049449]
- net/mlx5: Fix some error handling paths in 'mlx5e_tc_add_fdb_flow()' (Mohammad Kabat) [2049449]
- net/mlx5e: Delete forward rule for ct or sample action (Mohammad Kabat) [2049449]
- net/mlx5e: Fix ICOSQ recovery flow for XSK (Mohammad Kabat) [2049449]
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery flow (Mohammad Kabat) [2049449]
- net/mlx5e: Fix skb memory leak when TC classifier action offloads are disabled (Mohammad Kabat) [2049449]
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq (Mohammad Kabat) [2049449]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049449]
- net/mlx5: Fix SF health recovery flow (Mohammad Kabat) [2049449]
- net/mlx5: Fix error print in case of IRQ request failed (Mohammad Kabat) [2049449]
- net/mlx5: Use first online CPU instead of hard coded CPU (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix querying eswitch manager vport for ECPF (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix NULL vs IS_ERR checking in dr_domain_init_resources (Mohammad Kabat) [2049449]
- net/mlx5e: SHAMPO, Fix constant expression result (Mohammad Kabat) [2049449]
- net/mlx5: Fix access to a non-supported register (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix too early queueing of log timestamp work (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix use after free in mlx5_health_wait_pci_up (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use indirect table only if all destinations support it (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Check group pointer before reading bw_share value (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, fix single FDB creation on BlueField (Mohammad Kabat) [2049449]
- net/mlx5: E-switch, Respect BW share of the new group (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Fix recreation of VF LAG (Mohammad Kabat) [2049449]
- net/mlx5: Move MODIFY_RQT command to ignore list in internal error state (Mohammad Kabat) [2049449]
- net/mlx5e: Sync TIR params updates against concurrent create/modify (Mohammad Kabat) [2049449]
- net/mlx5e: Fix missing IPsec statistics on uplink representor (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting in case of encapsulation (Mohammad Kabat) [2049449]
- RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, return error if encap isn't supported (Mohammad Kabat) [2049449]
- net/mlx5: Lag, update tracker when state change event received (Mohammad Kabat) [2049449]
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts (Mohammad Kabat) [2049449]
- net/mlx5: Fix flow counters SF bulk query len (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, rebuild lag only when needed (Mohammad Kabat) [2049449]
- net/mlx5: Update error handler for UCTX and UMEM (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: DR, Handle eswitch manager and uplink vports separately (Mohammad Kabat) [2049449]
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove() (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Fix resetting of encap mode when entering switchdev (Mohammad Kabat) [2049449]
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib events (Mohammad Kabat) [2049449]
- net/mlx5e: kTLS, Fix crash in RX resync flow (Mohammad Kabat) [2049449]
- net/mlx5: Lag, fix a potential Oops with mlx5_lag_create_definer() (Mohammad Kabat) [2049449]
- net/mlx5: Support internal port as decap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Term table handling of internal port rules (Mohammad Kabat) [2049449]
- net/mlx5e: Add indirect tc offload of ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Offload internal port as encap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Offload tc rules that redirect to ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Accept action skbedit in the tc actions list (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Add ovs internal port mapping to metadata support (Mohammad Kabat) [2049449]
- net/mlx5e: Use generic name for the forwarding dev pointer (Mohammad Kabat) [2049449]
- net/mlx5e: Refactor rx handler of represetor device (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: Allow skipping counter refresh on creation (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Refactor checksum code in tx data path (Mohammad Kabat) [2049449]
- net/mlx5: CT: Remove warning of ignore_flow_level support for VFs (Mohammad Kabat) [2049449]
- net/mlx5: Add esw assignment back in mlx5e_tc_sample_unoffload() (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Make mlx5_lag_is_multipath() be static inline (Mohammad Kabat) [2049449]
- net/mlx5e: Prevent HW-GRO and CQE-COMPRESS features operate together (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW-GRO offload (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW_GRO statistics (Mohammad Kabat) [2049449]
- net/mlx5e: HW_GRO cqe handler implementation (Mohammad Kabat) [2049449]
- net/mlx5e: Add data path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add handle SHAMPO cqe support (Mohammad Kabat) [2049449]
- net/mlx5e: Add control path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add support to klm_umr_wqe (Mohammad Kabat) [2049449]
- net/mlx5e: Rename TIR lro functions to TIR packet merge functions (Mohammad Kabat) [2049449]
- net/mlx5: Add SHAMPO caps, HW bits and enumerations (Mohammad Kabat) [2049449]
- net/mlx5e: Rename lro_timeout to packet_merge_timeout (Mohammad Kabat) [2049449]
- net/mlx5: remove the recent devlink params (Mohammad Kabat) [2049449]
- net/mlx5: SF_DEV Add SF device trace points (Mohammad Kabat) [2049449]
- net/mlx5: SF, Add SF trace points (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure max_macs param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, support replacing existing FDB entry (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract code to lookup and del/notify entry (Mohammad Kabat) [2049449]
- net/mlx5: Add periodic update of host time to firmware (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Print health buffer by log level (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Extend health buffer dump (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Reduce flow counters bulk query buffer size for SFs (Mohammad Kabat) [2049449]
- net/mlx5: Fix unused function warning of mlx5i_flow_type_mask (Mohammad Kabat) [2049449]
- net/mlx5: Remove unnecessary checks for slow path flag (Mohammad Kabat) [2049449]
- net/mlx5e: don't write directly to netdev->dev_addr (Mohammad Kabat) [2049449]
- RDMA/mlx5: Use dev_addr_mod() (Mohammad Kabat) [2049449]
- RDMA/mlx5: fix build error with INFINIBAND_USER_ACCESS=n (Mohammad Kabat) [2049449]
- RDMA/mlx5: Attach ndescs to mlx5_ib_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Move struct mlx5_core_mkey to mlx5_ib (Mohammad Kabat) [2049449]
- RDMA/mlx5: Replace struct mlx5_core_mkey by u32 key (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove pd from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove size from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove iova from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Increase supported number of forward destinations to 32 (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use dynamic alloc for dest array (Mohammad Kabat) [2049449]
- net/mlx5: Lag, use steering to select the affinity port in LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create/destroy/modify port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create TTC tables for LAG port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create definers for LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set match mask according to the traffic type bitmap (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set LAG traffic type mapping (Mohammad Kabat) [2049449]
- net/mlx5: Lag, move lag files into directory (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new uplink destination type (Mohammad Kabat) [2049449]
- net/mlx5: Add support to create match definer (Mohammad Kabat) [2049449]
- net/mlx5: Introduce port selection namespace (Mohammad Kabat) [2049449]
- net/mlx5: Support partial TTC rules (Mohammad Kabat) [2049449]
- mlx5: prevent 64bit divide (Mohammad Kabat) [2049449]
- net/mlx5: Use system_image_guid to determine bonding (Mohammad Kabat) [2049449]
- net/mlx5: Use native_port_num as 1st option of device index (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new device index wrapper (Mohammad Kabat) [2049449]
- net/mlx5: Check return status first when querying system_image_guid (Mohammad Kabat) [2049449]
- net/mlx5: DR, Prefer kcalloc over open coded arithmetic (Mohammad Kabat) [2049449]
- net/mlx5e: Add extack msgs related to TC for better debug (Mohammad Kabat) [2049449]
- net/mlx5: CT: Fix missing cleanup of ct nat table on init failure (Mohammad Kabat) [2049449]
- net/mlx5: Disable roce at HCA level (Mohammad Kabat) [2049449]
- net/mlx5i: Enable Rx steering for IPoIB via ethtool (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, provide flow source hints (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from DTOR (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from init segment (Mohammad Kabat) [2049449]
- net/mlx5: Add layout to support default timeouts register (Mohammad Kabat) [2049449]
- ethernet: constify references to netdev->dev_addr in drivers (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add optional counter support in get_hw_stats callback (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add modify_op_stat() support (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add steering support in optional flow counters (Mohammad Kabat) [2049449]
- RDMA/mlx5: Support optional counters in hw_stats initialization (Mohammad Kabat) [2049449]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049449]
- net/mlx5: Add priorities for counters in RDMA namespaces (Mohammad Kabat) [2049449]
- net/mlx5: Add ifc bits to support optional counters (Mohammad Kabat) [2049449]
- net/mlx5: Enable single IRQ for PCI Function (Mohammad Kabat) [2049449]
- net/mlx5: Shift control IRQ to the last index (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, pop VLAN on egress table miss (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, mark reg_c1 when pushing VLAN (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract VLAN pop code to dedicated functions (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, refactor eswitch instance usage (Mohammad Kabat) [2049449]
- net/mlx5e: Support accept action (Mohammad Kabat) [2049449]
- net/mlx5e: Specify out ifindex when looking up encap route (Mohammad Kabat) [2049449]
- net/mlx5e: Reserve a value from TC tunnel options mapping (Mohammad Kabat) [2049449]
- net/mlx5e: Move parse fdb check into actions_match_supported_fdb() (Mohammad Kabat) [2049449]
- net/mlx5e: Split actions_match_supported() into a sub function (Mohammad Kabat) [2049449]
- net/mlx5e: Move mod hdr allocation to a single place (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Refactor sample offload error flow (Mohammad Kabat) [2049449]
- net/mlx5e: Add TX max rate support for MQPRIO channel mode (Mohammad Kabat) [2049449]
- net/mlx5e: Specify SQ stats struct for mlx5e_open_txqsq() (Mohammad Kabat) [2049449]
- RDMA/mlx5: Avoid taking MRs from larger MR cache pools when a pool is empty (Mohammad Kabat) [2049449]
- IB/mlx5: Flow through a more detailed return code from get_prefetchable_mr() (Mohammad Kabat) [2049449]
- net/mlx5e: Use array_size() helper (Mohammad Kabat) [2049449]
- net/mlx5: Use struct_size() helper in kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Use kvcalloc() instead of kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Tolerate failures in debug features while driver load (Mohammad Kabat) [2049449]
- net/mlx5: Warn for devlink reload when there are VFs alive (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing string for action type SAMPLER (Mohammad Kabat) [2049449]
- net/mlx5: DR, init_next_match only if needed (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix typo 'offeset' to 'offset' (Mohammad Kabat) [2049449]
- net/mlx5: DR, Increase supported num of actions to 32 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add support for SF vports (Mohammad Kabat) [2049449]
- net/mlx5: DR, Support csum recalculation flow table on SFs (Mohammad Kabat) [2049449]
- net/mlx5: DR, Align error messages for failure to obtain vport caps (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing query for vport 0 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Replace local WIRE_PORT macro with the existing MLX5_VPORT_UPLINK (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix vport number data type to u16 (Mohammad Kabat) [2049449]
- IB/mlx5: Enable UAR to have DevX UID (Mohammad Kabat) [2049449]
- net/mlx5: Add uid field to UAR allocation structures (Mohammad Kabat) [2049449]
- net/mlx5e: check return value of rhashtable_init (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for ingress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for egress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: loopback test is not supported in switchdev mode (Mohammad Kabat) [2049449]
- net/mlx5e: Use NL_SET_ERR_MSG_MOD() for errors parsing tunnel attributes (Mohammad Kabat) [2049449]
- net/mlx5e: Use tc sample stubs instead of ifdefs in source file (Mohammad Kabat) [2049449]
- net/mlx5e: Remove redundant priv arg from parse_pedit_to_reformat() (Mohammad Kabat) [2049449]
- net/mlx5e: Check action fwd/drop flag exists also for nic flows (Mohammad Kabat) [2049449]
- net/mlx5e: Set action fwd flag when parsing tc action goto (Mohammad Kabat) [2049449]
- net/mlx5e: Remove incorrect addition of action fwd flag (Mohammad Kabat) [2049449]
- net/mlx5e: Use correct return type (Mohammad Kabat) [2049449]
- net/mlx5e: Add error flow for ethtool -X command (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix code indentation in dr_ste_v1 (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum flags (Mohammad Kabat) [2049447]
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields (Mohammad Kabat) [2049447]
- net/mlx5e: Fix vlan data lost during suspend flow (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Return correct error code on group creation failure (Mohammad Kabat) [2049447]
- net/mlx5: Lag, change multipath and bonding to be mutually exclusive (Mohammad Kabat) [2049447]
- RDMA/mlx5: Initialize the ODP xarray when creating an ODP MR (Mohammad Kabat) [2049447]
- net/mlx5e: Fix division by 0 in mlx5e_select_queue for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp (Mohammad Kabat) [2049447]
- net/mlx5e: Switchdev representors are not vlan challenged (Mohammad Kabat) [2049447]
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path (Mohammad Kabat) [2049447]
- net/mlx5e: Allow only complete TXQs partition in MQPRIO channel mode (Mohammad Kabat) [2049447]
- net/mlx5: Fix cleanup of bridge delayed work (Mohammad Kabat) [2049447]
- RDMA/mlx5: Set user priority for DCT (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude setting of TX-port-TS and MQPRIO in channel mode (Mohammad Kabat) [2049447]
- net/mlx5e: Fix the presented RQ index in PTP stats (Mohammad Kabat) [2049447]
- net/mlx5: Fix setting number of EQs of SFs (Mohammad Kabat) [2049447]
- net/mlx5: Fix length of irq_index in chars (Mohammad Kabat) [2049447]
- net/mlx5: Avoid generating event after PPS out in Real time mode (Mohammad Kabat) [2049447]
- net/mlx5: Force round second at 1PPS out start time (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Fix double allocation of acl flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Improve MQPRIO resiliency (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Keep the value for maximum number of channels in-sync (Mohammad Kabat) [2049447]
- net/mlx5e: IPSEC RX, enable checksum complete (Mohammad Kabat) [2049447]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fix xlt_chunk_align calculation (Mohammad Kabat) [2049447]
- net/mlx5e: Fix condition when retrieving PTP-rqn (Mohammad Kabat) [2049447]
- net/mlx5e: Fix mutual exclusion between CQE compression and HW TS (Mohammad Kabat) [2049447]
- net/mlx5: Fix potential sleeping in atomic context (Mohammad Kabat) [2049447]
- net/mlx5: FWTrace, cancel work on alloc pd error flow (Mohammad Kabat) [2049447]
- net/mlx5: Lag, don't update lag if lag isn't supported (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, fix uninitialized variable usage (Mohammad Kabat) [2049447]
- RDMA/mlx5: Relax DCS QP creation checks (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add support for update FTE (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve rule tracking memory consumption (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove rehash ctrl struct from dr_htbl (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove HW specific STE type from nic domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Merge DR_STE_SIZE enums (Mohammad Kabat) [2049447]
- net/mlx5: DR, Skip source port matching on FDB RX domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add ignore_flow_level support for multi-dest flow tables (Mohammad Kabat) [2049447]
- net/mlx5: DR, Use FW API when updating FW-owned flow table (Mohammad Kabat) [2049447]
- net/mlx5: DR, replace uintN_t with kernel-style types (Mohammad Kabat) [2049447]
- net/mlx5: DR, Support IPv6 matching on flow label for STEv0 (Mohammad Kabat) [2049447]
- net/mlx5: DR, Reduce print level for FT chaining level check (Mohammad Kabat) [2049447]
- net/mlx5: DR, Warn and ignore SW steering rule insertion on QP err (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve error flow in actions_build_ste_arr (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable QP retransmission (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable VLAN pop on TX and VLAN push on RX (Mohammad Kabat) [2049447]
- net/mlx5: DR, Split modify VLAN state to separate pop/push states (Mohammad Kabat) [2049447]
- net/mlx5: DR, Added support for REMOVE_HEADER packet reformat (Mohammad Kabat) [2049447]
- net/mlx5: DR, fix a potential use-after-free bug (Mohammad Kabat) [2049447]
- net/mlx5e: Use correct eswitch for stack devices with lag (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir fwd group (Mohammad Kabat) [2049447]
- net/mlx5e: Fix possible use-after-free deleting fdb rule (Mohammad Kabat) [2049447]
- net/mlx5: Remove all auxiliary devices at the unregister event (Mohammad Kabat) [2049447]
- net/mlx5: Lag, fix multipath lag activation (Mohammad Kabat) [2049447]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Add QoS tracepoints (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow to add vports to rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow setting share/max tx rate limits of rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Introduce rate limiting groups API (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Enable devlink port tx_{share|max} rate control (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Move QoS related code to dedicated file (Mohammad Kabat) [2049447 2049610]
- net/mlx5e: TC, Support sample offload action for tunneled traffic (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Restore tunnel info for sample offload (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Remove CONFIG_NET_TC_SKB_EXT dependency when restoring tunnel (Mohammad Kabat) [2049447]
- net/mlx5e: Refactor ct to use post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: Introduce post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: CT, Use xarray to manage fte ids (Mohammad Kabat) [2049447]
- net/mlx5e: Move sample attribute to flow attribute (Mohammad Kabat) [2049447]
- net/mlx5e: Move esw/sample to en/tc/sample (Mohammad Kabat) [2049447]
- net/mlx5e: Remove mlx5e dependency from E-Switch sample (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, support LAG (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, allow merged eswitch connectivity (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, extract FDB delete notification to function (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, identify port by vport_num+esw_owner_vhca_id pair (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, obtain core device from eswitch instead of priv (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, release bridge in same function where it is taken (Mohammad Kabat) [2049447]
- net/mlx5e: Support MQPRIO channel mode (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Handle errors of netdev_set_num_tc() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Maintain MQPRIO mode parameter (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Abstract MQPRIO params (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support flow classification into RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support multiple RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Dynamically allocate TIRs in RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RSS to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce abstraction of RSS context (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce TIR create/destroy API in rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Do not try enable RSS when resetting indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Make use of netdev_warn() (Mohammad Kabat) [2049447]
- net/mlx5: Fix variable type to match 64bit (Mohammad Kabat) [2049447]
- net/mlx5: Initialize numa node for all core devices (Mohammad Kabat) [2049447]
- net/mlx5: Allocate individual capability (Mohammad Kabat) [2049447]
- net/mlx5: Reorganize current and maximal capabilities to be per-type (Mohammad Kabat) [2049447]
- net/mlx5: SF, use recent sysfs api (Mohammad Kabat) [2049447]
- net/mlx5: Refcount mlx5_irq with integer (Mohammad Kabat) [2049447]
- net/mlx5: Change SF missing dedicated MSI-X err message to dbg (Mohammad Kabat) [2049447]
- net/mlx5: Align mlx5_irq structure (Mohammad Kabat) [2049447]
- net/mlx5: Delete impossible dev->state checks (Mohammad Kabat) [2049447]
- net/mlx5: Fix inner TTC table creation (Mohammad Kabat) [2049447]
- net/mlx5: Fix typo in comments (Mohammad Kabat) [2049447]
- net/mlx5: Lag, Create shared FDB when in switchdev mode (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, add logic to enable shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Lag, move lag destruction to a workqueue (Mohammad Kabat) [2049447]
- net/mlx5: Lag, properly lock eswitch if needed (Mohammad Kabat) [2049447]
- net/mlx5: Add send to vport rules on paired device (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Add event callback for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Use shared mappings for restoring from metadata (Mohammad Kabat) [2049447]
- net/mlx5e: Add an option to create a shared mapping (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, set flow source for send to uplink rule (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add shared FDB support (Mohammad Kabat) [2049447]
- {net, RDMA}/mlx5: Extend send to vport rules (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fill port info based on the relevant eswitch (Mohammad Kabat) [2049447]
- net/mlx5: Lag, add initial logic for shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Return mdev from eswitch (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete not-available udata check (Mohammad Kabat) [2049447]
- RDMA/mlx5: Drop in-driver verbs object creations (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete device resource mutex that didn't protect anything (Mohammad Kabat) [2049447]
- RDMA/mlx5: Cancel pkey work before destroying device resources (Mohammad Kabat) [2049447]
- net/mlx5: Fix missing return value in mlx5_devlink_eswitch_inline_mode_set() (Mohammad Kabat) [2049447]
- net/mlx5e: Return -EOPNOTSUPP if more relevant when parsing tc actions (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant assignment of counter to null (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant parse_attr arg (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant cap check for flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant filter_dev arg from parse_tc_fdb_actions() (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant tc act includes (Mohammad Kabat) [2049447]
- net/mlx5: Embed mlx5_ttc_table (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Move TTC logic to fs_ttc (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Decouple TTC logic from mlx5e (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename some related TTC args and functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename traffic type enums (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Allocate the array of channels according to the real max_nch (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Hide all implementation details of mlx5e_rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce mlx5e_channels API to get RQNs (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use a new initializer to build uniform indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use the new TIR API for kTLS (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move management of indir traffic types to rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert TIR to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Create struct mlx5e_rss_params_hash (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mdev from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove lro_param from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mlx5e_priv usage from mlx5e_build_*tir_ctx*() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use mlx5e_rqt_get_rqtn to access RQT hardware id (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Take RQT out of TIR and group RX resources (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move RX resources to a separate struct (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move mlx5e_build_rss_params() call to init_rx (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RQT to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Check if inner FT is supported outside of create/destroy functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Take TIR destruction out of the TIR list lock (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Block LRO if firmware asks for tunneled LRO (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (Mohammad Kabat) [2049447 2049891]
- IB/mlx5: Rename is_apu_thread_cq function to is_apu_cq (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add DCS offload support (Mohammad Kabat) [2049447]
- RDMA/mlx5: Separate DCI QP creation logic (Mohammad Kabat) [2049447]
- net/mlx5: Add DCS caps & fields support (Mohammad Kabat) [2049447]

* Mon Aug 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-151.el9]
- crypto: ccp - Fix device IRQ counting by using platform_irq_count() (Al Stone) [2071840]
- amd-xgbe: Use platform_irq_count() (Al Stone) [2071840]
- MAINTAINERS: adjust file entry for of_net.c after (Al Stone) [2071840]
- rhel: CONFIG_OPEN_DICE is not set (Al Stone) [2071840]
- of/irq: fix typo in comment (Al Stone) [2071840]
- powerpc/powermac: constify device_node in of_irq_parse_oldworld() (Al Stone) [2071840]
- of/fdt: Ignore disabled memory nodes (Al Stone) [2071840]
- of: overlay: do not free changeset when of_overlay_apply returns error (Al Stone) [2071840]
- of: overlay: unittest: add tests for overlay notifiers (Al Stone) [2071840]
- of: overlay: add entry to of_overlay_action_name[] (Al Stone) [2071840]
- of: overlay: rework overlay apply and remove kfree()s (Al Stone) [2071840]
- of: overlay: rename variables to be consistent (Al Stone) [2071840]
- of: overlay: do not break notify on NOTIFY_{OK|STOP} (Al Stone) [2071840]
- mtd: phram: Allow probing via reserved-memory (Al Stone) [2071840]
- of: Create platform devices for OF framebuffers (Al Stone) [2071840]
- of: of_property_read_string return -ENODATA when !length (Al Stone) [2071840]
- of/irq: Use interrupts-extended to find parent (Al Stone) [2071840]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2071840]
- of/platform: Drop static setup of IRQ resource from DT core (Al Stone) [2071840]
- cma: factor out minimum alignment requirement (Al Stone) [2071840]
- Revert "of: base: Introduce of_alias_get_alias_list() to check alias IDs" (Al Stone) [2071840]
- of: unittest: print pass messages at PR_INFO level (Al Stone) [2071840]
- misc: open-dice: Add driver to expose DICE data to userspace (Al Stone) [2071840]
- of: unittest: update text of expected warnings (Al Stone) [2071840]
- of: Check 'of_node_reused' flag on of_match_device() (Al Stone) [2071840]
- of: property: define of_property_read_u{8,16,32,64}_array() unconditionally (Al Stone) [2071840]
- of: base: make small of_parse_phandle() variants static inline (Al Stone) [2071840]
- mm: kmemleak: alloc gray object for reserved region with direct map (Al Stone) [2071840]
- of: unittest: remove unneeded semicolon (Al Stone) [2071840]
- of: base: Improve argument length mismatch error (Al Stone) [2071840]
- of: base: Fix phandle argument length mismatch error message (Al Stone) [2071840]
- of: unittest: re-implement overlay tracking (Al Stone) [2071840]
- of: unittest: change references to obsolete overlay id (Al Stone) [2071840]
- of: Move simple-framebuffer device handling from simplefb to of (Al Stone) [2071840]
- of: unittest: 64 bit dma address test requires arch support (Al Stone) [2071840]
- of: unittest: fix warning on PowerPC frame size warning (Al Stone) [2071840]
- of/irq: Add a quirk for controllers with their own definition of interrupt-map (Al Stone) [2071840]
- of: base: Skip CPU nodes with "fail"/"fail-..." status (Al Stone) [2071840]
- of: property: fw_devlink: Fixup behaviour when 'node_not_dev' is set (Al Stone) [2071840]
- of/irq: Don't ignore interrupt-controller when interrupt-map failed (Al Stone) [2071840]
- of: Support using 'mask' in making device bus id (Al Stone) [2071840]
- memblock: use memblock_free for freeing virtual pointers (Al Stone) [2071840]
- memblock: rename memblock_free to memblock_phys_free (Al Stone) [2071840]
- xen/x86: free_p2m_page: use memblock_free_ptr() to free a virtual pointer (Al Stone) [2071840]
- memblock: drop memblock_free_early_nid() and memblock_free_early() (Al Stone) [2071840]
- of/irq: Allow matching of an interrupt-map local to an interrupt controller (Al Stone) [2071840]
- of: unittest: document intentional interrupt-map provider build warning (Al Stone) [2071840]
- of: unittest: fix EXPECT text for gpio hog errors (Al Stone) [2071840]
- of/unittest: Disable new dtc node_name_vs_property_name and interrupt_map warnings (Al Stone) [2071840]
- x86/of: Kill unused early_init_dt_scan_chosen_arch() (Al Stone) [2071840]
- of/unittest: Add of_node_put() before return (Al Stone) [2071840]
- of: make of_node_check_flag() device_node parameter const (Al Stone) [2071840]
- of: kobj: make of_node_is_(initialized|attached) parameters const (Al Stone) [2071840]
- of: Add of_get_cpu_hwid() to read hardware ID from CPU nodes (Al Stone) [2071840]
- ARM: 9119/1: amba: Properly handle device probe without IRQ domain (Al Stone) [2071840]
- ARM: 9120/1: Revert "amba: make use of -1 IRQs warn" (Al Stone) [2071840]
- soc: qcom: smem: Support reserved-memory description (Al Stone) [2071840]
- net: of: fix stub of_net helpers for CONFIG_NET=n (Al Stone) [2071840]
- of: net: add a helper for loading netdev->dev_addr (Al Stone) [2071840]
- of: net: move of_net under net/ (Al Stone) [2071840]
- of: remove duplicate declarations of __of_*_sysfs() functions (Al Stone) [2071840]
- fbdev: simplefb: fix Kconfig dependencies (Al Stone) [2071840]
- of, numa: Fetch empty NUMA node ID from distance map (Al Stone) [2071840]
- of: restricted dma: Fix condition for rmem init (Al Stone) [2071840]
- of: property: Disable fw_devlink DT support for X86 (Al Stone) [2071840]
- of: Don't allow __of_attached_node_sysfs() without CONFIG_SYSFS (Al Stone) [2071840]
- of: restricted dma: Don't fail device probe on rmem init failure (Al Stone) [2071840]
- of: Move of_dma_set_restricted_buffer() into device.c (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "leds" and "backlight" (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "resets" and "pwms" (Al Stone) [2071840]
- gpiolib: constify passed device_node pointer (Al Stone) [2071840]
- of: unify of_count_phandle_with_args() arguments with !CONFIG_OF (Al Stone) [2071840]
- of: Return success from of_dma_set_restricted_buffer() when !OF_ADDRESS (Al Stone) [2071840]
- of: kexec: Remove FDT_PROP_* definitions (Al Stone) [2071840]
- of: base: remove unnecessary for loop (Al Stone) [2071840]
- of: Add plumbing for restricted DMA pool (Al Stone) [2071840]
- of: Add stub for of_add_property() (Al Stone) [2071840]

* Fri Aug 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-150.el9]
- CI: Switch to c9s container image on quay.io (Michael Hofmann)
- KVM: x86: nSVM: implement nested LBR virtualization (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: correctly virtualize LBR msrs when L2 is running (Emanuele Giuseppe Esposito) [2079722]
- kvm: x86: SVM: use vmcb* instead of svm->vmcb where it makes sense (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: implement nested VMLOAD/VMSAVE (Emanuele Giuseppe Esposito) [2079722]
- nfs: only issue commit in DIO codepath if we have uncommitted data (Jeffrey Layton) [2028370]
- nfs: always check dreq->error after a commit (Jeffrey Layton) [2028370]
- nfs: add new nfs_direct_req tracepoint events (Jeffrey Layton) [2028370]
- nfsd: eliminate the NFSD_FILE_BREAK_* flags (Jeffrey Layton) [2107360]
- NFSD: Clean up the show_nf_flags() macro (Jeffrey Layton) [2107360]
- vmxnet3: do not reschedule napi for rx processing (Kamal Heib) [2115062]
- Revert "ACPI: APEI: explicit init of HEST and GHES in apci_init()" (Mark Langsdorf) [2115261]
- Revert "ACPI: APEI: rename ghes_init() with an "acpi_" prefix" (Mark Langsdorf) [2115261]
- KVM: selftests: Disable rseq_test for all architectures (Gavin Shan) [2116654]
- mm: Fix CVE-2022-2590 by reverting "mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte" (David Hildenbrand) [2116301] {CVE-2022-2590}
- scsi: megaraid: Clear READ queue map's nr_queues (Tomas Henzl) [2103830]
- SUNRPC release the transport of a relocated task with an assigned transport (Scott Mayhew) [2069732]
- SUNRPC don't resend a task on an offlined transport (Scott Mayhew) [2069732]
- Documentation: Describe net.ipv4.tcp_reflect_tos. (Guillaume Nault) [2070198]
- drm/amd/display: Fix new dmub notification enabling in DM (Mika Penttilä) [2107633]
- sfc: fix kernel panic when creating VF (Íñigo Huguet) [2104536]
- netdevsim: don't overwrite read only ethtool parms (Petr Oros) [2112332]
- netdevsim: fix uninit value in nsim_drv_configure_vfs() (Petr Oros) [2112332]
- netdevsim: rename 'driver' entry points (Petr Oros) [2112332]
- netdevsim: move max vf config to dev (Petr Oros) [2112332]
- netdevsim: move details of vf config to dev (Petr Oros) [2112332]
- netdevsim: move vfconfig to nsim_dev (Petr Oros) [2112332]
- netdevsim: take rtnl_lock when assigning num_vfs (Petr Oros) [2112332]
- netdevsim: remove max_vfs dentry (Petr Oros) [2112332]
- netdevsim: make array res_ids static const, makes object smaller (Petr Oros) [2112332]
- CI: Add automotive checks (Veronika Kabatova)
- fs: dlm: fix build with CONFIG_IPV6 disabled (Alexander Aring) [2026474]
- fs: dlm: don't call kernel_getpeername() in error_report() (Alexander Aring) [2026474]
- fs: dlm: use sk->sk_socket instead of con->sock (Alexander Aring) [2026474]

* Fri Aug 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-149.el9]
- netfilter: h323: merge nat hook pointers into one (Florian Westphal) [2111270]
- netfilter: nf_conntrack: use rcu accessors where needed (Florian Westphal) [2111270]
- netfilter: nf_conntrack: add missing __rcu annotations (Florian Westphal) [2111270]
- netfilter: conntrack: use correct format characters (Florian Westphal) [2111270]
- netfilter: conntrack: use fallthrough to cleanup (Florian Westphal) [2111270]
- netfilter: ctnetlink: fix up for "netfilter: conntrack: remove unconfirmed list" (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read typo in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: nfnetlink: fix warn in nfnetlink_unbind (Florian Westphal) [2111270]
- netfilter: conntrack: remove pr_debug callsites from tcp tracker (Florian Westphal) [2111270]
- netfilter: prefer extension check to pointer check (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_conntrack_events autodetect mode (Florian Westphal) [2111270]
- netfilter: conntrack: un-inline nf_ct_ecache_ext_add (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_ct_iter_data object for nf_ct_iterate_cleanup*() (Florian Westphal) [2111270]
- netfilter: nfnetlink: allow to detect if ctnetlink listeners exist (Florian Westphal) [2111270]
- netfilter: conntrack: avoid unconditional local_bh_disable (Florian Westphal) [2111270]
- netfilter: conntrack: remove unconfirmed list (Florian Westphal) [2111270]
- netfilter: conntrack: remove __nf_ct_unconfirmed_destroy (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: extensions: introduce extension genid count (Florian Westphal) [2111270]
- netfilter: remove nf_ct_unconfirmed_destroy helper (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: conntrack: remove the percpu dying list (Florian Westphal) [2111270]
- netfilter: conntrack: include ecache dying list in dumps (Florian Westphal) [2111270]
- netfilter: ecache: use dedicated list for event redelivery (Florian Westphal) [2111270]
- netfilter: conntrack: split inner loop of list dumping to own function (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove useless type conversion to bool (Florian Westphal) [2111270]
- netfilter: ecache: move to separate structure (Florian Westphal) [2111270]
- netfilter: ctnetlink: use dump structure instead of raw args (Florian Westphal) [2111270]
- netfilter: cttimeout: use option structure (Florian Westphal) [2111270]
- netfilter: ecache: don't use nf_conn spinlock (Florian Westphal) [2111270]
- netfilter: ecache: remove nf_exp_event_notifier structure (Florian Westphal) [2111270]
- netfilter: ecache: prepare for event notifier merge (Florian Westphal) [2111270]
- netfilter: ecache: add common helper for nf_conntrack_eventmask_report (Florian Westphal) [2111270]
- netfilter: ecache: remove another indent level (Florian Westphal) [2111270]
- netfilter: ecache: remove one indent level (Florian Westphal) [2111270]
- netfilter: conntrack: pptp: use single option structure (Florian Westphal) [2111270]
- netfilter: conntrack: don't refresh sctp entries in closed state (Florian Westphal) [2111270]
- netfilter: conntrack: revisit gc autotuning (Florian Westphal) [2111270]
- netfilter: nf_conntrack_netbios_ns: fix helper module alias (Florian Westphal) [2111270]
- netfilter: conntrack: Remove useless assignment statements (Florian Westphal) [2111270]
- netfilter: conntrack: Use memset_startat() to zero struct nf_conn (Florian Westphal) [2111270]
- netfilter: ctnetlink: missing counters and timestamp in nfnetlink_{log,queue} (Florian Westphal) [2111270]
- netfilter: ctnetlink: allow to filter dump by status bits (Florian Westphal) [2111270]
- netfilter: ctnetlink: add and use a helper for mark parsing (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove expired entries first (Florian Westphal) [2111270]
- net: align static siphash keys (Florian Westphal) [2111270]

* Thu Aug 18 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-148.el9]
- lockdown: also lock down previous kgdb use (Lenny Szubowicz) [2104750] {CVE-2022-21499}
- perf build: Stop using __weak bpf_object__next_map() to handle older libbpf versions (Michael Petlan) [2102240]
- perf build: Stop using __weak bpf_object__next_program() to handle older libbpf versions (Michael Petlan) [2102240]
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error injection (Nilesh Javali) [2106623]
- vhost-vdpa: call vhost_vdpa_cleanup during the release (Eugenio Pérez) [1939367]
- vdpasim: Off by one in vdpasim_set_group_asid() (Eugenio Pérez) [1939367]
- vdpasim: allow to enable a vq repeatedly (Eugenio Pérez) [1939367]
- vdpasim: control virtqueue support (Eugenio Pérez) [1939367]
- vdpa_sim: filter destination mac address (Eugenio Pérez) [1939367]
- vdpa_sim: factor out buffer completion logic (Eugenio Pérez) [1939367]
- vdpa_sim: advertise VIRTIO_NET_F_MTU (Eugenio Pérez) [1939367]
- vhost-vdpa: support ASID based IOTLB API (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to set group ASID (Eugenio Pérez) [1939367]
- vhost-vdpa: uAPI to get virtqueue group id (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of address spaces (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce asid based IOTLB (Eugenio Pérez) [1939367]
- vhost: support ASID in IOTLB API (Eugenio Pérez) [1939367]
- vhost_iotlb: split out IOTLB initialization (Eugenio Pérez) [1939367]
- vdpa: introduce config operations for associating ASID to a virtqueue group (Eugenio Pérez) [1939367]
- vdpa: multiple address spaces support (Eugenio Pérez) [1939367]
- vdpa: introduce virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: switch to use vhost-vdpa specific IOTLB (Eugenio Pérez) [1939367]
- vhost-vdpa: passing iotlb to IOMMU mapping helpers (Eugenio Pérez) [1939367]
- virtio-vdpa: don't set callback if virtio doesn't need it (Eugenio Pérez) [1939367]
- vhost: move the backend feature bits to vhost_types.h (Eugenio Pérez) [1939367]
- fs: dlm: change posix lock sigint handling (Alexander Aring) [2088518]
- fs: dlm: use dlm_plock_info for do_unlock_close (Alexander Aring) [2088518]
- fs: dlm: change plock interrupted message to debug again (Alexander Aring) [2088518]
- fs: dlm: add pid to debug log (Alexander Aring) [2088518]
- fs: dlm: plock use list_first_entry (Alexander Aring) [2088518]
- dlm: replace usage of found with dedicated list iterator variable (Alexander Aring) [2088518]
- dlm: move global to static inits (Alexander Aring) [2088518]
- dlm: remove unnecessary INIT_LIST_HEAD() (Alexander Aring) [2088518]
- dlm: improve plock logging if interrupted (Alexander Aring) [2088518]
- dlm: rearrange async condition return (Alexander Aring) [2088518]
- dlm: cleanup plock_op vs plock_xop (Alexander Aring) [2088518]
- dlm: replace sanity checks with WARN_ON (Alexander Aring) [2088518]
- fs: dlm: make dlm_callback_resume quite (Alexander Aring) [2009423]

* Wed Aug 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-147.el9]
- RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default (Jaroslav Kysela) [2065578]
- ASoC: SOF: make ctx_store and ctx_restore as optional (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Prevent double freeing of ipc_control_data via load_bytes (Jaroslav Kysela) [2065578]
- ASoC: imx-hdmi: Fix refcount leak in imx_hdmi_probe (Jaroslav Kysela) [2065578]
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe (Jaroslav Kysela) [2065578]
- ASoC: amd: Add support for enabling DMIC on acp6x via _DSD (Jaroslav Kysela) [2065578]
- soundwire: intel: prevent pm_runtime resume prior to system suspend (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (fw v1.0.0) (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirks for MacroSilicon MS2100/MS2106 devices (Jaroslav Kysela) [2065578]
- ASoC: cs47l15: Fix event generation for low power mux control (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Add ASP TX3/4 source to register patch (Jaroslav Kysela) [2065578]
- ASoC: dapm: Initialise kcontrol data for mux/demux controls (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: fix kernel NULL pointer dereference when IO error (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Correct some control names (Jaroslav Kysela) [2065578]
- ASoC: wm5110: Fix DRE control (Jaroslav Kysela) [2065578]
- ASoC: wm_adsp: Fix event for preloader (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_wm5102: Fix GPIO related probe-ordering problem (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Clarify the cl_dsp_init() flow (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Make sure that the fw load sequence is followed (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-dsp: Expose hda_dsp_core_power_up() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: initialize workqueues in probe (Jaroslav Kysela) [2065578]
- ASoC: rt7*-sdw: harden jack_detect_handler (Jaroslav Kysela) [2065578]
- ASoC: rt711: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_sdw: handle errors on card registration (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca-sdw: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Realtek/Maxim SoundWire codecs: disable pm_runtime on remove (Jaroslav Kysela) [2065578]
- ASoC: ops: Fix off by one in range control validation (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the ssp rate discovery in skl_get_ssp_clks() (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc221 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3 model (Jaroslav Kysela) [2065578]
- ALSA: hda - Add fixup for Dell Latitidue E5430 (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda: Fix compressed stream position tracking (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Move and correct size checks in sof_ipc3_control_load_bytes() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: resume bus/codec in .set_jack_detect (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: rt711: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ALSA: cs46xx: Fix missing snd_card_free() call at probe error (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo L140PU (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workarounds for Behringer UMC 204/404 HD (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Apply fixup for Lenovo Yoga Duet 7 properly (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - ALC897 headset MIC no sound (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: hda: Fix discovery of i915 graphics PCI device (Jaroslav Kysela) [2065578]
- ALSA: hda/via: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: memalloc: Drop x86-specific hack for WC allocations (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add HW8326 support (Jaroslav Kysela) [2065578]
- ALSA: hda: MTL: add HD Audio PCI ID and HDMI codec vendor ID (Jaroslav Kysela) [2065578]
- ASoC: es8328: Fix event generation for deemphasis control (Jaroslav Kysela) [2065578]
- ASoC: cs42l51: Correct minimum value for SX volume control (Jaroslav Kysela) [2065578]
- ASoC: cs42l56: Correct typo in minimum level for SX volume controls (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Correct TLV for Bypass Volume (Jaroslav Kysela) [2065578]
- ASoC: cs53l30: Correct number of volume levels on SX controls (Jaroslav Kysela) [2065578]
- ASoC: cs35l36: Update digital volume TLV (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Fix TLV scales for mixer controls (Jaroslav Kysela) [2065578]
- ASoC: Intel: cirrus-common: fix incorrect channel mapping (Jaroslav Kysela) [2065578]
- ASoC: qcom: lpass-platform: Update VMA access permissions in mmap callback (Jaroslav Kysela) [2065578]
- ASoC: nau8822: Add operation for internal PLL off and on (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for HP Dev One (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo Yoga DuetITL 2021 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant - Fix loopback issue with CX20632 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP (Jaroslav Kysela) [2065578]
- ASoC: rt5640: Do not manipulate pin "Platform Clock" if the "Platform Clock" is not in the DAPM (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: Fixed Build error (Jaroslav Kysela) [2065578]
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up" control (Jaroslav Kysela) [2065578]
- ASoC: max98090: Move check for invalid values before casting in max98090_put_enab_tlv() (Jaroslav Kysela) [2065578]
- ALSA: pcm: Check for null pointer of pointer substream before dereferencing it (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Set scontrol->priv to NULL after freeing it (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Fix an out-of-bounds access in otp_packed_element_t (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Move generic implicit fb quirk entries into quirks.c (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk bits for enabling/disabling generic implicit fb (Jaroslav Kysela) [2065578]
- ASoC: amd: Add driver data to acp6x machine driver (Jaroslav Kysela) [2065578]
- ASoC: rt1015p: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: max98357a: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: rt5645: Fix errorenous cleanup order (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: add missing platform_device_unregister in acp_pci_rn_probe (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_ssp_amp: fix no DMIC BE Link on Chromebooks (Jaroslav Kysela) [2065578]
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Correct get_control_data for non bytes payload (Jaroslav Kysela) [2065578]
- ASoC: dapm: Don't fold register value changes into notifications (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_rt5640: Add quirk for the HP Pro Tablet 408 (Jaroslav Kysela) [2065578]
- ALSA: jack: Access input_dev under mutex (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Cancel pending work at closing a MIDI substream (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15 9520 laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add new type for ALC245 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Optimize TEAC clock quirk (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Configure sync endpoints before data (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workaround for clock setup on TEAC devices (Jaroslav Kysela) [2065578]
- ALSA: ctxfi: Add SB046x PCI ID (Jaroslav Kysela) [2065578]
- ALSA: update kernel configuration for 9.1 (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Define PLL clock inputs (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: New codec bindings (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the binding include file for the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: rename q6afe.h to q6dsp-lpass-ports.h (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: Document Microchip's PDMC (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- ALSA: spi: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ALSA: sparc: no need to initialise statics to 0 (Jaroslav Kysela) [2065572]
- sound: core: Remove redundant variable and return the last statement (Jaroslav Kysela) [2065572]
- sound: core: remove initialise static variables to 0 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add cs35l51/53 IDs (Jaroslav Kysela) [2065572]
- ALSA: ppc: beep: fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix 'dmasound_setup' defined but not used (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix build when drivers are mixed =y/=m (Jaroslav Kysela) [2065572]
- ALSA: mips: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: update AlderLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: intel-dspconfig: add ES8336 support for CNL (Jaroslav Kysela) [2065572]
- ALSA: intel-dsp-config: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - avoid hung task timeout in i915 wait (Jaroslav Kysela) [2065572]
- ALSA: hda/i915: Fix one too many pci_dev_put() (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - skip acomp init if no matching display (Jaroslav Kysela) [2065572]
- ASoC: SOF: tokens: add token for Mediatek AFE (Jaroslav Kysela) [2065572]
- ALSA: uapi: use C90 comment style instead of C99 style (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Add new IPC command to free trace DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: fix 32 signed bit overflow (Jaroslav Kysela) [2065572]
- ASoC: SOF: add _D3_PERSISTENT flag to fw_ready message (Jaroslav Kysela) [2065572]
- ipc: debug: Add shared memory heap to memory scan (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: add information on I2S/TDM link mask (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: fix kernel-doc descriptor (Jaroslav Kysela) [2065572]
- ALSA: pcm: comment about relation between msbits hw parameter and [S|U]32 formats (Jaroslav Kysela) [2065572]
- ALSA: hda: Add helper macros for DSP capable devices (Jaroslav Kysela) [2065572]
- ALSA: cleanup double word in comment (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add support for hibernate memory retention mode (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct DSP power down (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Add Android board ACPI table handling (Jaroslav Kysela) [2065572]
- mfd: arizona: Add missing statics to the of_match_tables (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Split Windows ACPI init code into its own function (Jaroslav Kysela) [2065572]
- Documentation: sound: fix typo in control-names.rst (Jaroslav Kysela) [2065572]
- ALSA: wavefront: Proper check of get_user() error (Jaroslav Kysela) [2065572]
- ALSA: sc6000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: galaxy: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4236: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix memory leaks at memory allocator error paths (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix erroneous memory allocation (Jaroslav Kysela) [2065572]
- ALSA: sound/isa/gus: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ALSA: fireworks: fix wrong return count shorter than expected by 4 bytes (Jaroslav Kysela) [2065572]
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred transaction (Jaroslav Kysela) [2065572]
- soundwire: qcom: use __maybe_unused for swrm_runtime_resume() (Jaroslav Kysela) [2065572]
- soundwire: qcom: constify static struct qcom_swrm_data global variables (Jaroslav Kysela) [2065572]
- soundwire: qcom: add in-band wake up interrupt support (Jaroslav Kysela) [2065572]
- soundwire: qcom: add runtime pm support (Jaroslav Kysela) [2065572]
- soundwire: stream: make enable/disable/deprepare idempotent (Jaroslav Kysela) [2065572]
- soundwire: stream: sdw_stream_add_ functions can be called multiple times (Jaroslav Kysela) [2065572]
- soundwire: stream: introduce sdw_slave_rt_find() helper (Jaroslav Kysela) [2065572]
- soundwire: stream: separate alloc and config within sdw_stream_add_xxx() (Jaroslav Kysela) [2065572]
- soundwire: stream: move list addition to sdw_slave_alloc_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: rename and move master/slave_rt_free routines (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_stream_ functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_slave_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: move sdw_alloc_slave_rt() before 'master' helpers (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_master_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify sdw_alloc_master_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_port and sdw_master/slave_port functions (Jaroslav Kysela) [2065572]
- soundwire: stream: add 'slave' prefix for port range checks (Jaroslav Kysela) [2065572]
- soundwire: stream: split alloc and config in two functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split port allocation and configuration loops (Jaroslav Kysela) [2065572]
- soundwire: stream: add alloc/config/free helpers for ports (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify check on port range (Jaroslav Kysela) [2065572]
- soundwire: stream: add slave runtime to list earlier (Jaroslav Kysela) [2065572]
- soundwire: stream: remove unused parameter in sdw_stream_add_slave (Jaroslav Kysela) [2065572]
- soundwire: intel: fix wrong register name in intel_shim_wake (Jaroslav Kysela) [2065572]
- soundwire: bus: add dev_warn() messages to track UNATTACHED devices (Jaroslav Kysela) [2065572]
- soundwire: intel: remove PDM support (Jaroslav Kysela) [2065572]
- soundwire: intel: remove unnecessary init (Jaroslav Kysela) [2065572]
- soundwire: intel: improve suspend flows (Jaroslav Kysela) [2065572]
- soundwire: intel: Use auxiliary_device driver data helpers (Jaroslav Kysela) [2065572]
- soundwire: qcom: remove redundant version number read (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: x86: Use standard mmap helper for Intel HDMI LPE audio (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Check for error num after setting mask (Jaroslav Kysela) [2065572]
- ALSA: intel-nhlt: add helper to detect SSP link mask (Jaroslav Kysela) [2065572]
- ALSA: hda: Add snd_hdac_ext_bus_link_at() helper (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: reorder the config table (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: add JasperLake support (Jaroslav Kysela) [2065572]
- ALSA: HDA: hdac_ext_stream: use consistent prefixes for variables (Jaroslav Kysela) [2065572]
- ALSA: hda: Simplify DMIC-in-NHLT check (Jaroslav Kysela) [2065572]
- ALSA: hda: Fill gaps in NHLT endpoint-interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: Fix NULL pointer exception in sof_pci_probe callback (Jaroslav Kysela) [2065572]
- ASoC: ops: Validate input values in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: set prepare_slave_config (Jaroslav Kysela) [2065572]
- ASoC: max98090: Generate notifications on changes for custom control (Jaroslav Kysela) [2065572]
- ASoC: max98090: Reject invalid values in custom control put() (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Correct the reg 0x09 size to one byte (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-card: Fix nonatomic links (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-tdm-interface: Fix formatters in trigger" (Jaroslav Kysela) [2065572]
- ASoC: soc-ops: fix error handling (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for G12A tohdmi mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI CODEC mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI ACODEC mux (Jaroslav Kysela) [2065572]
- ASoC: da7219: Fix change notifications for tone generator frequency (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: fix sysclk shutdown (Jaroslav Kysela) [2065572]
- ASoC: wm8958: Fix change notifications for DSP controls (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix an error handling path in (rx|tx|va)_macro_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: Add a quirk for Huawei Matebook D15 (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add a quirk for headset at mic1 port (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: support a separate gpio to control headphone (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: simplify speaker gpio naming (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Disable the regulator when probing fails (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: correct device endpoints for max98373 (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec is in use (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak in sof_control_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: cleanup dailinks on widget unload (Jaroslav Kysela) [2065572]
- ASoC: rt711/5682: check if bus is active before deferred jack detection (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp on SSP2 (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: fix 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Avoid NULL deref in asoc_simple_set_tdm() (Jaroslav Kysela) [2065572]
- ASoC: meson: aiu: fix duplicate debugfs directory error (Jaroslav Kysela) [2065572]
- ASoC: soc-core: add debugfs_prefix member to snd_soc_component_driver (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Check failure for devm_snd_soc_register_component (Jaroslav Kysela) [2065572]
- ASoC: rk817: Use devm_clk_get() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Update handling of test key registers (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct handling of some registers in the cache (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for boost configuration (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for setting channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for errata patches (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move power initializations to reg_sequence (Jaroslav Kysela) [2065572]
- ASoC: rt5682: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-dapm: fix two incorrect uses of list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak of scontrol->name (Jaroslav Kysela) [2065572]
- codecs: rt5682s: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: topology: Correct error handling in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Remove system clock tree configuration for at91sam9g20ek (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix build error without SND_SOC_SOF_PCI_DEV (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s_tdm: Fixup config for SND_SOC_DAIFMT_DSP_A/B (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Fix jack_event() always return 0 (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: print the correct property name (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a new dai_get_clk topology IPC op (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add ops for setting up and tearing down pipelines (Jaroslav Kysela) [2065572]
- ASoC: SOF: expose sof_route_setup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add dai_link_fixup PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add trigger PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Define hw_params PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 PCM hw_free op (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: expose the sof_pcm_setup_connected_widgets() function (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC-specific PCM ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_ext control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_get/put control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add enum_get/put control ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add switch get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add volume_get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add IPC3 topology control ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC ops for kcontrol IO (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_suspend/resume IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_widget_setup/free IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: set up scheduler widget before all other widgets in the pipeline (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Add new registers included on i.MX8ULP (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Use kmemdup() to replace kzalloc + memcpy (Jaroslav Kysela) [2065572]
- ASoC: ak4642: Use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix misplaced lpass_macro_pds_exit call (Jaroslav Kysela) [2065572]
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call (Jaroslav Kysela) [2065572]
- ASoC: amd: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: Add missing of_node_put() in wcd934x_codec_parse_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Fix error handling in mt8195_mt6359_rt1019_rt5682_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: rt1308-sdw: get calibration params after power on (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Fix error handling in pm8916_wcd_analog_spmi_probe (Jaroslav Kysela) [2065572]
- ASoC: ti: Fix spelling mistake "cant" -> "can't" (Jaroslav Kysela) [2065572]
- ASoC: mediatek: Fix error handling in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in sam9x5_wm8731_driver_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Fix PM usage reference of rockchip_i2s_tdm_resume (Jaroslav Kysela) [2065572]
- ASoC: samsung: i2s: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove snd_sof_complete_pipeline() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make widget binding IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make control parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make DAI widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make route setup IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make effect widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make siggen widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make asrc widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make src widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mux/demux widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mixer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make pga widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make buffer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make scheduler widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add helper function for processing tuple arrays (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Introduce IPC ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce struct snd_sof_dai_link (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix `-Wpointer-bool-conversion` warning (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: Change the check for codec_dai (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over HDA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over CLDMA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Implement CLDMA transfer (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: General code loading flow (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Dynamic firmware resources management (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Declare module configuration types (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Firmware resources management utilities (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add basefw runtime-parameter requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add ROM requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add power management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add module management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add pipeline management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add code loading requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Inter process communication (Jaroslav Kysela) [2065572]
- ASoC: Intel: Introduce AVS driver (Jaroslav Kysela) [2065572]
- ASoC: Export DAI register and widget ctor and dctor functions (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare() in msm8916_wcd_digital_probe (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Don't reset clock of active DAI (Jaroslav Kysela) [2065572]
- ASoC: mchp-spdifrx: fix typo (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add reset controller (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove ipc_pcm_params() ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ipc: Add hda_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: stream-ipc: Add sof_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Mark snd_sof_dsp_ops.ipc_pcm_params() callback optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce optional callback to configure stream data offset (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Remove sof_pcm_dsp_params() wrapper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make pcm_hw_params snd_sof_dsp_ops callback IPC neutral (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Remove stale snd_sof_ipc_stream_pcm_params() declaration (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add topology overwrite for Taniks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Use proper DMA direction for the trace data buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: compress: fix null check after dereference (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: enable DMI L1 for playback streams (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix spelling mistake "microchopnes" -> "microphones" (Jaroslav Kysela) [2065572]
- ASoC: imx-es8328: Fix error return code in imx_es8328_probe() (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Disable TX clock when stop (Jaroslav Kysela) [2065572]
- ASoC: qcom: fix Kconfig for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc-msg-injector: Use devm_kzalloc() for the rx_buffer (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: keep all TxClk sources by txclk array (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix randconfig issue (Jaroslav Kysela) [2065572]
- ASoC: fsl_rpmsg: Remove SET_SYSTEM_SLEEP_PM_OPS callback (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcht_es8316: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add cfg-dmics component for UCM support (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: extend machine driver to support ES8326 codec (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add support for JD inverted quirk (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: log all quirks (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: use NHLT information to set dmic and SSP (Jaroslav Kysela) [2065572]
- ASoC: Intel: Revert "ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021" (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: make gpio optional (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add ESSX8336 support on Cannon Lake machines (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: quirk topology filename dynamically (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: report SSP link mask to machine driver (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: retrieve DMIC number for I2S boards (Jaroslav Kysela) [2065572]
- ASoC: SOF: move definition of snd_sof_ipc to header file (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_dai IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_tokens() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_token_sets() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify signature for token parsing functions (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a tuples array to struct snd_sof_widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: make sof_route_load() IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_widget IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: add PDMC driver (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: do not use a NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: rk817: Fix missing clk_disable_unprepare() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: Fix error handling in mt8192_mt6359_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add missing of_node_put() in imx8m_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s: Fix missing clk_disable_unprepare() in rockchip_i2s_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: acp3x: Fix signedness bug in acp3x (Jaroslav Kysela) [2065572]
- ASoC: amd: acp5x-pcm-dma: Fix signedness bug (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: support wb bt audio (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in snd_proto_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: change comp_dai to a pointer in struct snd_sof_dai (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: expose some get_token ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify the get_token op for string tokens (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Drop the size parameter from struct sof_topology_token (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code in sof_link_afe_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: removed unused function (Jaroslav Kysela) [2065572]
- ASoC: SOF: set swidget's core for scheduler widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: simplify snd_sof_device_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: remove snd_sof_pipeline_find() (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix signedness bug in acp5x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Expand firmware loading search options (Jaroslav Kysela) [2065572]
- ASoC: fsi: Add check for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: qcom: select correct WCD938X config for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Remove unnecessary param (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Stabilize the combo jack detection (Jaroslav Kysela) [2065572]
- ASoC: wm8350: Handle error for wm8350_register_irq (Jaroslav Kysela) [2065572]
- ASoC: atmel: Add missing of_node_put() in at91sam9g20ek_audio_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp3x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp_pdm_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Fix signedness bug in renoir_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: fix quirks for 2022 HP Spectre x360 13" (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add GPIOLIB dependency where missed (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: remove explicit dependency on GPIOLIB when DMIC is used" (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: implement 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: use DIV_ROUND_CLOSEST() to calculate divider (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Use better variable names (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: store full version instead of major/minor (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify register poking in fsl_sai_set_bclk (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify irq return value (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Drop unnecessary defines (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add Awinic AW8738 audio amplifier driver (Jaroslav Kysela) [2065572]
- ASoC: audio_graph_card2: Add support for variable slot widths (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Increase ACP_HW_SEM_RETRY_COUNT value (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Move group register configuration to acp-loader (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Use semaphore register to synchronize ipc's irq (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Flush cache after ATU_BASE_ADDR_GRP register update (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Do not set ipc_pcm_params ops as it is optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: acp-pcm: Take buffer information directly from runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: pci-tgl: add RPL-S support (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix DSP mbox start command and global enable order (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix max number of TX channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix GPIO2 configuration (Jaroslav Kysela) [2065572]
- ASoC: bt-sco: fix bt-sco-pcm-wb dai widget don't connect to the endpoint (Jaroslav Kysela) [2065572]
- ASoC: hdac_hda: Avoid unexpected match when pcm_name is "Analog" (Jaroslav Kysela) [2065572]
- ASoC: qcom: Fix error code in lpass_platform_copy() (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: prevent the potentially use of null pointer (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: set period_bytes_min based on maxburst (Jaroslav Kysela) [2065572]
- ASoC: dwc-i2s: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: amd: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: mxs-saif: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add entries in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_ssp_amp: rename driver and support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: cirrus-common: support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt1308: move rt1308 code to common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: create sof-realtek-common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: add RT1308 I2S machine driver and HDMI-in capture via I2S support. (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix spelling in comments (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: remove sof_fw_filename (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa881x: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: es7241: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98927: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98926: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98925: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9867: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9850: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98390: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98371: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98095: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98088: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda134x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: ml26124: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm512x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm186x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm1681: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3060: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: fsl: Drop unused argument from imx_pcm_dma_init() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-i2s: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ASoC: mc13783: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: isabelle: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: fix uninitialized symbol warning in machine driver (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: remove warnings and errors pointed out by checkpatch pl (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update DAI link name (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix for pm resume callback sequence (Jaroslav Kysela) [2065572]
- ASoC: es8328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: inno_rk3036: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es8316: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: wl1273: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es7134: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: twl4030: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1380: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: si476x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: tscs454: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: tscs42xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: lm49453: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add power domains support in digital macro codecs (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd-mbhc: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add simple clk stop support (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-platform: Update warning print to control excess logging (Jaroslav Kysela) [2065572]
- ASoC: acp: check the return value of devm_kzalloc() in acp_legacy_dai_links_create() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: check the return value of devm_kzalloc() in rt5663_parse_dp() (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Drop duplicate sof_compressed_ops declaration (Jaroslav Kysela) [2065572]
- ASoC: amd: Use platform_get_irq_byname() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: Make use of the helper component_compare/release_of (Jaroslav Kysela) [2065572]
- ASoC: SOF: Declare sof_compress_ops in sof-priv.h (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-sc7280: Add platform driver for lpass audio (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add lpass CPU driver for codec dma control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add regmap config support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add register definition for codec rddma and wrdma (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add helper function to get dma control and lpaif handle (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass: Add dma fields for codec dma lpass interface (Jaroslav Kysela) [2065572]
- ASoC: qcom: Move lpass_pcm_data structure to lpass header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix NULL ptr dereference when ENOMEM (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add DMIC machine driver ops (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-legacy: Add legacy card support for new machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Change card name for Guybrush Machine (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Fix buggy return value (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Add compress_ops for SOF platform component driver (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Fix the wrong jack type detected (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi-byt: Add new WM5102 ACPI HID (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update acp init and deinit sequence (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: apply sample bits pcm constraint (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update platform clock control sequence (Jaroslav Kysela) [2065572]
- ASoC: nau8821: enable no_capture_mute flag (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: refactor i2s master mode clock sequence code (Jaroslav Kysela) [2065572]
- ASoC: sc7280: Really depends on SOUNDWIRE (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix return value of wcd934x_rx_hph_mode_put (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wc938x: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing compander for aux (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: enable apll tuner (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Add topology overwrite for Felwinter (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2065572]
- ASoC: intel: skylake: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: unregister clients and machine drivers in .shutdown (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Update CTIA/OMTP switch control (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix the duplicated control name (Jaroslav Kysela) [2065572]
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min (Jaroslav Kysela) [2065572]
- ASoC: soc-core: skip zero num_dai component in searching dai name (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: make const array rates static (Jaroslav Kysela) [2065572]
- ASoC: SOF: Makefile: Fix randconfig sof-client build when SND_SOC_SOF=y (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Add switch control for selecting CTIA/OMTP Headset (Jaroslav Kysela) [2065572]
- ASoC: codec: wm8960: complete discharge on BIAS OFF->STANDBY (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Delete empty remove() function (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: remove numeric PCM3168A_NUM_SUPPLIES (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor format handling (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor hw_params routine (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: cleanup unintuitive mask usage (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Mark snd_compress_ops static (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_wm5102: use GFP_KERNEL (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add trace caps to speaker protection FW (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Make compressed buffers optional (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Add IIR filter configuration (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Correct control read size when parsing compressed buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic probe support to SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC message injector into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC flood test into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-client: Add support for clients not managed by pm framework (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC SOF client support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Split up utils.c into sof-utils and iomem-utils (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Read and pass the whole message to handlers for IPC events (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum sof_dsp_power_states to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop unused DSP power states: D3_HOT and D3_COLD (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Remove the sysclk and sysclk_src checking (Jaroslav Kysela) [2065572]
- ASoC: qcom: SC7280: Add machine driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add macro for lpass DAI id's max limit (Jaroslav Kysela) [2065572]
- ASoC: qcom: Actually clear DMA interrupt register for HDMI (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hdac_ext_stream: consistent prefixes for variables/members (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Enable combine mode soft (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Add compress ops implementation (Jaroslav Kysela) [2065572]
- ASoC: SOF: dma-trace: Pass pointer to params_ext struct in trace_init() (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: hda-trace: Pass the dma buffer pointer to hda_dsp_trace_prepare (Jaroslav Kysela) [2065572]
- ASoC: simple-mux: Depend on gpiolib rather than selecting it (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: max9759: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: simple-amplifier: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: dmic: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt5682: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5668: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: tas2770: Insert post reset delay (Jaroslav Kysela) [2065572]
- ASoC: madera: Add dependencies on MFD (Jaroslav Kysela) [2065572]
- ASoC: samsung: Explicitly include gpiolib header (Jaroslav Kysela) [2065572]
- ASoC: wm8962: Allow switching between analog and digital inputs (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Add support for the R329/D1 variant (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Update registers for more channels (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Set gpio_spkr_en to None for max speaker amplifer in machine driver (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: max98927: add missing header file (Jaroslav Kysela) [2065572]
- ASoC: ops: Check for negative values before reading them (Jaroslav Kysela) [2065572]
- ASoC: cs42l51: Improve error handling in cs42l51_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Do not allocate buffer for msg_data (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Drop header parameter from sof_ipc_tx_message_unlocked() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: cnl: Use pm_gate->hdr.cmd in cnl_compact_ipc_compress() (Jaroslav Kysela) [2065572]
- ASoC: amd: renoir: Add check for acp configuration flags (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-legacy: Add DMIC dai link support for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add ACP init()/deinit() callback for Renoir. (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic PCI driver module for ACP device (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add PDM controller based dmic dai for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic support for PDM controller on ACP (Jaroslav Kysela) [2065572]
- ASoC: rk3399_gru_sound: Wire up DP jack detection (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Fix deadlock on resume (Jaroslav Kysela) [2065572]
- ASoC: hdmi-codec: Fix OOB memory accesses (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Move debugfs removal out of spinlock (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix DPCM lockdep warning due to nested stream locks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Simplify count adjustment in trace_read (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Remove link assignment limitation (Jaroslav Kysela) [2065572]
- ASoC: tegra: Update AHUB driver for Tegra234 (Jaroslav Kysela) [2065572]
- ASoC: fsl: Add missing error handling in pcm030_fabric_probe (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: q6apm-dai: only stop graphs that are started (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix return value of mixer put function (Jaroslav Kysela) [2065572]
- ASoC: codecs: lpass-rx-macro: fix sidetone register offsets (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix incorrect used of portid (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Remove duplicate macros (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Add rz_ssi_set_substream() helper function (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Use a do-while loop in rz_ssi_pio_recv() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Add new system-clock-fixed flag (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Set sysclk on all components (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: create drvdata structure (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: codecs: Check for error pointer after calling devm_regmap_init_mmio (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add 512FS MCLK clock configuration (Jaroslav Kysela) [2065572]
- ASoC: amd: sof-mach: Add support for RT5682S and RT1019 card (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: separate max_buffer_size assignment (Jaroslav Kysela) [2065572]
- ASoC: samsung: remove unneeded ret variable (Jaroslav Kysela) [2065572]
- ASoC: codecs: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: Rename tlv320aic31xx-micbias.h as tlv320aic31xx.h (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Remove BCLK default value for tlv320aic31xx card (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add optional dt property for setting mclk-id (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for platform without amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add support for systems without i915 audio (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Compare sdw adr directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: match sdw version on link_slaves_found (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make return type of rz_ssi_stream_is_valid() to bool (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop ssi parameter from rz_ssi_stream_init() (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make the data structures available before registering the handlers (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop calling rz_ssi_pio_recv() recursively (Jaroslav Kysela) [2065572]
- ASoC: add support for TAS5805M digital amplifier (Jaroslav Kysela) [2065572]
- ASoC: topology: Optimize soc_tplg_dapm_graph_elems_load behavior (Jaroslav Kysela) [2065572]
- ASoC: topology: Allow TLV control to be either read or write (Jaroslav Kysela) [2065572]
- ASoC: topology: Remove superfluous error prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: add flag to disable IMR restore to sof_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add IMR restore support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add SSP helper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: use inclusive language for SSP clocks (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-mach: Fix Left and Right rt1019 amp devices (Jaroslav Kysela) [2065572]
- ASoC: mediatek: fix unmet dependency on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2065572]
- ASoC: max9759: fix underflow in speaker_gain_control_put() (Jaroslav Kysela) [2065572]
- ASoC: cpcap: Check for NULL pointer after calling of_get_child_by_name (Jaroslav Kysela) [2065572]
- ASoC: simple-card: fix probe failure on platform component (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple of period bytes (Jaroslav Kysela) [2065572]
- ASoC: wcd9335: Keep a RX port value for each SLIM RX mux (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-mach: Change default RT1019 amp dev id (Jaroslav Kysela) [2065572]
- ASoC: topology: Fix typo (Jaroslav Kysela) [2065572]
- ASoC: fsl_asrc: refine the check of available clock divider (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Add support for external GPIO jack-detect (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Support retrieving the codec IRQ from the AMCR0F28 ACPI dev (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add support for boards with an external jack-detect GPIO (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Allow snd_soc_component_set_jack() to override the codec IRQ (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Change jack_work to a delayed_work (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix possible NULL pointer deref on resume (Jaroslav Kysela) [2065572]
- ASoC: imx-card: improve the sound quality for low rate (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Fix mclk calculation issue for akcodec (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Need special setting for ak4497 on i.MX8MQ (Jaroslav Kysela) [2065572]
- ASoC: ak4375: Fix unused function error (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Add a remove() function (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add support for "toggle" preloaders (Jaroslav Kysela) [2065572]
- ASoC: fsl_mqs: fix MODULE_ALIAS (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move cs35l41_otp_unpack to shared code (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add playback support to PCM1_BE dai_link (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Register wclk with its parent_hws instead of parent_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: update control for RT5682 series (Jaroslav Kysela) [2065572]
- ASoC: samsung: idma: Check of ioremap return value (Jaroslav Kysela) [2065572]
- ASoC: mediatek: use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix part number ID error message (Jaroslav Kysela) [2065572]
- ALSA/ASoC: hda: move/rename snd_hdac_ext_stop_streams to hdac_stream.c (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Power on/off the speaker enable gpio pin based on DAPM callback. (Jaroslav Kysela) [2065572]
- ASoC: remove unneeded variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: release device_node after snd_soc_register_card (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: Intel/SOF: use set_stream() instead of set_tdm_slots() for HDAudio (Jaroslav Kysela) [2065572]
- ASoC/SoundWire: dai: expand 'stream' concept beyond SoundWire (Jaroslav Kysela) [2065572]
- ASoC/soundwire: intel: simplify callbacks for params/hw_free (Jaroslav Kysela) [2065572]
- ASOC: SOF: Intel: use snd_soc_dai_get_widget() (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Use separate outputs for HPH_L/HPH_R (Jaroslav Kysela) [2065572]
- ASoC: qcom: common: Parse "pin-switches" and "widgets" from DT (Jaroslav Kysela) [2065572]
- ASoC: core: Add snd_soc_of_parse_pin_switches() from simple-card-utils (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: Fix missing clk_disable_unprepare() on error in adc3xxx_i2c_probe() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add clarifying comments for sof_core_debug and DSP dump flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename snd_sof_get_status() and add kernel log level parameter (Jaroslav Kysela) [2065572]
- ASoC: SOF: dsp_arch_ops: add kernel log level parameter for oops and stack (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Always print DSP Panic message but use different message (Jaroslav Kysela) [2065572]
- ASoc: SOF: core: Update the FW boot state transition diagram (Jaroslav Kysela) [2065572]
- ASoC: SOF: pm: Force DSP off on suspend in BOOT_FAILED state also (Jaroslav Kysela) [2065572]
- ASoC: SOF: Set SOF_FW_BOOT_FAILED in case we have failure during boot (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Only allow sending of an IPC in SOF_FW_BOOT_COMPLETE state (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename 'enum snd_sof_fw_state' to 'enum sof_fw_state' (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum snd_sof_fw_state to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_BOOT_READY_OK (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_CRASHED (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a 'message' parameter to snd_sof_dsp_dbg_dump() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add 'non_recoverable' parameter to snd_sof_dsp_panic() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Use sof_debug_check_flag() instead of sof_core_debug directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Add simple wrapper to check flags in sof_core_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: Avoid re-defining the HDA_FW_BOOT_ATTEMPTS (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Use dev_warn() if the panic offsets differ (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4375: Change invert controls to a stereo switch (Jaroslav Kysela) [2065572]
- ASoC: Add AK4375 support (Jaroslav Kysela) [2065572]
- ASoC: bcm: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: xlnx: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Remove duplicate dependency in Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: fix a use after free bug in open() (Jaroslav Kysela) [2065572]
- ASoC: SOF: AMD: simplify return status handling (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Update sof_tplg_filename for SOF machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Enable SOF audio for Google chrome boards. (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195-mt6359: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: New codec driver (Jaroslav Kysela) [2065572]
- ASoC: sunxi: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: stm: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: samsung: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: qcom: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: mxs: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: meson: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: img: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: generic: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: fsl: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ti: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ateml: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: tlv320aic31xx: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ssm2305: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-mux: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-amplifier: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: sgtl5000: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: pcm3168a: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9860: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9759: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: es7241: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4118: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Check return value of pm_runtime_resume_and_get() (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Streamline locals declaration for PCM-functions (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Reduce size of catpt_component_open() (Jaroslav Kysela) [2065572]
- ASoC: tegra20: i2s: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support system suspend (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Reset hardware (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Use more resource-managed helpers (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Improve driver's code (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support device-tree (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Set FIFO trigger level (Jaroslav Kysela) [2065572]
- ASoC: SOF: Kconfig: Make the SOF_DEVELOPER_SUPPORT depend on SND_SOC_SOF (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Add null pointer check for substream->runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: avoid casting "const" attribute away (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME in platform trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: tegra20-spdif: stop setting slave_id (Jaroslav Kysela) [2065572]
- ASoC: AMD: fix depend/select mistake on SND_AMD_ACP_CONFIG (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: read back control data from DSP (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_type parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: control: Do not handle control notification with component type (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: Drop the `cmd` member from struct snd_sof_control (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Set control_data->cmd alongside scontrol->cmd (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ipc_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Rename send parameter in snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: Handle device_property_read_u32_array error codes (Jaroslav Kysela) [2065572]
- ASoC: SOF: OF: Avoid reverse module dependency (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: Fix an IS_ERR() vs NULL bug (Jaroslav Kysela) [2065572]
- ASoC: qcom: Distinguish headset codec by codec_dai->name (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: fix BE handling of PAUSE_RELEASE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: serialize BE triggers (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix and cleanup DPCM locking (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: align BE 'atomicity' with that of the FE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_ATOMIC for dpcm structure (Jaroslav Kysela) [2065572]
- ASoC: mediatek: assign correct type to argument (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-probes: Constify sof_probe_compr_ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove pm_runtime_put_autosuspend() for SOF OF device (Jaroslav Kysela) [2065572]
- ASoC: qcom: apq8016_sbc: Allow routing audio through QDSP6 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add comment on JasperLake support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-dai: remove unused fields (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: add quirks for HDAudio DMA position information (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda-stream: only enable DPIB if needed (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ctrl: apply symmetry for DPIB (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-stream: limit PROCEN workaround (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: ICL: move ICL-specific ops to icl.c (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- ASoC: amd: Convert to new style DAI format definitions (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: silence uninitialized variable warning (Jaroslav Kysela) [2065572]
- ASoC: AMD: acp-config: fix missing dependency on SND_SOC_ACPI (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Move rt1015 speaker amp to common file (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: add delay time to fix pop sound issue (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add 'static' qualifiers for max98390 routes (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add sof support on mt8195-mt6359-rt1019-rt5682 (Jaroslav Kysela) [2065572]
- ASoC: amd: acp6x-pdm-dma: Constify static snd_soc_dai_ops (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Remove unnecessary conditional (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Get rid of duplicate of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Setup parent device and get rid of unnecessary of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- sound/soc: remove useless bool conversion to bool variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add headset codec rt5682s support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add missing Kconfig option for tlv320aic31xx (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: support reserved memory assignment (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix the wrong state of the JD in the HDA header (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: tegra: Add master volume/mute control support (Jaroslav Kysela) [2065572]
- ASoC: Intel: Skylake: Use NHLT API to search for blob (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add max98390 2/4 speakers support (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: make several arrays static const (Jaroslav Kysela) [2065572]
- ASoC: intel: boards: bytcht*: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: Intel: hda_dsp_common: don't multiline PCM topology warning (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: sunxi: sun4i-spdif: Implement IEC958 control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for ALC5682I-VS codec (Jaroslav Kysela) [2065572]
- ASoC: sun8i-codec: Add AIF, ADC, and DAC volume controls (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: tidyup soc_pcm_pointer()'s delay update method (Jaroslav Kysela) [2065572]
- ASoC: intel: sst-mfld-platform-pcm: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-pcm-dma: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: soc-component: add snd_soc_pcm_component_delay() (Jaroslav Kysela) [2065572]
- ASoC: soc-dai: update snd_soc_dai_delay() to snd_soc_pcm_dai_delay() (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Use %%pR/%%pa to print resources/physical addresses (Jaroslav Kysela) [2065572]
- ASoC: codecs/jz4770: Add missing gain control after DAC/ADC mixer (Jaroslav Kysela) [2065572]
- ASoC: imx-hdmi: add put_device() after of_find_device_by_node() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: send DAI_CONFIG IPC during pause (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: dai: Expand DAI_CONFIG IPC flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: align the hw_free sequence with stop (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: move the check for prepared flag (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a helper for freeing PCM stream (Jaroslav Kysela) [2065572]
- ASoC: SOF: call platform hw_free for paused streams during suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: invoke platform hw_free for STOP/SUSPEND triggers (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: reset stream before coupling host and link DMA's (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Add a helper function for stream reset (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clear stream before freeing the DAI widget (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add SND_SOC_WCD938_SDW to codec list instead (Jaroslav Kysela) [2065572]
- ASoC: uniphier: drop selecting non-existing SND_SOC_UNIPHIER_AIO_DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add missing of_node_put() in platform_parse_resource() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: don't use list_for_each_entry_reverse() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add .ack support for HDaudio platforms (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: add .ack callback support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Support fsl,imx-audio-tlv320aic31xx codec (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Handle BCLK set as PLL input configuration (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add divs for bclk as clk_in (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add support for pll_r coefficient (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Fix typo in BCLK clock name (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-pci-dev: use community key on all Up boards (Jaroslav Kysela) [2065572]
- ASoC: stm32: spdifrx: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: stm32: dfsdm: add pm_runtime support for audio (Jaroslav Kysela) [2065572]
- ASoC: stm32: i2s: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: free DAI widget during stop and suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: add support for dynamic pipelines with multi-core (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: don't use the core op for power up/power down (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove sof_load_pipeline_ipc() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: CNL/ICL/APL: set core_get/core_put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: TGL: set core_get/put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add ops for core_get and core_put (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce num_cores and ref count per core (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: expose get_chip_info() (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement reset callback (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement DSP start (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Add code to manage DSP related clocks (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Remove useless condition check (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 dsp clock support (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add dai driver dsp ops callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add mt8195 device descriptor (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add fw loader and mt8195 dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for Mediatek AFE DAI (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 hardware support (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Fix overrun of unterminated control name string (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clear core reset for cache (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Move lockdep asserts to avoid potential null pointer (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Allow creation of event controls (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add offset to cs_dsp read/write (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clarify some kernel doc comments (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Perform NULL check in cs_dsp_coeff_write/read_ctrl (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add support for rev 2 coefficient files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Print messages from bin files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add pre_run callback (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add version checks on coefficient loading (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add lockdep asserts to interface functions (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: tidy includes in cs_dsp.c and cs_dsp.h (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Remove the wmfw_add_ctl helper function (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add support for SOF firmware authentication (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add trace logger support (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for AMD ACP DAIs (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Remove legacy acpi based machine struct (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir PCI driver interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add machine driver dsp ops for Renoir platform (Jaroslav Kysela) [2065572]
- ASoC: amd: Add module to determine ACP configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add PCM stream callback for Renoir dai's (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add dai driver dsp ops callback for Renoir (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add IPC support for ACP IP block (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add fw loader and renoir dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add helper callbacks for ACP's DMA configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir ACP HW support (Jaroslav Kysela) [2065572]
- ASoC: stm32: sai: increase channels_max limit (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Add support for IPC message injection (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: utils: Add generic function to get the reply for a tx message (Jaroslav Kysela) [2065572]
- ASoC: SOF: i.MX: simplify Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qcom: sdm845: only setup slim ports once (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Add support for special headset (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Unregister machine driver before IPC and debugfs (Jaroslav Kysela) [2065572]
- ASoC: adau1701: Replace legacy gpio interface for gpiod (Jaroslav Kysela) [2065572]
- ASoC: Intel: add sof-nau8825 machine driver (Jaroslav Kysela) [2065572]
- ASoC: codecs: Axe some dead code in 'wcd_mbhc_adc_hs_rem_irq()' (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: add link adr order check (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove get_next_be_id (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove sof_sdw_mic_codec_mockup_init (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove SOF_RT715_DAI_ID_FIX quirk (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: move DMIC link id overwrite to create_sdw_dailink (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: Use a fixed DAI link id for AMP (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: rename be_index/link_id to link_index (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: add SKU for Dell Latitude 9520 (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: return the original error number (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: send DMA_TRACE_FREE IPC during release (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: update ipc_log_header() (Jaroslav Kysela) [2065572]
- ASoC: codecs: tfa989x: Add support for tfa9897 optional rcv-gpios (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Restore Rane SL-1 quirk (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't get sample rate for MCT Trigger 5 USB-to-HDMI (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Clear MIDI port active flag after draining (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for MSI MAG X570S Torpedo MAX. (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Limit max buffer and period sizes per time (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Increase max buffer size (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for implicit fb (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing the constant (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE NT-USB (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Add support for the internal "standalone" switch (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Split scarlett2_config_items[] into 3 sections (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for new Corsair Virtuoso SE (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't abort resume upon errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: revert to IMPLICIT_FB_FIXED_DEV for M-Audio FastTrack Ultra (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: remove redundant assignment to variable c (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Correct quirk for VF0770 (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: initialize variables that could ignore errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: scarlett2: Use struct_size() helper in scarlett2_usb() (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machine (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for TongFang devices with pop noise (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for the Framework Laptop (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Dell Latitude 7520 (Jaroslav Kysela) [2065572]
- ALSA: hda - fix unused Realtek function when PM is not enabled (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Yoga Duet 7 13ITL6 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix mute led issue on thinkpad with cs35l41 s-codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook 845/865 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add HDMI codec VID for Raptorlake-P (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF (Jaroslav Kysela) [2065572]
- ALSA: nm256: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: rme9652: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdspm: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdsp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: oxygen: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lx6464es: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: aw2: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als300: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lola: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: bt87x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sis7019: Fix the missing error handling (Jaroslav Kysela) [2065572]
- ALSA: via82xx: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sonicvibes: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme96: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme32: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: riptide: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: maestro3: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: korg1212: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: intel8x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ice1724: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: fm801: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1968: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1938: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ens137x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: emu10k1x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs5535audio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4281: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: azt3328: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: au88x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: atiixp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als4000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ali5451: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ad1889: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: add quirk for Lenovo Thinkpad X12 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (Jaroslav Kysela) [2065572]
- ALSA: hda: Avoid unsol event during RPM suspending (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020 (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Dolphin HW variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Disable HSBIAS_SENSE_EN for Cyborg (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Support new Warlock MLK Variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Full Scale Volume setting for all variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Re-order quirk table into ascending order (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Warlock to use mono mic configuration (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable headset mic on Lenovo P360 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add mute and micmut LED support for Zbook Fury 17 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup (Jaroslav Kysela) [2065572]
- ALSA: pci: fix reading of swapped values from pcmreg in AC97 codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix LED on Zbook Studio G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Restore aux vol on suspend/resume (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GA402 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add AlderLake-PS variant PCI ID (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (Jaroslav Kysela) [2065572]
- ALSA: lola: add a check for the return of vmalloc() (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: remove redundant assignment to variable bytes (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Make use of the helper component_compare_dev_name (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Update scratch reg. communication (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Hardcode GCAP ISS value on T234 (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Add Tegra234 hda driver support (Jaroslav Kysela) [2065572]
- ALSA: hda: Expose codec cleanup and power-save functions (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose codec register procedures (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose snd_hda_codec_device_init() (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add keep-alive support for ADL-P and DG2 (Jaroslav Kysela) [2065572]
- ALSA: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix deadlock by COEF mutex (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix missing codec probe on Shenker Dock 15 (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix regression on forced probe mask option (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2019 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add PCI and HDMI IDs for Intel Raptor Lake (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Rename register macro names (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix driver index handling at re-binding (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda: Skip codec shutdown in case the codec is not registered (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GU603 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus Xtreme after reboot from Windows (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus Master (newer chipset) (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte X570 ALC1220 quirks (Jaroslav Kysela) [2065572]
- ALSA: hda: realtek: Fix race at concurrent COEF updates (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix signedness of sscanf() arguments (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix UAF of leds class devs at unbinding (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Warlock SKUs to patch_cs8409 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make cs35l41_hda_remove() return void (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Tidyup code (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make use of the helper function dev_err_probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add missing default cases (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Move cs35l41* calls to its own symbol namespace (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add calls to newly added test key function (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Avoid overwriting register patch (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix speakers and micmute on HP 855 G8 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: fix double free on error in probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependencies of CS35L41 on SPI/I2C buses (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Convert tables to shared source code (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix undefined reference to core functions (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix link problem (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: DSP Support (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependency on ASoC cs35l41 codec (Jaroslav Kysela) [2065572]
- ALSA: hda: ALC287: Add Lenovo IdeaPad Slim 9i 14ITL5 speaker quirk (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add CS35L41 support for Thinkpad laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for Legion 7 16ACHg6 laptop (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add support for CS35L41 in HDA systems (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Convert binding to yaml (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Correct description of ts-inv (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add warnings about DETECT_MODE and PLL_START (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Handle system suspend (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Change jack_detect_mutex to a lock of all IRQ handling (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Report full jack status when plug is detected (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant pll_divout member (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Simplify reporting of jack unplug (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to RS_PLUG/RS_UNPLUG masks (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to DETECT_MODE (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add control for audio slow-start switch (Jaroslav Kysela) [2065572]
- ALSA: mixart: Add sanity check for timer notify streams (Jaroslav Kysela) [2065572]
- ALSA: mixart: Reduce size of mixart_timer_notify (Jaroslav Kysela) [2065572]
- ALSA: mtpav: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: virmidi: Remove duplicated code (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Add fallback SG-buffer allocations for x86 (Jaroslav Kysela) [2065572]
- ALSA: core: Add snd_card_free_on_error() helper (Jaroslav Kysela) [2065572]
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data" (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and mmap_lock (Jaroslav Kysela) [2065572]
- ALSA: pcm: Add stream lock during PCM reset ioctl operations (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prealloc proc writes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prepare and hw_params/hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent read/write and buffer changes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent hw_params and hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: oss: Release temporary buffers upon errors (Jaroslav Kysela) [2065572]
- ALSA: oss: Fix PCM OSS buffer allocation overflow (Jaroslav Kysela) [2065572]
- ALSA: core: Fix typo in 'PCM Timer Interface' help (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: fix typo (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: use kzalloc (Jaroslav Kysela) [2065572]
- ALSA: memalloc: invalidate SG pages before sync (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Fix dma_need_sync() checks (Jaroslav Kysela) [2065572]
- ALSA: core: Simplify snd_power_ref_and_wait() with the standard macro (Jaroslav Kysela) [2065572]
- ALSA: seq: virmidi: Add a drain operation (Jaroslav Kysela) [2065572]
- ASoC: dai_dma: remove slave_id field (Jaroslav Kysela) [2065572]
- ALSA: seq: Set upper limit of processed events (Jaroslav Kysela) [2065572]
- ALSA: oss: remove useless NULL check before kfree (Jaroslav Kysela) [2065572]
- ALSA: pcm: introduce INFO_NO_REWINDS flag (Jaroslav Kysela) [2065572]
- ALSA: pcm: unconditionally check if appl_ptr is in 0..boundary range (Jaroslav Kysela) [2065572]

* Tue Aug 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-146.el9]
- cpufreq: fix memory leak in sun50i_cpufreq_nvmem_probe (Mark Langsdorf) [2072976]
- cpufreq: powernow-k8: Re-order the init checks (Mark Langsdorf) [2072976]
- cpufreq: amd-pstate: Add more tracepoint for AMD P-State module (Mark Langsdorf) [2072976]
- cpufreq: CPPC: Fix performance/frequency conversion (Mark Langsdorf) [2072976]
- cpufreq: unify show() and store() naming and use __ATTR_XX (Mark Langsdorf) [2072976]
- cpufreq: longhaul: Replace acpi_bus_get_device() (Mark Langsdorf) [2072976]
- cpufreq: Move to_gov_attr_set() to cpufreq.h (Mark Langsdorf) [2072976]
- cpufreq: use default_groups in kobj_type (Mark Langsdorf) [2072976]
- cpufreq: Fix initialization of min and max frequency QoS requests (Mark Langsdorf) [2072976]
- cpufreq: Fix a comment in cpufreq_policy_free (Mark Langsdorf) [2072976]
- cpufreq: Fix get_cpu_device() failure in add_cpu_dev_symlink() (Mark Langsdorf) [2072976]
- cpufreq: Use CPUFREQ_RELATION_E in DVFS governors (Mark Langsdorf) [2072976]
- cpufreq: Introducing CPUFREQ_RELATION_E (Mark Langsdorf) [2072976]
- cpufreq: Add an interface to mark inefficient frequencies (Mark Langsdorf) [2072976]
- cpufreq: Make policy min/max hard requirements (Mark Langsdorf) [2072976]
- PM: EM: Allow skipping inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Extend em_perf_domain with a flag field (Mark Langsdorf) [2072976]
- PM: EM: Mark inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Fix inefficient states detection (Mark Langsdorf) [2072976]
- PM: EM: Increase energy calculation precision (Mark Langsdorf) [2072976]
- cpufreq: tegra186/tegra194: Handle errors in BPMP response (Mark Langsdorf) [2072976]
- cpufreq: remove useless INIT_LIST_HEAD() (Mark Langsdorf) [2072976]
- cpufreq: s3c244x: add fallthrough comments for switch (Mark Langsdorf) [2072976]
- cpufreq: vexpress: Drop unused variable (Mark Langsdorf) [2072976]
- qede: Reduce verbosity of ptp tx timestamp (Manish Chopra) [2080656]
- redhat/configs: Enable Marvell OcteonTX2 crypto device (Vladis Dronov) [2042239]
- hwrng: cn10k - Enable compile testing (Vladis Dronov) [2042239]
- hwrng: cn10k - Make check_rng_health() return an error code (Vladis Dronov) [2042239]
- hwrng: cn10k - Optimize cn10k_rng_read() (Vladis Dronov) [2042239]
- hwrng: cn10k - Add random number generator support (Vladis Dronov) [2042239]
- hwrng: cavium - fix NULL but dereferenced coccicheck error (Vladis Dronov) [2042261]
- hwrng: cavium - HW_RANDOM_CAVIUM should depend on ARCH_THUNDER (Vladis Dronov) [2042261]
- hwrng: cavium - Check health status while reading random data (Vladis Dronov) [2042261]
- crypto: octeontx2 - fix potential null pointer access (Vladis Dronov) [2041740]
- crypto: octeontx2 - add firmware version in devlink info (Vladis Dronov) [2041740]
- crypto: octeontx2 - simplify the return expression of otx2_cpt_aead_cbc_aes_sha_setkey() (Vladis Dronov) [2041740]
- crypto: octeontx2 - fix missing unlock (Vladis Dronov) [2041740]
- crypto: octeontx2 - add synchronization between mailbox accesses (Vladis Dronov) [2041740]
- crypto: octeontx2 - remove CONFIG_DM_CRYPT check (Vladis Dronov) [2041740]
- crypto: octeontx2 - increase CPT HW instruction queue length (Vladis Dronov) [2041740]
- crypto: octeontx2 - disable DMA black hole on an DMA fault (Vladis Dronov) [2041740]
- crypto: octeontx2 - CN10K CPT to RNM workaround (Vladis Dronov) [2041740]
- crypto: octeontx2 - Avoid stack variable overflow (Vladis Dronov) [2041740]
- crypto: octeontx2 - prevent underflow in get_cores_bmap() (Vladis Dronov) [2041740]
- crypto: octeontx2 - out of bounds access in otx2_cpt_dl_custom_egrp_delete() (Vladis Dronov) [2041740]
- crypto: octeontx2 - Use swap() instead of swap_engines() (Vladis Dronov) [2041740]
- crypto: octeontx2 - parameters for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - add apis for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - uninitialized variable in kvf_limits_store() (Vladis Dronov) [2041740]
- crypto: octeontx2 - use swap() to make code cleaner (Vladis Dronov) [2041740]
- crypto: octeontx2 - set assoclen in aead_do_fallback() (Vladis Dronov) [2041740]

* Wed Aug 10 2022 Jan Stancek <jstancek@redhat.com> [5.14.0-145.el9]
- KVM: x86: do not report preemption if the steal time cache is stale (Vitaly Kuznetsov) [2115238]
- KVM: x86: revalidate steal time cache if MSR value changes (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Always enable TSC scaling for L2 when it was enabled for L1 (Vitaly Kuznetsov) [2115238]
- KVM: x86: Fully initialize 'struct kvm_lapic_irq' in kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2115238]
- KVM: SEV: Init target VMCBs in sev_migrate_from (Vitaly Kuznetsov) [2115238]
- KVM: SVM: fix tsc scaling cache logic (Vitaly Kuznetsov) [2115238]
- KVM: x86/mmu: Check every prev_roots in __kvm_mmu_free_obsolete_roots() (Vitaly Kuznetsov) [2115238]
- KVM: LAPIC: Drop pending LAPIC timer injection when canceling the timer (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid calling x86 emulator without a decoded instruction (Vitaly Kuznetsov) [2115238]
- KVM: SVM: Use kzalloc for sev ioctl interfaces to prevent kernel data leak (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid loading a vCPU after .vm_destroy was called (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Clear IDT vectoring on nested VM-Exit for double/triple fault (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Leave most VM-Exit info fields unmodified on failed VM-Entry (Vitaly Kuznetsov) [2115238]
- KVM: x86: Drop WARNs that assert a triple fault never "escapes" from L2 (Vitaly Kuznetsov) [2115238]
- virtio-ring: fix DMA metadata flags (Cindy Lu) [2000425]
- RDMA/cxgb4: Set queue pair state when being queried (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use non-atomic bitmap functions when possible (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_set() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_zalloc() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use helper function to set GUIDs (Rahul Lakkireddy) [2109523]
- cxgb4: Use the bitmap API to allocate bitmaps (Rahul Lakkireddy) [2109520]
- cxgb4: Fix typo in string (Rahul Lakkireddy) [2109520]
- cxgb4/cxgb4vf: Fix typo in comments (Rahul Lakkireddy) [2109520]
- cxgb4vf: remove unexpected word "the" (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4: Avoid potential negative array offset (Rahul Lakkireddy) [2109520]
- libcxgb: Don't accidentally set RTO_ONLINK in cxgb_find_route() (Rahul Lakkireddy) [2109520]
- cxgb4vf: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: allow reading unrecognized port module eeprom (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Fix an error code in cxgb4vf_pci_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: Use struct_group() for memcpy() region (Rahul Lakkireddy) [2109520]
- cxgb4: fix eeprom len when diagnostics not implemented (Rahul Lakkireddy) [2109520]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Make use of the helper function dev_err_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: improve printing NIC information (Rahul Lakkireddy) [2109520]
- net: chelsio: switch from 'pci_' to 'dma_' API (Rahul Lakkireddy) [2109520]
- cxgb4: make the array match_all_mac static, makes object smaller (Rahul Lakkireddy) [2109520]
- scsi: mpt3sas: Stop fw fault watchdog work item during system shutdown (Tomas Henzl) [2112378]
- redhat: nvme/tcp mistakenly uses blk_mq_tag_to_rq(nvme_tcp_tagset(queue)) (John Meneghini) [2112031]
- bnxt_en: Fix bnxt_refclk_read() (Ken Cox) [2111502]
- bnxt_en: fix livepatch query (Ken Cox) [2111502]
- bnxt_en: Fix bnxt_reinit_after_abort() code path (Ken Cox) [2111502]
- bnxt_en: reclaim max resources if sriov enable fails (Ken Cox) [2111502]
- eth: bnxt: make ulp_id unsigned to make GCC 12 happy (Ken Cox) [2111502]
- igc: Reinstate IGC_REMOVED logic and implement it properly (Corinna Vinschen) [2037987]
- intel/igc:fix repeated words in comments (Corinna Vinschen) [2037987]
- intel: remove unused macros (Corinna Vinschen) [2037987]
- igc: Change type of the 'igc_check_downshift' method (Corinna Vinschen) [2037987]
- igc: Remove unused phy_type enum (Corinna Vinschen) [2037987]
- igc: Remove igc_set_spd_dplx method (Corinna Vinschen) [2037987]
- igc: Fix suspending when PTM is active (Corinna Vinschen) [2037987]
- igc: Fix BUG: scheduling while atomic (Corinna Vinschen) [2037987]
- igc: Fix infinite loop in release_swfw_sync (Corinna Vinschen) [2037987]
- igc: igc_write_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: igc_read_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Corinna Vinschen) [2037987]
- igc: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037987]
- igc: switch to napi_build_skb() (Corinna Vinschen) [2037987]
- igc: Remove obsolete define (Corinna Vinschen) [2037987]
- igc: Remove obsolete mask (Corinna Vinschen) [2037987]
- igc: Remove obsolete nvm type (Corinna Vinschen) [2037987]
- igc: Remove unused phy type (Corinna Vinschen) [2037987]
- igc: Remove unused _I_PHY_ID define (Corinna Vinschen) [2037987]

* Mon Aug 08 2022 Jan Stancek <jstancek@redhat.com> [5.14.0-144.el9]
- dm raid: fix address sanitizer warning in raid_resume (Benjamin Marzinski) [2115117]
- dm raid: fix address sanitizer warning in raid_status (Benjamin Marzinski) [2115117]
- dm: return early from dm_pr_call() if DM device is suspended (Benjamin Marzinski) [2115117]
- dm thin: fix use-after-free crash in dm_sm_register_threshold_callback (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks discarded, not number of discard bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks written, not number of write bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks read, not number of read bios (Benjamin Marzinski) [2115117]
- dm writecache: return void from functions (Benjamin Marzinski) [2115117]
- dm kcopyd: use __GFP_HIGHMEM when allocating pages (Benjamin Marzinski) [2115117]
- dm writecache: set a default MAX_WRITEBACK_JOBS (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_add_disks (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_remove_disk (Benjamin Marzinski) [2115117]
- NFS: Fix initialisation of nfs_client cl_flags field (Scott Mayhew) [2114872]
- ipmi: When handling send message responses, don't process the message (Tony Camuso) [2102319]
- net: ena: Do not waste napi skb cache (Michal Schmidt) [2097646]
- opp: Don't print an error if required-opps is missing (Mark Salter) [2112431]
- scsi: smartpqi: Update version to 2.1.18-045 (Don Brace) [2101544]
- scsi: smartpqi: Update copyright to current year (Don Brace) [2101544]
- scsi: smartpqi: Add ctrl ready timeout module parameter (Don Brace) [2101544]
- scsi: smartpqi: Update deleting a LUN via sysfs (Don Brace) [2101544]
- scsi: smartpqi: Add module param to disable managed ints (Don Brace) [2101544]
- scsi: smartpqi: Fix RAID map race condition (Don Brace) [2101544]
- scsi: smartpqi: Fix DMA direction for RAID requests (Don Brace) [2101544]
- scsi: smartpqi: Stop logging spurious PQI reset failures (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for Lenovo controllers (Don Brace) [2101544]
- scsi: smartpqi: Add PCI ID for Adaptec SmartHBA 2100-8i (Don Brace) [2101544]
- scsi: smartpqi: Fix PCI control linkdown system hang (Don Brace) [2101544]
- scsi: smartpqi: Add driver support for multi-LUN devices (Don Brace) [2101544]
- scsi: smartpqi: Close write read holes (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for ramaxel controllers (Don Brace) [2101544]
- scsi: smartpqi: Add controller fw version to console log (Don Brace) [2101544]
- scsi: smartpqi: Shorten drive visibility after removal (Don Brace) [2101544]
- scsi: smartpqi: Fix typo in comment (Don Brace) [2101544]
- xfs: fix maxlevels comparisons in the btree staging code (Andrey Albershteyn) [2106569]
- xfs: use kmem_cache_free() for kmem_cache objects (Andrey Albershteyn) [2106569]
- xfs: fix incorrect unit conversion in scrub tracepoint (Andrey Albershteyn) [2106569]
- xfs: reserve quota for dir expansion when linking/unlinking files (Andrey Albershteyn) [2106569]
- xfs: fix xfs_ifree() error handling to not leak perag ref (Andrey Albershteyn) [2106569]
- xfs: reorder iunlink remove operation in xfs_ifree (Andrey Albershteyn) [2106569]
- xfs: don't generate selinux audit messages for capability testing (Andrey Albershteyn) [2106569]
- scsi: qla2xxx: Fix imbalance vha->vref_count (Nilesh Javali) [2109000]
- ext4: make sure ext4_append() always allocates new block (Lukas Czerner) [2070213]
- ext4: check if directory block is within i_size (Lukas Czerner) [2070213]

* Fri Aug 05 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-143.el9]
- sched, cpuset: Fix dl_cpu_busy() panic due to empty cs->cpus_allowed (Waiman Long) [2104946]
- intel_idle: Fix false positive RCU splats due to incorrect hardirqs state (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- um: Add missing apply_returns() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: emulate: do not adjust size of fastop and setcc subroutines (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: fix FASTOP_SIZE when return thunks are enabled (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- efi/x86: use naked RET on mixed mode call wrapper (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Remove apostrophe typo (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use DECLARE_PER_CPU for x86_spec_ctrl_current (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Remove UNTRAIN_RET from native_irq_return_ldt (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Mark retbleed_strings static (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/asm/32: Fix ANNOTATE_UNRET_SAFE use on 32-bit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/static_call: Serialize __static_call_fixup() properly (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Disable RRSBA behavior (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kexec: Disable RET on kexec (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Move PUSH_AND_CLEAR_REGS() back into error_entry (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add Cannon lake to RETBleed affected CPU list (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- redhat/configs: Add new mitigation configs for RetBleed CVEs (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retbleed: Add fine grained Kconfig knobs (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Enumerate BTC_NO (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/common: Stamp out the stepping madness (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent RSB underflow before vmenter (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fill RSB on vmexit for IBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Fix IBRS handling after vmexit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Convert launched argument to flags (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Flatten __vmx_vcpu_run() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Re-add UNWIND_HINT_{SAVE_RESTORE} (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Remove x86_spec_ctrl_mask (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use cached host SPEC_CTRL value for guest entry/exit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix SPEC_CTRL write on SMT state change (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix firmware entry SPEC_CTRL handling (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix RSB filling with CONFIG_RETPOLINE=n (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Add Spectral Chicken (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do IBPB fallback check only once (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add retbleed=ibpb (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Add UNTRAIN_RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Rename SYS* entry points (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Update Retpoline validation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- intel_idle: Disable IBRS during long idle (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report Intel retbleed vulnerability (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Split spectre_v2_select_mitigation() and spectre_v2_user_select_mitigation() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Add spectre_v2=ibrs option to support Kernel IBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Optimize SPEC_CTRL MSR writes (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Add kernel IBRS implementation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Enable STIBP for JMP2RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add AMD retbleed= boot parameter (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report AMD retbleed vulnerability (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: skip non-text sections when adding return-thunk sites (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Add magic AMD return-thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Treat .text.__x86.* as noinstr (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Avoid very early RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Use return-thunk in asm code (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/sev: Avoid using __x86_return_thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: Fix SETcc emulation for return thunks (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bpf: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/ftrace: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,static_call: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,objtool: Create .return_sites (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Undo return-thunk damage (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Use -mfunction-return (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Swizzle retpoline thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Cleanup some #ifdefery (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpufeatures: Move RETPOLINE flags to word 11 (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm/vmx: Make noinstr clean (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Fix register corruption in compat syscall (Waiman Long) [2090231]
- x86/entry: Remove skip_r11rcx (Waiman Long) [2090231]
- x86/entry: Use PUSH_AND_CLEAR_REGS for compat (Waiman Long) [2090231]
- x86/entry: Simplify entry_INT80_compat() (Waiman Long) [2090231]
- x86/entry: Don't call error_entry() for XENPV (Waiman Long) [2090231]
- x86/entry: Move CLD to the start of the idtentry macro (Waiman Long) [2090231]
- x86/entry: Move PUSH_AND_CLEAR_REGS out of error_entry() (Waiman Long) [2090231]
- x86/entry: Switch the stack after error_entry() returns (Waiman Long) [2090231]
- x86/traps: Use pt_regs directly in fixup_bad_iret() (Waiman Long) [2090231]
- x86/retpoline: Add ANNOTATE_NOENDBR for retpolines (Waiman Long) [2090231]
- x86/static_call: Add ANNOTATE_NOENDBR to static call trampoline (Waiman Long) [2090231]
- objtool: Fix SLS validation for kcov tail-call replacement (Waiman Long) [2090231]
- x86,static_call: Fix __static_call_return0 for i386 (Waiman Long) [2090231]
- crypto: x86/poly1305 - Fixup SLS (Waiman Long) [2090231]
- kvm/emulate: Fix SETcc emulation for ENDBR (Waiman Long) [2090231]
- x86/ibt: Annotate text references (Waiman Long) [2090231]
- x86/alternative: Simplify int3_selftest_ip (Waiman Long) [2090231]
- x86/ibt,kvm: Add ENDBR to fastops (Waiman Long) [2090231]
- x86/ibt,entry: Sprinkle ENDBR dust (Waiman Long) [2090231]
- x86/ibt,xen: Sprinkle the ENDBR (Waiman Long) [2090231]
- x86/entry: Cleanup PARAVIRT (Waiman Long) [2090231]
- x86/ibt: Add ANNOTATE_NOENDBR (Waiman Long) [2090231]
- redhat/configs: Disable CONFIG_X86_KERNEL_IBT (Waiman Long) [2090231]
- x86/ibt: Base IBT bits (Waiman Long) [2090231]
- objtool,efi: Update __efi64_thunk annotation (Waiman Long) [2090231]
- objtool: Fix truncated string warning (Waiman Long) [2090231]
- redhat/configs: Disable CONFIG_SLS (Waiman Long) [2090231]
- x86: Add straight-line-speculation mitigation (Waiman Long) [2090231]
- x86/alternative: Relax text_poke_bp() constraint (Waiman Long) [2090231]
- objtool: Add straight-line-speculation validation (Waiman Long) [2090231]
- x86: Prepare inline-asm for straight-line-speculation (Waiman Long) [2090231]
- x86: Prepare asm files for straight-line-speculation (Waiman Long) [2090231]
- x86/mce: Reduce number of machine checks taken during recovery (Waiman Long) [2090231]
- x86/lib/atomic64_386_32: Rename things (Waiman Long) [2090231]
- x86: Use -mindirect-branch-cs-prefix for RETPOLINE builds (Waiman Long) [2090231]
- x86: Move RETPOLINE*_CFLAGS to arch Makefile (Waiman Long) [2090231]
- x86/xen: Add xenpv_restore_regs_and_return_to_usermode() (Waiman Long) [2090231]
- x86/entry: Use the correct fence macro after swapgs in kernel CR3 (Waiman Long) [2090231]
- x86/entry: Add a fence for kernel entry SWAPGS in paranoid_entry() (Waiman Long) [2090231]
- objtool: Fix pv_ops noinstr validation (Waiman Long) [2090231]
- static_call,x86: Robustify trampoline patching (Waiman Long) [2090231]
- x86/xen: switch initial pvops IRQ functions to dummy ones (Waiman Long) [2090231]
- bpf,x86: Respect X86_FEATURE_RETPOLINE* (Waiman Long) [2090231]
- x86/alternative: Add debug prints to apply_retpolines() (Waiman Long) [2090231]
- x86/alternative: Try inline spectre_v2=retpoline,amd (Waiman Long) [2090231]
- x86/alternative: Handle Jcc __x86_indirect_thunk_\reg (Waiman Long) [2090231]
- x86/alternative: Implement .retpoline_sites support (Waiman Long) [2090231]
- x86/retpoline: Create a retpoline thunk array (Waiman Long) [2090231]
- x86/retpoline: Move the retpoline thunk declarations to nospec-branch.h (Waiman Long) [2090231]
- x86/asm: Fixup odd GEN-for-each-reg.h usage (Waiman Long) [2090231]
- x86/asm: Fix register order (Waiman Long) [2090231]
- x86/retpoline: Remove unused replacement symbols (Waiman Long) [2090231]
- objtool,x86: Replace alternatives with .retpoline_sites (Waiman Long) [2090231]
- objtool: Shrink struct instruction (Waiman Long) [2090231]
- objtool: Explicitly avoid self modifying code in .altinstr_replacement (Waiman Long) [2090231]
- objtool: Classify symbols (Waiman Long) [2090231]
- objtool: Remove reloc symbol type checks in get_alt_entry() (Waiman Long) [2090231]
- objtool: print out the symbol type when complaining about it (Waiman Long) [2090231]
- objtool: Teach get_alt_entry() about more relocation types (Waiman Long) [2090231]
- kbuild: reuse $(cmd_objtool) for cmd_cc_lto_link_modules (Waiman Long) [2090231]
- kbuild: detect objtool update without using .SECONDEXPANSION (Waiman Long) [2090231]
- kbuild: factor out OBJECT_FILES_NON_STANDARD check into a macro (Waiman Long) [2090231]
- kbuild: store the objtool command in *.cmd files (Waiman Long) [2090231]
- kbuild: rename __objtool_obj and reuse it for cmd_cc_lto_link_modules (Waiman Long) [2090231]
- kbuild: move objtool_args back to scripts/Makefile.build (Waiman Long) [2090231]
- x86/mce: Drop copyin special case for #MC (Waiman Long) [2090231]
- objtool: Support pv_opsindirect calls for noinstr (Waiman Long) [2090231]
- x86/xen: Rework the xen_{cpu,irq,mmu}_opsarrays (Waiman Long) [2090231]
- objtool: Handle __sanitize_cov*() tail calls (Waiman Long) [2090231]
- objtool: Introduce CFI hash (Waiman Long) [2090231]
- kbuild: clean up objtool_args slightly (Waiman Long) [2090231]
- kbuild: remove stale *.symversions (Waiman Long) [2090231]
- kbuild: remove unused quiet_cmd_update_lto_symversions (Waiman Long) [2090231]
- kbuild: Fix TRIM_UNUSED_KSYMS with LTO_CLANG (Waiman Long) [2090231]
- Makefile: remove stale cc-option checks (Waiman Long) [2090231]
- x86/build: Remove stale cc-option checks (Waiman Long) [2090231]
- xen: assume XENFEAT_mmu_pt_update_preserve_ad being set for pv guests (Waiman Long) [2090231]
- dmaengine: idxd: Fixup upstream merge conflict resolution (Jerry Snitselaar) [2100482]
- dmaengine: idxd: skip clearing device context when device is read-only (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_transfer_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_batch_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: fix device cleanup on disable (Jerry Snitselaar) [2100482]
- Revert "dmaengine: idxd: Separate user and kernel pasid enabling" (Jerry Snitselaar) [2100482]

* Thu Aug 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-142.el9]
- sit: do not call ipip6_dev_free() from sit_init_net() (Hangbin Liu) [2089080]
- net: ping6: Fix memleak in ipv6_renew_options(). (Ivan Vecera) [2112338]
- dma-direct: use the correct size for dma_set_encrypted() (Jerry Snitselaar) [2105609]
- dma-debug: make things less spammy under memory pressure (Jerry Snitselaar) [2105609]
- dma-iommu: Check that swiotlb is active before trying to use it (Jerry Snitselaar) [2105609]
- Documentation: add a description for net.core.high_order_alloc_disable (Antoine Tenart) [2068582]
- Input: bcm5974 - set missing URB_NO_TRANSFER_DMA_MAP urb flag (Benjamin Tissoires) [2070873]
- Input: add Marine Navigation Keycodes (Benjamin Tissoires) [2070873]
- Revert "Input: clear BTN_RIGHT/MIDDLE on buttonpads" (Benjamin Tissoires) [2070873]
- Input: synaptics - enable InterTouch on ThinkPad T14/P14s Gen 1 AMD (Benjamin Tissoires) [2070873]
- Input: add bounds checking to input_set_capability() (Benjamin Tissoires) [2070873]
- Input: add input_copy_abs() function (Benjamin Tissoires) [2070873]
- Input: set EV_ABS in dev->evbit even if input_alloc_absinfo() fails (Benjamin Tissoires) [2070873]
- Input: aiptek - properly check endpoint type (Benjamin Tissoires) [2070873]
- Input: elan_i2c - fix regulator enable count imbalance after suspend/resume (Benjamin Tissoires) [2070873]
- Input: elan_i2c - move regulator_[en|dis]able() out of elan_[en|dis]able_power() (Benjamin Tissoires) [2070873]
- Input: psmouse - set up dependency between PS/2 and SMBus companions (Benjamin Tissoires) [2070873]
- Input: clear BTN_RIGHT/MIDDLE on buttonpads (Benjamin Tissoires) [2070873]
- Input: gpio-keys - avoid clearing twice some memory (Benjamin Tissoires) [2070873]
- Input: byd - fix typo in a comment (Benjamin Tissoires) [2070873]
- Input: ff-core - correct magnitude setting for rumble compatibility (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - clean up the query device fields (Benjamin Tissoires) [2070873]
- Input: appletouch - initialize work before device registration (Benjamin Tissoires) [2070873]
- Input: elants_i2c - do not check Remark ID on eKTH3900/eKTH5312 (Benjamin Tissoires) [2070873]
- Input: i8042 - enable deferred probe quirk for ASUS UM325UA (Benjamin Tissoires) [2070873]
- Input: elantech - fix stack out of bound access in elantech_change_report_id() (Benjamin Tissoires) [2070873]
- Input: i8042 - add deferred probe support (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - use macros for the bit masks (Benjamin Tissoires) [2070873]
- Input: elantench - fix misreporting trackpoint coordinates (Benjamin Tissoires) [2070873]
- Input: synaptics-rmi4 - Fix device hierarchy (Benjamin Tissoires) [2070873]
- Input: remove unused header <linux/input/cy8ctmg110_pdata.h> (Benjamin Tissoires) [2070873]
- Input: elants_i2c - make use of devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- Input: touchscreen - avoid bitwise vs logical OR warning (Benjamin Tissoires) [2070873]
- Input: elan_i2c - reduce the resume time for controller in Whitebox (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "useable" -> "usable" (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "Modul" -> "Module" (Benjamin Tissoires) [2070873]
- Input: remove dead CSR Prima2 PWRC driver (Benjamin Tissoires) [2070873]
- Input: parkbd - switch to use module_parport_driver() (Benjamin Tissoires) [2070873]
- Revert "Input: serio - make write method mandatory" (Benjamin Tissoires) [2070873]
- Input: serio - make write method mandatory (Benjamin Tissoires) [2070873]
- Input: ixp4xx-beeper - delete driver (Benjamin Tissoires) [2070873]
- HID: elan: Fix potential double free in elan_input_configured (Benjamin Tissoires) [2070873]
- HID: hid-led: fix maximum brightness for Dream Cheeky (Benjamin Tissoires) [2070873]
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe (Benjamin Tissoires) [2070873]
- HID: multitouch: add quirks to enable Lenovo X12 trackpoint (Benjamin Tissoires) [2070873]
- HID: multitouch: Add support for Google Whiskers Touchpad (Benjamin Tissoires) [2070873]
- HID: Add driver for Razer Blackwidow keyboards (Benjamin Tissoires) [2070873]
- HID: add SiGma Micro driver (Benjamin Tissoires) [2070873]
- HID: google: modify HID device groups of eel (Benjamin Tissoires) [2070873]
- HID: google: Add support for vivaldi to hid-hammer (Benjamin Tissoires) [2070873]
- HID: google: extract Vivaldi hid feature mapping for use in hid-hammer (Benjamin Tissoires) [2070873]
- Input: extract ChromeOS vivaldi physmap show function (Benjamin Tissoires) [2070873]
- HID: google: switch to devm when registering keyboard backlight LED (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update (Benjamin Tissoires) [2070873]
- HID: input: accommodate priorities for slotted devices (Benjamin Tissoires) [2070873]
- HID: input: remove the need for HID_QUIRK_INVERT (Benjamin Tissoires) [2070873]
- HID: input: enforce Invert usage to be processed before InRange (Benjamin Tissoires) [2070873]
- HID: core: for input reports, process the usages by priority list (Benjamin Tissoires) [2070873]
- HID: compute an ordered list of input fields to process (Benjamin Tissoires) [2070873]
- HID: input: move up out-of-range processing of input values (Benjamin Tissoires) [2070873]
- HID: input: rework spaghetti code with switch statements (Benjamin Tissoires) [2070873]
- HID: input: tag touchscreens as such if the physical is not there (Benjamin Tissoires) [2070873]
- HID: core: split data fetching from processing in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: de-duplicate some code in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: statically allocate read buffers (Benjamin Tissoires) [2070873]
- HID: uclogic: Support multiple frame input devices (Benjamin Tissoires) [2070873]
- HID: uclogic: Define report IDs before their descriptors (Benjamin Tissoires) [2070873]
- HID: uclogic: Put version first in rdesc namespace (Benjamin Tissoires) [2070873]
- HID: uclogic: Use "frame" instead of "buttonpad" (Benjamin Tissoires) [2070873]
- HID: uclogic: Use different constants for frame report IDs (Benjamin Tissoires) [2070873]
- HID: uclogic: Specify total report size to buttonpad macro (Benjamin Tissoires) [2070873]
- HID: uclogic: Switch to matching subreport bytes (Benjamin Tissoires) [2070873]
- HID: uclogic: Replace pen_frame_flag with subreport_list (Benjamin Tissoires) [2070873]
- HID: uclogic: Remove pen usage masking (Benjamin Tissoires) [2070873]
- HID: apple: properly reflect LEDS dependency (Benjamin Tissoires) [2070873]
- HID: apple: Add fn mapping for MacBook Pros with Touch Bar (Benjamin Tissoires) [2070873]
- HID: apple: Add necessary IDs and configuration for T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Add support for keyboard backlight on certain T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 with fingerprint reader battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard 2015 FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard first generation FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Refactor key translation setup (Benjamin Tissoires) [2070873]
- HID: uclogic: Handle virtual frame reports (Benjamin Tissoires) [2070873]
- HID: uclogic: Skip non-input raw events earlier (Benjamin Tissoires) [2070873]
- HID: uclogic: Access pen/frame params directly in raw_event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Split pen and frame raw event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion 13th frame button (Benjamin Tissoires) [2070873]
- HID: uclogic: Rename Huion HS64 PID to Huion Tablet 2 (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion tilt reporting (Benjamin Tissoires) [2070873]
- HID: i2c-hid: remove unneeded semicolon (Benjamin Tissoires) [2070873]
- HID: i2c-hid: note that I2C xfer buffers are DMA-safe (Benjamin Tissoires) [2070873]
- HID: i2c-hid: no longer need raw access to HID descriptor structure (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use helpers to do endian conversion in i2c_hid_get_input() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: rework i2c_hid_get_report() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: convert i2c_hid_execute_reset() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: create a helper for SET_POWER command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: define i2c_hid_read_register() and use it (Benjamin Tissoires) [2070873]
- HID: i2c-hid: explicitly code setting and sending reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: refactor reset command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use "struct i2c_hid" as argument in most calls (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix GET/SET_REPORT for unnumbered reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix handling numbered reports with IDs of 15 and above (Benjamin Tissoires) [2070873]
- HID: google: Use struct_size() helper in kzalloc() (Benjamin Tissoires) [2070873]
- HID: Add new Letsketch tablet driver (Benjamin Tissoires) [2070873]
- HID: elo: Revert USB reference counting (Benjamin Tissoires) [2070873]
- HID: elo: fix memory leak in elo_probe (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_ALL_APPLICATIONS (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_DICTATE (Benjamin Tissoires) [2070873]
- HID: nintendo: check the return value of alloc_workqueue() (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix sysfs attributes leak (Benjamin Tissoires) [2070873]
- HID: hid-thrustmaster: fix OOB read in thrustmaster_interrupts (Benjamin Tissoires) [2070873]
- HID: Add support for open wheel and no attachment to T300 (Benjamin Tissoires) [2070873]
- HID: logitech-dj: add new lightspeed receiver id (Benjamin Tissoires) [2070873]
- HID:Add support for UGTABLET WP5540 (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Fix a lockdep splat (Benjamin Tissoires) [2070873]
- HID: apple: Set the tilde quirk flag on the Wellspring 5 and later (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid using stale array indicies to read contact count (Benjamin Tissoires) [2070873]
- HID: wacom: Ignore the confidence flag when a touch is removed (Benjamin Tissoires) [2070873]
- HID: wacom: Reset expected and received contact counts at the same time (Benjamin Tissoires) [2070873]
- HID: uhid: Use READ_ONCE()/WRITE_ONCE() for ->running (Benjamin Tissoires) [2070873]
- HID: uhid: Fix worker destroying device without any protection (Benjamin Tissoires) [2070873]
- HID: vivaldi: Minor cleanups (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix handling devices not using numbered reports (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15t-dr100 (Benjamin Tissoires) [2070873]
- HID: magicmouse: Fix an error handling path in magicmouse_probe() (Benjamin Tissoires) [2070873]
- HID: address kernel-doc warnings (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ishtp-fw-loader: Fix a kernel-doc formatting issue (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: Specify no cache snooping on TGL and ADL (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_frame_init_v1_buttonpad (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_huion_init (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_get_str_desc (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_init (Benjamin Tissoires) [2070873]
- HID: apple: Add Magic Keyboard 2021 with fingerprint reader FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 magic keyboard FN key mapping (Benjamin Tissoires) [2070873]
- HID: magicmouse: set Magic Trackpad 2021 name (Benjamin Tissoires) [2070873]
- HID: magicmouse: set device name when it has been personalized (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with number pad (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with fingerprint reader (Benjamin Tissoires) [2070873]
- HID: i2c-hid-of: Expose the touchscreen-inverted properties (Benjamin Tissoires) [2070873]
- HID: quirks: Allow inverting the absolute X/Y values (Benjamin Tissoires) [2070873]
- HID: hidraw: Replace hidraw device table mutex with a rwsem (Benjamin Tissoires) [2070873]
- HID: thrustmaster use swap() to make code cleaner (Benjamin Tissoires) [2070873]
- HID: debug: Add USI usages (Benjamin Tissoires) [2070873]
- HID: input: Make hidinput_find_field() static (Benjamin Tissoires) [2070873]
- HID: Add hid usages for USI style pens (Benjamin Tissoires) [2070873]
- HID: hid-input: Add suffix also for HID_DG_PEN (Benjamin Tissoires) [2070873]
- HID: Add map_msc() to avoid boilerplate code (Benjamin Tissoires) [2070873]
- HID: do not inline some hid_hw_ functions (Benjamin Tissoires) [2070873]
- HID: add suspend/resume helpers (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Use BIT to define quirks (Benjamin Tissoires) [2070873]
- HID: apple: Do not reset quirks when the Fn key is not found (Benjamin Tissoires) [2070873]
- HID: magicmouse: Report battery level over USB (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Report wakeup events (Benjamin Tissoires) [2070873]
- HID: potential dereference of null pointer (Benjamin Tissoires) [2070873]
- HID: holtek: fix mouse probing (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on Asus UX550VE (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: only enable IRQ wakeup when requested (Benjamin Tissoires) [2070873]
- HID: google: add eel USB id (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-prodikeys (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-chicony (Benjamin Tissoires) [2070873]
- HID: bigbenff: prevent null pointer dereference (Benjamin Tissoires) [2070873]
- HID: sony: fix error path in probe (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy on some USB HID drivers (Benjamin Tissoires) [2070873]
- HID: check for valid USB device for many HID drivers (Benjamin Tissoires) [2070873]
- HID: wacom: fix problems when device is not a valid USB device (Benjamin Tissoires) [2070873]
- HID: add hid_is_usb() function to make it simpler for USB detection (Benjamin Tissoires) [2070873]
- HID: quirks: Add quirk for the Microsoft Surface 3 type-cover (Benjamin Tissoires) [2070873]
- HID: multitouch: Fix Iiyama ProLite T1931SAW (0eef:0001 again!) (Benjamin Tissoires) [2070873]
- HID: nintendo: eliminate dead datastructures in !CONFIG_NINTENDO_FF case (Benjamin Tissoires) [2070873]
- HID: magicmouse: prevent division by 0 on scroll (Benjamin Tissoires) [2070873]
- HID: thrustmaster: fix sparse warnings (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15-eu0xxx (Benjamin Tissoires) [2070873]
- HID: input: set usage type to key on keycode remap (Benjamin Tissoires) [2070873]
- HID: input: Fix parsing of HID_CP_CONSUMER_CONTROL fields (Benjamin Tissoires) [2070873]
- HID: ft260: fix i2c probing for hwmon devices (Benjamin Tissoires) [2070873]
- Revert "HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK" (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fix module device-id handling (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: hid-client: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fw-loader: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: use constants for modaliases (Benjamin Tissoires) [2070873]
- HID: wacom: Use "Confidence" flag to prevent reporting invalid contacts (Benjamin Tissoires) [2070873]
- HID: nintendo: unlock on error in joycon_leds_create() (Benjamin Tissoires) [2070873]
- HID: nintendo: fix -Werror build (Benjamin Tissoires) [2070873]
- HID: playstation: require multicolor LED functionality (Benjamin Tissoires) [2070873]
- HID: u2fzero: properly handle timeouts in usb_submit_urb (Benjamin Tissoires) [2070873]
- HID: u2fzero: clarify error check and length calculations (Benjamin Tissoires) [2070873]
- HID: u2fzero: Support NitroKey U2F revision of the device (Benjamin Tissoires) [2070873]
- HID: wacom: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: wacom: Shrink critical section in `wacom_add_shared_data` (Benjamin Tissoires) [2070873]
- HID: nintendo: prevent needless queueing of the rumble worker (Benjamin Tissoires) [2070873]
- HID: nintendo: ratelimit subcommands and rumble (Benjamin Tissoires) [2070873]
- HID: nintendo: improve rumble performance and stability (Benjamin Tissoires) [2070873]
- HID: nintendo: add IMU support (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for reading user calibration (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for charging grip (Benjamin Tissoires) [2070873]
- HID: nintendo: set controller uniq to MAC (Benjamin Tissoires) [2070873]
- HID: nintendo: reduce device removal subcommand errors (Benjamin Tissoires) [2070873]
- HID: nintendo: patch hw version for userspace HID mappings (Benjamin Tissoires) [2070873]
- HID: nintendo: send subcommands after receiving input report (Benjamin Tissoires) [2070873]
- HID: nintendo: improve subcommand reliability (Benjamin Tissoires) [2070873]
- HID: nintendo: add rumble support (Benjamin Tissoires) [2070873]
- HID: nintendo: add home led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add power supply support (Benjamin Tissoires) [2070873]
- HID: nintendo: add player led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add nintendo switch controller driver (Benjamin Tissoires) [2070873]
- HID: playstation: fix return from dualsense_player_led_set_brightness() (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense player LEDs through LED class. (Benjamin Tissoires) [2070873]
- leds: add new LED_FUNCTION_PLAYER for player LEDs for game controllers. (Benjamin Tissoires) [2070873]
- Documentation: leds: standartizing LED names (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense lightbar through a multi-color LED. (Benjamin Tissoires) [2070873]
- HID: surface-hid: Allow driver matching for target ID 1 devices (Benjamin Tissoires) [2070873]
- HID: surface-hid: Use correct event registry for managing HID events (Benjamin Tissoires) [2070873]
- HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK (Benjamin Tissoires) [2070873]
- HID: apple: Bring back flag for Apple tilde key quirk (Benjamin Tissoires) [2070873]
- HID: apple: Add support for the 2021 Magic Keyboard (Benjamin Tissoires) [2070873]
- HID: apple: Rename MAGIC_KEYBOARD_ANSI to MAGIC_KEYBOARD_2015 (Benjamin Tissoires) [2070873]
- HID: multitouch: disable sticky fingers for UPERFECT Y (Benjamin Tissoires) [2070873]
- HID: cougar: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: roccat: Use struct_group() to zero kone_mouse_event (Benjamin Tissoires) [2070873]
- HID: cp2112: Use struct_group() for memcpy() region (Benjamin Tissoires) [2070873]
- HID: Add support for side buttons of Xiaomi Mi Dual Mode Wireless Mouse Silent (Benjamin Tissoires) [2070873]
- HID: hid-debug: clean up snprintf() checks in hid_resolv_usage() (Benjamin Tissoires) [2070873]
- HID: apple: Eliminate obsolete IR receiver quirks (Benjamin Tissoires) [2070873]
- HID: core: add TransducerSerialNumber2 (Benjamin Tissoires) [2070873]
- HID: u2fzero: ignore incomplete packets without data (Benjamin Tissoires) [2070873]
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device IDs (Benjamin Tissoires) [2070873]
- HID: apple: Fix logical maximum and usage maximum of Magic Keyboard JIS (Benjamin Tissoires) [2070873]
- HID: betop: fix slab-out-of-bounds Write in betop_probe (Benjamin Tissoires) [2070873]
- HID: usbhid: Simplify code in hid_submit_ctrl() (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix warning caused by 0-length input reports (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix flood of "control queue full" messages (Benjamin Tissoires) [2070873]
- HID: sony: Fix more ShanWan clone gamepads to not rumble when plugged in. (Benjamin Tissoires) [2070873]
- HID: sony: support for the ghlive ps4 dongles (Benjamin Tissoires) [2070873]
- HID: thrustmaster: clean up Makefile and adapt quirks (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Fix Elan touchpad regression (Benjamin Tissoires) [2070873]
- HID: asus: Prevent Claymore sending suspend event (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: battery: provide CAPACITY property for newer devices (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in thrustmaster_interrupts() (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in remove (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leaks in probe (Benjamin Tissoires) [2070873]
- HID: elo: update the reference count of the usb device structure (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: Use 'atomic_inc_return' instead of hand-writing it (Benjamin Tissoires) [2070873]
- HID: apple: Add missing scan code event for keys handled by hid-apple (Benjamin Tissoires) [2070873]
- HID: cmedia: add support for HS-100B mute button (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Use the devm variant of regulator_register_notifier() (Benjamin Tissoires) [2070873]
- HID: wacom: Refactor touch input mute checks into a common function (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid sending empty sync events (Benjamin Tissoires) [2070873]
- HID: wacom: Short-circuit processing of touch when it is disabled (Benjamin Tissoires) [2070873]
- HID: wacom: set initial hardware touch switch state to 'off' (Benjamin Tissoires) [2070873]
- HID: usbhid: free raw_report buffers in usbhid_stop (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Tie the reset line to true state of the regulator (Benjamin Tissoires) [2070873]
- HID: magicmouse: high-resolution scroll threshold (Benjamin Tissoires) [2070873]
- HID: magicmouse: enable high-resolution scroll (Benjamin Tissoires) [2070873]
- HID: input: do not report stylus battery state as "full" (Benjamin Tissoires) [2070873]
- HID: amd_sfh: Modify the hid name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Modify the bus name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for sensor discovery (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Remove useless DMA-32 fallback configuration (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add interrupt handler to process interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add functionality to clear interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Disable the interrupt for all command (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Correct the structure field name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add illuminance mask to limit ALS max value (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Increase sensor command timeout (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Update Copyright details (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dev_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Use dma_set_mask_and_coherent() (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dma_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add dyndbg prints for debugging (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for PM suspend and resume (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Move hid probe after sensor is enabled (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add command response to check command status (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix period data field to enable sensor (Benjamin Tissoires) [2054930 2070873]

* Wed Aug 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-141.el9]
- Documentation: Add an explanation of NFSv4 client identifiers (Dave Wysochanski) [2112933]
- powerpc/bpf: Fix use of user_pt_regs in uapi (Desnes A. Nunes do Rosario) [2113065]
- Documentation: filesystems: proc: update meminfo section (David Hildenbrand) [2075394]
- mm: make slab and vmalloc allocators __GFP_NOLOCKDEP aware (Waiman Long) [2109001]
- mm/munlock: protect the per-CPU pagevec by a local_lock_t (Waiman Long) [2109671]
- mm/migration: add trace events for base page and HugeTLB migrations (Waiman Long) [2109671]
- powercap: intel_rapl: add support for ALDERLAKE_N (David Arcari) [2096965]
- ACPI: VIOT: Fix ACS setup (Eric Auger) [2101431]
- iommu/vt-d: Fix PCI bus rescan device hot add (Jerry Snitselaar) [2101592]
- iommu/vt-d: Fix RID2PASID setup/teardown failure (Jerry Snitselaar) [2101592]
- scsi: qla2xxx: Fix excessive I/O error messages by default (Nilesh Javali) [2083241]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2067297]
- ACPI: CPPC: Change default error code and clean up debug messages in probe (Mark Langsdorf) [2067297]
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data (Mark Langsdorf) [2067297]
- ACPI: tables: Make LAPIC_ADDR_OVR address readable in message (Mark Langsdorf) [2067297]
- ACPI: IPMI: replace usage of found with dedicated list iterator variable (Mark Langsdorf) [2067297]
- ACPI, APEI: Use the correct variable for sizeof() (Mark Langsdorf) [2067297]
- clocksource: acpi_pm: fix return value of __setup handler (Mark Langsdorf) [2067297]
- ACPI / x86: Add support for LPS0 callback handler (Mark Langsdorf) [2067297]
- ACPI: bus: Avoid using CPPC if not supported by firmware (Mark Langsdorf) [2067297]
- Revert "ACPI: Pass the same capabilities to the _OSC regardless of the query flag" (Mark Langsdorf) [2067297]
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU (Mark Langsdorf) [2067297]
- PM: hibernate: Honour ACPI hardware signature by default for virtual guests (Mark Langsdorf) [2067297]
- ACPI: NFIT: Remove block aperture support (Mark Langsdorf) [2067297]
- x86, ACPI: rename init_freq_invariance_cppc() to arch_init_invariance_cppc() (Mark Langsdorf) [2067297]
- ACPI/APEI: Limit printable size of BERT table data (Mark Langsdorf) [2067297]
- ACPI: APEI: fix return value of __setup handlers (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Lenovo Yoga Tablet 1050F/L (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Nextbook Ares 8 (Mark Langsdorf) [2067297]
- ACPICA: Avoid walking the ACPI Namespace if it is not there (Mark Langsdorf) [2067297]
- ACPI: APEI: rename ghes_init() with an "acpi_" prefix (Mark Langsdorf) [2067297]
- ACPI: APEI: explicit init of HEST and GHES in apci_init() (Mark Langsdorf) [2067297]
- ACPI: processor idle: Check for architectural support for LPI (Mark Langsdorf) [2067297]
- ACPI: LPSS: Provide an SSP type to the driver (Mark Langsdorf) [2067297]
- ACPI: LPSS: Constify properties member in struct lpss_device_desc (Mark Langsdorf) [2067297]
- ACPI: platform: Constify properties parameter in acpi_create_platform_device() (Mark Langsdorf) [2067297]
- ACPI: battery: Add device HID and quirk for Microsoft Surface Go 3 (Mark Langsdorf) [2067297]
- ACPI: fan: Add additional attributes for fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Properly handle fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Optimize struct acpi_fan_fif (Mark Langsdorf) [2067297]
- ACPI: fan: Separate file for attributes creation (Mark Langsdorf) [2067297]
- ACPI: fan: Fix error reporting to user space (Mark Langsdorf) [2067297]
- ACPI: clean up double words in two comments (Mark Langsdorf) [2067297]
- ACPI: property: Get rid of redundant 'else' (Mark Langsdorf) [2067297]
- ACPI: scan: Use ida_alloc() instead of ida_simple_get() (Mark Langsdorf) [2067297]
- ACPI: EC: Rearrange code in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Reduce indentation level in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Do not return result from advance_transaction() (Mark Langsdorf) [2067297]
- ACPI: EC / PM: Print additional debug message in acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067297]
- ACPI: PM: Print additional debug message in acpi_s2idle_wake() (Mark Langsdorf) [2067297]
- ACPI: tables: Add CEDT signature to the list of known tables (Mark Langsdorf) [2067297]
- ACPI: properties: Consistently return -ENOENT if there are no more references (Mark Langsdorf) [2067297]
- ACPI: OSL: Fix and clean up acpi_os_read/write_port() (Mark Langsdorf) [2067297]
- ACPICA: Use uintptr_t and offsetof() in Linux kernel builds (Mark Langsdorf) [2067297]

* Tue Aug 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-140.el9]
- tracing: Show size of requested perf buffer (Michael Petlan) [2106297]
- tracing: Increase PERF_MAX_TRACE_SIZE to handle Sentinel1 and docker together (Michael Petlan) [2106297]
- ibmvnic: Properly dispose of all skbs during a failover. (Steve Best) [2107561]
- powerpc/fadump: save CPU reg data in vmcore when PHYP terminates LPAR (Steve Best) [2104440]
- perf cpumap: Add perf_cpu_map__for_each_idx() (Michael Petlan) [2085427]
- perf stat: Make use of index clearer with perf_counts (Michael Petlan) [2085427]
- perf stat: Fix and validate CPU map inputs in synthetic PERF_RECORD_STAT events (Michael Petlan) [2085427]

* Mon Aug 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-139.el9]
- RDMA/irdma: Fix sleep from invalid context BUG (Kamal Heib) [2097326]
- RDMA/irdma: Do not advertise 1GB page size for x722 (Kamal Heib) [2097326]
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (Kamal Heib) [2097326]
- RDMA/hfi1: Fix potential integer multiplication overflow errors (Kamal Heib) [2097326]
- RDMA/hfi1: Prevent use of lock before it is initialized (Kamal Heib) [2097326]
- KVM: selftests: Fix target thread to be migrated in rseq_test (Gavin Shan) [2106955]
- net: mld: fix reference count leak in mld_{query | report}_work() (Hangbin Liu) [2067774]
- vsock/virtio: add support for device suspend/resume (Stefano Garzarella) [2107589]
- vsock/virtio: factor our the code to initialize and delete VQs (Stefano Garzarella) [2107589]
- hv_sock: Add validation for untrusted Hyper-V values (Stefano Garzarella) [2107589]
- vsock/virtio: enable VQs early on probe (Stefano Garzarella) [2107589]
- vsock/virtio: read the negotiated features before using VQs (Stefano Garzarella) [2107589]
- vsock/virtio: initialize vdev->priv before using VQs (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET broken buffer test (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET receive timeout test (Stefano Garzarella) [2107589]
- vsock: each transport cycles only on its own sockets (Stefano Garzarella) [2107589]
- vhost/vsock: don't check owner in vhost_vsock_stop() while releasing (Stefano Garzarella) [2107589]
- vsock: remove vsock from connected table when connect is interrupted by a signal (Stefano Garzarella) [2107589]
- platform: goldfish: pipe: Use platform_get_irq() to get the interrupt (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add missing of_node_put() in ls2k_reset_init() (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add Loongson-2K1000 reset platform driver (Mark Langsdorf) [2068298]
- platform/mellanox: mlxbf-pmc: Fix an IS_ERR() vs NULL bug in mlxbf_pmc_map_counters (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: fix error code in mlxreg_lc_create_static_devices() (Mark Langsdorf) [2068298]
- redhat/configs: enable CONFIG_MLXREG_LC (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: Add initial support for Nvidia line card devices (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new field for secured access (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Extend number of hwmon attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-hotplug: Extend logic for hotplug devices operations (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new type to support modular systems (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix argument base in kstrtou32() call (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_debugfs: detach log reader wq from devm (Mark Langsdorf) [2068298]
- platform: chrome: Split trace include file (Mark Langsdorf) [2068298]
- platform/chrome: sensorhub: Add trace events for sample (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Update mux flags during partner removal (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Configure muxes at start of port update (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Get mux state inside configure_mux (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Move mux flag checks (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Make cros_ec_unregister() return void (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Check for EC device (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Make try power role optional (Mark Langsdorf) [2068298]
- redhat/configs: don't enable ChromeOS privacy screen (Mark Langsdorf) [2068298]
- platform/chrome: Add driver for ChromeOS privacy-screen (Mark Langsdorf) [2068298]
- drm/privacy-screen: Fix sphinx warning (Mark Langsdorf) [2068298]
- drm/privacy_screen: Add drvdata in drm_privacy_screen (Mark Langsdorf) [2068298]
- drm/connector: Add a drm_connector privacy-screen helper functions (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add notifier support (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add X86 specific arch init code (Mark Langsdorf) [2068298]
- drm: Add privacy-screen class (v4) (Mark Langsdorf) [2068298]
- drm/connector: Add support for privacy-screen properties (v4) (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Add version for ec_command (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Make data pointers void (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Move ec_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Rename cros_ec_pd_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Fix spelling mistake "responsed" -> "response" (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_sensorhub: simplify getting .driver_data (Mark Langsdorf) [2068298]
- platform/chrome: cros-ec-typec: Cleanup use of check_features (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Use existing feature check (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Fix check_features ret val (Mark Langsdorf) [2068298]
- drm/mgag200: Enable atomic gamma lut update (Jocelyn Falempe) [2078542]
- drm/mgag200: Optimize damage clips (Jocelyn Falempe) [2078542]
- drm/mgag200: Add FB_DAMAGE_CLIPS support (Jocelyn Falempe) [2078542]
- cgroup: use irqsave in cgroup_rstat_flush_locked(). (Waiman Long) [2060150]
- cgroup-v1: Correct privileges check in release_agent writes (Waiman Long) [2060150]
- cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug (Waiman Long) [2060150]
- psi: Fix uaf issue when psi trigger is destroyed while being polled (Waiman Long) [2060150]
- cgroup/cpuset: Make child cpusets restrict parents on v1 hierarchy (Waiman Long) [2060150]
- cgroup/cpuset: Don't let child cpusets restrict parent in default hierarchy (Waiman Long) [2060150]
- mm/page_alloc: detect allocation forbidden by cpuset and bail out early (Waiman Long) [2060150]
- cgroup: Fix rootcg cpu.stat guest double counting (Waiman Long) [2060150]
- cgroup: no need for cgroup_mutex for /proc/cgroups (Waiman Long) [2060150]
- cgroup: remove cgroup_mutex from cgroupstats_build (Waiman Long) [2060150]
- cgroup: reduce dependency on cgroup_mutex (Waiman Long) [2060150]
- cgroup/cpuset: Change references of cpuset_mutex to cpuset_rwsem (Waiman Long) [2060150]

* Fri Jul 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-138.el9]
- tools/testing/nvdimm: Fix security_init() symbol collision (Jeff Moyer) [2096788]
- NFSD: Move fill_pre_wcc() and fill_post_wcc() (Benjamin Coddington) [2110576]
- Revert "nfsd: skip some unnecessary stats in the v4 case" (Benjamin Coddington) [2110576]
- Documentation: fix udp_wmem_min in ip-sysctl.rst (Xin Long) [2087560]
- redhat/configs/common: Enable CONFIG_LZ4_COMPRESS (Andrew Walsh) [2110097]
- net: bonding: fix use-after-free after 802.3ad slave unbind (Jonathan Toppins) [2109349]
- net: bonding: fix possible NULL deref in rlb code (Jonathan Toppins) [2109349]
- bonding: guard ns_targets by CONFIG_IPV6 (Jonathan Toppins) [2109349]
- bonding: show NS IPv6 targets in proc master info (Jonathan Toppins) [2109349]
- bonding: NS target should accept link local address (Jonathan Toppins) [2109349]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2109349]
- usb: chipidea: udc: check request status before setting device address (Torez Smith) [2084667]
- USB: gadget: Fix double-free bug in raw_gadget driver (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Meteor Lake xHCI (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Raptor Lake xHCI (Torez Smith) [2084667]
- xhci: turn off port power in shutdown (Torez Smith) [2084667]
- xhci: Keep interrupt disabled in initialization until host is running. (Torez Smith) [2084667]
- USB: serial: option: add Quectel RM500K module support (Torez Smith) [2084667]
- USB: serial: option: add Quectel EM05-G modem (Torez Smith) [2084667]
- USB: serial: pl2303: add support for more HXN (G) types (Torez Smith) [2084667]
- usb: typec: wcove: Drop wrong dependency to INTEL_SOC_PMIC (Torez Smith) [2084667]
- usb: gadget: uvc: fix list double add in uvcg_video_pump (Torez Smith) [2084667]
- dt-bindings: usb: ehci: Increase the number of PHYs (Torez Smith) [2084667]
- dt-bindings: usb: ohci: Increase the number of PHYs (Torez Smith) [2084667]
- usb: gadget: Fix non-unique driver names in raw-gadget driver (Torez Smith) [2084667]
- USB: serial: option: add Telit LE910Cx 0x1250 composition (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->ep safe in ffs_epfile_io() (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->status safe in ffs_epfile_io() (Torez Smith) [2084667]
- xhci: Fix null pointer dereference in resume if xhci has only one roothub (Torez Smith) [2084667]
- USB: fixup for merge issue with "usb: dwc3: Don't switch OTG -> peripheral if extcon is present" (Torez Smith) [2084667]
- usb: cdnsp: Fixed setting last_trb incorrectly (Torez Smith) [2084667]
- usb: gadget: u_ether: fix regression in setting fixed MAC address (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: Fix refcount leak in lpc32xx_udc_probe (Torez Smith) [2084667]
- usb: dwc2: Fix memory leak in dwc2_hcd_init (Torez Smith) [2084667]
- usb: dwc3: gadget: Fix IN endpoint max packet size allocation (Torez Smith) [2084667]
- docs: usb: fix literal block marker in usbmon verification example (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV31 with new baseline (Torez Smith) [2084667]
- USB: serial: io_ti: add Agilent E5805A support (Torez Smith) [2084667]
- dt-bindings: reset: update st,stih407-powerdown.yaml references (Torez Smith) [2084667]
- dt-bindings: Update QCOM USB subsystem maintainer information (Torez Smith) [2084667]
- dt-bindings: usb: snps,dwc3: Add missing 'dma-coherent' property (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: fix a NULL vs IS_ERR() check in probe (Torez Smith) [2084667]
- USB: new quirk for Dell Gen 2 devices (Torez Smith) [2084667]
- tty: remove CMSPAR ifdefs (Torez Smith) [2084667]
- usb: dwc3: core: Add error log when core soft reset failed (Torez Smith) [2084667]
- usb: dwc3: gadget: Move null pinter check to proper place (Torez Smith) [2084667]
- usb: hub: Simplify error and success path in port_over_current_notify (Torez Smith) [2084667]
- usb: cdns3: allocate TX FIFO size according to composite EP number (Torez Smith) [2084667]
- usb: dwc3: Fix ep0 handling when getting reset while doing control transfer (Torez Smith) [2084667]
- usb: Probe EHCI, OHCI controllers asynchronously (Torez Smith) [2084667]
- usb: isp1760: Fix out-of-bounds array access (Torez Smith) [2084667]
- xhci: Don't defer primary roothub registration if there is only one roothub (Torez Smith) [2084667]
- USB: serial: option: add Quectel BG95 modem (Torez Smith) [2084667]
- USB: serial: pl2303: fix type detection for odd device (Torez Smith) [2084667]
- dt-bindings: usb: ci-hdrc-usb2: fix node node for ethernet controller (Torez Smith) [2084667]
- media: stkwebcam: move stk_camera_read_reg() scratch buffer to struct stk_camera (Torez Smith) [2084667]
- media: pvrusb2: fix array-index-out-of-bounds in pvr2_i2c_core_init (Torez Smith) [2084667]
- media: gspca: make the read-only array table static const (Torez Smith) [2084667]
- usb: xhci-mtk: remove bandwidth budget table (Torez Smith) [2084667]
- usb: xhci-mtk: fix fs isoc's transfer error (Torez Smith) [2084667]
- usb: gadget: fix race when gadget driver register via ioctl (Torez Smith) [2084667]
- usb: typec: tcpci_mt6360: Update for BMC PHY setting (Torez Smith) [2084667]
- xhci: Allow host runtime PM as default for Intel Alder Lake N xHCI (Torez Smith) [2084667]
- xhci: Remove quirk for over 10 year old evaluation hardware (Torez Smith) [2084667]
- xhci: prevent U2 link power state if Intel tier policy prevented U1 (Torez Smith) [2084667]
- xhci: use generic command timer for stop endpoint commands. (Torez Smith) [2084667]
- usb: host: xhci-plat: omit shared hcd if either root hub has no ports (Torez Smith) [2084667]
- usb: host: xhci-plat: prepare operation w/o shared hcd (Torez Smith) [2084667]
- usb: host: xhci-plat: create shared hcd after having added main hcd (Torez Smith) [2084667]
- xhci: prepare for operation w/o shared hcd (Torez Smith) [2084667]
- xhci: factor out parts of xhci_gen_setup() (Torez Smith) [2084667]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2084667]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2084667]
- usb: host: ehci-xilinx: adding description for return value (Torez Smith) [2084667]
- usb: gadget: udc: Remove useless variable assignment in xudc_read_fifo() (Torez Smith) [2084667]
- USB: c67x00: remove unnecessary check of res (Torez Smith) [2084667]
- usb: host: ehci-xilinx: Fix quoted string split across lines (Torez Smith) [2084667]
- USB / dwc3: Fix a checkpatch warning in core.c (Torez Smith) [2084667]
- thunderbolt: Add KUnit test for devices with no DisplayPort adapters (Torez Smith) [2084667]
- thunderbolt: Fix buffer allocation of devices with no DisplayPort adapters (Torez Smith) [2084667]
- USB: gadget: Add ID numbers to gadget names (Torez Smith) [2084667]
- media: uvcvideo: Add UVC_GUID_FORMAT_H265 (Torez Smith) [2084667]
- media: uvcvideo: Undup use uvc_endpoint_max_bpi() code (Torez Smith) [2084667]
- media: uvcvideo: Simplify uvc_endpoint_max_bpi() (Torez Smith) [2084667]
- media: uvcvideo: Fix memory leak if uvc_ctrl_add_mapping fails (Torez Smith) [2084667]
- media: uvcvideo: Fix bit overflow in uvc_probe_video (Torez Smith) [2084667]
- media: uvcvideo: Fix missing check to determine if element is found in list (Torez Smith) [2084667]
- media: docs: media: uvcvideo: Use linux-media mailing list (Torez Smith) [2084667]
- usb: gadget: uvc: allow for application to cleanly shutdown (Torez Smith) [2084667]
- usb: typec: tcpci: Don't skip cleanup in .remove() on error (Torez Smith) [2084667]
- usb: cdc-wdm: fix reading stuck on device close (Torez Smith) [2084667]
- usb: gadget: uvc: track frames in format entries (Torez Smith) [2084667]
- usb: gadget: uvc: move structs to common header (Torez Smith) [2084667]
- usb: gadget: uvc: prevent index variables to start from 0 (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: fix clock matching (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: add IPQ8074, MSM8994, QCS404 and SM6125 (Torez Smith) [2084667]
- usb: dwc3: gadget: Delay issuing End Transfer (Torez Smith) [2084667]
- usb: dwc3: gadget: Only End Transfer for ep0 data phase (Torez Smith) [2084667]
- usb: dwc3: ep0: Don't prepare beyond Setup stage (Torez Smith) [2084667]
- usb: dwc3: gadget: Don't modify GEVNTCOUNT in pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Refactor pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Prevent repeat pullup() (Torez Smith) [2084667]
- usb: dwc3: xilinx: Add gpio-reset support (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-xilinx: add optional property reset-gpios (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add binding for SDX65 (Torez Smith) [2084667]
- dt-bindings: usb: da8xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- dt-bindings: usb: am33xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- usb: dwc3: remove a possible unnecessary 'out of memory' message (Torez Smith) [2084667]
- usb: dwc3: host: Stop setting the ACPI companion (Torez Smith) [2084667]
- usb: core: acpi: Use the sysdev pointer instead of controller device (Torez Smith) [2084667]
- dt-bindings: usb: mediatek,mtu3: add binding for MT8195 SoC (Torez Smith) [2084667]
- usb: ehci-omap: drop unused ehci_read() function (Torez Smith) [2084667]
- USB: gadget: Fix return of -EBUSY (Torez Smith) [2084667]
- usb: dwc2: gadget: don't reset gadget's driver->bus (Torez Smith) [2084667]
- USB: serial: qcserial: add support for Sierra Wireless EM7590 (Torez Smith) [2084667]
- USB: serial: ftdi_sio: clean up printk format specifier (Torez Smith) [2084667]
- USB: serial: option: add Fibocom MA510 modem (Torez Smith) [2084667]
- USB: serial: option: add Fibocom L610 modem (Torez Smith) [2084667]
- USB: serial: pl2303: add device id for HP LM930 Display (Torez Smith) [2084667]
- thunderbolt: Add support for XDomain lane bonding (Torez Smith) [2084667]
- thunderbolt: Ignore port locked error in tb_port_wait_for_link_width() (Torez Smith) [2084667]
- thunderbolt: Split setting link width and lane bonding into own functions (Torez Smith) [2084667]
- thunderbolt: Move tb_port_state() prototype to correct place (Torez Smith) [2084667]
- thunderbolt: Add debug logging when lane is enabled/disabled (Torez Smith) [2084667]
- Revert "usb: misc: Add onboard_usb_hub driver" (Torez Smith) [2084667]
- Revert "usb: core: hcd: Create platform devices for onboard hubs in probe()" (Torez Smith) [2084667]
- thunderbolt: Link USB4 ports to their USB Type-C connectors (Torez Smith) [2084667]
- thunderbolt: Make iommu_dma_protection more accurate (Torez Smith) [2084667]
- iommu: Add capability for pre-boot DMA protection (Torez Smith) [2084667]
- iommu: Introduce device_iommu_capable() (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: Map the mailbox with memremap() (Torez Smith) [2084667]
- usb: phy: generic: Get the vbus supply (Torez Smith) [2084667]
- usb: dwc3: gadget: Return proper request status (Torez Smith) [2084667]
- usb: core: hcd: Create platform devices for onboard hubs in probe() (Torez Smith) [2084667]
- usb: misc: Add onboard_usb_hub driver (Torez Smith) [2084667]
- USB: gadget: Add a new bus for gadgets (Torez Smith) [2084667]
- USB: gadget: Fix mistakes in UDC core kerneldoc (Torez Smith) [2084667]
- USB: gadget: Register udc before gadget (Torez Smith) [2084667]
- USB: gadget: Rename usb_gadget_probe_driver() (Torez Smith) [2084667]
- usb: core: devices: drop redundant buffer overflow checks (Torez Smith) [2084667]
- dt-bindings: usb: generic-ohci: Add HPE GXP ohci binding (Torez Smith) [2084667]
- usb: Enable various new TypeC drivers. (Torez Smith) [2084667]
- dt-bindings: usb: generic-ehci: Add HPE GXP ehci binding (Torez Smith) [2084667]
- usb: typec: mux: Add On Semi fsa4480 driver (Torez Smith) [2084667]
- dt-bindings: usb: Add binding for fcs,fsa4480 (Torez Smith) [2084667]
- usb: typec: mux: Allow multiple mux_devs per mux (Torez Smith) [2084667]
- usb: typec: mux: Introduce indirection (Torez Smith) [2084667]
- usb: typec: mux: Check dev_set_name() return value (Torez Smith) [2084667]
- device property: Add helper to match multiple connections (Torez Smith) [2084667]
- usb: dwc3: pci: add support for the Intel Meteor Lake-P (Torez Smith) [2084667]
- usb: typec: ucsi: Wait for the USB role switches (Torez Smith) [2084667]
- usb: typec: ucsi: add a common function ucsi_unregister_connectors() (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2UL bindings (Torez Smith) [2084667]
- testusb: Fix warning comparing pointer to 0 (Torez Smith) [2084667]
- USB: hcd-pci: Fully suspend across freeze/thaw cycle (Torez Smith) [2084667]
- usb: deprecate the third argument of usb_maxpacket() (Torez Smith) [2084667]
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking (Torez Smith) [2084667]
- USB: core: Disable remote wakeup for freeze/quiesce (Torez Smith) [2084667]
- drivers: usb: host: Fix deadlock in oxu_bus_suspend() (Torez Smith) [2084667]
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using giveback (Torez Smith) [2084667]
- usb: dwc3: EP clear halt leading to clearing of delayed_status (Torez Smith) [2084667]
- usb: dwc3: core: Only handle soft-reset in DCTL (Torez Smith) [2084667]
- usb: dwc3: Don't switch OTG -> peripheral if extcon is present (Torez Smith) [2084667]
- usb: gadget: configfs: clear deactivation flag in configfs_composite_unbind() (Torez Smith) [2084667]
- usb: misc: eud: Fix an error handling path in eud_probe() (Torez Smith) [2084667]
- usb: musb: mediatek: Use clk_bulk API to simplify clock operations (Torez Smith) [2084667]
- USB: dwc2: Add OTG support for Ingenic SoCs. (Torez Smith) [2084667]
- dt-bindings: dwc2: Add bindings for new Ingenic SoCs. (Torez Smith) [2084667]
- usb: gadget: net2272: clean up comments (Torez Smith) [2084667]
- usb: core: devices: remove dead code under #ifdef PROC_EXTRA (Torez Smith) [2084667]
- USB: omap_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: clean up comments (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: clean up comments (Torez Smith) [2084667]
- usb: musb: Fix missing of_node_put() in omap2430_probe (Torez Smith) [2084667]
- usb: gadget: f_acm: add support for USB_CDC_REQ_SEND_BREAK (Torez Smith) [2084667]
- usb: dwc3: gadget: increase tx fifo size for ss isoc endpoints (Torez Smith) [2084667]
- usb: host: ohci-omap: Make it CCF clk API compatible (Torez Smith) [2084667]
- usb: gadget: omap_udc: Make it CCF clk API compatible (Torez Smith) [2084667]
- USB / dwc3: Fix three doc-build warnings (Torez Smith) [2084667]
- usb: core: Don't hold the device lock while sleeping in do_proc_control() (Torez Smith) [2084667]
- usb: dwc3: Try usb-role-switch first in dwc3_drd_init (Torez Smith) [2084667]
- usb: dwc3: core: Fix tx/rx threshold settings (Torez Smith) [2084667]
- usb: mtu3: fix USB 3.0 dual-role-switch from device to host (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: add missing required reg (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: include usb-hcd schema (Torez Smith) [2084667]
- USB: storage: karma: fix rio_karma_init return (Torez Smith) [2084667]
- usb: gadget: net2280: use swap() instead of open coding it (Torez Smith) [2084667]
- usb: gadget: u_audio: clean up some inconsistent indenting (Torez Smith) [2084667]
- USB: host: isp116x: check return value after calling platform_get_resource() (Torez Smith) [2084667]
- usb:oxu210hp-hcd: Use platform_get_irq() to get the interrupt (Torez Smith) [2084667]
- usb-storage: isd200: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: shuttle_usbat: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: alauda: fix initFunction error return (Torez Smith) [2084667]
- usb: Prepare cleanup of powerpc's asm/prom.h (Torez Smith) [2084667]
- usb: usbip: add missing device lock on tweak configuration cmd (Torez Smith) [2084667]
- usb: usbip: fix a refcount leak in stub_probe() (Torez Smith) [2084667]
- xhci: Enable runtime PM on second Alderlake controller (Torez Smith) [2084667]
- usb: dwc3: fix backwards compat with rockchip devices (Torez Smith) [2084667]
- usb: misc: fix improper handling of refcount in uss720_probe() (Torez Smith) [2084667]
- USB: Fix ehci infinite suspend-resume loop issue in zhaoxin (Torez Smith) [2084667]
- usb: typec: tcpm: Fix undefined behavior due to shift overflowing the constant (Torez Smith) [2084667]
- usb: typec: rt1719: Fix build error without CONFIG_POWER_SUPPLY (Torez Smith) [2084667]
- usb: typec: ucsi: Fix role swapping (Torez Smith) [2084667]
- usb: typec: ucsi: Fix reuse of completion structure (Torez Smith) [2084667]
- usb: xhci: tegra:Fix PM usage reference leak of tegra_xusb_unpowergate_partitions (Torez Smith) [2084667]
- drivers: usb: dwc3: Add AM62 USB wrapper driver (Torez Smith) [2084667]
- dt-bindings: usb: Add documentation for AM62 USB Wrapper module (Torez Smith) [2084667]
- usb: typec: tipd: Only update power status on IRQ (Torez Smith) [2084667]
- usb: typec: mux: intel_pmc_mux: Add retry logic to a PMC command (Torez Smith) [2084667]
- usb: gadget: uvc: improve sg exit condition (Torez Smith) [2084667]
- usb: gadget: uvc: giveback vb2 buffer on req complete (Torez Smith) [2084667]
- usb: gadget: uvc: rework uvcg_queue_next_buffer to uvcg_complete_buffer (Torez Smith) [2084667]
- usb: gadget: uvc: remove pause flag use (Torez Smith) [2084667]
- usb: gadget: uvc: allow changing interface name via configfs (Torez Smith) [2084667]
- ARM: omap: dma: make usb support optional (Torez Smith) [2084667]
- ARM: omap1: innovator: move ohci phy power handling to board file (Torez Smith) [2084667]
- usb: omap: avoid mach/*.h headers (Torez Smith) [2084667]
- ARM: omap1: move mach/usb.h to include/linux/soc (Torez Smith) [2084667]
- USB: serial: whiteheat: fix heap overflow in WHITEHEAT_GET_DTR_RTS (Torez Smith) [2084667]
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB (Torez Smith) [2084667]
- usb: gadget: uvc: Fix crash when encoding data for usb request (Torez Smith) [2084667]
- thunderbolt: Use different lane for second DisplayPort tunnel (Torez Smith) [2084667]
- thunderbolt: Dump path config space entries during discovery (Torez Smith) [2084667]
- thunderbolt: Use decimal number with port numbers (Torez Smith) [2084667]
- thunderbolt: Fix typo in comment (Torez Smith) [2084667]
- media: dvb-usb: dib0700_devices: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mc: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mb: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp7045: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp702x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: umt-010: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: ttusb2: use an enum for the device number (Torez Smith) [2084667]
- media: technisat-usb2: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: pctv452e: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: opera1: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: nova-t-usb2: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: m920x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: gp8psk: use an enum for the device number (Torez Smith) [2084667]
- media: dw2102: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dtv5100: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: dtt200u: use an enum for the device number (Torez Smith) [2084667]
- media: digitv: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cxusb: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cinergyT2-core: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: az6027: use an enum for the device number (Torez Smith) [2084667]
- media: af9005: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: a800: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: Add helper macros for using USB VID/PID (Torez Smith) [2084667]
- media: dvb-usb: vp702x: reference to usb ID table (Torez Smith) [2084667]
- media: dvb-usb: move USB IDs to dvb-usb-ids.h (Torez Smith) [2084667]
- media: dvb-usb-ids.h: sort entries (Torez Smith) [2084667]
- USB: quirks: add STRING quirk for VCOM device (Torez Smith) [2084667]
- USB: quirks: add a Realtek card reader (Torez Smith) [2084667]
- cdc_ether: export usbnet_cdc_zte_rx_fixup (Torez Smith) [2084667]
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075 compositions (Torez Smith) [2084667]
- usb: cdns3: Fix issue for clear halt endpoint (Torez Smith) [2084667]
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to 500ms (Torez Smith) [2084667]
- xhci: stop polling roothubs after shutdown (Torez Smith) [2084667]
- USB: Fix xhci event ring dequeue pointer ERDP update issue (Torez Smith) [2084667]
- thunderbolt: test: use NULL macros (Torez Smith) [2084667]
- thunderbolt: Replace usage of found with dedicated list iterator variable (Torez Smith) [2084667]
- usb: gadget: fsl_qe_udc: Add missing semicolon in qe_ep_dequeue() (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add compatible for mt8186 (Torez Smith) [2084667]
- usb: dwc3: Issue core soft reset before enabling run/stop (Torez Smith) [2084667]
- usb: gadget: Makefile: remove ccflags-y (Torez Smith) [2084667]
- USB: usb-storage: Fix use of bitfields for hardware data in ene_ub6250.c (Torez Smith) [2084667]
- usb: gadget: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- usb: usbip: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- xen/usb: harden xen_hcd against malicious backends (Torez Smith) [2084667]
- usb: dwc3: gadget: Wait for ep0 xfers to complete during dequeue (Torez Smith) [2084667]
- usb: dwc3: gadget: move cmd_endtransfer to extra function (Torez Smith) [2084667]
- usb: dwc3: gadget: ep_queue simplify isoc start condition (Torez Smith) [2084667]
- xen/usb: don't use arbitrary_virt_to_machine() (Torez Smith) [2084667]
- usb: common: usb-conn-gpio: Make VBUS supply completely optional (Torez Smith) [2084667]
- USB: storage: ums-realtek: fix error code in rts51x_read_mem() (Torez Smith) [2084667]
- usb: early: xhci-dbc: Fix xdbc number parsing (Torez Smith) [2084667]
- usb: early: xhci-dbc: Remove duplicate keep parsing (Torez Smith) [2084667]
- usb: gadget: udc: s3c2410: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: dummy_hcd: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: composite: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: replace usage of rc to check if a list element was found (Torez Smith) [2084667]
- usb: gadget: composite: remove check of list iterator against head past the loop body (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: udc: max3420_udc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: legacy: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: configfs: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: aspeed: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc-xilinx: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: omap_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: net2280: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: net2272: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: mv_udc_core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: mv_u3d: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: gr_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: goku_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: at91: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: pxa25x: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: atmel: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: bdc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: fsl: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: dwc3: pci: Add support for Intel Alder Lake (Torez Smith) [2084667]
- usb: dwc3: omap: fix "unbalanced disables for smps10_out1" on omap5evm (Torez Smith) [2084667]
- usb: dwc3: gadget: Give some time to schedule isoc (Torez Smith) [2084667]
- usb: dwc3: core: do not use 3.0 clock when operating in 2.0 mode (Torez Smith) [2084667]
- dt-bindings: usb: add rk3568 compatible to rockchip, dwc3 (Torez Smith) [2084667]
- usb: dwc3: imx8mp: Add support for setting SOC specific flags (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-imx8mp: Add imx8mp specific flags (Torez Smith) [2084667]
- usb: dwc3: imx8mp: rename iomem base pointer (Torez Smith) [2084667]
- usb: dwc3-meson-g12a: constify drvdata structs (Torez Smith) [2084667]
- usb: raw-gadget: return -EINVAL if no proper ep address available (Torez Smith) [2084667]
- dt-bindings: usb: hcd: correct usb-device path (Torez Smith) [2084667]
- usb: raw-gadget: use kzalloc (Torez Smith) [2084667]
- usb: gadget: udc: fix typos in comments (Torez Smith) [2084667]
- media: xc2028: rename the driver from tuner-xc2028 (Torez Smith) [2084667]
- USB: serial: usb_wwan: remove redundant assignment to variable i (Torez Smith) [2084667]
- USB: serial: pl2303: fix GS type detection (Torez Smith) [2084667]
- media: hdpvr: initialize dev->worker at hdpvr_register_videodev (Torez Smith) [2084667]
- media: stk1160: use dma_alloc_noncontiguous API (Torez Smith) [2084667]
- media: stk1160: move transfer_buffer and urb to same struct 'stk1160_urb' (Torez Smith) [2084667]
- media: stk1160: If start stream fails, return buffers with VB2_BUF_STATE_QUEUED (Torez Smith) [2084667]
- media: stk1160: fix number of buffers in case not all buffers are created (Torez Smith) [2084667]
- media: Revert "media: em28xx: add missing em28xx_close_extension" (Torez Smith) [2084667]
- thunderbolt: Rename EEPROM handling bits to match USB4 spec (Torez Smith) [2084667]
- thunderbolt: Clarify register definitions for `tb_cap_plug_events` (Torez Smith) [2084667]
- USB: serial: pl2303: add IBM device IDs (Torez Smith) [2084667]
- usb: host: xhci: Remove some unnecessary return value initializations (Torez Smith) [2084667]
- usb: host: xhci: add blank line in xhci_halt() (Torez Smith) [2084667]
- usb: host: xhci: update hci_version operation in xhci_gen_setup() (Torez Smith) [2084667]
- usb: host: xhci: fix a comment typo in xhci_mem_init() (Torez Smith) [2084667]
- usb: host: xhci: use ffs() in xhci_mem_init() (Torez Smith) [2084667]
- xhci: fix runtime PM imbalance in USB2 resume (Torez Smith) [2084667]
- xhci: fix uninitialized string returned by xhci_decode_ctrl_ctx() (Torez Smith) [2084667]
- xhci: fix garbage USBSTS being logged in some cases (Torez Smith) [2084667]
- xhci: make xhci_handshake timeout for xhci_reset() adjustable (Torez Smith) [2084667]
- usb: typec: tipd: Forward plug orientation to typec subsystem (Torez Smith) [2084667]
- usb: Drop commas after SoC match table sentinels (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: convert to dtschema (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-dwc3: convert to dtschema (Torez Smith) [2084667]
- USB: serial: simple: add Nokia phone driver (Torez Smith) [2084667]
- ACPI: bus: Introduce acpi_bus_for_each_dev() (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add disable-over-current (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add iommus (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: fix compatible of Intel Agilex (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/V2L bindings (Torez Smith) [2084667]
- USB: serial: make use of UART_LCR_WLEN() + tty_get_char_size() (Torez Smith) [2084667]
- USB: core: Update kerneldoc for usb_get_dev() and usb_get_intf() (Torez Smith) [2084667]
- Revert "usb: host: xhci: mvebu: make USB 3.0 PHY optional for Armada 3720" (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add msm8953 compatible (Torez Smith) [2084667]
- usb: misc: USB_QCOM_EUD should depend on ARCH_QCOM (Torez Smith) [2084667]
- xhci: omit mem read just after allocation of trb (Torez Smith) [2084667]
- usb: host: ehci-q: make qtd_fill() return *unsigned int* (Torez Smith) [2084667]
- scsi: usb: Stop using the SCSI pointer (Torez Smith) [2084667]
- scsi: Remove drivers/scsi/scsi.h (Torez Smith) [2084667]
- dt-bindings: usb: do not use deprecated synopsys prefix (Torez Smith) [2084667]
- stkwebcam: add new Asus laptop to upside_down table (Torez Smith) [2084667]
- media: usb: go7007: s2250-board: fix leak in probe() (Torez Smith) [2084667]
- media: gspca: remove redundant assignment of variable n (Torez Smith) [2084667]
- media: go7007: Constify static struct snd_device_ops (Torez Smith) [2084667]
- media: em28xx: initialize refcount before kref_get (Torez Smith) [2084667]
- media: usb: pwc-uncompress: Use struct_size() helper in pwc_decompress() (Torez Smith) [2084667]
- thunderbolt: Drop duplicate NULL checks around nvmem_unregister() (Torez Smith) [2084667]
- usb: dwc3: pci: Also apply Bay Trail GPIO mappings to ulpi-device (Torez Smith) [2084667]
- usb: dwc3: pci: Set "linux,phy_charger_detect" property on some Bay Trail boards (Torez Smith) [2084667]
- usb: dwc3: pci: Set the swnode from inside dwc3_pci_quirks() (Torez Smith) [2084667]
- usb: typec: Support the WUSB3801 port controller (Torez Smith) [2084667]
- usb: typec: Factor out non-PD fwnode properties (Torez Smith) [2084667]
- dt-bindings: usb: Add WUSB3801 Type-C Port Controller (Torez Smith) [2084667]
- usb: xhci: fix minmax.cocci warnings (Torez Smith) [2084667]
- usb: host: xhci: drop redundant checks (Torez Smith) [2084667]
- usb: remove Link Powermanagement (LPM) disable before port reset. (Torez Smith) [2084667]
- xhci: Allocate separate command structures for each LPM command (Torez Smith) [2084667]
- xhci: dbgtty: use IDR to support several dbc instances. (Torez Smith) [2084667]
- xhci: dbc: Don't call dbc_tty_init() on every dbc tty probe (Torez Smith) [2084667]
- xhci: dbc: Rename xhci_dbc_init and xhci_dbc_exit (Torez Smith) [2084667]
- xhci: dbc: create and remove dbc structure in dbgtty driver. (Torez Smith) [2084667]
- xhci: dbc: refactor xhci_dbc_init() (Torez Smith) [2084667]
- usb: dwc3: drd: Don't check against CONFIG_OF (Torez Smith) [2084667]
- usb: host: xhci-mtk: Simplify supplies handling with regulator_bulk (Torez Smith) [2084667]
- media: uvcvideo: Add support for Apple T2-attached FaceTime HD Camera (Torez Smith) [2084667]
- usb: host: ehci-platform: Update brcm, xgs-iproc-ehci workaround (Torez Smith) [2084667]
- usb: host: {e|o}hci-dbg: kill useless 'ret' variable initializers (Torez Smith) [2084667]
- usbip: vudc: Make use of the helper macro LIST_HEAD() (Torez Smith) [2084667]
- usb: ulpi: Add debugfs support (Torez Smith) [2084667]
- usb: misc: eud: Add driver support for Embedded USB Debugger(EUD) (Torez Smith) [2084667]
- bindings: usb: dwc3: Update dwc3 properties for EUD connector (Torez Smith) [2084667]
- usb: typec: rt1719: Add support for Richtek RT1719 (Torez Smith) [2084667]
- dt-bindings: usb: rt1719: Add binding for Richtek RT1719 (Torez Smith) [2084667]
- usb: xhci-mtk: add support ip-sleep wakeup for mt8195 (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add support ip-sleep for mt8195 (Torez Smith) [2084667]
- usb: dwc2: Add platform specific data for Intel's Agilex (Torez Smith) [2084667]
- USB: usbfs: Use a spinlock instead of atomic accesses to tally used memory. (Torez Smith) [2084667]
- usb: ehci: add pci device support for Aspeed platforms (Torez Smith) [2084667]
- usb: dwc3: Program GFLADJ (Torez Smith) [2084667]
- usb: dwc3: Calculate REFCLKPER based on reference clock (Torez Smith) [2084667]
- usb: dwc3: Get clocks individually (Torez Smith) [2084667]
- dt-bindings: usb: dwc3: Deprecate snps,ref-clock-period-ns (Torez Smith) [2084667]
- scsi: usb: storage: Complete the SCSI request directly (Torez Smith) [2084667]
- usb: gadget: f_uac2: Neaten and reduce size of afunc_validate_opts (Torez Smith) [2084667]
- usb: gadget: f_uac2: change maxpctksize/maxpcktsize to wMaxPacketSize (Torez Smith) [2084667]
- thunderbolt: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- thunderbolt: Add internal xHCI connect flows for Thunderbolt 3 devices (Torez Smith) [2084667]
- thunderbolt: Add missing device ID to tb_switch_is_alpine_ridge() (Torez Smith) [2084667]
- thunderbolt: Disable LTTPR on Intel Titan Ridge (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add speed names to bInterval dbg/warn (Torez Smith) [2084667]
- usb: gadget: f_uac2: Optionally determine bInterval for HS and SS (Torez Smith) [2084667]
- usb: gadget: audio: Add HS/SS bInterval params for UAC2 (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add HS/SS bInterval to configfs (Torez Smith) [2084667]
- usb: udc: Fix typo in comment (Torez Smith) [2084667]
- USB: ACPI: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- usb: gadget: f_uac2: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: u_audio: Add suspend call (Torez Smith) [2084667]
- usb: gadget: u_audio: Rate ctl notifies about current srate (0=stopped) (Torez Smith) [2084667]
- usb: gadget: f_uac1: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: f_uac2: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: u_audio: Add capture/playback srate getter (Torez Smith) [2084667]
- usb: gadget: u_audio: Move dynamic srate from params to rtd (Torez Smith) [2084667]
- usb: gadget: u_audio: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget:audio: Replace deprecated macro S_IRUGO (Torez Smith) [2084667]
- usb: gadget: f_mass_storage: Make CD-ROM emulation work with Mac OS-X (Torez Smith) [2084667]
- usb: xhci-mtk: Use struct_size() helper in create_sch_ep() (Torez Smith) [2084667]
- USB: hcd-pci: Use PCI_STD_NUM_BARS when checking standard BARs (Torez Smith) [2084667]
- usb: gadget: f_fs: Use struct_size() and flex_array_size() helpers (Torez Smith) [2084667]
- usb: host: fotg210: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: core: Bail out when port is stuck in reset loop (Torez Smith) [2084667]
- usb: gadget: f_phonet: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: host: xhci-plat: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- dt-bindings: usb: add bindings for microchip mpfs musb (Torez Smith) [2084667]
- scsi: usb: Call scsi_done() directly (Torez Smith) [2084667]
- usb: cdnsp: remove not used temp_64 variables (Torez Smith) [2084667]
- usb: cdnsp: fix cdnsp_decode_trb function to properly handle ret value (Torez Smith) [2084667]
- usb: dwc3: drd: Add support for usb-conn-gpio based usb-role-switch (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Fix control endpoint's definitions (Torez Smith) [2084667]
- usb: gadget: f_serial: Ensure gserial disconnected during unbind (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Do not program SPARAM (Torez Smith) [2084667]
- usb: host: ehci-sched: Use struct_size() in kzalloc() (Torez Smith) [2084667]
- thunderbolt: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- usb: enable Design Ware Drivers (Torez Smith) [2084667]
- tty: serial: define UART_LCR_WLEN() macro (Torez Smith) [2084667]
- media: gspca: make array regs_to_read static const (Torez Smith) [2084667]
- block: Fix handling of offline queues in blk_mq_alloc_request_hctx() (Ming Lei) [2108481]
- nvme: fix RCU hole that allowed for endless looping in multipath round robin (Gopal Tiwari) [2108624]
- vdpa/mlx5: Use consistent RQT size (Cindy Lu) [2063693]
- vdpa/mlx5: add validation for VIRTIO_NET_CTRL_MQ_VQ_PAIRS_SET command (Cindy Lu) [2063693]
- vdpa/mlx5: should verify CTRL_VQ feature exists for MQ (Cindy Lu) [2063693]
- fscache: Avoid ASSERTCMP if two threads race into fscache_disable_cookie (Dave Wysochanski) [2073727]
- blk-mq: don't create hctx debugfs dir until q->debugfs_dir is created (Ming Lei) [2105622]
- redhat: enable CONFIG_MAXLINEAR_GPHY as module (Petr Oros) [2071857]
- net: phy: enhance GPY115 loopback disable function (Petr Oros) [2071857]
- net: phy: add Maxlinear GPY115/21x/24x driver (Petr Oros) [2071857]
- net: phy: add API to read 802.3-c45 IDs (Petr Oros) [2071857]

* Fri Jul 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-137.el9]
- md: fix double free of io_acct_set bioset (Nigel Croxon) [2105293]
- md: Don't set mddev private to NULL in raid0 pers->free (Nigel Croxon) [2105293]
- md: remove most calls to bdevname (Nigel Croxon) [2105293]
- md: protect md_unregister_thread from reentrancy (Nigel Croxon) [2105293]
- md: don't unregister sync_thread with reconfig_mutex held (Nigel Croxon) [2105293]
- md: Replace role magic numbers with defined constants (Nigel Croxon) [2105293]
- md/raid0: Ignore RAID0 layout if the second zone has only one device (Nigel Croxon) [2105293]
- md/raid5: Annotate functions that hold device_lock with __must_hold (Nigel Croxon) [2105293]
- md/raid5-ppl: Annotate with rcu_dereference_protected() (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement access when mddev_lock is held (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement accesses when nr_pending is elevated (Nigel Croxon) [2105293]
- md/raid5: Add __rcu annotation to struct disk_info (Nigel Croxon) [2105293]
- md/raid5: Un-nest struct raid5_percpu definition (Nigel Croxon) [2105293]
- md/raid5: Cleanup setup_conf() error returns (Nigel Croxon) [2105293]
- md: replace deprecated strlcpy & remove duplicated line (Nigel Croxon) [2105293]
- md/bitmap: don't set sb values if can't pass sanity check (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in md_reload_sb (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in does_sb_need_changing (Nigel Croxon) [2105293]
- raid5: introduce MD_BROKEN (Nigel Croxon) [2105293]
- md: Set MD_BROKEN for RAID1 and RAID10 (Nigel Croxon) [2105293]
- raid5: initialize the stripe_head embeeded bios as needed (Nigel Croxon) [2105293]
- raid5-cache: statically allocate the recovery ra bio (Nigel Croxon) [2105293]
- raid5-cache: fully initialize flush_bio when needed (Nigel Croxon) [2105293]
- raid5-ppl: fully initialize the bio in ppl_new_iounit (Nigel Croxon) [2105293]
- md: use msleep() in md_notify_reboot() (Nigel Croxon) [2105293]
- md: raid1/raid10: drop pending_cnt (Nigel Croxon) [2105293]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2101792]
- sfc: fix considering that all channels have TX queues (Íñigo Huguet) [2106076]
- sfc: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2106076]
- NFSv4.1 support for NFS4_RESULT_PRESERVER_UNLINKED (Scott Mayhew) [2066368]
- bpf: Fix request_sock leak in sk lookup helpers (Felix Maurer) [2102742]
- xsk: Fix generic transmit when completion queue reservation fails (Felix Maurer) [2102742]
- xsk: Fix handling of invalid descriptors in XSK TX batching API (Felix Maurer) [2102742]
- xsk: Fix possible crash when multiple sockets are created (Felix Maurer) [2102742]
- xsk: Fix l2fwd for copy mode + busy poll combo (Felix Maurer) [2102742]
- bpf: Support dual-stack sockets in bpf_tcp_check_syncookie (Felix Maurer) [2102742]
- xsk: Fix race at socket teardown (Felix Maurer) [2102742]
- netdevsim: don't overwrite read only ethtool parms (Antoine Tenart) [2101836]
- Bluetooth: btmtksdio: fix possible FW initialization failure (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: fix the reset takes too long (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: Fix kernel oops when sdio suspend. (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: support bluetooth reset mechanism (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix btmtksdio_[drv|fw]_pmctrl() (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: refactor btmtksdio_runtime_[suspend|resume]() (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix bus hang with wrong privilege (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Enable SCO over I2S (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix firmware coredump retrieve (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Support wake on bluetooth (Gopal Tiwari) [2097262]
- Enable MTK BT Support for RHEL (Gopal Tiwari) [2097262]
- redhat: workaround CKI cross compilation for scripts (Jan Stancek) [2101805]
- redhat/configs: Support QAT devices for x86 only (Vladis Dronov) [2040726]
- crypto: qat - expose device config through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - relocate and rename adf_sriov_prepare_restart() (Vladis Dronov) [2040726]
- crypto: qat - change behaviour of adf_cfg_add_key_value_param() (Vladis Dronov) [2040726]
- crypto: qat - expose device state through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - Removes the x86 dependency on the QAT drivers (Vladis Dronov) [2040726]
- crypto: qat - replace get_current_node() with numa_node_id() (Vladis Dronov) [2040726]
- crypto: qat - add support for 401xx devices (Vladis Dronov) [2040726]
- crypto: qat - re-enable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - honor CRYPTO_TFM_REQ_MAY_SLEEP flag (Vladis Dronov) [2040726]
- crypto: qat - add param check for DH (Vladis Dronov) [2040726]
- crypto: qat - add param check for RSA (Vladis Dronov) [2040726]
- crypto: qat - remove dma_free_coherent() for DH (Vladis Dronov) [2040726]
- crypto: qat - fix memory leak in RSA (Vladis Dronov) [2040726]
- crypto: qat - add backlog mechanism (Vladis Dronov) [2040726]
- crypto: qat - refactor submission logic (Vladis Dronov) [2040726]
- crypto: qat - use pre-allocated buffers in datapath (Vladis Dronov) [2040726]
- crypto: qat - set to zero DH parameters before free (Vladis Dronov) [2040726]
- crypto: qat - Fix unsigned function returning negative constant (Vladis Dronov) [2040726]
- crypto: qat - remove line wrapping for pfvf_ops functions (Vladis Dronov) [2040726]
- crypto: qat - use u32 variables in all GEN4 pfvf_ops (Vladis Dronov) [2040726]
- crypto: qat - replace disable_vf2pf_interrupts() (Vladis Dronov) [2040726]
- crypto: qat - leverage the GEN2 VF mask definiton (Vladis Dronov) [2040726]
- crypto: qat - rework the VF2PF interrupt handling logic (Vladis Dronov) [2040726]
- crypto: qat - fix off-by-one error in PFVF debug print (Vladis Dronov) [2040726]
- crypto: qat - fix wording and formatting in code comment (Vladis Dronov) [2040726]
- crypto: qat - test PFVF registers for spurious interrupts on GEN4 (Vladis Dronov) [2040726]
- crypto: qat - add check for invalid PFVF protocol version 0 (Vladis Dronov) [2040726]
- crypto: qat - add missing restarting event notification in VFs (Vladis Dronov) [2040726]
- crypto: qat - remove unnecessary tests to detect PFVF support (Vladis Dronov) [2040726]
- crypto: qat - remove unused PFVF stubs (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded braces (Vladis Dronov) [2040726]
- crypto: qat - fix ETR sources enabled by default on GEN2 devices (Vladis Dronov) [2040726]
- crypto: qat - set COMPRESSION capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - set CIPHER capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - stop using iommu_present() (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf rts_map_msg structures (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf cap_msg structures (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded assignment (Vladis Dronov) [2040726]
- crypto: qat - disable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - enable power management for QAT GEN4 (Vladis Dronov) [2040726]
- crypto: qat - move and rename GEN4 error register definitions (Vladis Dronov) [2040726]
- crypto: qat - add misc workqueue (Vladis Dronov) [2040726]
- crypto: qat - don't cast parameter in bit operations (Vladis Dronov) [2040726]
- crypto: qat - fix access to PFVF interrupt registers for GEN4 (Vladis Dronov) [2040726]
- crypto: qat - fix a signedness bug in get_service_enabled() (Vladis Dronov) [2040726]
- e1000e: Fix possible overflow in LTR decoding (Ken Cox) [2037986]
- e1000e: Print PHY register address when MDI read/write fails (Ken Cox) [2037986]
- e1000e: Correct NVM checksum verification flow (Ken Cox) [2037986]
- e1000e: Fix possible HW unit hang after an s0ix exit (Ken Cox) [2037986 2049953]
- e1000e: Handshake with CSME starts from ADL platforms (Ken Cox) [2037986 2049953]
- e1000e: Separate ADP board type from TGP (Ken Cox) [2037986 2049953]
- e1000e: Fix packet loss on Tiger Lake and later (Ken Cox) [2037986]
- e1000e: Separate TGP board type from SPT (Ken Cox) [2037986]
- e1000e: Remove redundant statement (Ken Cox) [2037986]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037986]
- net: e1000e: solve insmod 'Unknown symbol mutex_lock' error (Ken Cox) [2037986]
- net/e1000e: Fix spelling mistake "The" -> "This" (Ken Cox) [2037986]
- e1000e: Add space to the debug print (Ken Cox) [2037986]
- e1000e: Add support for Lunar Lake (Ken Cox) [2037986]
- e1000e: Additional PHY power saving in S0ix (Ken Cox) [2037986 2049953]
- e1000e: Add polling mechanism to indicate CSME DPG exit (Ken Cox) [2037986 2049953]
- e1000e: Add handshake with the CSME to support S0ix (Ken Cox) [2037986 2049953]
- cpuidle,intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE (Lenny Szubowicz) [2075710]
- intel_idle: Add AlderLake support (Lenny Szubowicz) [2075710]
- intel_idle: Fix SPR C6 optimization (Lenny Szubowicz) [2075710]
- intel_idle: Fix the 'preferred_cstates' module parameter (Lenny Szubowicz) [2075710]
- cpuidle: intel_idle: Update intel_idle() kerneldoc comment (Lenny Szubowicz) [2075710]

* Tue Jul 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-136.el9]
- nfsd: destroy percpu stats counters after reply cache shutdown (Jeffrey Layton) [1998042]
- drivers/base: fix userspace break from using bin_attributes for cpumap and cpulist (Phil Auld) [2107713]
- x86/kexec: fix memory leak of elf header buffer (Tao Liu) [2072422]
- xfs: use setattr_copy to set vfs inode attributes (Pavel Reichl) [2085722]
- xfs: ensure log flush at the end of a synchronous fallocate call (Pavel Reichl) [2085722]
- xfs: set prealloc flag in xfs_alloc_file_space() (Pavel Reichl) [2085722]
- xfs: fallocate() should call file_modified() (Pavel Reichl) [2085722]
- xfs: remove XFS_PREALLOC_SYNC (Pavel Reichl) [2085722]
- ipv4: drop dst in multicast routing path (Guillaume Nault) [2104124]
- net: igmp: respect RCU rules in ip_mc_source() and ip_mc_msfilter() (Guillaume Nault) [2104124]
- net/ipv4/igmp: Use struct_size() helper (Guillaume Nault) [2104124]
- selftests: net: fix nexthop warning cleanup double ip typo (Guillaume Nault) [2104124]
- selftests: net: add delete nexthop route warning test (Guillaume Nault) [2104124]
- net: ipv4: fix route with nexthop object delete warning (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_FLOW in multipath route (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_GATEWAY in multipath route (Guillaume Nault) [2104124]
- bpftool: Enable libbpf's strict mode by default (Yauheni Kaliuta) [2100795]
- irqchip/gicv3: Handle resource request failure consistently (Mark Salter) [2083380]
- genirq: Remove WARN_ON_ONCE() in generic_handle_domain_irq() (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority mask handling (Mark Salter) [2083380]
- irqchip/gic-v3: Refactor ISB + EOIR at ack time (Mark Salter) [2083380]
- irqchip/gic-v3: Ensure pseudo-NMIs have an ISB between ack and handling (Mark Salter) [2083380]
- irqchip/gic-v3: Claim iomem resources (Mark Salter) [2083380]
- irqchip/gic-v3: Relax polling of GIC{R,D}_CTLR.RWP (Mark Salter) [2083380]
- irqchip/gic-v3: Detect LPI invalidation MMIO registers (Mark Salter) [2083380]
- irqchip/gic-v3: Exposes bit values for GICR_CTLR.{IR, CES} (Mark Salter) [2083380]
- irqchip/gic, gic-v3: Prevent GSI to SGI translations (Mark Salter) [2083380]
- irqchip/gic-v3: Fix GICR_CTLR.RWP polling (Mark Salter) [2083380]
- irqchip/gic-v4: Wait for GICR_VPENDBASER.Dirty to clear before descheduling (Mark Salter) [2083380]
- irqchip/gic-v3: Use dsb(ishst) to order writes with ICC_SGI1R_EL1 accesses (Mark Salter) [2083380]
- irqchip/gic-v3-its: Skip HP notifier when no ITS is registered (Mark Salter) [2083380]
- irqchip/gic-v3-its: Reset each ITS's BASERn register before probe (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix build for !SMP (Mark Salter) [2083380]
- irqchip/gic-v4: Disable redistributors' view of the VPE table at boot time (Mark Salter) [2083380]
- irqchip/gic-v2m: Add const to of_device_id (Mark Salter) [2083380]
- irqchip/gic-v3-its: Limit memreserve cpuhp state lifetime (Mark Salter) [2083380]
- irqchip/gic-v3-its: Postpone LPI pending table freeing and memreserve (Mark Salter) [2083380]
- irqchip/gic-v3-its: Give the percpu rdist struct its own flags field (Mark Salter) [2083380]
- irqchip/irq-gic-v3-its.c: Force synchronisation when issuing INVALL (Mark Salter) [2083380]
- irq: remove handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- Documentation: Fix irq-domain.rst build warning (Mark Salter) [2083380]
- Documentation: Update irq_domain.rst with new lookup APIs (Mark Salter) [2083380]
- irq: remove CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: arm64: perform irqentry in entry code (Mark Salter) [2083380]
- irq: add a (temporary) CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: add generic_handle_arch_irq() (Mark Salter) [2083380]
- irq: simplify handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- irqchip/gic: Work around broken Renesas integration (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix potential VPE leak on error (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority comparison when non-secure priorities are used (Mark Salter) [2083380]
- irqchip/gic-v3: Fix selection of partition domain for EPPIs (Mark Salter) [2083380]
- irqchip/gic-v3: Add __gic_get_ppi_index() to find the PPI number from hwirq (Mark Salter) [2083380]
- irqchip/gic-v3: Switch to bitmap_zalloc() (Mark Salter) [2083380]
- irqchip/gic-v2m: Switch to bitmap_zalloc() (Mark Salter) [2083380]

* Thu Jul 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-135.el9]
- PCI/PM: Fix bridge_d3_blacklist[] Elo i2 overwrite of Gigabyte X299 (Myron Stowe) [2015786]
- PCI/PM: Avoid putting Elo i2 PCIe Ports in D3cold (Myron Stowe) [2015786]
- PCI/ACPI: Allow D3 only if Root Port can signal and wake from D3 (Myron Stowe) [2015786]
- thunderbolt: Do not make DROM read success compulsory (Myron Stowe) [2015786]
- thunderbolt: Do not resume routers if UID is not set (Myron Stowe) [2015786]
- thunderbolt: Retry DROM reads for more failure scenarios (Myron Stowe) [2015786]
- PCI: PM: Fix ordering of operations in pci_back_from_sleep() (Myron Stowe) [2015786]
- PCI: PM: Do not call platform_pci_power_manageable() unnecessarily (Myron Stowe) [2015786]
- PCI: PM: Make pci_choose_state() call pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Rearrange pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Simplify acpi_pci_power_manageable() (Myron Stowe) [2015786]
- PCI: PM: Drop struct pci_platform_pm_ops (Myron Stowe) [2015786]
- PCI: ACPI: PM: Do not use pci_platform_pm_ops for ACPI (Myron Stowe) [2015786]
- PCI: PM: Do not use pci_platform_pm_ops for Intel MID PM (Myron Stowe) [2015786]
- driver core: Split device_platform_notify() (Myron Stowe) [2015786]
- software nodes: Split software_node_notify() (Myron Stowe) [2015786]
- PCI: PM: Enable PME if it can be signaled from D3cold (Myron Stowe) [2015786]
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently (Myron Stowe) [2015786]
- PCI: Use pci_update_current_state() in pci_enable_device_flags() (Myron Stowe) [2015786]
- net: tipc: fix possible refcount leak in tipc_sk_create() (Xin Long) [2106046]
- tipc: fix use-after-free Read in tipc_named_reinit (Xin Long) [2106046]
- tipc: check attribute length for bearer name (Xin Long) [2106046]
- nvdimm/blk: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/blk: avoid calling del_gendisk() on early failures (Ming Lei) [2103992]
- nvdimm/btt: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/btt: use goto error labels on btt_blk_init() (Ming Lei) [2103992]
- nvdimm/btt: do not call del_gendisk() if not needed (Ming Lei) [2103992]
- nvdimm/pmem: use add_disk() error handling (Ming Lei) [2103992]
- mmc: block: Add error handling support for add_disk() (Ming Lei) [2103992]
- memstick: mspro_block: Add error handling support for add_disk() (Ming Lei) [2103992]
- netfilter: nf_tables: stricter validation of element data (Florian Westphal) [2104592] {CVE-2022-34918}
- net: openvswitch: fix misuse of the cached connection on tuple changes (Timothy Redaelli) [2104139]
- ethtool: Fix get module eeprom fallback (Davide Caratti) [2103977]
- veth: Add updating of trans_start (Davide Caratti) [2103977]
- selftests: mptcp: Initialize variables to quiet gcc 12 warnings (Davide Caratti) [2103906]
- mptcp: fix conflict with <netinet/in.h> (Davide Caratti) [2103906]
- selftests: mptcp: more stable diag tests (Davide Caratti) [2103906]
- mptcp: fix race on unaccepted mptcp sockets (Davide Caratti) [2103906]
- mptcp: consistent map handling on failure (Davide Caratti) [2103906]
- mptcp: fix shutdown vs fallback race (Davide Caratti) [2103906]
- mptcp: invoke MP_FAIL response when needed (Davide Caratti) [2103906]
- mptcp: introduce MAPPING_BAD_CSUM (Davide Caratti) [2103906]
- mptcp: fix error mibs accounting (Davide Caratti) [2103906]
- selftests: mptcp: add MP_FAIL reset testcase (Davide Caratti) [2103906]
- mptcp: Do not traverse the subflow connection list without lock (Davide Caratti) [2103906]
- mptcp: Check for orphaned subflow before handling MP_FAIL timer (Davide Caratti) [2103906]
- mptcp: stop using the mptcp_has_another_subflow() helper (Davide Caratti) [2103906]
- net: sched: add barrier to fix packet stuck problem for lockless qdisc (Davide Caratti) [2103902]
- net: sched: fixed barrier to prevent skbuff sticking in qdisc backlog (Davide Caratti) [2103902]
- tipc: move bc link creation back to tipc_node_create (Xin Long) [2086388]
- netfilter: nf_tables: replace BUG_ON by element length check (Florian Westphal) [2102148]
- netfilter: nf_log: incorrect offset to network header (Florian Westphal) [2102148]
- netfilter: conntrack: fix crash due to confirmed bit load reordering (Florian Westphal) [2102148]
- netfilter: nft_set_pipapo: release elements in clone from abort path (Florian Westphal) [2102148]
- netfilter: nf_tables: avoid skb access on nf_stolen (Florian Westphal) [2102148]
- netfilter: nf_tables: consolidate rule verdict trace call (Florian Westphal) [2102148]
- netfilter: br_netfilter: do not skip all hooks with 0 priority (Florian Westphal) [2102148]
- netfilter: nft_dynset: restore set element counter when failing to update (Florian Westphal) [2102148]
- selftests: netfilter: correct PKTGEN_SCRIPT_PATHS in nft_concat_range.sh (Florian Westphal) [2102148]
- netfilter: use get_random_u32 instead of prandom (Florian Westphal) [2102148]
- netfilter: nf_tables: bail out early if hardware offload is not supported (Florian Westphal) [2102148]
- netfilter: nf_tables: memleak flow rule from commit path (Florian Westphal) [2102148]
- netfilter: nf_tables: release new hooks on unsupported flowtable flags (Florian Westphal) [2102148]
- netfilter: nf_tables: always initialize flowtable hook list in transaction (Florian Westphal) [2102148]
- netfilter: nf_tables: delete flowtable hooks via transaction list (Florian Westphal) [2102148]
- netfilter: nf_tables: hold mutex on netns pre_exit path (Florian Westphal) [2102148]
- netfilter: conntrack: re-fetch conntrack after insertion (Florian Westphal) [2102148]
- netfilter: flowtable: move dst_check to packet path (Florian Westphal) [2102148]
- netfilter: flowtable: fix TCP flow teardown (Florian Westphal) [2102148]
- netfilter: flowtable: pass flowtable to nf_flow_table_iterate() (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: fix offload with pppoe + vlan (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: skip dst neigh lookup for ppp devices (Florian Westphal) [2102148]
- netfilter: flowtable: fix excessive hw offload attempts after failure (Florian Westphal) [2102148]
- netfilter: nf_nat_h323: eliminate anonymous module_init & module_exit (Florian Westphal) [2102148]
- netfilter: ip6t_rt: fix rt0_hdr parsing in rt_mt6 (Florian Westphal) [2102148]
- netfilter: socket: icmp6: fix use-after-scope (Florian Westphal) [2102148]
- selftests/net: fix section name when using xdp_dummy.o (Hangbin Liu) [2103541]
- selftests/net: enable lo.accept_local in psock_snd test (Hangbin Liu) [2103541]
- tunnels: do not assume mac header is set in skb_tunnel_check_pmtu() (Guillaume Nault) [2101491]
- erspan: do not assume transport header is always set (Guillaume Nault) [2101491]
- ip_gre: test csum_start instead of transport header (Guillaume Nault) [2101491]
- udp_tunnel: Fix end of loop test in udp_tunnel_nic_unregister() (Guillaume Nault) [2101491]
- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd (Paolo Abeni) [2101465]
- tcp: add accessors to read/set tp->snd_cwnd (Paolo Abeni) [2101465]
- ipv6: take care of disable_policy when restoring routes (Hangbin Liu) [2100718]
- mld: respect RCU rules in ip6_mc_source() and ip6_mc_msfilter() (Hangbin Liu) [2100718]
- net/ipv6/mcast: Use struct_size() helper (Hangbin Liu) [2100718]
- gso: do not skip outer ip header in case of ipip and net_failover (Hangbin Liu) [2100718]

* Thu Jul 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-134.el9]
- redhat: fix kernel_variant_package option definition (Herton R. Krzesinski)
- audit: free module name (Richard Guy Briggs) [2100261]
- audit,io_uring,io-wq: call __audit_uring_exit for dummy contexts (Richard Guy Briggs) [2100261]
- certs: Add FIPS selftests (David Howells) [2080044]
- certs: Move load_certificate_list() to be with the asymmetric keys code (David Howells) [2080044]
- scsi: core: Add scsi_done_direct() for immediate completion (Ewan D. Milne) [2094105]
- scsi: core: Rename scsi_mq_done() into scsi_done() and export it (Ewan D. Milne) [2094105]
- scsi: core: Use a structure member to track the SCSI command submitter (Ewan D. Milne) [2094105]

* Wed Jul 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-133.el9]
- lockd: fix nlm_close_files (Jeffrey Layton) [2082816]
- lockd: set fl_owner when unlocking files (Jeffrey Layton) [2082816]
- intel/igb:fix repeated words in comments (Corinna Vinschen) [2037984]
- igb: remove unexpected word "the" (Corinna Vinschen) [2037984]
- igb: Make DMA faster when CPU is active on the PCIe link (Corinna Vinschen) [2037984]
- igb: fix a use-after-free issue in igb_clean_tx_ring (Corinna Vinschen) [2037984]
- igb: Remove duplicate defines (Corinna Vinschen) [2037984]
- igb: skip phy status check where unavailable (Corinna Vinschen) [2037984]
- igb: Convert kmap() to kmap_local_page() (Corinna Vinschen) [2037984]
- igb: zero hwtstamp by default (Corinna Vinschen) [2037984]
- igb: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037984]
- igb: support EXTTS on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: support PEROUT on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: move PEROUT and EXTTS isr logic to separate functions (Corinna Vinschen) [2037984]
- igb: move SDP config initialization to separate function (Corinna Vinschen) [2037984]
- igb: switch to napi_build_skb() (Corinna Vinschen) [2037984]
- igb: remove never changed variable `ret_val' (Corinna Vinschen) [2037984]
- soc: qcom: aoss: Fix missing put_device call in qmp_get (Steve Best) [2100219]
- soc: qcom: aoss: Expose send for generic usecase (Steve Best) [2100219]
- soc: qcom: mdt_loader: be more informative on errors (Steve Best) [2100219]
- soc: qcom: mdt_loader: Split out split-file-loader (Steve Best) [2100219]
- revert remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2100219]
- net: openvswitch: fix parsing of nw_proto for IPv6 fragments (Antoine Tenart) [2101452]
- net: openvswitch: fix misuse of the cached connection on tuple changes (Antoine Tenart) [2101452]
- kasan: fix a missing header include of static_keys.h (Mark Salter) [2070169]
- linkage: Fix issue with missing symbol size (Mark Salter) [2070169]
- arm64: mte: Ensure the cleared tags are visible before setting the PTE (Mark Salter) [2070169]
- arm64: Enable repeat tlbi workaround on KRYO4XX gold CPUs (Mark Salter) [2070169]
- arm64: cpufeature: remove duplicate ID_AA64ISAR2_EL1 entry (Mark Salter) [2070169]
- arm64: vdso: fix makefile dependency on vdso.so (Mark Salter) [2070169]
- arm[64]/memremap: don't abuse pfn_valid() to ensure presence of linear map (Mark Salter) [2070169]
- arm64: mm: fix p?d_leaf() (Mark Salter) [2070169]
- arm64: Add part number for Arm Cortex-A78AE (Mark Salter) [2070169]
- arm64: patch_text: Fixup last cpu should be master (Mark Salter) [2070169]
- cpuidle: PSCI: Move the `has_lpi` check to the beginning of the function (Mark Salter) [2070169]
- docs: sysfs-devices-system-cpu: document "asymm" value for mte_tcf_preferred (Mark Salter) [2070169]
- arm64/mte: Remove asymmetric mode from the prctl() interface (Mark Salter) [2070169]
- arm64/mte: Add userspace interface for enabling asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add hwcap for asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add a little bit of documentation for mte_update_sctlr_user() (Mark Salter) [2070169]
- arm64/mte: Document ABI for asymmetric mode (Mark Salter) [2070169]
- arm64: mte: avoid clearing PSTATE.TCO on entry unless necessary (Mark Salter) [2070169]
- kasan: split kasan_*enabled() functions into a separate header (Mark Salter) [2070169]
- arm64: Add cavium_erratum_23154_cpus missing sentinel (Mark Salter) [2070169]
- irqchip/gic-v3: Workaround Marvell erratum 38545 when reading IAR (Mark Salter) [2070169]
- arm64: drop unused includes of <linux/personality.h> (Mark Salter) [2070169]
- arm64: prevent instrumentation of bp hardening callbacks (Mark Salter) [2070169]
- arm64: cpufeature: Remove cpu_has_fwb() check (Mark Salter) [2070169]
- arm64: atomics: remove redundant static branch (Mark Salter) [2070169]
- arm64: entry: Save some nops when CONFIG_ARM64_PSEUDO_NMI is not set (Mark Salter) [2070169]
- arm64/mm: Drop use_1G_block() (Mark Salter) [2070169]
- arm64: avoid flushing icache multiple times on contiguous HugeTLB (Mark Salter) [2070169]
- arm64/hugetlb: Define __hugetlb_valid_size() (Mark Salter) [2070169]
- arm64/mm: Consolidate TCR_EL1 fields (Mark Salter) [2070169]
- Revert "arm64: Mitigate MTE issues with str{n}cmp()" (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strncmp (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strcmp (Mark Salter) [2070169]
- arm64: cpufeature: Warn if we attempt to read a zero width field (Mark Salter) [2070169]
- arm64: cpufeature: Add missing .field_width for GIC system registers (Mark Salter) [2070169]
- arm64: signal: nofpsimd: Do not allocate fp/simd context when not available (Mark Salter) [2070169]
- arm64: cpufeature: Always specify and use a field width for capabilities (Mark Salter) [2070169]
- arm64: module: remove (NOLOAD) from linker script (Mark Salter) [2070169]
- arm64: clean up symbol aliasing (Mark Salter) [2070169]
- linkage: add SYM_FUNC_ALIAS{,_LOCAL,_WEAK}() (Mark Salter) [2070169]
- arm64: Add support of PAuth QARMA3 architected algorithm (Mark Salter) [2070169]
- arm64: cpufeature: Mark existing PAuth architected algorithm as QARMA5 (Mark Salter) [2070169]
- arm64: cpufeature: Account min_field_value when cheking secondaries for PAuth (Mark Salter) [2070169]
- arm64: insn: add encoders for atomic operations (Mark Salter) [2070169]
- arm64: move AARCH64_BREAK_FAULT into insn-def.h (Mark Salter) [2070169]
- arm64: insn: Generate 64 bit mask immediates correctly (Mark Salter) [2070169]
- arm64: booting.rst: Clarify on requiring non-secure EL2 (Mark Salter) [2070169]
- arm64: fix clang warning about TRAMP_VALIAS (Mark Salter) [2070169]
- arm64: Do not include __READ_ONCE() block in assembly files (Mark Salter) [2070169]
- arm64: kasan: fix include error in MTE functions (Mark Salter) [2070169]
- arm64: Ensure execute-only permissions are not allowed without EPAN (Mark Salter) [2070169]
- arm64: Enable Cortex-A510 erratum 2051678 by default (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2051678 workaround (Mark Salter) [2070169]
- arm64: cpufeature: List early Cortex-A510 parts as having broken dbm (Mark Salter) [2070169]
- arm64: errata: Update ARM64_ERRATUM_[2119858|2224489] with Cortex-X2 ranges (Mark Salter) [2070169]
- arm64: vdso: Fix "no previous prototype" warning (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE trace data corruption (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE invalid prohibited states (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE ignored system register writes (Mark Salter) [2070169]
- arm64: mm: apply __ro_after_init to memory_limit (Mark Salter) [2070169]
- arm64: atomics: lse: Dereference matching size (Mark Salter) [2070169]
- asm-generic: Add missing brackets for io_stop_wc macro (Mark Salter) [2070169]
- arm64: Use correct method to calculate nomap region boundaries (Mark Salter) [2070169]
- arm64: Drop outdated links in comments (Mark Salter) [2070169]
- arm64: errata: Fix exec handling in erratum 1418040 workaround (Mark Salter) [2070169]
- arm64: Unhash early pointer print plus improve comment (Mark Salter) [2070169]
- asm-generic: introduce io_stop_wc() and add implementation for ARM64 (Mark Salter) [2070169]
- arm64: errata: Enable TRBE workaround for write to out-of-range address (Mark Salter) [2070169]
- arm64: errata: Enable workaround for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_WRITE_OUT_OF_RANGE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE write to out-of-range (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TSB_FLUSH_FAILURE (Mark Salter) [2070169]
- arm64: errata: Add workaround for TSB flush failures (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_OVERWRITE_FILL_MODE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- arm64: remove __dma_*_area() aliases (Mark Salter) [2070169]
- docs/arm64: delete a space from tagged-address-abi (Mark Salter) [2070169]
- arm64/fp: Add comments documenting the usage of state restore functions (Mark Salter) [2070169]
- arm64: mm: Use asid feature macro for cheanup (Mark Salter) [2070169]
- arm64: mm: Rename asid2idx() to ctxid2asid() (Mark Salter) [2070169]
- arm64: kexec: reduce calls to page_address() (Mark Salter) [2070169]
- arm64: extable: remove unused ex_handler_t definition (Mark Salter) [2070169]
- arm64: entry: Use SDEI event constants (Mark Salter) [2070169]
- arm64: Simplify checking for populated DT (Mark Salter) [2070169]
- arm64: Ensure that the 'bti' macro is defined where linkage.h is included (Mark Salter) [2070169]
- arm64: Use BTI C directly and unconditionally (Mark Salter) [2070169]
- arm64: Unconditionally override SYM_FUNC macros (Mark Salter) [2070169]
- arm64: Add macro version of the BTI instruction (Mark Salter) [2070169]
- arm64: Enable KCSAN (Mark Salter) [2070169]
- arm64/sve: Minor clarification of ABI documentation (Mark Salter) [2070169]
- arm64/sve: Generalise vector length configuration prctl() for SME (Mark Salter) [2070169]
- arm64/sve: Make sysctl interface for SVE reusable by SME (Mark Salter) [2070169]
- arm64: perf: Support new DT compatibles (Mark Salter) [2070169]
- arm64: perf: Simplify registration boilerplate (Mark Salter) [2070169]
- arm64: perf: Support Denver and Carmel PMUs (Mark Salter) [2070169]
- arm64: atomics: lse: define RETURN ops in terms of FETCH ops (Mark Salter) [2070169]
- arm64: atomics: lse: improve constraints for simple ops (Mark Salter) [2070169]
- arm64: atomics: lse: define ANDs in terms of ANDNOTs (Mark Salter) [2070169]
- arm64: atomics lse: define SUBs in terms of ADDs (Mark Salter) [2070169]
- arm64: atomics: format whitespace consistently (Mark Salter) [2070169]
- arm64/xor: use EOR3 instructions when available (Mark Salter) [2070169]
- arm64: mm: log potential KASAN shadow alias (Mark Salter) [2070169]
- arm64: mm: use die_kernel_fault() in do_mem_abort() (Mark Salter) [2070169]
- arm64: mte: DC {GVA,GZVA} shouldn't be used when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: clear_page() shouldn't use DC ZVA when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: Snapshot thread flags (Mark Salter) [2070169]
- dlm: fix missing lkb refcount handling (Alexander Aring) [2084605]

* Tue Jul 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-132.el9]
- SUNRPC: Don't leak sockets in xs_local_connect() (Jeffrey Layton) [2089430]
- SUNRPC: clean up some inconsistent indenting (Jeffrey Layton) [2089430]
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free() (Jeffrey Layton) [2089430]
- SUNRPC: Don't call connect() more than once on a TCP socket (Jeffrey Layton) [2089430]
- kdump: round up the total memory size to 128M for crashkernel reservation (Tao Liu) [2058040]
- topology/sysfs: Add PPIN in sysfs under cpu topology (Mark Langsdorf) [2067284]
- x86/cpu: Read/save PPIN MSR during initialization (Mark Langsdorf) [2067284]
- x86/cpu: Merge Intel and AMD ppin_init() functions (Mark Langsdorf) [2067284]
- x86/build: Use the proper name CONFIG_FW_LOADER (Mark Langsdorf) [2067252]
- gpio: mockup: Convert to use software nodes (Mark Langsdorf) [2067252]
- of: unittest: update text of expected warnings (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: fix signedness bug in mc146818_get_time() (Mark Langsdorf) [2067284]
- topology/sysfs: get rid of htmldoc warning (Mark Langsdorf) [2067284]
- topology: Fix up build warning in topology_is_visible() (Mark Langsdorf) [2067284]
- arch_topology: Do not set llc_sibling if llc_id is invalid (Mark Langsdorf) [2067284]
- topology/sysfs: Hide PPIN on systems that do not support it. (Mark Langsdorf) [2067284]
- regmap: allow a defined reg_base to be added to every address (Mark Langsdorf) [2067284]
- regmap: add configurable downshift for addresses (Mark Langsdorf) [2067284]
- drivers/base/dd.c : Remove the initial value of the global variable (Mark Langsdorf) [2067284]
- devres: fix typos in comments (Mark Langsdorf) [2067284]
- base: soc: Make soc_device_match() simpler and easier to read (Mark Langsdorf) [2067284]
- driver core: dd: fix return value of __setup handler (Mark Langsdorf) [2067284]
- driver core: Refactor sysfs and drv/bus remove hooks (Mark Langsdorf) [2067284]
- driver core: Refactor multiple copies of device cleanup (Mark Langsdorf) [2067284]
- arch_topology: obtain cpu capacity using information from CPPC (Mark Langsdorf) [2067284]
- PM: core: keep irq flags in device_pm_check_callbacks() (Mark Langsdorf) [2067284]
- PM: sleep: Add device name to suspend_report_result() (Mark Langsdorf) [2067284]
- PM: runtime: Have devm_pm_runtime_enable() handle pm_runtime_dont_use_autosuspend() (Mark Langsdorf) [2067284]
- PM: sleep: wakeup: Fix typos in comments (Mark Langsdorf) [2067284]
- PM: domains: Fix sleep-in-atomic bug caused by genpd_debug_remove() (Mark Langsdorf) [2067284]
- PM: domains: use dev_err_probe() to simplify error handling (Mark Langsdorf) [2067284]
- PM: domains: Prevent power off for parent unless child is in deepest state (Mark Langsdorf) [2067284]
- firmware_loader: EXTRA_FIRMWARE does not support compressed files (Mark Langsdorf) [2067284]
- driver core: cleanup double words comments (Mark Langsdorf) [2067284]
- device property: Don't split fwnode_get_irq*() APIs in the code (Mark Langsdorf) [2067284]
- regmap: irq: cleanup comments (Mark Langsdorf) [2067284]
- platform: use dev_err_probe() in platform_get_irq_byname() (Mark Langsdorf) [2067284]
- devtmpfs: drop redundant fs parameters from internal fs (Mark Langsdorf) [2067284]
- topology/sysfs: Add format parameter to macro defining "show" functions for proc (Mark Langsdorf) [2067284]
- component: Replace most references to 'master' with 'aggregate device' (Mark Langsdorf) [2067284]
- device property: Add fwnode_irq_get_byname (Mark Langsdorf) [2067284]
- regmap-irq: Fix typo in comment (Mark Langsdorf) [2067284]
- driver core: Free DMA range map when device is released (Mark Langsdorf) [2067284]
- regmap-irq: Update interrupt clear register for proper reset (Mark Langsdorf) [2067284]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067284]
- devtmpfs regression fix: reconfigure on each mount (Mark Langsdorf) [2067284]
- regmap: debugfs: Fix indentation (Mark Langsdorf) [2067284]
- regmap: Call regmap_debugfs_exit() prior to _init() (Mark Langsdorf) [2067284]
- driver core: Make bus notifiers in right order in really_probe() (Mark Langsdorf) [2067284]
- driver core: Move driver_sysfs_remove() after driver_sysfs_add() (Mark Langsdorf) [2067284]
- headers/uninline: Uninline single-use function: kobject_has_children() (Mark Langsdorf) [2067284]
- redhat: enable CONFIG_DEVTMPFS_SAFE (Mark Langsdorf) [2067284]
- devtmpfs: mount with noexec and nosuid (Mark Langsdorf) [2067284]
- driver core: Simplify async probe test code by using ktime_ms_delta() (Mark Langsdorf) [2067284]
- kobject: remove kset from struct kset_uevent_ops callbacks (Mark Langsdorf) [2067284]
- driver core: make kobj_type constant. (Mark Langsdorf) [2067284]
- PM: runtime: Simplify locking in pm_runtime_put_suppliers() (Mark Langsdorf) [2067284]
- software node: fix wrong node passed to find nargs_prop (Mark Langsdorf) [2067284]
- driver core: platform: document registration-failure requirement (Mark Langsdorf) [2067284]
- device property: Add fwnode_iomap() (Mark Langsdorf) [2067284]
- device property: Drop fwnode_graph_get_remote_node() (Mark Langsdorf) [2067284]
- device property: Use fwnode_graph_for_each_endpoint() macro (Mark Langsdorf) [2067284]
- device property: Implement fwnode_graph_get_endpoint_count() (Mark Langsdorf) [2067284]
- device property: Fix documentation for FWNODE_GRAPH_DEVICE_DISABLED (Mark Langsdorf) [2067284]
- device property: Fix fwnode_graph_devcon_match() fwnode leak (Mark Langsdorf) [2067284]
- PM: runtime: Add safety net to supplier device release (Mark Langsdorf) [2067284]
- PM: runtime: Capture device status before disabling runtime PM (Mark Langsdorf) [2067284]
- rtc: Check return value from mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: change return values of mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: cmos: take rtc_lock while reading from CMOS (Mark Langsdorf) [2067284]
- device property: Check fwnode->secondary when finding properties (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Move the text into the code (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify the release of devices from find device (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify __auxiliary_driver_register (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify auxiliary_device creation (Mark Langsdorf) [2067284]
- topology/sysfs: rework book and drawer topology ifdefery (Mark Langsdorf) [2067284]
- topology/sysfs: export cluster attributes only if an architectures has support (Mark Langsdorf) [2067284]
- topology/sysfs: export die attributes only if an architectures has support (Mark Langsdorf) [2067284]
- driver core: platform: Make use of the helper function dev_err_probe() (Mark Langsdorf) [2067284]
- device property: Remove device_add_properties() API (Mark Langsdorf) [2067284]
- PCI: Convert to device_create_managed_software_node() (Mark Langsdorf) [2067284]
- driver core: Don't call device_remove_properties() from device_del() (Mark Langsdorf) [2067284]
- arch_topology: Remove unused topology_set_thermal_pressure() and related (Mark Langsdorf) [2067284]
- thermal: cpufreq_cooling: Use new thermal pressure update function (Mark Langsdorf) [2067284]
- arch_topology: Introduce thermal pressure update function (Mark Langsdorf) [2067284]
- regmap: allow to define reg_update_bits for no bus configuration (Mark Langsdorf) [2067284]
- PM: sleep: Fix error handling in dpm_prepare() (Mark Langsdorf) [2067252]
- arch_numa: simplify numa_distance allocation (Mark Langsdorf) [2067252]
- arm64: support page mapping percpu first chunk allocator (Mark Langsdorf) [2067252]
- PM: sleep: Avoid calling put_device() under dpm_list_mtx (Mark Langsdorf) [2067252]
- PM: sleep: Fix runtime PM based cpuidle support (Mark Langsdorf) [2067252]
- PM / wakeirq: support enabling wake-up irq after runtime_suspend called (Mark Langsdorf) [2067252]
- device property: Drop redundant NULL checks (Mark Langsdorf) [2067252]
- PM: sleep: Pause cpuidle later and resume it earlier during system transitions (Mark Langsdorf) [2067252]
- PM: suspend: Do not pause cpuidle in the suspend-to-idle path (Mark Langsdorf) [2067252]
- regmap: spi: Set regmap max raw r/w from max_transfer_size (Mark Langsdorf) [2067252]
- PM: sleep: Do not let "syscore" devices runtime-suspend during system transitions (Mark Langsdorf) [2067252]
- x86/build: Tuck away built-in firmware under FW_LOADER (Mark Langsdorf) [2067252]
- vmlinux.lds.h: wrap built-in firmware support under FW_LOADER (Mark Langsdorf) [2067252]
- firmware_loader: move struct builtin_fw to the only place used (Mark Langsdorf) [2067252]
- x86/microcode: Use the firmware_loader built-in API (Mark Langsdorf) [2067252]
- firmware_loader: remove old DECLARE_BUILTIN_FIRMWARE() (Mark Langsdorf) [2067252]
- firmware_loader: formalize built-in firmware API (Mark Langsdorf) [2067252]
- component: do not leave master devres group open after bind (Mark Langsdorf) [2067252]
- driver core: Provide device_match_acpi_handle() helper (Mark Langsdorf) [2067252]
- regmap: Fix possible double-free in regcache_rbtree_exit() (Mark Langsdorf) [2067252]
- device property: build kunit tests without structleak plugin (Mark Langsdorf) [2067252]
- driver core: Reject pointless SYNC_STATE_ONLY device links (Mark Langsdorf) [2067252]
- firmware_loader: add a sanity check for firmware_request_builtin() (Mark Langsdorf) [2067252]
- firmware_loader: split built-in firmware call (Mark Langsdorf) [2067252]
- firmware_loader: fix pre-allocated buf built-in firmware use (Mark Langsdorf) [2067252]
- drivers/base/component.c: remove superfluous header files from component.c (Mark Langsdorf) [2067252]
- drivers/base/arch_topology.c: remove superfluous header (Mark Langsdorf) [2067252]
- driver core: use NUMA_NO_NODE during device_initialize (Mark Langsdorf) [2067252]
- driver core: Fix possible memory leak in device_link_add() (Mark Langsdorf) [2067252]
- driver core: Add debug logs when fwnode links are added/deleted (Mark Langsdorf) [2067252]
- driver core: Create __fwnode_link_del() helper function (Mark Langsdorf) [2067252]
- driver core: Set deferred probe reason when deferred by driver core (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Add support for FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD (Mark Langsdorf) [2067252]
- driver core: Clarify that dev_err_probe() is OK even w/out -EPROBE_DEFER (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Improve handling of cyclic dependencies (Mark Langsdorf) [2067252]
- driver core: platform: Make use of the helper macro SET_RUNTIME_PM_OPS() (Mark Langsdorf) [2067252]
- PM: base: power: don't try to use non-existing RTC for storing data (Mark Langsdorf) [2067252]
- PM: sleep: core: Avoid setting power.must_resume to false (Mark Langsdorf) [2067252]
- PM: sleep: wakeirq: drop useless parameter from dev_pm_attach_wake_irq() (Mark Langsdorf) [2067252]
- PM: domains: Fix domain attach for CONFIG_PM_OPP=n (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_clk_create helper (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_runtime_enable helper (Mark Langsdorf) [2067252]
- regmap: teach regmap to use raw spinlocks if requested in the config (Mark Langsdorf) [2067252]
- driver core: platform: Remove platform_device_add_properties() (Mark Langsdorf) [2067252]
- PM: domains: Add support for 'required-opps' to set default perf state (Mark Langsdorf) [2067252]
- Revert "media: device property: Call fwnode_graph_get_endpoint_by_id() for fwnode->secondary" (Mark Langsdorf) [2067252]
- device property: Check fwnode->secondary in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2067252]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Mark Langsdorf) [2067252]
- regmap: allow const array for {devm_,}regmap_field_bulk_alloc reg_fields (Mark Langsdorf) [2067252]
- driver: base: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- cacheinfo: clear cache_leaves(cpu) in free_cache_attributes() (Mark Langsdorf) [2067252]
- driver core: Fix error return code in really_probe() (Mark Langsdorf) [2067252]
- firmware: fix theoretical UAF race with firmware cache and resume (Mark Langsdorf) [2067252]
- driver: base: Replace symbolic permissions with octal permissions (Mark Langsdorf) [2067252]
- driver core: Split device_platform_notify() (Mark Langsdorf) [2067252]
- software nodes: Split software_node_notify() (Mark Langsdorf) [2067252]
- regmap: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- regmap: fix the offset of register error log (Mark Langsdorf) [2067252]
- nfs: reexport documentation (Dave Wysochanski) [2006399]

* Mon Jul 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-131.el9]
- scsi: lpfc: Copyright updates for 14.2.0.5 patches (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.5 (Paul Ely) [2102818]
- scsi: lpfc: Remove Menlo/Hornet related code (Paul Ely) [2102818]
- scsi: lpfc: Refactor lpfc_nvmet_prep_abort_wqe() into lpfc_sli_prep_abort_xri() (Paul Ely) [2102818]
- scsi: lpfc: Fix lost NVMe paths during LIF bounce stress test (Paul Ely) [2102818]
- scsi: lpfc: Fix attempted FA-PWWN usage after feature disable (Paul Ely) [2102818]
- scsi: lpfc: Fix possible memory leak when failing to issue CMF WQE (Paul Ely) [2102818]
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in queuecommand after VMID (Paul Ely) [2102818]
- scsi: lpfc: Set PU field when providing D_ID in XMIT_ELS_RSP64_CX iocb (Paul Ely) [2102818]
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with malformed user input (Paul Ely) [2102818]
- scsi: lpfc: Fix uninitialized cqe field in lpfc_nvme_cancel_iocb() (Paul Ely) [2102818]
- scsi: lpfc: Change FA-PWWN detection methodology (Paul Ely) [2102818]
- scsi: lpfc: Remove failing soft_wwn support (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.4 (Paul Ely) [2102818]
- scsi: lpfc: Allow reduced polling rate for nvme_admin_async_event cmd completion (Paul Ely) [2102818]
- scsi: lpfc: Add more logging of cmd and cqe information for aborted NVMe cmds (Paul Ely) [2102818]
- scsi: lpfc: Fix port stuck in bypassed state after LIP in PT2PT topology (Paul Ely) [2102818]
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is aborted (Paul Ely) [2102818]
- scsi: lpfc: Address NULL pointer dereference after starget_to_rport() (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following SLI path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following abort path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in lpfc_ct_reject_event() (Paul Ely) [2102818]
- scsi: lpfc: Add support for ATTO Fibre Channel devices (Paul Ely) [2102818]
- scsi: lpfc: Add support for VMID tagging of NVMe I/Os (Paul Ely) [2102818]
- scsi: lpfc: Rework lpfc_vmid_get_appid() to be protocol independent (Paul Ely) [2102818]
- scsi: lpfc: Commonize VMID code location (Paul Ely) [2102818]
- scsi: nvme-fc: Add new routine nvme_fc_io_getuuid() (Paul Ely) [2102818]
- scsi: target: pscsi: Set SCF_TREAT_READ_AS_NORMAL flag only if there is valid data (Maurizio Lombardi) [2080216]
- x86/speculation/mmio: Print SMT warning (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- KVM: x86/speculation: Disable Fill buffer clear within guests (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/srbds: Update SRBDS mitigation selection (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation: Add a common function for MD_CLEAR mitigation update (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- Documentation: Add documentation for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/tsx: Disable TSX development mode at boot (Waiman Long) [2090254]
- x86/tsx: Use MSR_TSX_CTRL to clear CPUID bits (Waiman Long) [2090254]
- Documentation: Add L1D flushing Documentation (Waiman Long) [2090254]
- x86, prctl: Hook L1D flushing in via prctl (Waiman Long) [2090254]
- x86/mm: Prepare for opt-in based L1D flush in switch_mm() (Waiman Long) [2090254]
- x86/process: Make room for TIF_SPEC_L1D_FLUSH (Waiman Long) [2090254]
- sched: Add task_work callback for paranoid L1D flush (Waiman Long) [2090254]
- x86/mm: Refactor cond_ibpb() to support other use cases (Waiman Long) [2090254]
- cpuidle: psci: Fix regression leading to no genpd governor (Mark Langsdorf) [2067314]
- cpuidle: Factor-out power domain related code from PSCI domain driver (Mark Langsdorf) [2067314]
- cpuidle: haltpoll: Call cpuidle_poll_state_init() later (Mark Langsdorf) [2067314]
- cpuidle: use default_groups in kobj_type (Mark Langsdorf) [2067314]
- cpuidle: Fix cpuidle_remove_state_sysfs() kerneldoc comment (Mark Langsdorf) [2067314]
- cpuidle: menu: Fix typo in a comment (Mark Langsdorf) [2067314]
- cpuidle: Fix kobject memory leaks in error paths (Mark Langsdorf) [2067314]
- Reinstate some of "swiotlb: rework "fix info leak with DMA_FROM_DEVICE"" (Chris von Recklinghausen) [2059703] {CVE-2022-0854}
- swiotlb: fix info leak with DMA_FROM_DEVICE (Chris von Recklinghausen) [2059703] {CVE-2022-0854}

* Fri Jul 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-130.el9]
- scsi: iscsi: Fix session removal on shutdown (Chris Leech) [2101762]
- scsi: qedi: Use QEDI_MODE_NORMAL for error handling (Chris Leech) [2101762]
- scsi: iscsi: Add helper to remove a session from the kernel (Chris Leech) [2101762]
- scsi: iscsi: Clean up bound endpoints during shutdown (Chris Leech) [2101762]
- scsi: iscsi: Allow iscsi_if_stop_conn() to be called from kernel (Chris Leech) [2101762]
- scsi: iscsi: Fix HW conn removal use after free (Chris Leech) [2101762]
- scsi: iscsi: Make iscsi_unregister_transport() return void (Chris Leech) [2101762]
- scsi: core: iscsi: Directly use ida_alloc()/ida_free() (Chris Leech) [2101762]
- scsi: iscsi: Exclude zero from the endpoint ID range (Chris Leech) [2101762]
- scsi: iscsi: Fix harmless double shift bug (Chris Leech) [2101762]
- scsi: libiscsi: Remove unnecessary memset() in iscsi_conn_setup() (Chris Leech) [2101762]
- scsi: libiscsi: Teardown iscsi_cls_conn gracefully (Chris Leech) [2101762]
- scsi: libiscsi: Add iscsi_cls_conn to sysfs after initialization (Chris Leech) [2101762]
- scsi: iscsi: Add helper functions to manage iscsi_cls_conn (Chris Leech) [2101762]
- scsi: iscsi: Drop temp workq_name (Chris Leech) [2101762]
- scsi: iscsi: Use the session workqueue for recovery (Chris Leech) [2101762]
- scsi: iscsi: ql4xxx: Use per-session workqueue for unbinding (Chris Leech) [2101762]
- scsi: iscsi: Remove iscsi_scan_finished() (Chris Leech) [2101762]
- scsi: libiscsi: Fix UAF in iscsi_conn_get_param()/iscsi_conn_teardown() (Chris Leech) [2101762]
- scsi: libiscsi: Move ehwait initialization to iscsi_session_setup() (Chris Leech) [2101762]
- filemap: Fix serialization adding transparent huge pages to page cache (Aristeu Rozanski) [2083861]
- mm/huge_memory: Fix xarray node memory leak (Aristeu Rozanski) [2083861]
- filemap: Cache the value of vm_flags (Aristeu Rozanski) [2083861]
- mm/readahead: Fix readahead with large folios (Aristeu Rozanski) [2083861]
- mm/hwpoison: use pr_err() instead of dump_page() in get_any_page() (Aristeu Rozanski) [2083861]
- XArray: Disallow sibling entries of nodes (Aristeu Rozanski) [2083861]
- tmpfs: fix regressions from wider use of ZERO_PAGE (Aristeu Rozanski) [2083861]
- mm/rmap: Fix handling of hugetlbfs pages in page_vma_mapped_walk (Aristeu Rozanski) [2083861]
- mm/mempolicy: Use vma_alloc_folio() in new_page() (Aristeu Rozanski) [2083861]
- mm: Add vma_alloc_folio() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in migrate_misplaced_transhuge_page() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in alloc_migration_target() (Aristeu Rozanski) [2083861]
- mm/munlock: update Documentation/vm/unevictable-lru.rst (Aristeu Rozanski) [2083861]
- mm/munlock: add lru_add_drain() to fix memcg_stat_test (Aristeu Rozanski) [2083861]
- XArray: Update the LRU list in xas_split() (Aristeu Rozanski) [2083861]
- XArray: Fix xas_create_range() when multi-order entry present (Aristeu Rozanski) [2083861]
- mm: unmap_mapping_range_tree() with i_mmap_rwsem shared (Aristeu Rozanski) [2083861]
- mm: warn on deleting redirtied only if accounted (Aristeu Rozanski) [2083861]
- mm/thp: fix NR_FILE_MAPPED accounting in page_*_file_rmap() (Aristeu Rozanski) [2083861]
- mm: filemap_unaccount_folio() large skip mapcount fixup (Aristeu Rozanski) [2083861]
- mm: delete __ClearPageWaiters() (Aristeu Rozanski) [2083861]
- mm/hugetlb.c: export PageHeadHuge() (Aristeu Rozanski) [2083861]
- mm: rework swap handling of zap_pte_range (Aristeu Rozanski) [2083861]
- mm: change zap_details.zap_mapping into even_cows (Aristeu Rozanski) [2083861]
- mm: rename zap_skip_check_mapping() to should_zap_page() (Aristeu Rozanski) [2083861]
- mm: don't skip swap entry even if zap_details specified (Aristeu Rozanski) [2083861]
- mm: replace multiple dcache flush with flush_dcache_folio() (Aristeu Rozanski) [2083861]
- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte() and __mcopy_atomic() (Aristeu Rozanski) [2083861]
- mm: shmem: fix missing cache flush in shmem_mfill_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in hugetlb_mcopy_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in copy_huge_page_from_user() (Aristeu Rozanski) [2083861]
- mm: fix missing cache flush for all tail pages of compound page (Aristeu Rozanski) [2083861]
- mm: thp: fix wrong cache flush in remove_migration_pmd() (Aristeu Rozanski) [2083861]
- tmpfs: do not allocate pages on read (Aristeu Rozanski) [2083861]
- shmem: mapping_set_exiting() to help mapped resilience (Aristeu Rozanski) [2083861]
- selftests/vm/transhuge-stress: Support file-backed PMD folios (Aristeu Rozanski) [2083861]
- mm/filemap: Support VM_HUGEPAGE for file mappings (Aristeu Rozanski) [2083861]
- mm/readahead: Switch to page_cache_ra_order (Aristeu Rozanski) [2083861]
- mm/readahead: Add large folio readahead (Aristeu Rozanski) [2083861]
- mm: Support arbitrary THP sizes (Aristeu Rozanski) [2083861]
- mm: Make large folios depend on THP (Aristeu Rozanski) [2083861]
- mm: Fix READ_ONLY_THP warning (Aristeu Rozanski) [2083861]
- mm/filemap: Allow large folios to be added to the page cache (Aristeu Rozanski) [2083861]
- mm: Turn can_split_huge_page() into can_split_folio() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert pageout() to take a folio (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_references() into folio_check_references() (Aristeu Rozanski) [2083861]
- mm/vmscan: Account large folios correctly (Aristeu Rozanski) [2083861]
- mm/vmscan: Optimise shrink_page_list for non-PMD-sized folios (Aristeu Rozanski) [2083861]
- mm/vmscan: Free non-shmem folios without splitting them (Aristeu Rozanski) [2083861]
- mm/rmap: Constify the rmap_walk_control argument (Aristeu Rozanski) [2083861]
- mm/rmap: Convert rmap_walk() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn page_anon_vma() into folio_anon_vma() (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_lock_anon_vma_read() into folio_lock_anon_vma_read() (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_young() to use a folio (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_mkold() to use a folio (Aristeu Rozanski) [2083861]
- mm/migrate: Convert remove_migration_ptes() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert make_device_exclusive_range() to use folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_migrate() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_unmap() to take a folio (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_referenced() into folio_referenced() (Aristeu Rozanski) [2083861]
- mm/mlock: Add mlock_vma_folio() (Aristeu Rozanski) [2083861]
- mm/rmap: Use a folio in page_mkclean_one() (Aristeu Rozanski) [2083861]
- mm/page_idle: Convert page_idle_clear_pte_refs() to use a folio (Aristeu Rozanski) [2083861]
- mm: Convert page_vma_mapped_walk to work on PFNs (Aristeu Rozanski) [2083861]
- sparc32: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- powerpc: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- mm: Add DEFINE_PAGE_VMA_WALK and DEFINE_FOLIO_VMA_WALK (Aristeu Rozanski) [2083861]
- mm: Add folio_pgoff() (Aristeu Rozanski) [2083861]
- mm: Add split_folio_to_list() (Aristeu Rozanski) [2083861]
- mm: Add folio_mapcount() (Aristeu Rozanski) [2083861]
- mm: Turn head_compound_mapcount() into folio_entire_mapcount() (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_dirty_writeback() into folio_check_dirty_writeback() (Aristeu Rozanski) [2083861]
- fs: Move many prototypes to pagemap.h (Aristeu Rozanski) [2083861]
- mm/truncate: Combine invalidate_mapping_pagevec() and __invalidate_mapping_pages() (Aristeu Rozanski) [2083861]
- mm: Turn deactivate_file_page() into deactivate_file_folio() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert __invalidate_mapping_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Split invalidate_inode_page() into mapping_evict_folio() (Aristeu Rozanski) [2083861]
- mm: Convert remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Replace page_mapped() call in invalidate_inode_page() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert invalidate_inode_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Inline invalidate_complete_page() into its one caller (Aristeu Rozanski) [2083861]
- splice: Use a folio in page_cache_pipe_buf_try_steal() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert __remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn putback_lru_page() into folio_putback_lru() (Aristeu Rozanski) [2083861]
- mm: Add lru_to_folio() (Aristeu Rozanski) [2083861]
- mm/memcg: Convert mem_cgroup_swapout() to take a folio (Aristeu Rozanski) [2083861]
- mm/workingset: Convert workingset_eviction() to take a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert check_and_migrate_movable_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add three folio wrappers (Aristeu Rozanski) [2083861]
- mm: Turn isolate_lru_page() into folio_isolate_lru() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_range_next() into gup_folio_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_next() into gup_folio_next() (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pgd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pud() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pmd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_hugepte() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_pte_range() to use a folio (Aristeu Rozanski) [2083861]
- mm/hugetlb: Use try_grab_folio() instead of try_grab_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Add gup_put_folio() (Aristeu Rozanski) [2083861]
- mm: Remove page_cache_add_speculative() and page_cache_get_speculative() (Aristeu Rozanski) [2083861]
- mm/gup: Convert try_grab_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Add try_get_folio() and try_grab_folio() (Aristeu Rozanski) [2083861]
- mm: Turn page_maybe_dma_pinned() into folio_maybe_dma_pinned() (Aristeu Rozanski) [2083861]
- mm: Add folio_pincount_ptr() (Aristeu Rozanski) [2083861]
- mm: Make compound_pincount always available (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_sub() (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_add() (Aristeu Rozanski) [2083861]
- mm/gup: Handle page split race more efficiently (Aristeu Rozanski) [2083861]
- mm/gup: Remove an assumption of a contiguous memmap (Aristeu Rozanski) [2083861]
- mm/gup: Fix some contiguous memmap assumptions (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_next() (Aristeu Rozanski) [2083861]
- mm/gup: Optimise compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_range() (Aristeu Rozanski) [2083861]
- mm/gup: Increment the page refcount before the pincount (Aristeu Rozanski) [2083861]
- mm: Convert swap_set_page_dirty() to swap_dirty_folio() (Aristeu Rozanski) [2083861]
- fs: Add aops->dirty_folio (Aristeu Rozanski) [2083861]
- fs: Add aops->launder_folio (Aristeu Rozanski) [2083861]
- fs: Add invalidate_folio() aops method (Aristeu Rozanski) [2083861]
- fs: Turn do_invalidatepage() into folio_invalidate() (Aristeu Rozanski) [2083861]
- buffer: Add folio_buffers() (Aristeu Rozanski) [2083861]
- fs/remap_range: Pass the file pointer to read_mapping_folio() (Aristeu Rozanski) [2083861]
- fs: read_mapping_page() should take a struct file argument (Aristeu Rozanski) [2083861]
- mm: refactor check_and_migrate_movable_pages (Aristeu Rozanski) [2083861]
- mm: don't include <linux/memremap.h> in <linux/mm.h> (Aristeu Rozanski) [2083861]
- mm: simplify freeing of devmap managed pages (Aristeu Rozanski) [2083861]
- mm: move free_devmap_managed_page to memremap.c (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_vma_page() check against VM_SPECIAL (Aristeu Rozanski) [2083861]
- mm: fix use-after-free bug when mm->mmap is reused after being freed (Aristeu Rozanski) [2083861]
- mm/thp: shrink_page_list() avoid splitting VM_LOCKED THP (Aristeu Rozanski) [2083861]
- mm/thp: collapse_file() do try_to_unmap(TTU_BATCH_FLUSH) (Aristeu Rozanski) [2083861]
- mm/munlock: page migration needs mlock pagevec drained (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_page() munlock_page() batch by pagevec (Aristeu Rozanski) [2083861]
- mm/munlock: delete smp_mb() from __pagevec_lru_add_fn() (Aristeu Rozanski) [2083861]
- mm/migrate: __unmap_and_move() push good newpage to LRU (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_pte_range() when mlocking or munlocking (Aristeu Rozanski) [2083861]
- mm/munlock: maintain page->mlock_count while unevictable (Aristeu Rozanski) [2083861]
- mm/munlock: replace clear_page_mlock() by final clearance (Aristeu Rozanski) [2083861]
- mm/munlock: rmap call mlock_vma_page() munlock_vma_page() (Aristeu Rozanski) [2083861]
- mm/munlock: delete munlock_vma_pages_all(), allow oomreap (Aristeu Rozanski) [2083861]
- mm/munlock: delete FOLL_MLOCK and FOLL_POPULATE (Aristeu Rozanski) [2083861]
- mm/munlock: delete page_mlock() and all its works (Aristeu Rozanski) [2083861]
- fs/proc: task_mmu.c: don't read mapcount for migration entry (Aristeu Rozanski) [2083861]
- mm/migrate.c: rework migration_entry_wait() to not take a pageref (Aristeu Rozanski) [2083861]
- filemap: Use folio_put_refs() in filemap_free_folio() (Aristeu Rozanski) [2083861]
- mm: Add folio_put_refs() (Aristeu Rozanski) [2083861]
- mm: drop node from alloc_pages_vma (Aristeu Rozanski) [2083861]
- mm/oom_kill: allow process_mrelease to run under mmap_lock protection (Aristeu Rozanski) [2083861]
- mm: document locking restrictions for vm_operations_struct::close (Aristeu Rozanski) [2083861]
- mm: protect free_pgtables with mmap_lock write lock in exit_mmap (Aristeu Rozanski) [2083861]
- pagevec: Initialise folio_batch->percpu_pvec_drained (Aristeu Rozanski) [2083861]
- mm: Use multi-index entries in the page cache (Aristeu Rozanski) [2083861]
- XArray: Add xas_advance() (Aristeu Rozanski) [2083861]
- truncate,shmem: Handle truncates that split large folios (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range to folios (Aristeu Rozanski) [2083861]
- fs: Convert vfs_dedupe_file_range_compare to folios (Aristeu Rozanski) [2083861]
- mm: Remove pagevec_remove_exceptionals() (Aristeu Rozanski) [2083861]
- mm: Convert find_lock_entries() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Return only folios from find_get_entries() (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Add invalidate_complete_folio2() (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Skip known-truncated indices (Aristeu Rozanski) [2083861]
- truncate,shmem: Add truncate_inode_folio() (Aristeu Rozanski) [2083861]
- shmem: Convert part of shmem_undo_range() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add unmap_mapping_folio() (Aristeu Rozanski) [2083861]
- mm/slub: Convert __free_slab() to use struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert alloc_slab_page() to return a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert print_page_info() to print_slab_info() (Aristeu Rozanski) [2083861]
- mm/slub: Convert kfree() to use a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert detached_freelist to use a struct slab (Aristeu Rozanski) [2083861]
- mm: Convert check_heap_object() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Use struct slab in kmem_obj_info() (Aristeu Rozanski) [2083861]
- mm: Convert __ksize() to struct slab (Aristeu Rozanski) [2083861]
- mm: Convert virt_to_cache() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Convert [un]account_slab_page() to struct slab (Aristeu Rozanski) [2083861]
- mm: Split slab into its own type (Aristeu Rozanski) [2083861]
- truncate: Add truncate_cleanup_folio() (Aristeu Rozanski) [2083861]
- filemap: Add filemap_release_folio() (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_page_mkwrite (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_map_pages (Aristeu Rozanski) [2083861]
- filemap: Use folios in next_uptodate_page (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete_batch to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_pages to use folios (Aristeu Rozanski) [2083861]
- filemap: Drop the refcount while waiting for page lock (Aristeu Rozanski) [2083861]
- filemap: Add read_cache_folio and read_mapping_folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_fault to folio (Aristeu Rozanski) [2083861]
- filemap: Convert do_async_mmap_readahead to take a folio (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_ra_unbounded to folios (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_async_ra() to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_range_uptodate to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_create_page to folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read_page to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_pages_contig to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch to use folios (Aristeu Rozanski) [2083861]
- filemap: Remove thp_contains() (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_entry to return a folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_remove_folio and __filemap_remove_folio (Aristeu Rozanski) [2083861]
- filemap: Convert tracing of page cache operations to folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_unaccount_folio() (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete to take a folio (Aristeu Rozanski) [2083861]
- filemap: Add folio_put_wait_locked() (Aristeu Rozanski) [2083861]
- mm: Add folio_test_pmd_mappable() (Aristeu Rozanski) [2083861]
- iov_iter: Convert iter_xarray to use folios (Aristeu Rozanski) [2083861]
- iov_iter: Add copy_folio_to_iter() (Aristeu Rozanski) [2083861]
- pagevec: Add folio_batch (Aristeu Rozanski) [2083861]
- mm/writeback: Improve __folio_mark_dirty() comment (Aristeu Rozanski) [2083861]
- mm/doc: Add documentation for folio_test_uptodate (Aristeu Rozanski) [2083861]
- fs/writeback: Convert inode_switch_wbs_work_fn to folios (Aristeu Rozanski) [2083861]
- mm: add virt_to_folio() and folio_address() (Aristeu Rozanski) [2083861]
- dax: remove the pgmap sanity checks in generic_fsdax_supported (Aristeu Rozanski) [2083861]
- mm: migrate: simplify the file-backed pages validation when migrating its mapping (Aristeu Rozanski) [2083861]
- mm/rmap.c: avoid double faults migrating device private pages (Aristeu Rozanski) [2083861]
- mm: add zap_skip_check_mapping() helper (Aristeu Rozanski) [2083861]
- mm: drop first_index/last_index in zap_details (Aristeu Rozanski) [2083861]
- mm: clear vmf->pte after pte_unmap_same() returns (Aristeu Rozanski) [2083861]
- mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte (Aristeu Rozanski) [2083861]
- dax: stop using bdevname (Aristeu Rozanski) [2083861]
- bpf: Let bpf_warn_invalid_xdp_action() report more info (Ivan Vecera) [2073454]
- bpf: Do not WARN in bpf_warn_invalid_xdp_action() (Ivan Vecera) [2073454]
- redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel (Herton R. Krzesinski) [2027654]
- scsi: csiostor: Add module softdep on cxgb4 (Rahul Lakkireddy) [1977553]

* Thu Jul 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-129.el9]
- fuse: send security context of inode on file (Vivek Goyal) [2101526]
- fuse: extend init flags (Vivek Goyal) [2101526]
- security, lsm: dentry_init_security() Handle multi LSM registration (Vivek Goyal) [2101526]
- security: Return xattr name from security_dentry_init_security() (Vivek Goyal) [2101526]
- fuse: add FOPEN_NOFLUSH (Vivek Goyal) [2101526]
- net: fix data-race in dev_isalive() (Hangbin Liu) [2101278]
- net: Write lock dev_base_lock without disabling bottom halves. (Hangbin Liu) [2101278]
- net: fix IFF_TX_SKB_NO_LINEAR definition (Hangbin Liu) [2101278]
- sock: redo the psock vs ULP protection check (Hangbin Liu) [2101278]
- net: fix dev_fill_forward_path with pppoe + bridge (Hangbin Liu) [2101278]
- net: Fix features skip in for_each_netdev_feature() (Hangbin Liu) [2101278]
- RDMA/irdma: Add SW mechanism to generate completions on error (Kamal Heib) [2100317]
- RDMA/irdma: Remove the redundant variable (Kamal Heib) [2100317]
- RDMA/irdma: Add support for DSCP (Kamal Heib) [2100317]
- RDMA/irdma: Use irq_update_affinity_hint() (Kamal Heib) [2100317]
- RDMA/irdma: Set protocol based on PF rdma_mode flag (Kamal Heib) [2096127 2100317]
- spec: Keep .BTF section in modules (Viktor Malik) [2097188]
- NFSD: Instantiate a struct file when creating a regular NFSv4 file (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd_open_verified() (Benjamin Coddington) [1905809]
- NFSD: Remove do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv4 OPEN(CREATE) (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv3 CREATE (Benjamin Coddington) [1905809]
- NFSD: Refactor nfsd_create_setattr() (Benjamin Coddington) [1905809]
- NFSD: Avoid calling fh_drop_write() twice in do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd3_proc_create() (Benjamin Coddington) [1905809]
- ext4: fix up test_dummy_encryption handling for new mount API (Lukas Czerner) [2099577]
- ext4: only allow test_dummy_encryption when supported (Lukas Czerner) [2099577]
- fscrypt: add new helper functions for test_dummy_encryption (Lukas Czerner) [2099577]
- fscrypt: factor out fscrypt_policy_to_key_spec() (Lukas Czerner) [2099577]
- ext4: fix super block checksum incorrect after mount (Lukas Czerner) [2099577]
- ext4: fix bug_on ext4_mb_use_inode_pa (Lukas Czerner) [2099577]
- ext4: make variable "count" signed (Lukas Czerner) [2099577]
- ext4: add reserved GDT blocks check (Lukas Czerner) [2099577]
- ext4: fix bug_on in __es_tree_search (Lukas Czerner) [2099577]
- ext4: avoid cycles in directory h-tree (Lukas Czerner) [2099577]
- ext4: verify dir block before splitting it (Lukas Czerner) [2099577]
- ext4: filter out EXT4_FC_REPLAY from on-disk superblock field s_state (Lukas Czerner) [2099577]
- ext4: fix bug_on in ext4_writepages (Lukas Czerner) [2099577]
- ext4: fix memory leak in parse_apply_sb_mount_options() (Lukas Czerner) [2099577]
- ext4: reject the 'commit' option on ext2 filesystems (Lukas Czerner) [2099577]
- ext4: fix race condition between ext4_write and ext4_convert_inline_data (Lukas Czerner) [2099577]
- ext4: fix journal_ioprio mount option handling (Lukas Czerner) [2099577]
- ext4: mark group as trimmed only if it was fully scanned (Lukas Czerner) [2099577]
- ext4: fix use-after-free in ext4_rename_dir_prepare (Lukas Czerner) [2099577]
- ext4: fix warning in ext4_handle_inode_extension (Lukas Czerner) [2099577]
- redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY (Patrick Talbert) [2071955]
- Revert "mm: remove the extra ZONE_DEVICE struct page refcount" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.17..v5.18 (Karol Herbst) [2043115]
- seq_file: include linux/string_helpers.h (Karol Herbst) [2043115]
- iosys-map: Add a few more helpers (Karol Herbst) [2043115]
- iosys-map: Add offset to iosys_map_memcpy_to() (Karol Herbst) [2043115]
- dma-buf-map: Rename to iosys-map (Karol Herbst) [2043115]
- Revert "virtio: wrap config->reset calls" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.16..v5.17 (Karol Herbst) [2043115]
- drm/i915/rpl-s: Add PCI IDS for Raptor Lake S (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.15..v5.16 (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.14..v5.15 (Karol Herbst) [2043115]
- fbdev: fbmem: add a helper to determine if an aperture is used by a fw fb (Karol Herbst) [2043115]
- redhat/configs: enable CONFIG_UDMABUF (Karol Herbst) [2012748]
- redhat/configs: set new DRM configs (Karol Herbst) [2043115]
- Makefiles: set initial DRM version (Karol Herbst) [2043115]

* Tue Jul 12 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-128.el9]
- block: remove WARN_ON() from bd_link_disk_holder (Ming Lei) [2094256]
- block: pop cached rq before potentially blocking rq_qos_throttle() (Ming Lei) [2094256]
- block: remove queue from struct blk_independent_access_range (Ming Lei) [2094256]
- block: freeze the queue earlier in del_gendisk (Ming Lei) [2094256]
- block: remove per-disk debugfs files in blk_unregister_queue (Ming Lei) [2094256]
- block: serialize all debugfs operations using q->debugfs_mutex (Ming Lei) [2094256]
- block: disable the elevator int del_gendisk (Ming Lei) [2094256]
- net: add missing include in include/net/gro.h (Ivan Vecera) [2101789]
- net: gro: populate net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive into net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive_list to udp_offload.c (Ivan Vecera) [2101789]
- net: move gro definitions to include/net/gro.h (Ivan Vecera) [2101789]
- net:dev: Change napi_gro_complete return type to void (Ivan Vecera) [2101789]
- move netdev_boot_setup into Space.c (Ivan Vecera) [2101789]
- sched: Fix balance_push() vs __sched_setscheduler() (Phil Auld) [2100215]
- selftests, xsk: Fix bpf_res cleanup test (Felix Maurer) [2090981]

* Sat Jul 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-127.el9]
- intel/igbvf:fix repeated words in comments (Corinna Vinschen) [2037985]
- igbvf: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037985]
- x86/sme: Explicitly map new EFI memmap table as encrypted (Rafael Aquini) [2091830]
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in mem_encrypt_identity.c (Rafael Aquini) [2091830]
- aarch64: Enable NVIDIA Jetson Xavier SoCs (Craig Magina) [2098285]
- r8169: improve driver unload and system shutdown behavior on DASH-enabled systems (Jose Ignacio Tornos Martinez) [2070952]
- r8169: factor out redundant RTL8168d PHY config functionality to rtl8168d_1_common() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: support L1.2 control on RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_disable_exit_l1() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1.2 if system vendor flags it as safe (Jose Ignacio Tornos Martinez) [2070952]
- r8169: don't use pci_irq_vector() in atomic context (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Avoid misuse of pm_ptr() macro (Jose Ignacio Tornos Martinez) [2070952]
- r8169: fix incorrect mac address assignment (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1/L1.1 from RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Add device 10ec:8162 to driver r8169 (Jose Ignacio Tornos Martinez) [2070952]
- ethernet: r8169: use eth_hw_addr_set() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_enable_exit_l1 (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L0s state (Jose Ignacio Tornos Martinez) [2070952]
- r8169: rename rtl_csi_access_enable to rtl_set_aspm_entry_latency (Jose Ignacio Tornos Martinez) [2070952]
- powercap: intel_rapl: add support for RaptorLake (David Arcari) [2076725]
- perf/x86/cstate: Add SAPPHIRERAPIDS_X CPU support (Michael Petlan) [2094573]
- fs: dlm: filter user dlm messages for kernel locks (Alexander Aring) [2026117]
- scsi: storvsc: Fix unsigned comparison to zero (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix validation for unsolicited incoming packets (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix storvsc_queuecommand() memory leak (Mohammed Gamal) [2030695]

* Thu Jul 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-126.el9]
- mm/page_alloc: always attempt to allocate at least one page during bulk allocation (Joel Savitz) [2094045]
- KVM: arm64: Warn if accessing timer pending state outside of vcpu context (Gavin Shan) [2075082]
- KVM: arm64: Replace vgic_v3_uaccess_read_pending with vgic_uaccess_read_pending (Gavin Shan) [2075082]
- KVM: arm64: Don't read a HW interrupt pending state in user context (Gavin Shan) [2075082]
- KVM: arm64: Always start with clearing SVE flag on load (Gavin Shan) [2075082]
- KVM: arm64: Don't hypercall before EL2 init (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Consistently populate ID_AA64PFR0_EL1.GIC (Gavin Shan) [2075082]
- KVM: arm64: Inject exception on out-of-IPA-range translation fault (Gavin Shan) [2075082]
- KVM/arm64: Don't emulate a PMU for 32-bit guests if feature not set (Gavin Shan) [2075082]
- KVM: arm64: Handle host stage-2 faults from 32-bit EL0 (Gavin Shan) [2075082]
- selftests: KVM: Free the GIC FD when cleaning up in arch_timer (Gavin Shan) [2075082]
- KVM: arm64: selftests: Introduce vcpu_width_config (Gavin Shan) [2075082]
- KVM: arm64: mixed-width check should be skipped for uninitialized vCPUs (Gavin Shan) [2075082]
- arm64: alternatives: mark patch_alternative() as `noinstr` (Gavin Shan) [2075082]
- KVM: arm64: vgic: Remove unnecessary type castings (Gavin Shan) [2075082]
- KVM: arm64: Don't split hugepages outside of MMU write lock (Gavin Shan) [2075082]
- KVM: arm64: Drop unneeded minor version check from PSCI v1.x handler (Gavin Shan) [2075082]
- KVM: arm64: Actually prevent SMC64 SYSTEM_RESET2 from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: Generally disallow SMC64 for AArch32 guests (Gavin Shan) [2075082]
- arm64: Fix comments in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- arm64: errata: avoid duplicate field initializer (Gavin Shan) [2075082]
- KVM: arm64: fix typos in comments (Gavin Shan) [2075082]
- KVM: arm64: Generalise VM features into a set of flags (Gavin Shan) [2075082]
- KVM: arm64: Really propagate PSCI SYSTEM_RESET2 arguments to userspace (Gavin Shan) [2075082]
- KVM: arm64: Only open the interrupt window on exit due to an interrupt (Gavin Shan) [2075082]
- KVM: arm64: Enable Cortex-A510 erratum 2077057 by default (Gavin Shan) [2075082]
- arm64: Always use individual bits in CPACR floating point enables (Gavin Shan) [2075082]
- arm64: Define CPACR_EL1_FPEN similarly to other floating point controls (Gavin Shan) [2075082]
- KVM: arm64: Remove unneeded semicolons (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Skip tests if we can't create a vgic-v3 (Gavin Shan) [2075082]
- KVM: arm64: Indicate SYSTEM_RESET2 in kvm_run::system_event flags field (Gavin Shan) [2075082]
- KVM: arm64: Expose PSCI SYSTEM_RESET2 call to the guest (Gavin Shan) [2075082]
- KVM: arm64: Bump guest PSCI version to 1.1 (Gavin Shan) [2075082]
- KVM: arm64: Don't miss pending interrupts for suspended vCPU (Gavin Shan) [2075082]
- arm64: Correct wrong label in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- KVM: arm64: vgic: Read HW interrupt pending state from the HW (Gavin Shan) [2075082]
- KVM: arm64: Refuse to run VCPU if the PMU doesn't match the physical CPU (Gavin Shan) [2075082]
- KVM: arm64: Add KVM_ARM_VCPU_PMU_V3_SET_PMU attribute (Gavin Shan) [2075082]
- KVM: arm64: Keep a list of probed PMUs (Gavin Shan) [2075082]
- KVM: arm64: Keep a per-VM pointer to the default PMU (Gavin Shan) [2075082]
- perf: Fix wrong name in comment for struct perf_cpu_context (Gavin Shan) [2075082]
- KVM: arm64: Do not change the PMU event filter after a VCPU has run (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Implement CONFIG_DEBUG_LIST at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Drop unused param from kvm_psci_version() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: use a tighter assert in vgic_poke_irq() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix some vgic related comments (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix the failure check in kvm_set_gsi_routing_irqchip_check (Gavin Shan) [2075082]
- kvm: selftests: aarch64: pass vgic_irq guest args as a pointer (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix assert in gicv3_access_reg (Gavin Shan) [2075082]
- KVM: arm64: Make active_vmids invalid on vCPU schedule out (Gavin Shan) [2075082]
- KVM: arm64: Align the VMID allocation with the arm64 ASID (Gavin Shan) [2075082]
- KVM: arm64: Make VMID bits accessible outside of allocator (Gavin Shan) [2075082]
- KVM: arm64: Introduce a new VMID allocator for KVM (Gavin Shan) [2075082]
- arm64/fpsimd: Clarify the purpose of using last in fpsimd_save() (Gavin Shan) [2075082]
- KVM: arm64: Add some more comments in kvm_hyp_handle_fpsimd() (Gavin Shan) [2075082]
- KVM: arm64: Add comments for context flush and sync callbacks (Gavin Shan) [2075082]
- KVM: arm64: Add fast path to handle permission relaxation during dirty logging (Gavin Shan) [2075082]
- KVM: arm64: Use read/write spin lock for MMU protection (Gavin Shan) [2075082]
- KVM: arm64: Emulate the OS Lock (Gavin Shan) [2075082]
- KVM: arm64: Allow guest to set the OSLK bit (Gavin Shan) [2075082]
- KVM: arm64: Stash OSLSR_EL1 in the cpu context (Gavin Shan) [2075082]
- KVM: arm64: Correctly treat writes to OSLSR_EL1 as undefined (Gavin Shan) [2075082]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2077057 (Gavin Shan) [2075082]
- KVM: arm64: Workaround Cortex-A510's single-step and PAC trap errata (Gavin Shan) [2075082]
- KVM: arm64: Stop handle_exit() from handling HVC twice when an SError occurs (Gavin Shan) [2075082]
- KVM: arm64: Avoid consuming a stale esr value when SError occur (Gavin Shan) [2075082]
- kvm/arm64: rework guest entry logic (Gavin Shan) [2075082]
- KVM: arm64: Use shadow SPSR_EL1 when injecting exceptions on !VHE (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Restrict SEIS workaround to known broken systems (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use the mm_ops indirection for cache maintenance (Gavin Shan) [2075082]
- KVM: arm64: Put kvm_arch_vcpu_get_ip() inside CONFIG_GUEST_PERF_EVENTS (Gavin Shan) [2075082]
- KVM: arm64: vgic: Replace kernel.h with the necessary inclusions (Gavin Shan) [2075082]
- KVM: arm64: Fix comment typo in kvm_vcpu_finalize_sve() (Gavin Shan) [2075082]
- KVM: arm64: selftests: get-reg-list: Add pauth configuration (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test for restoring active IRQs (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add ISPENDR write tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for IRQFD in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: Add IRQ GSI routing library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test_inject_fail to vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for LEVEL_INFO in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Level-sensitive interrupts tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add preemption tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set EOI mode in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set number of IRQs in vgic_irq test (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Abstract the injection functions in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vgic_irq to test userspace IRQ injection (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vGIC library functions to deal with vIRQ state (Gavin Shan) [2075082]
- KVM: selftests: Add kvm_irq_line library function (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add GICv3 register accessor library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add function for accessing GICv3 dist and redist registers (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Move gic_v3.h to shared headers (Gavin Shan) [2075082]
- KVM: arm64: Fix comment on barrier in kvm_psci_vcpu_on() (Gavin Shan) [2075082]
- KVM: arm64: Fix comment for kvm_reset_vcpu() (Gavin Shan) [2075082]
- KVM: arm64: Use defined value for SCTLR_ELx_EE (Gavin Shan) [2075082]
- KVM: arm64: Rework kvm_pgtable initialisation (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Unshare guest structs during teardown (Gavin Shan) [2075082]
- KVM: arm64: Expose unshare hypercall to the host (Gavin Shan) [2075082]
- KVM: arm64: Implement do_unshare() helper for unsharing memory (Gavin Shan) [2075082]
- KVM: arm64: Implement __pkvm_host_share_hyp() using do_share() (Gavin Shan) [2075082]
- KVM: arm64: Implement do_share() helper for sharing memory (Gavin Shan) [2075082]
- KVM: arm64: Introduce wrappers for host and hyp spin lock accessors (Gavin Shan) [2075082]
- KVM: arm64: Extend pkvm_page_state enumeration to handle absent pages (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Refcount the pages shared with EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce kvm_share_hyp() (Gavin Shan) [2075082]
- KVM: arm64: Implement kvm_pgtable_hyp_unmap() at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Hook up ->page_count() for hypervisor stage-1 page-table (Gavin Shan) [2075082]
- KVM: arm64: Fixup hyp stage-1 refcount (Gavin Shan) [2075082]
- KVM: arm64: Refcount hyp stage-1 pgtable pages (Gavin Shan) [2075082]
- KVM: arm64: Provide {get,put}_page() stubs for early hyp allocator (Gavin Shan) [2075082]
- KVM: arm64: vgic: Demote userspace-triggered console prints to kvm_debug() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make kvm_host_owns_hyp_mappings() robust to VHE (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Stub io map functions (Gavin Shan) [2075082]
- KVM: arm64: Make __io_map_base static (Gavin Shan) [2075082]
- KVM: arm64: Make the hyp memory pool static (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Disable GICv2 support (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Fix hyp_pool max order (Gavin Shan) [2075082]
- KVM: arm64: Use Makefile.kvm for common files (Gavin Shan) [2075082]
- KVM: arm64: Drop unused workaround_flags vcpu field (Gavin Shan) [2075082]
- KVM: arm64: Move vGIC v4 handling for WFI out arch callback hook (Gavin Shan) [2075082]
- arm64/kvm: Fix bitrotted comment for SVE handling in handle_exit.c (Gavin Shan) [2075082]
- KVM: arm64: Move host EL1 code out of hyp/ directory (Gavin Shan) [2075082]
- KVM: arm64: Generate hyp_constants.h for the host (Gavin Shan) [2075082]
- arm64: Add missing include of asm/cpufeature.h to asm/mmu.h (Gavin Shan) [2075082]
- KVM: arm64: Constify kvm_io_gic_ops (Gavin Shan) [2075082]
- KVM: arm64: Add minimal handling for the ARMv8.7 PMU (Gavin Shan) [2075082]
- KVM: arm64: Drop vcpu->arch.has_run_once for vcpu->pid (Gavin Shan) [2075082]
- KVM: arm64: Merge kvm_arch_vcpu_run_pid_change() and kvm_vcpu_first_run_init() (Gavin Shan) [2075082]
- KVM: arm64: Restructure the point where has_run_once is advertised (Gavin Shan) [2075082]
- KVM: arm64: Move kvm_arch_vcpu_run_pid_change() out of line (Gavin Shan) [2075082]
- KVM: arm64: Move SVE state mapping at HYP to finalize-time (Gavin Shan) [2075082]
- KVM: arm64: Move pkvm's special 32bit handling into a generic infrastructure (Gavin Shan) [2075082]
- KVM: arm64: Save PSTATE early on exit (Gavin Shan) [2075082]
- arm64/fpsimd: Document the use of TIF_FOREIGN_FPSTATE by KVM (Gavin Shan) [2075082]
- KVM: arm64: Stop mapping current thread_info at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce flag shadowing TIF_FOREIGN_FPSTATE (Gavin Shan) [2075082]
- KVM: arm64: Remove unused __sve_save_state (Gavin Shan) [2075082]
- KVM: arm64: Get rid of host SVE tracking/saving (Gavin Shan) [2075082]
- KVM: arm64: Reorder vcpu flag definitions (Gavin Shan) [2075082]
- KVM: arm64: Cap KVM_CAP_NR_VCPUS by kvm_arm_default_max_vcpus() (Gavin Shan) [2075082]
- KVM: arm64: Fix host stage-2 finalization (Gavin Shan) [2075082]
- KVM: arm64: Change the return type of kvm_vcpu_preferred_target() (Gavin Shan) [2075082]
- KVM: arm64: nvhe: Fix a non-kernel-doc comment (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Give priority to standard traps over pvm handling (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Pass vpcu instead of kvm to kvm_get_exit_handler_array() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Move kvm_handle_pvm_restricted around (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Consolidate include files (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Preserve pending SError on exit from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Handle GICv3 traps as required (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop sysregs that should never be routed to the host (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop AArch32-specific registers (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make the ERR/ERX*_EL1 registers RAZ/WI (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use a single function to expose all id-regs (Gavin Shan) [2075082]
- KVM: arm64: Fix early exit ptrauth handling (Gavin Shan) [2075082]
- KVM: arm64: Add memcg accounting to KVM allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic: Add memcg accounting to vgic allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Align emulated cpuif LPI state machine with the pseudocode (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Don't advertise ICC_CTLR_EL1.SEIS (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Reduce common group trapping to ICV_DIR_EL1 when possible (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Work around GICv3 locally generated SErrors (Gavin Shan) [2075082]
- KVM: arm64: Force ID_AA64PFR0_EL1.GIC=1 when exposing a virtual GICv3 (Gavin Shan) [2075082]
- KVM: arm64: Fix reporting of endianess when the access originates at EL0 (Gavin Shan) [2075082]
- KVM: arm64: Handle protected guests at 32 bits (Gavin Shan) [2075082]
- KVM: arm64: Trap access to pVM restricted features (Gavin Shan) [2075082]
- KVM: arm64: Move sanitized copies of CPU features (Gavin Shan) [2075082]
- KVM: arm64: Initialize trap registers for protected VMs (Gavin Shan) [2075082]
- KVM: arm64: Add handlers for protected VM System Registers (Gavin Shan) [2075082]
- KVM: arm64: Simplify masking out MTE in feature id reg (Gavin Shan) [2075082]
- KVM: arm64: Add missing field descriptor for MDCR_EL2 (Gavin Shan) [2075082]
- KVM: arm64: Pass struct kvm to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Move early handlers to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Don't include switch.h into nvhe/kvm-main.c (Gavin Shan) [2075082]
- KVM: arm64: Move __get_fault_info() and co into their own include file (Gavin Shan) [2075082]
- KVM: arm64: Replace get_raz_id_reg() with get_raz_reg() (Gavin Shan) [2075082]
- KVM: arm64: Use get_raz_reg() for userspace reads of PMSWINC_EL0 (Gavin Shan) [2075082]
- KVM: arm64: Return early from read_id_reg() if register is RAZ (Gavin Shan) [2075082]
- KVM: arm64: Depend on HAVE_KVM instead of OF (Gavin Shan) [2075082]
- KVM: arm64: Unconditionally include generic KVM's Kconfig (Gavin Shan) [2075082]
- KVM: arm64: Allow KVM to be disabled from the command line (Gavin Shan) [2075082]
- KVM: arm64: Disable privileged hypercalls after pKVM finalisation (Gavin Shan) [2075082]
- KVM: arm64: Prevent re-finalisation of pKVM for a given CPU (Gavin Shan) [2075082]
- KVM: arm64: Propagate errors from __pkvm_prot_finalize hypercall (Gavin Shan) [2075082]
- KVM: arm64: Reject stub hypercalls after pKVM has been initialised (Gavin Shan) [2075082]
- arm64: Prevent kexec and hibernation if is_protected_kvm_enabled() (Gavin Shan) [2075082]
- KVM: arm64: Turn __KVM_HOST_SMCCC_FUNC_* into an enum (mostly) (Gavin Shan) [2075082]
- KVM: arm64: Revert "KVM: arm64: Count VMID-wide TLB invalidations" (Gavin Shan) [2075082]
- cxl/core: Remove cxld_const_init in cxl_decoder_alloc() (John W. Linville) [2072584]
- cxl/pmem: Fix module reload vs workqueue state (John W. Linville) [2072584]
- cxl/memdev: Remove unused cxlmd field (John W. Linville) [2072584]
- cxl/core: Convert to EXPORT_SYMBOL_NS_GPL (John W. Linville) [2072584]
- cxl/memdev: Change cxl_mem to a more descriptive name (John W. Linville) [2072584]
- cxl/mbox: Remove bad comment (John W. Linville) [2072584]
- cxl/pmem: Fix reference counting for delayed work (John W. Linville) [2072584]
- cxl/pci: Split cxl_pci_setup_regs() (John W. Linville) [2072584]
- cxl/pci: Add @base to cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Make more use of cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Remove pci request/release regions (John W. Linville) [2072584]
- cxl/pci: Fix NULL vs ERR_PTR confusion (John W. Linville) [2072584]
- cxl/pci: Remove dev_dbg for unknown register blocks (John W. Linville) [2072584]
- cxl/pci: Convert register block identifiers to an enum (John W. Linville) [2072584]
- cxl/acpi: Do not fail cxl_acpi_probe() based on a missing CHBS (John W. Linville) [2072584]
- cxl/pci: Disambiguate cxl_pci further from cxl_mem (John W. Linville) [2072584]
- cxl/core: Split decoder setup into alloc + add (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mock memory device + driver (John W. Linville) [2072584]
- cxl/mbox: Move command definitions to common location (John W. Linville) [2072584]
- cxl/bus: Populate the target list at decoder create (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mocked-up CXL port hierarchy (John W. Linville) [2072584]
- cxl/pmem: Add support for multiple nvdimm-bridge objects (John W. Linville) [2072584]
- cxl/pmem: Translate NVDIMM label commands to CXL label commands (John W. Linville) [2072584]
- cxl/mbox: Add exclusive kernel command support (John W. Linville) [2072584]
- cxl/mbox: Convert 'enabled_cmds' to DECLARE_BITMAP (John W. Linville) [2072584]
- cxl/pci: Use module_pci_driver (John W. Linville) [2072584]
- cxl/mbox: Move mailbox and other non-PCI specific infrastructure to the core (John W. Linville) [2072584]
- cxl/pci: Drop idr.h (John W. Linville) [2072584]
- cxl/mbox: Introduce the mbox_send operation (John W. Linville) [2072584]
- cxl/pci: Clean up cxl_mem_get_partition_info() (John W. Linville) [2072584]
- cxl/pci: Make 'struct cxl_mem' device type generic (John W. Linville) [2072584]
- cxl/registers: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pmem: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pci: Fix debug message in cxl_probe_regs() (John W. Linville) [2072584]
- cxl/pci: Fix lockdown level (John W. Linville) [2072584]
- cxl/acpi: Do not add DSDT disabled ACPI0016 host bridge ports (John W. Linville) [2072584]
- cxl/mem: Adjust ram/pmem range to represent DPA ranges (John W. Linville) [2072584]
- cxl/mem: Account for partitionable space in ram/pmem ranges (John W. Linville) [2072584]
- cxl/pci: Store memory capacity values (John W. Linville) [2072584]
- cxl/pci: Simplify register setup (John W. Linville) [2072584]
- cxl/pci: Ignore unknown register block types (John W. Linville) [2072584]
- cxl/core: Move memdev management to core (John W. Linville) [2072584]
- cxl/pci: Introduce cdevm_file_operations (John W. Linville) [2072584]
- cxl/core: Move register mapping infrastructure (John W. Linville) [2072584]
- cxl/core: Move pmem functionality (John W. Linville) [2072584]
- cxl/core: Improve CXL core kernel docs (John W. Linville) [2072584]
- cxl: Move cxl_core to new directory (John W. Linville) [2072584]

* Wed Jul 06 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-125.el9]
- cifs: fix bad fids sent over wire (Ronnie Sahlberg) [2088775]
- SMB3: EBADF/EIO errors in rename/open caused by race condition in smb2_compound_op (Ronnie Sahlberg) [2088775]
- i40e: Fix call trace in setup_tx_descriptors (Ivan Vecera) [2037980]
- i40e: Fix calculating the number of queue pairs (Ivan Vecera) [2037980]
- i40e: Fix adding ADQ filter to TC0 (Ivan Vecera) [2037980]
- i40e: i40e_main: fix a missing check on list iterator (Ivan Vecera) [2037980]
- i40e, xsk: Get rid of redundant 'fallthrough' (Ivan Vecera) [2037980]
- i40e, xsk: Diversify return values from xsk_wakeup call paths (Ivan Vecera) [2037980]
- i40e, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ivan Vecera) [2037980]
- i40e: Add Ethernet Connection X722 for 10GbE SFP+ support (Ivan Vecera) [2037980]
- i40e: Add vsi.tx_restart to i40e ethtool stats (Ivan Vecera) [2037980]
- i40e: Add tx_stopped stat (Ivan Vecera) [2037980]
- i40e: Add support for MPLS + TSO (Ivan Vecera) [2037980]
- i40e: little endian only valid checksums (Ivan Vecera) [2037980]
- i40e: stop disabling VFs due to PF error responses (Ivan Vecera) [2037980]
- Revert "i40e: Fix reset bw limit when DCB enabled with 1 TC" (Ivan Vecera) [2037980]
- i40e: remove dead stores on XSK hotpath (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking busy rx pages (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking pages waived (Ivan Vecera) [2037980]
- i40e: Add a stat tracking new RX page allocations (Ivan Vecera) [2037980]
- i40e: Aggregate and export RX page reuse stat (Ivan Vecera) [2037980]
- i40e: Remove rx page reuse double count (Ivan Vecera) [2037980]
- i40e: Fix race condition while adding/deleting MAC/VLAN filters (Ivan Vecera) [2037980]
- i40e: Add new version of i40e_aq_add_macvlan function (Ivan Vecera) [2037980]
- i40e: Add new versions of send ASQ command functions (Ivan Vecera) [2037980]
- i40e: Add sending commands in atomic context (Ivan Vecera) [2037980]
- i40e: Remove unused RX realloc stat (Ivan Vecera) [2037980]
- i40e: Disable hw-tc-offload feature on driver load (Ivan Vecera) [2037980]
- i40e: Fix reset path while removing the driver (Ivan Vecera) [2037980]
- i40e: Fix reset bw limit when DCB enabled with 1 TC (Ivan Vecera) [2037980]
- i40e: respect metadata on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: Remove useless DMA-32 fallback configuration (Ivan Vecera) [2037980]
- i40e: fix unsigned stat widths (Ivan Vecera) [2037980]
- i40e: Fix for failed to init adminq while VF reset (Ivan Vecera) [2037980]
- i40e: Fix queues reservation for XDP (Ivan Vecera) [2037980]
- i40e: Fix issue when maximum queues is exceeded (Ivan Vecera) [2037980]
- i40e: Increase delay to 1 s after global EMP reset (Ivan Vecera) [2037980]
- i40e: remove variables set but not used (Ivan Vecera) [2037980]
- i40e: Remove non-inclusive language (Ivan Vecera) [2037980]
- i40e: Update FW API version (Ivan Vecera) [2037980]
- i40e: Minimize amount of busy-waiting during AQ send (Ivan Vecera) [2037980]
- i40e: Add ensurance of MacVlan resources for every trusted VF (Ivan Vecera) [2037980]
- i40e: Fix incorrect netdev's real number of RX/TX queues (Ivan Vecera) [2037980]
- i40e: Fix for displaying message regarding NVM version (Ivan Vecera) [2037980]
- i40e: fix use-after-free in i40e_sync_filters_subtask() (Ivan Vecera) [2037980]
- i40e: Fix to not show opcode msg on unsuccessful VF MAC change (Ivan Vecera) [2037980]
- i40e: switch to napi_build_skb() (Ivan Vecera) [2037980]
- i40e: Use irq_update_affinity_hint() (Ivan Vecera) [2037980]
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc (Ivan Vecera) [2037980]
- i40e: Fix pre-set max number of queues for VF (Ivan Vecera) [2037980]
- i40e: Fix failed opcode appearing if handling messages from VF (Ivan Vecera) [2037980]
- i40e: Fix display error code in dmesg (Ivan Vecera) [2037980]
- i40e: Fix creation of first queue by omitting it if is not power of two (Ivan Vecera) [2037980]
- i40e: Fix warning message and call stack during rmmod i40e driver (Ivan Vecera) [2037980]
- i40e: Fix ping is lost after configuring ADq on VF (Ivan Vecera) [2037980]
- i40e: Fix changing previously set num_queue_pairs for PFs (Ivan Vecera) [2037980]
- i40e: Fix NULL ptr dereference on VSI filter sync (Ivan Vecera) [2037980]
- i40e: Fix correct max_pkt_size on VF RX queue (Ivan Vecera) [2037980]
- i40e: Simplify bool conversion (Ivan Vecera) [2037980]
- i40e: Fix freeing of uninitialized misc IRQ vector (Ivan Vecera) [2037980]
- i40e: Use the xsk batched rx allocation interface (Ivan Vecera) [2037980]
- i40e: Fix spelling mistake "dissable" -> "disable" (Ivan Vecera) [2037980]
- i40e: add support for PTP external synchronization clock (Ivan Vecera) [2037980]
- i40e: improve locking of mac_filter_hash (Ivan Vecera) [2037980]
- time: Handle negative seconds correctly in timespec64_to_ns() (Íñigo Huguet) [2097394]
- iavf: Fix issue with MAC address of VF shown as zero (Petr Oros) [2037976]
- Revert "iavf: Fix deadlock occurrence during resetting VF interface" (Petr Oros) [2037976]
- iavf: Fix hang during reboot/shutdown (Petr Oros) [2037976]
- iavf: Fix double free in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix adopting new combined setting (Petr Oros) [2037976]
- iavf: Fix handling of vlan strip virtual channel messages (Petr Oros) [2037976]
- iavf: Fix __IAVF_RESETTING state usage (Petr Oros) [2037976]
- iavf: Fix missing check for running netdev (Petr Oros) [2037976]
- iavf: Fix deadlock in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix race in init state (Petr Oros) [2037976]
- iavf: Fix locking for VIRTCHNL_OP_GET_OFFLOAD_VLAN_V2_CAPS (Petr Oros) [2037976]
- iavf: Fix init state closure on remove (Petr Oros) [2037976]
- iavf: Add waiting so the port is initialized in remove (Petr Oros) [2037976]
- iavf: Rework mutexes for better synchronisation (Petr Oros) [2037976]
- iavf: Remove non-inclusive language (Petr Oros) [2037976]
- iavf: Fix incorrect use of assigning iavf_status to int (Petr Oros) [2037976]
- iavf: stop leaking iavf_status as "errno" values (Petr Oros) [2037976]
- iavf: remove redundant ret variable (Petr Oros) [2037976]
- iavf: Add usage of new virtchnl format to set default MAC (Petr Oros) [2037976]
- iavf: refactor processing of VLAN V2 capability message (Petr Oros) [2037976]
- iavf: Add support for 50G/100G in AIM algorithm (Petr Oros) [2037976]
- iavf: Remove useless DMA-32 fallback configuration (Petr Oros) [2037976]
- iavf: Use irq_update_affinity_hint() (Petr Oros) [2037976]
- iavf: remove an unneeded variable (Petr Oros) [2037976]
- iavf: Fix limit of total number of queues to active queues of VF (Petr Oros) [2037976]
- iavf: switch to napi_build_skb() (Petr Oros) [2037976]
- iavf: Restrict maximum VLAN filters for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 offload enable/disable (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 hotpath (Petr Oros) [2037976]
- iavf: Add support VIRTCHNL_VF_OFFLOAD_VLAN_V2 during netdev config (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 negotiation (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (again) (Petr Oros) [2037976]
- iavf: missing unlocks in iavf_watchdog_task() (Petr Oros) [2037976]
- iavf: Fix reporting when setting descriptor count (Petr Oros) [2037976]
- iavf: restore MSI state on reset (Petr Oros) [2037976]
- iavf: Fix displaying queue statistics shown by ethtool (Petr Oros) [2037976]
- iavf: Refactor string format to avoid static analysis warnings (Petr Oros) [2037976]
- iavf: Refactor text of informational message (Petr Oros) [2037976]
- iavf: Fix static code analysis warning (Petr Oros) [2037976]
- iavf: Refactor iavf_mac_filter struct memory usage (Petr Oros) [2037976]
- iavf: Enable setting RSS hash key (Petr Oros) [2037976]
- iavf: Add trace while removing device (Petr Oros) [2037976]
- iavf: return errno code instead of status code (Petr Oros) [2037976]
- iavf: Log info when VF is entering and leaving Allmulti mode (Petr Oros) [2037976]
- iavf: Add change MTU message (Petr Oros) [2037976]
- iavf: Fix VLAN feature flags after VFR (Petr Oros) [2037976]
- iavf: Fix refreshing iavf adapter stats on ethtool request (Petr Oros) [2037976]
- iavf: Fix deadlock occurrence during resetting VF interface (Petr Oros) [2037976]
- iavf: Prevent changing static ITR values if adaptive moderation is on (Petr Oros) [2037976]
- iavf: Restore VLAN filters after link down (Petr Oros) [2037976]
- iavf: Fix for setting queues to 0 (Petr Oros) [2037976]
- iavf: Fix for the false positive ASQ/ARQ errors while issuing VF reset (Petr Oros) [2037976]
- iavf: validate pointers (Petr Oros) [2037976]
- iavf: prevent accidental free of filter structure (Petr Oros) [2037976]
- iavf: Fix failure to exit out from last all-multicast mode (Petr Oros) [2037976]
- iavf: don't clear a lock we don't hold (Petr Oros) [2037976]
- iavf: free q_vectors before queues in iavf_disable_vf (Petr Oros) [2037976]
- iavf: check for null in iavf_fix_features (Petr Oros) [2037976]
- iavf: Fix return of set the new channel count (Petr Oros) [2037976]
- iavf: Fix kernel BUG in free_msi_irqs (Petr Oros) [2037976]
- iavf: Add helper function to go from pci_dev to adapter (Petr Oros) [2037976]
- iavf: Combine init and watchdog state machines (Petr Oros) [2037976]
- iavf: Add __IAVF_INIT_FAILED state (Petr Oros) [2037976]
- iavf: Refactor iavf state machine tracking (Petr Oros) [2037976]
- iavf: fix double unlock of crit_lock (Petr Oros) [2037976]
- iavf: use mutexes for locking of critical sections (Petr Oros) [2037976]
- iavf: fix locking of critical sections (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (Petr Oros) [2037976]
- bnxt_en: parse and report result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: Enable packet timestamping for all RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Configure ptp filters during bnxt open (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.95 (Ken Cox) [2042819 2043783]
- bnxt_en: Fix unnecessary dropping of RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Initiallize bp->ptp_lock first before using it (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS flag (Ken Cox) [2042819 2043783]
- bnxt: add page_pool support for aggregation ring when using xdp (Ken Cox) [2042819 2043783]
- bnxt: change receive ring space parameters (Ken Cox) [2042819 2043783]
- bnxt: rename bnxt_rx_pages to bnxt_rx_agg_pages_skb (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_pages operate on skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt: add flag to denote that an xdp program is currently attached (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_xdp to separate xdp_init_buff/xdp_prepare_buff (Ken Cox) [2042819 2043783]
- bnxt_en: Prevent XDP redirect from running when stopping TX queue (Ken Cox) [2042819 2043783]
- bnxt_en: reserve space inside receive page for skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt_en: Synchronize tx when xdp redirects happen on same ring (Ken Cox) [2042819 2043783]
- net: bnxt_ptp: fix compilation error (Ken Cox) [2042819 2043783]
- bnxt: revert hastily merged uAPI aberrations (Ken Cox) [2042819 2043783]
- bnxt_en: add an nvm test for hw diagnose (Ken Cox) [2042819 2043783]
- bnxt_en: implement hw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Do not destroy health reporters during reset (Ken Cox) [2042819 2043783]
- bnxt_en: Eliminate unintended link toggle during FW reset (Ken Cox) [2042819 2043783]
- bnxt_en: Properly report no pause support on some cards (Ken Cox) [2042819 2043783]
- bnxt_en: introduce initial link state of unknown (Ken Cox) [2042819 2043783]
- bnxt_en: parse result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: add more error checks to HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: refactor error handling of HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: Handle async event when the PHC is updated in RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Implement .adjtime() for PTP RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Add driver support to use Real Time Counter for PTP (Ken Cox) [2042819 2043783]
- bnxt_en: PTP: Refactor PTP initialization functions (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.73 (Ken Cox) [2042819 2043783]
- bnxt_en: fix kernel doc warnings in bnxt_hwrm.c (Ken Cox) [2042819 2043783]
- bnxt_en: Increase firmware message response DMA wait time (Ken Cox) [2042819 2043783]
- bnxt_en: Fix devlink fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: Restore the resets_reliable flag in bnxt_open() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix incorrect multicast rx mask setting when not requested (Ken Cox) [2042819 2043783]
- bnxt_en: Fix occasional ethtool -t loopback test failures (Ken Cox) [2042819 2043783]
- bnxt_en: Fix offline ethtool selftest with RDMA enabled (Ken Cox) [2042819 2043783]
- bnxt_en: Fix active FEC reporting to ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: improve firmware timeout messaging (Ken Cox) [2042819 2043783]
- bnxt_en: use firmware provided max timeout for messages (Ken Cox) [2042819 2043783]
- bnxt_en: improve VF error messages when PF is unavailable (Ken Cox) [2042819 2043783]
- bnxt_en: add dynamic debug support for HWRM messages (Ken Cox) [2042819 2043783]
- bnxt_en: Use page frag RX buffers for better software GRO performance (Ken Cox) [2042819 2043783]
- bnxt_en: convert to xdp_do_flush (Ken Cox) [2042819 2043783]
- bnxt_en: Support CQE coalescing mode in ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: Support configurable CQE coalescing mode (Ken Cox) [2042819 2043783]
- bnxt_en: enable interrupt sampling on 5750X for DIM (Ken Cox) [2042819 2043783]
- bnxt_en: Log error report for dropped doorbell (Ken Cox) [2042819 2043783]
- bnxt_en: Add event handler for PAUSE Storm event (Ken Cox) [2042819 2043783]
- flow_offload: reject to offload tc actions in offload drivers (Ken Cox) [2042819 2043783]
- bnxt_en: Fix compile error regression when CONFIG_BNXT_SRIOV is not set (Ken Cox) [2042819 2043783]
- bnxt_en: reject indirect blk offload when hw-tc-offload is off (Ken Cox) [2042819 2043783]
- bnxt_en: fix format specifier in live patch error message (Ken Cox) [2042819 2043783]
- bnxt_en: extend RTNL to VF check in devlink driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ken Cox) [2042819 2043783]
- bnxt_en: Remove not used other ULP define (Ken Cox) [2042819 2043783]
- bnxt_en: Provide stored devlink "fw" version on older firmware (Ken Cox) [2042819 2043783]
- bnxt_en: implement firmware live patching (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.63 (Ken Cox) [2042819 2043783]
- bnxt_en: implement dump callback for fw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Retrieve coredump and crashdump size via FW command (Ken Cox) [2042819 2043783]
- bnxt_en: move coredump functions into dedicated file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor coredump functions (Ken Cox) [2042819 2043783]
- bnxt_en: improve fw diagnose devlink health messages (Ken Cox) [2042819 2043783]
- bnxt_en: consolidate fw devlink health reporters (Ken Cox) [2042819 2043783]
- bnxt_en: remove fw_reset devlink health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: improve error recovery information messages (Ken Cox) [2042819 2043783]
- bnxt_en: add enable_remote_dev_reset devlink parameter (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: refactor cancellation of resource reservations (Ken Cox) [2042819 2043783]
- bnxt_en: refactor printing of device info (Ken Cox) [2042819 2043783]
- ethernet: constify references to netdev->dev_addr in drivers (Ken Cox) [2042819 2043783]
- bnxt: use netif_is_rxfh_configured instead of open code (Ken Cox) [2042819 2043783]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2042819 2043783]
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest (Ken Cox) [2042819 2043783]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Ken Cox) [2042819 2043783]
- bnxt_en: Clean up completion ring page arrays completely (Ken Cox) [2042819 2043783]
- bnxt_en: make bnxt_free_skbs() safe to call after bnxt_free_mem() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix error recovery regression (Ken Cox) [2042819 2043783]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Ken Cox) [2042819 2043783]
- bnxt: Read VPD with pci_vpd_alloc() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible unintended driver initiated error recovery (Ken Cox) [2042819 2043783]
- bnxt_en: Fix UDP tunnel logic (Ken Cox) [2042819 2043783]
- bnxt_en: Fix asic.rev in devlink dev info command (Ken Cox) [2042819 2043783]
- bnxt_en: fix read of stored FW_PSID version on P5 devices (Ken Cox) [2042819 2043783]
- bnxt_en: fix stored FW_PSID version masks (Ken Cox) [2042819 2043783]
- bnxt_en: Fix 64-bit doorbell operation on 32-bit kernels (Ken Cox) [2042819 2043783]
- bnxt_en: support multiple HWRM commands in flight (Ken Cox) [2042819 2043783]
- bnxt_en: discard out of sequence HWRM responses (Ken Cox) [2042819 2043783]
- bnxt_en: remove legacy HWRM interface (Ken Cox) [2042819 2043783]
- bnxt_en: update all firmware calls to use the new APIs (Ken Cox) [2042819 2043783]
- bnxt_en: use link_lock instead of hwrm_cmd_lock to protect link_info (Ken Cox) [2042819 2043783]
- bnxt_en: add support for HWRM request slices (Ken Cox) [2042819 2043783]
- bnxt_en: add HWRM request assignment API (Ken Cox) [2042819 2043783]
- bnxt_en: introduce new firmware message API based on DMA pools (Ken Cox) [2042819 2043783]
- bnxt_en: move HWRM API implementation into separate file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor the HWRM_VER_GET firmware calls (Ken Cox) [2042819 2043783]
- bnxt_en: remove DMA mapping for KONG response (Ken Cox) [2042819 2043783]
- bnxt: count discards due to memory allocation errors (Ken Cox) [2042819 2043783]
- bnxt: count packets discarded because of netpoll (Ken Cox) [2042819 2043783]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2042819 2043783]
- Revert "bnxt: Read VPD with pci_vpd_alloc()" (Ken Cox) [2042819 2043783]
- Revert "bnxt: Search VPD with pci_vpd_find_ro_info_keyword()" (Ken Cox) [2042819 2043783]
- bnxt_en: Increase maximum RX ring size if jumbo ring is not used (Ken Cox) [2042819 2043783]
- bnxt_en: Don't use static arrays for completion ring pages (Ken Cox) [2042819 2043783]
- bnxt_en: Log if an invalid signal detected on TSIO pin (Ken Cox) [2042819 2043783]
- gfs2: Make sure FITRIM minlen is rounded up to fs block size (Andrew Price) [2066375]
- redhat/configs enable CONFIG_ICE_HWTS (Petr Oros) [2037974]
- redhat/configs enable CONFIG_ICE_SWITCHDEV (Petr Oros) [2037974]
- ice: Fix memory corruption in VF driver (Petr Oros) [2037974]
- ice: Fix queue config fail handling (Petr Oros) [2037974]
- ice: Sync VLAN filtering features for DVM (Petr Oros) [2037974]
- ice: Fix PTP TX timestamp offset calculation (Petr Oros) [2037974]
- ice: Fix interrupt moderation settings getting cleared (Petr Oros) [2037974]
- ice: fix possible under reporting of ethtool Tx and Rx statistics (Petr Oros) [2037974]
- ice: fix crash when writing timestamp on RX rings (Petr Oros) [2037974]
- ice: fix PTP stale Tx timestamps cleanup (Petr Oros) [2037974]
- ice: clear stale Tx queue settings before configuring (Petr Oros) [2037974]
- ice: Fix race during aux device (un)plugging (Petr Oros) [2037974]
- ice: fix use-after-free when deinitializing mailbox snapshot (Petr Oros) [2037974]
- ice: wait 5 s for EMP reset after firmware flash (Petr Oros) [2037974]
- ice: Protect vf_state check by cfg_lock in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix incorrect locking in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix memory leak in ice_get_orom_civd_data() (Petr Oros) [2037974]
- ice: fix crash in switchdev mode (Petr Oros) [2037974]
- ice: allow creating VFs for !CONFIG_NET_SWITCHDEV (Petr Oros) [2037974]
- ice: xsk: check if Rx ring was filled up to the end (Petr Oros) [2037974]
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap (Petr Oros) [2037974]
- ice: clear cmd_type_offset_bsz for TX rings (Petr Oros) [2037974]
- ice: xsk: fix VSI state check in ice_xsk_wakeup() (Petr Oros) [2037974]
- ice: synchronize_rcu() when terminating rings (Petr Oros) [2037974]
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg (Petr Oros) [2037974]
- ice: Set txq_teid to ICE_INVAL_TEID on ring creation (Petr Oros) [2037974]
- ice: Fix broken IFF_ALLMULTI handling (Petr Oros) [2037974]
- ice: Fix MAC address setting (Petr Oros) [2037974]
- ice: Clear default forwarding VSI during VSI release (Petr Oros) [2037974]
- ice: xsk: Fix indexing in ice_tx_xsk_pool() (Petr Oros) [2037974]
- ice: xsk: Stop Rx processing when ntc catches ntu (Petr Oros) [2037974]
- ice: xsk: Eliminate unnecessary loop iteration (Petr Oros) [2037974]
- ice: don't allow to run ice_send_event_to_aux() in atomic ctx (Petr Oros) [2037974]
- ice: fix 'scheduling while atomic' on aux critical err interrupt (Petr Oros) [2037974]
- ice: add trace events for tx timestamps (Petr Oros) [2037974]
- ice: fix return value check in ice_gnss.c (Petr Oros) [2037974]
- ice: destroy flow director filter mutex after releasing VSIs (Petr Oros) [2037974]
- ice: fix NULL pointer dereference in ice_update_vsi_tx_ring_stats() (Petr Oros) [2037974]
- ice: remove PF pointer from ice_check_vf_init (Petr Oros) [2037974]
- ice: introduce ice_virtchnl.c and ice_virtchnl.h (Petr Oros) [2037974]
- ice: cleanup long lines in ice_sriov.c (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_LOCK flag (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_NOTIFY flag (Petr Oros) [2037974]
- ice: convert ice_reset_vf to take flags (Petr Oros) [2037974]
- ice: convert ice_reset_vf to standard error codes (Petr Oros) [2037974]
- ice: make ice_reset_all_vfs void (Petr Oros) [2037974]
- ice: drop is_vflr parameter from ice_reset_all_vfs (Petr Oros) [2037974]
- ice: move reset functionality into ice_vf_lib.c (Petr Oros) [2037974]
- ice: fix a long line warning in ice_reset_vf (Petr Oros) [2037974]
- ice: introduce VF operations structure for reset flows (Petr Oros) [2037974]
- ice: fix incorrect dev_dbg print mistaking 'i' for vf->vf_id (Petr Oros) [2037974]
- ice: introduce ice_vf_lib.c, ice_vf_lib.h, and ice_vf_lib_private.h (Petr Oros) [2037974]
- ice: use ice_is_vf_trusted helper function (Petr Oros) [2037974]
- ice: log an error message when eswitch fails to configure (Petr Oros) [2037974]
- ice: cleanup error logging for ice_ena_vfs (Petr Oros) [2037974]
- ice: move ice_set_vf_port_vlan near other .ndo ops (Petr Oros) [2037974]
- ice: refactor spoofchk control code in ice_sriov.c (Petr Oros) [2037974]
- ice: rename ICE_MAX_VF_COUNT to avoid confusion (Petr Oros) [2037974]
- ice: remove unused definitions from ice_sriov.h (Petr Oros) [2037974]
- ice: convert vf->vc_ops to a const pointer (Petr Oros) [2037974]
- ice: remove circular header dependencies on ice.h (Petr Oros) [2037974]
- ice: rename ice_virtchnl_pf.c to ice_sriov.c (Petr Oros) [2037974]
- ice: rename ice_sriov.c to ice_vf_mbx.c (Petr Oros) [2037974]
- ice: Fix FV offset searching (Petr Oros) [2037974]
- ice: Add support for outer dest MAC for ADQ tunnels (Petr Oros) [2037974]
- ice: avoid XDP checks in ice_clean_tx_irq() (Petr Oros) [2037974]
- ice: change "can't set link" message to dbg level (Petr Oros) [2037974]
- ice: Add slow path offload stats on port representor in switchdev (Petr Oros) [2037974]
- ice: Add support for inner etype in switchdev (Petr Oros) [2037974]
- ice: Fix curr_link_speed advertised speed (Petr Oros) [2037974]
- ice: Don't use GFP_KERNEL in atomic context (Petr Oros) [2037974]
- ice: stop disabling VFs due to PF error responses (Petr Oros) [2037974]
- ice: xsk: fix GCC version checking against pragma unroll presence (Petr Oros) [2037974]
- ice: convert VF storage to hash table with krefs and RCU (Petr Oros) [2037974]
- ice: introduce VF accessor functions (Petr Oros) [2037974]
- ice: factor VF variables to separate structure (Petr Oros) [2037974]
- ice: convert ice_for_each_vf to include VF entry iterator (Petr Oros) [2037974]
- ice: use ice_for_each_vf for iteration during removal (Petr Oros) [2037974]
- ice: remove checks in ice_vc_send_msg_to_vf (Petr Oros) [2037974]
- ice: move VFLR acknowledge during ice_free_vfs (Petr Oros) [2037974]
- ice: move clear_malvf call in ice_free_vfs (Petr Oros) [2037974]
- ice: pass num_vfs to ice_set_per_vf_res() (Petr Oros) [2037974]
- ice: store VF pointer instead of VF ID (Petr Oros) [2037974]
- ice: refactor unwind cleanup in eswitch mode (Petr Oros) [2037974]
- ice: add TTY for GNSS module for E810T device (Petr Oros) [2037974]
- ice: initialize local variable 'tlv' (Petr Oros) [2037974]
- ice: check the return of ice_ptp_gettimex64 (Petr Oros) [2037974]
- ice: fix concurrent reset and removal of VFs (Petr Oros) [2037974]
- ice: fix setting l4 port flag when adding filter (Petr Oros) [2037974]
- ice: Match on all profiles in slow-path (Petr Oros) [2037974]
- ice: enable parsing IPSEC SPI headers for RSS (Petr Oros) [2037974]
- ice: Simplify tracking status of RDMA support (Petr Oros) [2037974]
- ice: fix IPIP and SIT TSO offload (Petr Oros) [2037974]
- ice: fix an error code in ice_cfg_phy_fec() (Petr Oros) [2037974]
- ice: Add ability for PF admin to enable VF VLAN pruning (Petr Oros) [2037974]
- ice: Add support for 802.1ad port VLANs VF (Petr Oros) [2037974]
- ice: Advertise 802.1ad VLAN filtering and offloads for PF netdev (Petr Oros) [2037974]
- ice: Support configuring the device to Double VLAN Mode (Petr Oros) [2037974]
- ice: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037974]
- ice: Add hot path support for 802.1Q and 802.1ad VLAN offloads (Petr Oros) [2037974]
- ice: Add outer_vlan_ops and VSI specific VLAN ops implementations (Petr Oros) [2037974]
- ice: Adjust naming for inner VLAN operations (Petr Oros) [2037974]
- ice: Use the proto argument for VLAN ops (Petr Oros) [2037974]
- ice: Refactor vf->port_vlan_info to use ice_vlan (Petr Oros) [2037974]
- ice: Introduce ice_vlan struct (Petr Oros) [2037974]
- ice: Add new VSI VLAN ops (Petr Oros) [2037974]
- ice: Add helper function for adding VLAN 0 (Petr Oros) [2037974]
- ice: Refactor spoofcheck configuration functions (Petr Oros) [2037974]
- ice: xsk: Borrow xdp_tx_active logic from i40e (Petr Oros) [2037974]
- ice: xsk: Improve AF_XDP ZC Tx and use batching API (Petr Oros) [2037974]
- ice: xsk: Avoid potential dead AF_XDP Tx processing (Petr Oros) [2037974]
- ice: Make Tx threshold dependent on ring length (Petr Oros) [2037974]
- ice: xsk: Handle SW XDP ring wrap and bump tail more often (Petr Oros) [2037974]
- ice: xsk: Force rings to be sized to power of 2 (Petr Oros) [2037974]
- ice: Remove likely for napi_complete_done (Petr Oros) [2037974]
- ice: add support for DSCP QoS for IDC (Petr Oros) [2037974]
- ice: respect metadata on XSK Rx to skb (Petr Oros) [2037974]
- ice: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Petr Oros) [2037974]
- ice: respect metadata in legacy-rx/ice_construct_skb() (Petr Oros) [2037974]
- ice: Remove useless DMA-32 fallback configuration (Petr Oros) [2037974]
- ice: Use bitmap_free() to free bitmap (Petr Oros) [2037974]
- ice: Optimize a few bitmap operations (Petr Oros) [2037974]
- ice: Slightly simply ice_find_free_recp_res_idx (Petr Oros) [2037974]
- ice: improve switchdev's slow-path (Petr Oros) [2037974]
- ice: replay advanced rules after reset (Petr Oros) [2037974]
- net: fixup build after bpf header changes (Petr Oros) [2037974]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2037974]
- ice: Add flow director support for channel mode (Petr Oros) [2037974]
- ice: switch to napi_build_skb() (Petr Oros) [2037974]
- ice: xsk: fix cleaned_count setting (Petr Oros) [2037974]
- ice: xsk: allow empty Rx descriptors on XSK ZC data path (Petr Oros) [2037974]
- ice: xsk: do not clear status_error0 for ntu + nb_buffs descriptor (Petr Oros) [2037974]
- ice: remove dead store on XSK hotpath (Petr Oros) [2037974]
- ice: xsk: allocate separate memory for XDP SW ring (Petr Oros) [2037974]
- ice: xsk: return xsk buffers back to pool when cleaning the ring (Petr Oros) [2037974]
- ice: trivial: fix odd indenting (Petr Oros) [2037974]
- ice: support crosstimestamping on E822 devices if supported (Petr Oros) [2037974]
- ice: exit bypass mode once hardware finishes timestamp calibration (Petr Oros) [2037974]
- ice: ensure the hardware Clock Generation Unit is configured (Petr Oros) [2037974]
- ice: implement basic E822 PTP support (Petr Oros) [2037974]
- ice: convert clk_freq capability into time_ref (Petr Oros) [2037974]
- ice: introduce ice_ptp_init_phc function (Petr Oros) [2037974]
- ice: use 'int err' instead of 'int status' in ice_ptp_hw.c (Petr Oros) [2037974]
- ice: PTP: move setting of tstamp_config (Petr Oros) [2037974]
- ice: introduce ice_base_incval function (Petr Oros) [2037974]
- ice: Fix E810 PTP reset flow (Petr Oros) [2037974]
- ice: Don't put stale timestamps in the skb (Petr Oros) [2037974]
- ice: Use div64_u64 instead of div_u64 in adjfine (Petr Oros) [2037974]
- ice: use modern kernel API for kick (Petr Oros) [2037974]
- ice: tighter control over VSI_DOWN state (Petr Oros) [2037974]
- ice: use prefetch methods (Petr Oros) [2037974]
- ice: update to newer kernel API (Petr Oros) [2037974]
- ice: support immediate firmware activation via devlink reload (Petr Oros) [2037974]
- ice: reduce time to read Option ROM CIVD data (Petr Oros) [2037974]
- ice: move ice_devlink_flash_update and merge with ice_flash_pldm_image (Petr Oros) [2037974]
- ice: move and rename ice_check_for_pending_update (Petr Oros) [2037974]
- ice: devlink: add shadow-ram region to snapshot Shadow RAM (Petr Oros) [2037974]
- ice: Remove unused ICE_FLOW_SEG_HDRS_L2_MASK (Petr Oros) [2037974]
- ice: Remove unnecessary casts (Petr Oros) [2037974]
- ice: Propagate error codes (Petr Oros) [2037974]
- ice: Remove excess error variables (Petr Oros) [2037974]
- ice: Cleanup after ice_status removal (Petr Oros) [2037974]
- ice: Remove enum ice_status (Petr Oros) [2037974]
- ice: Use int for ice_status (Petr Oros) [2037974]
- ice: Remove string printing for ice_status (Petr Oros) [2037974]
- ice: Refactor status flow for DDP load (Petr Oros) [2037974]
- ice: Refactor promiscuous functions (Petr Oros) [2037974]
- ice: refactor PTYPE validating (Petr Oros) [2037974]
- ice: Add package PTYPE enable information (Petr Oros) [2037974]
- ice: safer stats processing (Petr Oros) [2037974]
- ice: fix adding different tunnels (Petr Oros) [2037974]
- ice: fix choosing UDP header type (Petr Oros) [2037974]
- ice: ignore dropped packets during init (Petr Oros) [2037974]
- ice: rearm other interrupt cause register after enabling VFs (Petr Oros) [2037974]
- ice: fix FDIR init missing when reset VF (Petr Oros) [2037974]
- ice: xsk: clear status_error0 for each allocated desc (Petr Oros) [2037974]
- net/ice: Remove unused enum (Petr Oros) [2037974]
- net/ice: Fix boolean assignment (Petr Oros) [2037974]
- ice: avoid bpf_prog refcount underflow (Petr Oros) [2037974]
- ice: fix vsi->txq_map sizing (Petr Oros) [2037974]
- net/ice: Add support for enable_iwarp and enable_roce devlink param (Petr Oros) [2037974]
- ice: Hide bus-info in ethtool for PRs in switchdev mode (Petr Oros) [2037974]
- ice: Clear synchronized addrs when adding VFs in switchdev mode (Petr Oros) [2037974]
- intel: Simplify bool conversion (Petr Oros) [2037974]
- ice: fix error return code in ice_get_recp_frm_fw() (Petr Oros) [2037974]
- ice: Fix clang -Wimplicit-fallthrough in ice_pull_qvec_from_rc() (Petr Oros) [2037974]
- ice: Add support to print error on PHY FW load failure (Petr Oros) [2037974]
- ice: Add support for changing MTU on PR in switchdev mode (Petr Oros) [2037974]
- ice: send correct vc status in switchdev (Petr Oros) [2037974]
- ice: support for GRE in eswitch (Petr Oros) [2037974]
- ice: low level support for tunnels (Petr Oros) [2037974]
- ice: VXLAN and Geneve TC support (Petr Oros) [2037974]
- ice: support for indirect notification (Petr Oros) [2037974]
- ice: Add tc-flower filter support for channel (Petr Oros) [2037974]
- ice: enable ndo_setup_tc support for mqprio_qdisc (Petr Oros) [2037974]
- ice: Add infrastructure for mqprio support via ndo_setup_tc (Petr Oros) [2037974]
- ice: fix an error code in ice_ena_vfs() (Petr Oros) [2037974]
- ice: Refactor PR ethtool ops (Petr Oros) [2037974]
- ice: Manage act flags for switchdev offloads (Petr Oros) [2037974]
- ice: Forbid trusted VFs in switchdev mode (Petr Oros) [2037974]
- ice: introduce XDP_TX fallback path (Petr Oros) [2037974]
- ice: optimize XDP_TX workloads (Petr Oros) [2037974]
- ice: propagate xdp_ring onto rx_ring (Petr Oros) [2037974]
- ice: do not create xdp_frame on XDP_TX (Petr Oros) [2037974]
- ice: unify xdp_rings accesses (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PR (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PF (Petr Oros) [2037974]
- ice: Allow changing lan_en and lb_en on all kinds of filters (Petr Oros) [2037974]
- ice: cleanup rules info (Petr Oros) [2037974]
- ice: allow deleting advanced rules (Petr Oros) [2037974]
- ice: allow adding advanced rules (Petr Oros) [2037974]
- ice: create advanced switch recipe (Petr Oros) [2037974]
- ice: manage profiles and field vectors (Petr Oros) [2037974]
- ice: implement low level recipes functions (Petr Oros) [2037974]
- ice: add port representor ethtool ops and stats (Petr Oros) [2037974]
- ice: switchdev slow path (Petr Oros) [2037974]
- ice: rebuild switchdev when resetting all VFs (Petr Oros) [2037974]
- ice: enable/disable switchdev when managing VFs (Petr Oros) [2037974]
- ice: introduce new type of VSI for switchdev (Petr Oros) [2037974]
- ice: set and release switchdev environment (Petr Oros) [2037974]
- ice: allow changing lan_en and lb_en on dflt rules (Petr Oros) [2037974]
- ice: manage VSI antispoof and destination override (Petr Oros) [2037974]
- ice: allow process VF opcodes in different ways (Petr Oros) [2037974]
- ice: introduce VF port representor (Petr Oros) [2037974]
- ice: Move devlink port to PF/VF struct (Petr Oros) [2037974]
- ice: support basic E-Switch mode control (Petr Oros) [2037974]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Petr Oros) [2037974]
- ice: Use the xsk batched rx allocation interface (Petr Oros) [2037974]
- ice: Use xdp_buf instead of rx_buf for xsk zero-copy (Petr Oros) [2037974]
- ice: Only lock to update netdev dev_addr (Petr Oros) [2037974]
- ice: restart periodic outputs around time changes (Petr Oros) [2037974]
- ice: fix Tx queue iteration for Tx timestamp enablement (Petr Oros) [2037974]

* Mon Jul 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-124.el9]
- scsi: ibmvfc: Allocate/free queue resource only during probe/remove (Diego Domingos) [2099962]
- ceph: wait on async create before checking caps for syncfs (Jeffrey Layton) [2094965]
- lib: bitmap: Introduce node-aware alloc API (Ivan Vecera) [2101768]
- dm raid: fix accesses beyond end of raid member array (Benjamin Marzinski) [2090507]
- block: remove bioset_init_from_src (Benjamin Marzinski) [2090507]
- dm: fix bio_set allocation (Benjamin Marzinski) [2090507]
- dm mirror log: clear log bits up to BITS_PER_LONG boundary (Benjamin Marzinski) [2090507]
- dm: fix BLK_STS_DM_REQUEUE handling when dm_io represents split bio (Benjamin Marzinski) [2090507]
- dm: do not return early from dm_io_complete if BLK_STS_AGAIN without polling (Benjamin Marzinski) [2090507]
- dm era: commit metadata in postsuspend after worker stops (Benjamin Marzinski) [2090507]
- dm: fix narrow race for REQ_NOWAIT bios being issued despite no support (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_put_live_table_bio (Benjamin Marzinski) [2090507]
- dm: improve abnormal bio processing (Benjamin Marzinski) [2090507]
- dm: simplify bio-based IO accounting further (Benjamin Marzinski) [2090507]
- dm: improve dm_io reference counting (Benjamin Marzinski) [2090507]
- dm: don't grab target io reference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm: improve bio splitting and associated IO accounting (Benjamin Marzinski) [2090507]
- dm: introduce dm_{get,put}_live_table_bio called from dm_submit_bio (Benjamin Marzinski) [2090507]
- dm mirror log: round up region bitmap size to BITS_PER_LONG (Benjamin Marzinski) [2090507]
- dm: fix race in dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm verity: set DM_TARGET_IMMUTABLE feature flag (Benjamin Marzinski) [2090507]
- dm table: fix dm_table_supports_poll to return false if no data devices (Benjamin Marzinski) [2090507]
- dm cache metadata: remove unnecessary variable in __dump_mapping (Benjamin Marzinski) [2090507]
- dm mpath: provide high-resolution timer to HST for bio-based (Benjamin Marzinski) [2090507]
- dm crypt: make printing of the key constant-time (Benjamin Marzinski) [2090507]
- dm integrity: fix error code in dm_integrity_ctr() (Benjamin Marzinski) [2090507]
- dm stats: add cond_resched when looping over entries (Benjamin Marzinski) [2090507]
- dm: put all polled dm_io instances into a single list (Benjamin Marzinski) [2090507]
- dm: switch to bdev based IO accounting interfaces (Benjamin Marzinski) [2090507]
- dm: pass dm_io instance to dm_io_acct directly (Benjamin Marzinski) [2090507]
- dm: don't pass bio to __dm_start_io_acct and dm_end_io_acct (Benjamin Marzinski) [2090507]
- dm: use bio_sectors in dm_aceept_partial_bio (Benjamin Marzinski) [2090507]
- dm: simplify basic targets (Benjamin Marzinski) [2090507]
- dm: conditionally enable branching for less used features (Benjamin Marzinski) [2090507]
- dm: move hot dm_io members to same cacheline as dm_target_io (Benjamin Marzinski) [2090507]
- dm: add local variables to clone_endio and __map_bio (Benjamin Marzinski) [2090507]
- dm: mark various branches unlikely (Benjamin Marzinski) [2090507]
- dm: simplify dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm: simplify dm_io access in dm_split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_set_error and __dm_io_dec_pending (Benjamin Marzinski) [2090507]
- dm: conditionally enable BIOSET_PERCPU_CACHE for dm_io bioset (Benjamin Marzinski) [2090507]
- dm: allow dm_accept_partial_bio() for dm_io without duplicate bios (Benjamin Marzinski) [2090507]
- dm zone: fix NULL pointer dereference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm mpath: only use ktime_get_ns() in historical selector (Benjamin Marzinski) [2090507]
- dm: fix bio polling to handle possibile BLK_STS_AGAIN (Benjamin Marzinski) [2090507]
- dm: fix dm_io and dm_target_io flags race condition on Alpha (Benjamin Marzinski) [2090507]
- dm integrity: set journal entry unused when shrinking device (Benjamin Marzinski) [2090507]
- dm ioctl: log an error if the ioctl structure is corrupted (Benjamin Marzinski) [2090507]
- dm: consolidate spinlocks in dm_io struct (Benjamin Marzinski) [2090507]
- dm: reduce size of dm_io and dm_target_io structs (Benjamin Marzinski) [2090507]
- dm: switch dm_target_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: switch dm_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: update email address in MAINTAINERS (Benjamin Marzinski) [2090507]
- dm: return void from __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_complete (Benjamin Marzinski) [2090507]
- dm cache: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: simplify dm_sumbit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm thin: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add WARN_ON_ONCE to dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: support bio polling (Benjamin Marzinski) [2090507]
- block: add ->poll_bio to block_device_operations (Benjamin Marzinski) [2090507]
- dm mpath: use DMINFO instead of printk with KERN_INFO (Benjamin Marzinski) [2090507]
- dm: stop using bdevname (Benjamin Marzinski) [2090507]
- dm-zoned: remove the ->name field in struct dmz_dev (Benjamin Marzinski) [2090507]
- dm: remove unnecessary local variables in __bind (Benjamin Marzinski) [2090507]
- dm: requeue IO if mapping table not yet available (Benjamin Marzinski) [2090507]
- dm io: remove stale comment block for dm_io() (Benjamin Marzinski) [2090507]
- dm thin metadata: remove unused dm_thin_remove_block and __remove (Benjamin Marzinski) [2090507]
- dm thin: use time_is_before_jiffies instead of open coding it (Benjamin Marzinski) [2090507]
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_cleanup_zoned_dev() (Benjamin Marzinski) [2090507]
- dm ioctl: prevent potential spectre v1 gadget (Benjamin Marzinski) [2090507]
- dm: cleanup double word in comment (Benjamin Marzinski) [2090507]
- dm ima: fix wrong length calculation for no_data string (Benjamin Marzinski) [2090507]
- dm cache policy smq: make static read-only array table const (Benjamin Marzinski) [2090507]
- dm delay: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm crypt: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add dm_submit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm: flag clones created by __send_duplicate_bios (Benjamin Marzinski) [2090507]
- dm: reduce dm_io and dm_target_io struct sizes (Benjamin Marzinski) [2090507]
- dm: move duplicate code from callers of alloc_tio into alloc_tio (Benjamin Marzinski) [2090507]
- dm: record old_sector in dm_target_io before calling map function (Benjamin Marzinski) [2090507]
- dm: remove legacy code only needed before submit_bio recursion (Benjamin Marzinski) [2090507]
- dm: remove unused mapped_device argument from free_tio (Benjamin Marzinski) [2090507]
- dm: remove impossible BUG_ON in __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: reduce code duplication in __map_bio (Benjamin Marzinski) [2090507]
- dm: refactor dm_split_and_process_bio a bit (Benjamin Marzinski) [2090507]
- dm: fold __clone_and_map_data_bio into __split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: rename split functions (Benjamin Marzinski) [2090507]
- dm: reorder members in mapped_device struct (Benjamin Marzinski) [2090507]
- dm: eliminate copying of dm_io fields in dm_io_dec_pending (Benjamin Marzinski) [2090507]

* Fri Jul 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-123.el9]
- exec: Force single empty string when argv is empty (Diego Domingos) [2099482]
- scsi: ibmvfc: Store vhost pointer during subcrq allocation (Gustavo Walbon) [2098103]
- powerpc: Enable execve syscall exit tracepoint (Steve Best) [2095526]
- rcu-tasks: Use delayed_work to delay rcu_tasks_verify_self_tests() (Waiman Long) [2094506]
- rcu-tasks: Be more patient for RCU Tasks boot-time testing (Waiman Long) [2094506]
- redhat/configs: Add new refcnt tracker options (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2096377]
- net: add dev->dev_registered_tracker (Ivan Vecera) [2096377]
- net/smc: use GFP_ATOMIC allocation in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net/smc: fix ref_tracker issue in smc_pnet_add() (Ivan Vecera) [2096377]
- net: refine dev_put()/dev_hold() debugging (Ivan Vecera) [2096377]
- ref_tracker: add a count of untracked references (Ivan Vecera) [2096377]
- ref_tracker: implement use-after-free detection (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct rpc_xprt (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct gss_auth (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct svc_xprt (Ivan Vecera) [2096377]
- net/smc: fix possible NULL deref in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net: bridge: fix net device refcount tracking issue in error path (Ivan Vecera) [2096377]
- ref_tracker: use __GFP_NOFAIL more carefully (Ivan Vecera) [2096377]
- net: sched: do not allocate a tracker in tcf_exts_init() (Ivan Vecera) [2096377]
- af_packet: fix tracking issues in packet_do_bind() (Ivan Vecera) [2096377]
- netlink: do not allocate a device refcount tracker in ethnl_default_notify() (Ivan Vecera) [2096377]
- net/sched: add missing tracker information in qdisc_create() (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: add netns refcount tracker to masq_dev_work (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: defer conntrack walk to work queue (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: make async masq_inet6_event handling generic (Ivan Vecera) [2096377]
- netfilter: nfnetlink: add netns refcount tracker to struct nfulnl_instance (Ivan Vecera) [2096377]
- ethtool: always write dev in ethnl_parse_header_dev_get (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct packet_type (Ivan Vecera) [2096377]
- ethtool: use ethnl_parse_header_dev_put() (Ivan Vecera) [2096377]
- net: dev_replace_track() cleanup (Ivan Vecera) [2096377]
- net: linkwatch: be more careful about dev->linkwatch_dev_tracker (Ivan Vecera) [2096377]
- mptcp: adjust to use netns refcount tracker (Ivan Vecera) [2096377]
- ipv6: use GFP_ATOMIC in rt6_probe() (Ivan Vecera) [2096377]
- xfrm: add net device refcount tracker to struct xfrm_state_offload (Ivan Vecera) [2096377]
- ethtool: fix null-ptr-deref on ref tracker (Ivan Vecera) [2096377]
- ppp: add netns refcount tracker (Ivan Vecera) [2096377]
- l2tp: add netns refcount tracker to l2tp_dfs_seq_data (Ivan Vecera) [2096377]
- net: sched: add netns refcount tracker to struct tcf_exts (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct seq_net_private (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct sock (Ivan Vecera) [2096377]
- net: add networking namespace refcount tracker (Ivan Vecera) [2096377]
- xfrm: use net device refcount tracker helpers (Ivan Vecera) [2096377]
- net: sched: act_mirred: add net device refcount tracker (Ivan Vecera) [2096377]
- openvswitch: add net device refcount tracker to struct vport (Ivan Vecera) [2096377]
- netlink: add net device refcount tracker to struct ethnl_req_info (Ivan Vecera) [2096377]
- net/smc: add net device tracker to struct smc_pnetentry (Ivan Vecera) [2096377]
- pktgen add net device refcount tracker (Ivan Vecera) [2096377]
- llc: add net device refcount tracker (Ivan Vecera) [2096377]
- ax25: add net device refcount tracker (Ivan Vecera) [2096377]
- inet: add net device refcount tracker to struct fib_nh_common (Ivan Vecera) [2096377]
- net: switchdev: add net device refcount tracker (Ivan Vecera) [2096377]
- net: watchdog: add net device refcount tracker (Ivan Vecera) [2096377]
- net: bridge: add net device refcount tracker (Ivan Vecera) [2096377]
- vlan: add net device refcount tracker (Ivan Vecera) [2096377]
- net: eql: add net device refcount tracker (Ivan Vecera) [2096377]
- vrf: use dev_replace_track() for better tracking (Ivan Vecera) [2096377]
- netpoll: add net device refcount tracker to struct netpoll (Ivan Vecera) [2096377]
- ipmr, ip6mr: add net device refcount tracker to struct vif_device (Ivan Vecera) [2096377]
- net: failover: add net device refcount tracker (Ivan Vecera) [2096377]
- net: linkwatch: add net device refcount tracker (Ivan Vecera) [2096377]
- net/sched: add net device refcount tracker to struct Qdisc (Ivan Vecera) [2096377]
- ipv4: add net device refcount tracker to struct in_device (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct inet6_dev (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_adjacent (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neigh_parms (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct pneigh_entry (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neighbour (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct ip6_tnl (Ivan Vecera) [2096377]
- sit: add net device refcount tracking to ip_tunnel (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to rt6_probe_deferred() (Ivan Vecera) [2096377]
- net: dst: add net device refcount tracking to dst_entry (Ivan Vecera) [2096377]
- drop_monitor: add net device refcount tracker (Ivan Vecera) [2096377]
- net: add net device refcount tracker to dev_ifsioc() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to ethtool_phys_id() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_rx_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker infrastructure (Ivan Vecera) [2096377]
- lib: add tests for reference tracker (Ivan Vecera) [2096377]
- lib: add reference counting tracking infrastructure (Ivan Vecera) [2096377]
- net: drop nopreempt requirement on sock_prot_inuse_add() (Ivan Vecera) [2096377]
- net: merge net->core.prot_inuse and net->core.sock_inuse (Ivan Vecera) [2096377]
- net: make sock_inuse_add() available (Ivan Vecera) [2096377]
- net: inline sock_prot_inuse_add() (Ivan Vecera) [2096377]
- netdevice: move xdp_rxq within netdev_rx_queue (Ivan Vecera) [2096377]
- nfs: fix broken handling of the softreval mount option (Benjamin Coddington) [2095275]

* Thu Jun 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-122.el9]
- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers (Jonathan Toppins) [2094911]
- exec: Force single empty string when argv is empty (Rafael Aquini) [2097485]
- mptcp: Do TCP fallback on early DSS checksum failure (Paolo Abeni) [2100072]
- mptcp: fix checksum byte order (Paolo Abeni) [2100072]
- platform/x86/intel/sdsi: Fix bug in multi packet reads (David Arcari) [2098067]
- platform/x86/intel/sdsi: Poll on ready bit for writes (David Arcari) [2098067]
- platform/x86/intel/sdsi: Handle leaky bucket (David Arcari) [2098067]
- hv_netvsc: Fix potential dereference of NULL pointer (Mohammed Gamal) [2086626]
- hv_netvsc: Add support for XDP_REDIRECT (Mohammed Gamal) [2086626]
- hv_netvsc: Print value of invalid ID in netvsc_send_{completion,tx_complete}() (Mohammed Gamal) [2086626]
- net: hyperv: remove use of bpf_op_t (Mohammed Gamal) [2086626]
- hv_netvsc: Add check for kvmalloc_array (Mohammed Gamal) [2086626]
- net: netvsc: remove break after return (Mohammed Gamal) [2086626]
- Netvsc: Call hv_unmap_memory() in the netvsc_device_remove() (Mohammed Gamal) [2086626]
- net: netvsc: Add Isolation VM support for netvsc driver (Mohammed Gamal) [2086626]
- hv_netvsc: Use bitmap_zalloc() when applicable (Mohammed Gamal) [2086626]
- hv_netvsc: Add comment of netvsc_xdp_xmit() (Mohammed Gamal) [2086626]
- hv_netvsc: use netif_is_bond_master() instead of open code (Mohammed Gamal) [2086626]
- arm64: kdump: Do not allocate crash low memory if not needed (Pingfan Liu) [2091852]
- docs: kdump: Update the crashkernel description for arm64 (Pingfan Liu) [2091852]
- of: Support more than one crash kernel regions for kexec -s (Pingfan Liu) [2091852]
- of: fdt: Add memory for devices by DT property "linux,usable-memory-range" (Pingfan Liu) [2091852]
- arm64: kdump: Reimplement crashkernel=X (Pingfan Liu) [2091852]
- arm64: Use insert_resource() to simplify code (Pingfan Liu) [2091852]
- kdump: return -ENOENT if required cmdline option does not exist (Pingfan Liu) [2091852]
- arm64: mm: use IS_ENABLED(CONFIG_KEXEC_CORE) instead of #ifdef (Pingfan Liu) [2091852]
- arm64: mm: Drop 'const' from conditional arm64_dma_phys_limit definition (Pingfan Liu) [2091852]
- arm64: Do not defer reserve_crashkernel() for platforms with no DMA memory zones (Pingfan Liu) [2091852]
- efi: apply memblock cap after memblock_add() (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,usable-memory-range handling (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,elfcorehdr handling (Pingfan Liu) [2091852]
- of/fdt: move elfcorehdr reservation early for crash dump kernel (Pingfan Liu) [2091852]
- of/fdt: Don't worry about non-memory region overlap for no-map (Pingfan Liu) [2091852]
- of: fdt: Aggregate the processing of "linux,usable-memory-range" (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_memory() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_root() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_chosen() to call directly (Pingfan Liu) [2091852]
- of/fdt: Remove of_scan_flat_dt() usage for __fdt_scan_reserved_mem() (Pingfan Liu) [2091852]
- of: fdt: Rename reserve_elfcorehdr() to fdt_reserve_elfcorehdr() (Pingfan Liu) [2091852]
- of: fdt: Use IS_ENABLED(CONFIG_BLK_DEV_INITRD) instead of #ifdef (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling usable memory range property (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling elf core headers property (Pingfan Liu) [2091852]
- of: fdt: Remove weak early_init_dt_mark_hotplug_memory_arch() (Pingfan Liu) [2091852]
- of: fdt: Remove early_init_dt_reserve_memory_arch() override capability (Pingfan Liu) [2091852]
- of: fdt: do not update local variable after use (Pingfan Liu) [2091852]
- of: fdt: remove unnecessary codes (Pingfan Liu) [2091852]
- mei: me: add Alder Lake N device id. (David Arcari) [2072663]
- mei: me: disable driver on the ign firmware (David Arcari) [2072663]
- mei: me: add Ice Lake-N device id. (David Arcari) [2072663]
- iwlwifi: fix use-after-free (Jose Ignacio Tornos Martinez) [2093882]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2092422]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2092422]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2092422]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2092422]
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2092422]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2092422]
- redhat/configs: Allow CRYPTO_CHACHA20 to remain a module (Vladis Dronov) [1917926]
- crypto: s390 - add crypto library interface for ChaCha20 (Vladis Dronov) [1917926]
- s390/crypto: add SIMD implementation for ChaCha20 (Vladis Dronov) [1917926]

* Wed Jun 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-121.el9]
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on x86_64 (Eric Auger) [2089765]
- crypto: fips - make proc files report fips module name and version (Simo Sorce) [2080499]
- fuse: clean up error exits in fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: always initialize sb->s_fs_info (Miklos Szeredi) [2021800]
- fuse: clean up fuse_mount destruction (Miklos Szeredi) [2021800]
- fuse: get rid of fuse_put_super() (Miklos Szeredi) [2021800]
- fuse: check s_root when destroying sb (Miklos Szeredi) [2021800]
- fuse: allow sharing existing sb (Miklos Szeredi) [2021800]
- fuse: move fget() to fuse_get_tree() (Miklos Szeredi) [2021800]
- fuse: move option checking into fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: name fs_context consistently (Miklos Szeredi) [2021800]
- gfs2: Stop using glock holder auto-demotion for now (Andreas Gruenbacher) [2082193]
- gfs2: buffered write prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Align read and write chunks to the page cache (Andreas Gruenbacher) [2082193]
- gfs2: Pull return value test out of should_fault_in_pages (Andreas Gruenbacher) [2082193]
- gfs2: Clean up use of fault_in_iov_iter_{read,write}able (Andreas Gruenbacher) [2082193]
- gfs2: Variable rename (Andreas Gruenbacher) [2082193]
- gfs2: Fix filesystem block deallocation for short writes (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_end cleanup (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_failed fix (Andreas Gruenbacher) [2082193]
- gfs2: Don't re-check for write past EOF unnecessarily (Andreas Gruenbacher) [2082193]
- gfs2: No short reads or writes upon glock contention (Andreas Gruenbacher) [2082193]
- fs/iomap: Fix buffered write page prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Make sure not to return short direct writes (Andreas Gruenbacher) [2082193]
- gfs2: Remove dead code in gfs2_file_read_iter (Andreas Gruenbacher) [2082193]
- gfs2: Fix gfs2_file_buffered_write endless loop workaround (Andreas Gruenbacher) [2082193]
- gfs2: Minor retry logic cleanup (Andreas Gruenbacher) [2082193]
- gfs2: Disable page faults during lockless buffered reads (Andreas Gruenbacher) [2082193]
- gfs2: Fix should_fault_in_pages() logic (Andreas Gruenbacher) [2082193]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2082193]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2082193]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2082193]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2082193]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2082193]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2082193]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2082193]
- redhat/kernel.spec.template: fix standalone tools build (Jan Stancek) [2081992]
- arm64/mte: Clarify mode reported by PR_GET_TAGGED_ADDR_CTRL (Mark Salter) [2076088]
- arm64: mte: change PR_MTE_TCF_NONE back into an unsigned long (Mark Salter) [2076088]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Mark Salter) [2076088]
- kselftest/arm64: Skip VL_INHERIT tests for unsupported vector types (Mark Salter) [2076088]
- kselftest/arm64: Parameterise ptrace vector length information (Mark Salter) [2076088]
- arm64: extable: fix load_unaligned_zeropad() reg indices (Mark Salter) [2076088]
- arm64: kexec: Fix missing error code 'ret' warning in load_other_segments() (Mark Salter) [2076088]
- arm64: ftrace: add missing BTIs (Mark Salter) [2076088]
- arm64: kexec: use __pa_symbol(empty_zero_page) (Mark Salter) [2076088]
- arm64: update PAC description for kernel (Mark Salter) [2076088]
- arm64: uaccess: avoid blocking within critical sections (Mark Salter) [2076088]
- arm64: mm: Fix VM_BUG_ON(mm != &init_mm) for trans_pgd (Mark Salter) [2076088]
- arm64: pgtable: make __pte_to_phys/__phys_to_pte_val inline functions (Mark Salter) [2076088]
- arm64: Track no early_pgtable_alloc() for kmemleak (Mark Salter) [2076088]
- arm64: vdso: remove -nostdlib compiler flag (Mark Salter) [2076088]
- arm64: arm64_ftr_reg->name may not be a human-readable string (Mark Salter) [2076088]
- kasan: arm64: fix pcpu_page_first_chunk crash with KASAN_VMALLOC (Mark Salter) [2076088]
- arm64: support page mapping percpu first chunk allocator (Mark Salter) [2076088]
- arm64: cpufeature: Export this_cpu_has_cap helper (Mark Salter) [2076088]
- arm64: Select POSIX_CPU_TIMERS_TASK_WORK (Mark Salter) [2076088]
- arm64: Document boot requirements for FEAT_SME_FA64 (Mark Salter) [2076088]
- arm64: ftrace: use function_nocfi for _mcount as well (Mark Salter) [2076088]
- arm64: asm: setup.h: export common variables (Mark Salter) [2076088]
- arm64/traps: Avoid unnecessary kernel/user pointer conversion (Mark Salter) [2076088]
- arm64/sve: Fix warnings when SVE is disabled (Mark Salter) [2076088]
- arm64/sve: Add stub for sve_max_virtualisable_vl() (Mark Salter) [2076088]
- arm64/sve: Track vector lengths for tasks in an array (Mark Salter) [2076088]
- arm64/sve: Explicitly load vector length when restoring SVE state (Mark Salter) [2076088]
- arm64/sve: Put system wide vector length information into structs (Mark Salter) [2076088]
- arm64/sve: Use accessor functions for vector lengths in thread_struct (Mark Salter) [2076088]
- arm64/sve: Rename find_supported_vector_length() (Mark Salter) [2076088]
- arm64/sve: Make access to FFR optional (Mark Salter) [2076088]
- arm64/sve: Make sve_state_size() static (Mark Salter) [2076088]
- arm64/sve: Remove sve_load_from_fpsimd_state() (Mark Salter) [2076088]
- arm64/fp: Reindent fpsimd_save() (Mark Salter) [2076088]
- selftests: arm64: Factor out utility functions for assembly FP tests (Mark Salter) [2076088]
- selftests: arm64: Add coverage of ptrace flags for SVE VL inheritance (Mark Salter) [2076088]
- selftests: arm64: Verify that all possible vector lengths are handled (Mark Salter) [2076088]
- selftests: arm64: Fix and enable test for setting current VL in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Remove bogus error check on writing to files (Mark Salter) [2076088]
- selftests: arm64: Fix printf() format mismatch in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Move FPSIMD in SVE ptrace test into a function (Mark Salter) [2076088]
- selftests: arm64: More comprehensively test the SVE ptrace interface (Mark Salter) [2076088]
- selftests: arm64: Verify interoperation of SVE and FPSIMD register sets (Mark Salter) [2076088]
- selftests: arm64: Clarify output when verifying SVE register set (Mark Salter) [2076088]
- selftests: arm64: Document what the SVE ptrace test is doing (Mark Salter) [2076088]
- selftests: arm64: Remove extraneous register setting code (Mark Salter) [2076088]
- selftests: arm64: Don't log child creation as a test in SVE ptrace test (Mark Salter) [2076088]
- selftests: arm64: Use a define for the number of SVE ptrace tests to be run (Mark Salter) [2076088]
- arm64: vmlinux.lds.S: remove `.fixup` section (Mark Salter) [2076088]
- arm64: extable: add load_unaligned_zeropad() handler (Mark Salter) [2076088]
- arm64: extable: add a dedicated uaccess handler (Mark Salter) [2076088]
- arm64: extable: add `type` and `data` fields (Mark Salter) [2076088]
- arm64: extable: use `ex` for `exception_table_entry` (Mark Salter) [2076088]
- arm64: extable: make fixup_exception() return bool (Mark Salter) [2076088]
- arm64: extable: consolidate definitions (Mark Salter) [2076088]
- arm64: gpr-num: support W registers (Mark Salter) [2076088]
- arm64: factor out GPR numbering helpers (Mark Salter) [2076088]
- arm64: kvm: use kvm_exception_table_entry (Mark Salter) [2076088]
- arm64: lib: __arch_copy_to_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_copy_from_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_clear_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: vdso32: require CROSS_COMPILE_COMPAT for gcc+bfd (Mark Salter) [2076088]
- arm64: vdso32: suppress error message for 'make mrproper' (Mark Salter) [2076088]
- arm64: vdso32: drop test for -march=armv8-a (Mark Salter) [2076088]
- arm64: vdso32: drop the test for dmb ishld (Mark Salter) [2076088]
- arm64: Add a capability for FEAT_ECV (Mark Salter) [2076088]
- arm64: mte: Add asymmetric mode support (Mark Salter) [2076088]
- arm64: mte: CPU feature detection for Asymm MTE (Mark Salter) [2076088]
- arm64: mte: Bitfield definitions for Asymm MTE (Mark Salter) [2076088]
- arm64: kasan: mte: move GCR_EL1 switch to task switch when KASAN disabled (Mark Salter) [2076088]
- arm64/mm: drop HAVE_ARCH_PFN_VALID (Mark Salter) [2076088]
- arm64: trans_pgd: remove trans_pgd_map_page() (Mark Salter) [2076088]
- arm64: kexec: remove cpu-reset.h (Mark Salter) [2076088]
- arm64: kexec: remove the pre-kexec PoC maintenance (Mark Salter) [2076088]
- arm64: kexec: keep MMU enabled during kexec relocation (Mark Salter) [2076088]
- arm64: kexec: install a copy of the linear-map (Mark Salter) [2076088]
- arm64: kexec: use ld script for relocation function (Mark Salter) [2076088]
- arm64: kexec: relocate in EL1 mode (Mark Salter) [2076088]
- arm64: kexec: configure EL2 vectors for kexec (Mark Salter) [2076088]
- arm64: kexec: pass kimage as the only argument to relocation function (Mark Salter) [2076088]
- arm64: kexec: Use dcache ops macros instead of open-coding (Mark Salter) [2076088]
- arm64: kexec: skip relocation code for inplace kexec (Mark Salter) [2076088]
- arm64: kexec: flush image and lists during kexec load time (Mark Salter) [2076088]
- arm64: hibernate: abstract ttrb0 setup function (Mark Salter) [2076088]
- arm64: trans_pgd: hibernate: Add trans_pgd_copy_el2_vectors (Mark Salter) [2076088]
- arm64: kernel: add helper for booted at EL2 and not VHE (Mark Salter) [2076088]
- arm64: mm: update max_pfn after memory hotplug (Mark Salter) [2076088]
- arm64/mm: Add pud_sect_supported() (Mark Salter) [2076088]
- arm64: mm: Drop pointless call to set_max_mapnr() (Mark Salter) [2076088]
- arm64/hugetlb: fix CMA gigantic page order for non-4K PAGE_SIZE (Mark Salter) [2076088]
- kselftest/arm64: signal: Skip tests if required features are missing (Mark Salter) [2076088]
- arm64: Mitigate MTE issues with str{n}cmp() (Mark Salter) [2076088]
- arm64: add MTE supported check to thread switching and syscall entry/exit (Mark Salter) [2076088]
- arm64: Mark __stack_chk_guard as __ro_after_init (Mark Salter) [2076088]
- arm64/kernel: remove duplicate include in process.c (Mark Salter) [2076088]
- arm64/sve: Use correct size when reinitialising SVE state (Mark Salter) [2076088]
- arm64: remove GCC version check for ARCH_SUPPORTS_INT128 (Mark Salter) [2076088]
- arm64: mm: limit linear region to 51 bits for KVM in nVHE mode (Mark Salter) [2076088]
- arm64: mm: fix comment typo of pud_offset_phys() (Mark Salter) [2076088]
- arm64: signal32: Drop pointless call to sigdelsetmask() (Mark Salter) [2076088]
- arm64/sve: Better handle failure to allocate SVE register storage (Mark Salter) [2076088]
- arm64: Document the requirement for SCR_EL3.HCE (Mark Salter) [2076088]
- arm64: head: avoid over-mapping in map_memory (Mark Salter) [2076088]
- arm64/sve: Add a comment documenting the binutils needed for SVE asm (Mark Salter) [2076088]
- arm64/sve: Add some comments for sve_save/load_state() (Mark Salter) [2076088]
- arm64: replace in_irq() with in_hardirq() (Mark Salter) [2076088]
- arm64: mm: Fix TLBI vs ASID rollover (Mark Salter) [2076088]
- arm64: entry: Add SYM_CODE annotation for __bad_stack (Mark Salter) [2076088]
- arm64: fix typo in a comment (Mark Salter) [2076088]
- arm64: move the (z)install rules to arch/arm64/Makefile (Mark Salter) [2076088]
- arm64/sve: Make fpsimd_bind_task_to_cpu() static (Mark Salter) [2076088]
- arm64: unnecessary end 'return;' in void functions (Mark Salter) [2076088]
- arm64/sme: Document boot requirements for SME (Mark Salter) [2076088]
- arm64: use __func__ to get function name in pr_err (Mark Salter) [2076088]
- arm64: SSBS/DIT: print SSBS and DIT bit when printing PSTATE (Mark Salter) [2076088]
- arm64: cpufeature: Use defined macro instead of magic numbers (Mark Salter) [2076088]
- kselftest/arm64: signal: Add a TODO list for signal handling tests (Mark Salter) [2076088]
- kselftest/arm64: signal: Add test case for SVE register state in signals (Mark Salter) [2076088]
- kselftest/arm64: signal: Verify that signals can't change the SVE vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Check SVE signal frame shows expected vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Support signal frames with SVE register data (Mark Salter) [2076088]
- kselftest/arm64: signal: Add SVE to the set of features we can check for (Mark Salter) [2076088]
- kselftest/arm64: pac: Fix skipping of tests on systems without PAC (Mark Salter) [2076088]
- kselftest/arm64: mte: Fix misleading output when skipping tests (Mark Salter) [2076088]
- kselftest/arm64: Add a TODO list for floating point tests (Mark Salter) [2076088]
- kselftest/arm64: Add tests for SVE vector configuration (Mark Salter) [2076088]
- kselftest/arm64: Validate vector lengths are set in sve-probe-vls (Mark Salter) [2076088]
- kselftest/arm64: Provide a helper binary and "library" for SVE RDVL (Mark Salter) [2076088]
- kselftest/arm64: Ignore check_gcr_el1_cswitch binary (Mark Salter) [2076088]
- Documentation: arm64: describe asymmetric 32-bit support (Mark Salter) [2076088]
- arm64: Remove logic to kill 32-bit tasks on 64-bit-only cores (Mark Salter) [2076088]
- arm64: Hook up cmdline parameter to allow mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Advertise CPUs capable of running 32-bit applications in sysfs (Mark Salter) [2076088]
- arm64: Prevent offlining first CPU with 32-bit EL0 on mismatched system (Mark Salter) [2076088]
- arm64: exec: Adjust affinity for compat tasks with mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Implement task_cpu_possible_mask() (Mark Salter) [2076088]
- KVM: arm64: Add feature register flag definitions (Mark Salter) [2076088]
- arm64/perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Mark Salter) [2076088]
- arm64: entry: call exit_to_user_mode() from C (Mark Salter) [2076088]
- arm64: entry: move bulk of ret_to_user to C (Mark Salter) [2076088]
- arm64: entry: clarify entry/exit helpers (Mark Salter) [2076088]
- arm64: entry: consolidate entry/exit helpers (Mark Salter) [2076088]
- arm64/cpufeature: Optionally disable MTE via command-line (Mark Salter) [2076088]
- arm64: kasan: mte: remove redundant mte_report_once logic (Mark Salter) [2076088]
- arm64: kasan: mte: use a constant kernel GCR_EL1 value (Mark Salter) [2076088]
- arm64: avoid double ISB on kernel entry (Mark Salter) [2076088]
- arm64: mte: optimize GCR_EL1 modification on kernel entry/exit (Mark Salter) [2076088]
- Documentation: document the preferred tag checking mode feature (Mark Salter) [2076088]
- arm64: mte: introduce a per-CPU tag checking mode preference (Mark Salter) [2076088]
- arm64: move preemption disablement to prctl handlers (Mark Salter) [2076088]
- arm64: mte: change ASYNC and SYNC TCF settings into bitfields (Mark Salter) [2076088]
- arm64: mte: rename gcr_user_excl to mte_ctrl (Mark Salter) [2076088]
- arm64: mte: avoid TFSRE0_EL1 related operations unless in async mode (Mark Salter) [2076088]
- arm64/kexec: Test page size support with new TGRAN range values (Mark Salter) [2076088]
- arm64: Add compile-time asserts for siginfo_t offsets (Mark Salter) [2076088]
- Kbuild: use -std=gnu11 for KBUILD_USERCFLAGS (Waiman Long) [2074118]
- Kbuild: move to -std=gnu11 (Waiman Long) [2074118]
- Kbuild: use -Wdeclaration-after-statement (Waiman Long) [2074118]
- Kbuild: add -Wno-shift-negative-value where -Wextra is used (Waiman Long) [2074118]
- kbuild: Add a comment above -Wno-gnu (Waiman Long) [2074118]
- kbuild: Remove -Wno-format-invalid-specifier from clang block (Waiman Long) [2074118]

* Mon Jun 27 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-120.el9]
- vmxnet3: disable overlay offloads if UPT device does not support (Kamal Heib) [2095826]
- vmxnet3: update to version 7 (Kamal Heib) [2095826]
- vmxnet3: use ext1 field to indicate encapsulated packet (Kamal Heib) [2095826]
- vmxnet3: limit number of TXDs used for TSO packet (Kamal Heib) [2095826]
- vmxnet3: add command to set ring buffer sizes (Kamal Heib) [2095826]
- vmxnet3: add support for out of order rx completion (Kamal Heib) [2095826]
- vmxnet3: add support for large passthrough BAR register (Kamal Heib) [2095826]
- vmxnet3: add support for capability registers (Kamal Heib) [2095826]
- vmxnet3: prepare for version 7 changes (Kamal Heib) [2095826]
- net: vmxnet3: fix possible NULL pointer dereference in vmxnet3_rq_cleanup() (Kamal Heib) [2095826]
- net: vmxnet3: fix possible use-after-free bugs in vmxnet3_rq_alloc_rx_buf() (Kamal Heib) [2095826]
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse() (Florian Westphal) [2096401] {CVE-2022-2078}
- fanotify: Fix stale file descriptor in copy_event_to_user() (Andrey Albershteyn) [2054337] {CVE-2022-1998}
- scsi: mpi3mr: Fix kernel-doc (Tomas Henzl) [2091880]
- scsi: mpi3mr: Rework mrioc->bsg_device model to fix warnings (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add target device related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add shost related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return error if dma_alloc_coherent() fails (Tomas Henzl) [2091880]
- scsi: mpi3mr: Fix a NULL vs IS_ERR() bug in mpi3mr_bsg_init() (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return I/Os to an unrecoverable HBA with DID_ERROR (Tomas Henzl) [2091880]
- scsi: mpi3mr: Hidden drives not removed during soft reset (Tomas Henzl) [2091880]
- scsi: mpi3mr: Increase I/O timeout value to 60s (Tomas Henzl) [2091880]
- scsi: mpi3mr: Update driver version to 8.0.0.69.0 (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for NVMe passthrough (Tomas Henzl) [2091880]
- scsi: mpi3mr: Expose adapter state to sysfs (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for PEL commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for MPT commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Move data structures/definitions from MPI headers to uapi header (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for driver commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add bsg device support (Tomas Henzl) [2091880]
- tcp: Don't acquire inet_listen_hashbucket::lock with disabled BH. (Paolo Abeni) [2090409]
- block/bfq: Enable I/O statistics (Ming Lei) [2083917]
- blk-mq: don't clear flush_rq from tags->rqs[] (Ming Lei) [2083917]
- blk-mq: avoid to touch q->elevator without any protection (Ming Lei) [2083917]
- blk-mq: protect q->elevator by ->sysfs_lock in blk_mq_elv_switch_none (Ming Lei) [2083917]
- md/raid5-ppl: Fix argument order in bio_alloc_bioset() (Ming Lei) [2083917]
- dm: fix bio length of empty flush (Ming Lei) [2083917]
- rhel: configs: add config option CONFIG_CRYPTO_CRC64* (Ming Lei) [2083917]
- rhel: configs: enable BLOCK_LEGACY_AUTOLOAD (Ming Lei) [2083917]
- bcache: put bch_bio_map() back to correct location in journal_write_unlocked() (Ming Lei) [2083917]
- bcache: fix wrong bdev parameter when calling bio_alloc_clone() in do_bio_hook() (Ming Lei) [2083917]
- block: null_blk: Fix null_zone_write() (Ming Lei) [2083917]
- nbd: use pr_err to output error message (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- nbd: fix io hung while disconnecting device (Ming Lei) [2083917]
- nbd: don't clear 'NBD_CMD_INFLIGHT' flag if request is not completed (Ming Lei) [2083917]
- nbd: fix race between nbd_alloc_config() and module removal (Ming Lei) [2083917]
- nbd: call genl_unregister_family() first in nbd_cleanup() (Ming Lei) [2083917]
- blk-mq: remove the done argument to blk_execute_rq_nowait (Ming Lei) [2083917]
- blk-mq: avoid a mess of casts for blk_end_sync_rq (Ming Lei) [2083917]
- blk-mq: remove __blk_execute_rq_nowait (Ming Lei) [2083917]
- block: Fix potential deadlock in blk_ia_range_sysfs_show() (Ming Lei) [2083917]
- block: fix bio_clone_blkg_association() to associate with proper blkcg_gq (Ming Lei) [2083917]
- block: remove useless BUG_ON() in blk_mq_put_tag() (Ming Lei) [2083917]
- blk-mq: do not update io_ticks with passthrough requests (Ming Lei) [2083917]
- block: make bioset_exit() fully resilient against being called twice (Ming Lei) [2083917]
- block: use bio_queue_enter instead of blk_queue_enter in bio_poll (Ming Lei) [2083917]
- block: document BLK_STS_AGAIN usage (Ming Lei) [2083917]
- block: take destination bvec offsets into account in bio_copy_data_iter (Ming Lei) [2083917]
- blk-iolatency: Fix inflight count imbalances and IO hangs on offline (Ming Lei) [2083917]
- blk-mq: don't touch ->tagset in blk_mq_get_sq_hctx (Ming Lei) [2083917]
- mtip32xx: fix typo in comment (Ming Lei) [2083917]
- nbd: Fix hung on disconnect request if socket is closed before (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment from the UAPI header (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment (Ming Lei) [2083917]
- loop: add a SPDX header (Ming Lei) [2083917]
- loop: remove loop.h (Ming Lei) [2083917]
- block: null_blk: Improve device creation with configfs (Ming Lei) [2083917]
- block: null_blk: Cleanup messages (Ming Lei) [2083917]
- block: null_blk: Cleanup device creation and deletion (Ming Lei) [2083917]
- block: null_blk: Fix code style issues (Ming Lei) [2083917]
- xen-blkback: use bdev_discard_alignment (Ming Lei) [2083917]
- rnbd-srv: use bdev_discard_alignment (Ming Lei) [2083917]
- nvme: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- loop: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- dasd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- raid5: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- dm-zoned: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- virtio_blk: fix the discard_granularity and discard_alignment queue limits (Ming Lei) [2083917]
- null_blk: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- nbd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- ubd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- aoe: Avoid flush_scheduled_work() usage (Ming Lei) [2083917]
- null-blk: save memory footprint for struct nullb_cmd (Ming Lei) [2083917]
- block/rnbd-clt: Avoid flush_workqueue(system_long_wq) usage (Ming Lei) [2083917]
- loop: don't destroy lo->workqueue in __loop_clr_fd (Ming Lei) [2083917]
- loop: remove lo_refcount and avoid lo_mutex in ->open / ->release (Ming Lei) [2083917]
- loop: avoid loop_validate_mutex/lo_mutex in ->release (Ming Lei) [2083917]
- loop: suppress uevents while reconfiguring the device (Ming Lei) [2083917]
- loop: implement ->free_disk (Ming Lei) [2083917]
- loop: only freeze the queue in __loop_clr_fd when needed (Ming Lei) [2083917]
- loop: don't freeze the queue in lo_release (Ming Lei) [2083917]
- loop: remove the racy bd_inode->i_mapping->nrpages asserts (Ming Lei) [2083917]
- loop: initialize the worker tracking fields once (Ming Lei) [2083917]
- loop: de-duplicate the idle worker freeing code (Ming Lei) [2083917]
- block: turn bdev->bd_openers into an atomic_t (Ming Lei) [2083917]
- block: add a disk_openers helper (Ming Lei) [2083917]
- zram: cleanup zram_remove (Ming Lei) [2083917]
- zram: cleanup reset_store (Ming Lei) [2083917]
- nbd: use the correct block_device in nbd_bdev_reset (Ming Lei) [2083917]
- drdb: Switch to kvfree_rcu() API (Ming Lei) [2083917]
- drbd: Replace "unsigned" with "unsigned int" (Ming Lei) [2083917]
- drbd: Make use of PFN_UP helper macro (Ming Lei) [2083917]
- block: drbd: drbd_receiver: Remove redundant assignment to err (Ming Lei) [2083917]
- drbd: address enum mismatch warnings (Ming Lei) [2083917]
- drbd: fix duplicate array initializer (Ming Lei) [2083917]
- blk-mq: fix typo in comment (Ming Lei) [2083917]
- bfq: Remove bfq_requeue_request_body() (Ming Lei) [2083917]
- bfq: Remove superfluous conversion from RQ_BIC() (Ming Lei) [2083917]
- bfq: Allow current waker to defend against a tentative one (Ming Lei) [2083917]
- bfq: Relax waker detection for shared queues (Ming Lei) [2083917]
- blk-cgroup: delete rcu_read_lock_held() WARN_ON_ONCE() (Ming Lei) [2083917]
- blk-throttle: Set BIO_THROTTLED when bio has been throttled (Ming Lei) [2083917]
- blk-cgroup: Remove unnecessary rcu_read_lock/unlock() (Ming Lei) [2083917]
- blk-cgroup: always terminate io.stat lines (Ming Lei) [2083917]
- block, bfq: make bfq_has_work() more accurate (Ming Lei) [2083917]
- block, bfq: protect 'bfqd->queued' by 'bfqd->lock' (Ming Lei) [2083917]
- block: cleanup the VM accounting in submit_bio (Ming Lei) [2083917]
- block: Fix the bio.bi_opf comment (Ming Lei) [2083917]
- block: reorder the REQ_ flags (Ming Lei) [2083917]
- blk-iocost: combine local_stat and desc_stat to stat (Ming Lei) [2083917]
- block: improve the error message from bio_check_eod (Ming Lei) [2083917]
- block: allow passing a NULL bdev to bio_alloc_clone/bio_init_clone (Ming Lei) [2083917]
- block: remove superfluous calls to blkcg_bio_issue_init (Ming Lei) [2083917]
- kthread: unexport kthread_blkcg (Ming Lei) [2083917]
- blk-cgroup: cleanup blkcg_maybe_throttle_current (Ming Lei) [2083917]
- blk-cgroup: cleanup blk_cgroup_congested (Ming Lei) [2083917]
- blk-cgroup: move blkcg_css to blk-cgroup.c (Ming Lei) [2083917]
- blk-cgroup: remove unneeded includes from <linux/blk-cgroup.h> (Ming Lei) [2083917]
- blk-cgroup: remove pointless CONFIG_BLOCK ifdefs (Ming Lei) [2083917]
- blk-cgroup: replace bio_blkcg with bio_blkcg_css (Ming Lei) [2083917]
- blktrace: cleanup the __trace_note_message interface (Ming Lei) [2083917]
- blk-cgroup: move struct blkcg to block/blk-cgroup.h (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{pin,unpin}_online out of line (Ming Lei) [2083917]
- blk-cgroup: move blk_cgroup_congested out line (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{get,set}_fc_appid out of line (Ming Lei) [2083917]
- nvme-fc: fold t fc_update_appid into fc_appid_store (Ming Lei) [2083917]
- nvme-fc: don't support the appid attribute without CONFIG_BLK_CGROUP_FC_APPID (Ming Lei) [2083917]
- blk-cgroup: remove __bio_blkcg (Ming Lei) [2083917]
- block/partitions/ldm: Remove redundant assignments (Ming Lei) [2083917]
- block/partitions/atari: Remove redundant assignment (Ming Lei) [2083917]
- block/partitions/acorn: Remove redundant assignments (Ming Lei) [2083917]
- block/blk-map: Remove redundant assignment (Ming Lei) [2083917]
- block/badblocks: Remove redundant assignments (Ming Lei) [2083917]
- block: change exported IO accounting interface from gendisk to bdev (Ming Lei) [2083917]
- direct-io: remove random prefetches (Ming Lei) [2083917]
- block: decouple REQ_OP_SECURE_ERASE from REQ_OP_DISCARD (Ming Lei) [2083917]
- block: add a bdev_discard_granularity helper (Ming Lei) [2083917]
- block: remove QUEUE_FLAG_DISCARD (Ming Lei) [2083917]
- block: add a bdev_max_discard_sectors helper (Ming Lei) [2083917]
- block: refactor discard bio size limiting (Ming Lei) [2083917]
- block: move {bdev,queue_limit}_discard_alignment out of line (Ming Lei) [2083917]
- block: use bdev_discard_alignment in part_discard_alignment_show (Ming Lei) [2083917]
- block: remove queue_discard_alignment (Ming Lei) [2083917]
- block: move bdev_alignment_offset and queue_limit_alignment_offset out of line (Ming Lei) [2083917]
- block: use bdev_alignment_offset in disk_alignment_offset_show (Ming Lei) [2083917]
- block: use bdev_alignment_offset in part_alignment_offset_show (Ming Lei) [2083917]
- block: add a bdev_max_zone_append_sectors helper (Ming Lei) [2083917]
- block: add a bdev_stable_writes helper (Ming Lei) [2083917]
- block: add a bdev_fua helper (Ming Lei) [2083917]
- block: add a bdev_write_cache helper (Ming Lei) [2083917]
- block: add a bdev_nonrot helper (Ming Lei) [2083917]
- mm: use bdev_is_zoned in claim_swapfile (Ming Lei) [2083917]
- drbd: cleanup decide_on_discard_support (Ming Lei) [2083917]
- drbd: use bdev_alignment_offset instead of queue_alignment_offset (Ming Lei) [2083917]
- drbd: use bdev based limit helpers in drbd_send_sizes (Ming Lei) [2083917]
- drbd: remove assign_p_sizes_qlim (Ming Lei) [2083917]
- target: fix discard alignment on partitions (Ming Lei) [2083917]
- target: pass a block_device to target_configure_unmap_from_queue (Ming Lei) [2083917]
- target: remove an incorrect unmap zeroes data deduction (Ming Lei) [2083917]
- bfq: Make sure bfqg for which we are queueing requests is online (Ming Lei) [2083917]
- bfq: Get rid of __bio_blkcg() usage (Ming Lei) [2083917]
- bfq: Track whether bfq_group is still online (Ming Lei) [2083917]
- bfq: Remove pointless bfq_init_rq() calls (Ming Lei) [2083917]
- bfq: Drop pointless unlock-lock pair (Ming Lei) [2083917]
- bfq: Update cgroup information before merging bio (Ming Lei) [2083917]
- bfq: Split shared queues on move between cgroups (Ming Lei) [2083917]
- bfq: Avoid merging queues with different parents (Ming Lei) [2083917]
- bfq: Avoid false marking of bic as stably merged (Ming Lei) [2083917]
- pktcdvd: stop using bio_reset (Ming Lei) [2083917]
- block: turn bio_kmalloc into a simple kmalloc wrapper (Ming Lei) [2083917]
- target/pscsi: remove pscsi_get_bio (Ming Lei) [2083917]
- squashfs: always use bio_kmalloc in squashfs_bio_read (Ming Lei) [2083917]
- block: allow use of per-cpu bio alloc cache by block drivers (Ming Lei) [2083917]
- block: allow using the per-cpu bio cache from bio_alloc_bioset (Ming Lei) [2083917]
- blk-mq: fix passthrough plugging (Ming Lei) [2083917]
- block: wire-up support for passthrough plugging (Ming Lei) [2083917]
- scsi: block: Remove REQ_OP_WRITE_SAME support (Ming Lei) [2083917]
- scsi: dm: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: md: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: sd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: rnbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: drbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: cxlflash: Query write_zeroes limit for zeroing (Ming Lei) [2083917]
- block/mq-deadline: Set the fifo_time member also if inserting at head (Ming Lei) [2083917]
- Revert "block: release rq qos structures for queue without disk" (Ming Lei) [2083917]
- bfq: Fix warning in bfqq_request_over_limit() (Ming Lei) [2083917]
- Revert "block: inherit request start time from bio for BLK_CGROUP" (Ming Lei) [2083917]
- iocost: don't reset the inuse weight of under-weighted debtors (Ming Lei) [2083917]
- block: don't print I/O error warning for dead disks (Ming Lei) [2083917]
- block/compat_ioctl: fix range check in BLKGETSIZE (Ming Lei) [2083917]
- block: null_blk: end timed out poll request (Ming Lei) [2083917]
- block: fix offset/size check in bio_trim() (Ming Lei) [2083917]
- asm-generic: fix __get_unaligned_be48() on 32 bit platforms (Ming Lei) [2083917]
- block: move lower_48_bits() to block (Ming Lei) [2083917]
- drbd: set QUEUE_FLAG_STABLE_WRITES (Ming Lei) [2083917]
- drbd: fix an invalid memory access caused by incorrect use of list iterator (Ming Lei) [2083917]
- drbd: Fix five use after free bugs in get_initial_state (Ming Lei) [2083917]
- cdrom: remove unused variable (Ming Lei) [2083917]
- Revert "nbd: fix possible overflow on 'first_minor' in nbd_dev_add()" (Ming Lei) [2083917]
- drbd: remove check of list iterator against head past the loop body (Ming Lei) [2083917]
- drbd: remove usage of list iterator variable after loop (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- MAINTAINERS: add drbd co-maintainer (Ming Lei) [2083917]
- drbd: fix potential silent data corruption (Ming Lei) [2083917]
- loop: fix ioctl calls using compat_loop_info (Ming Lei) [2083917]
- n64cart: convert bi_disk to bi_bdev->bd_disk fix build (Ming Lei) [2083917]
- blk-wbt: remove wbt_track stub (Ming Lei) [2083917]
- block: use dedicated list iterator variable (Ming Lei) [2083917]
- block: Fix the maximum minor value is blk_alloc_ext_minor() (Ming Lei) [2083917]
- block: avoid calling blkg_free() in atomic context (Ming Lei) [2083917]
- crypto: fix crc64 testmgr digest byte order (Ming Lei) [2083917]
- nvme: add support for enhanced metadata (Ming Lei) [2083917]
- block: add pi for extended integrity (Ming Lei) [2083917]
- crypto: add rocksoft 64b crc guard tag framework (Ming Lei) [2083917]
- lib: add rocksoft model crc64 (Ming Lei) [2083917]
- linux/kernel: introduce lower_48_bits function (Ming Lei) [2083917]
- asm-generic: introduce be48 unaligned accessors (Ming Lei) [2083917]
- nvme: allow integrity on extended metadata formats (Ming Lei) [2083917]
- block: support pi with extended metadata (Ming Lei) [2083917]
- fs: do not pass __GFP_HIGHMEM to bio_alloc in do_mpage_readpage (Ming Lei) [2083917]
- f2fs: pass the bio operation to bio_alloc_bioset (Ming Lei) [2083917]
- f2fs: don't pass a bio to f2fs_target_device (Ming Lei) [2083917]
- nilfs2: pass the operation to bio_alloc (Ming Lei) [2083917]
- ext4: pass the operation to bio_alloc (Ming Lei) [2083917]
- mpage: pass the operation to bio_alloc (Ming Lei) [2083917]
- virtio_blk: eliminate anonymous module_init & module_exit (Ming Lei) [2083917]
- floppy: use memcpy_{to,from}_bvec (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in recv_dless_read (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in drbd_csum_bio (Ming Lei) [2083917]
- bcache: use bvec_kmap_local in bio_csum (Ming Lei) [2083917]
- nvdimm-btt: use bvec_kmap_local in btt_rw_integrity (Ming Lei) [2083917]
- nvdimm-blk: use bvec_kmap_local in nd_blk_rw_integrity (Ming Lei) [2083917]
- zram: use memcpy_from_bvec in zram_bvec_write (Ming Lei) [2083917]
- zram: use memcpy_to_bvec in zram_bvec_read (Ming Lei) [2083917]
- aoe: use bvec_kmap_local in bvcpy (Ming Lei) [2083917]
- iss-simdisk: use bvec_kmap_local in simdisk_submit_bio (Ming Lei) [2083917]
- null_blk: null_alloc_page() cleanup (Ming Lei) [2083917]
- null_blk: remove hardcoded null_alloc_page() param (Ming Lei) [2083917]
- null_blk: remove hardcoded alloc_cmd() parameter (Ming Lei) [2083917]
- loop: allow user to set the queue depth (Ming Lei) [2083917]
- loop: remove extra variable in lo_req_flush (Ming Lei) [2083917]
- loop: remove extra variable in lo_fallocate() (Ming Lei) [2083917]
- loop: use sysfs_emit() in the sysfs xxx show() (Ming Lei) [2083917]
- null_blk: fix return value from null_add_dev() (Ming Lei) [2083917]
- loop: clean up grammar in warning message (Ming Lei) [2083917]
- block/rnbd: Remove a useless mutex (Ming Lei) [2083917]
- block/rnbd: client device does not care queue/rotational (Ming Lei) [2083917]
- block/rnbd-clt: fix CHECK:BRACES warning (Ming Lei) [2083917]
- block: cancel all throttled bios in del_gendisk() (Ming Lei) [2083917]
- block: let blkcg_gq grab request queue's refcnt (Ming Lei) [2083917]
- block: avoid use-after-free on throttle data (Ming Lei) [2083917]
- block/bfq-iosched: Fix spelling mistake "tenative" -> "tentative" (Ming Lei) [2083917]
- sr: simplify the local variable initialization in sr_block_open() (Ming Lei) [2083917]
- block: don't merge across cgroup boundaries if blkcg is enabled (Ming Lei) [2083917]
- block: move rq_qos_exit() into disk_release() (Ming Lei) [2083917]
- block: do more work in elevator_exit (Ming Lei) [2083917]
- block: move blk_exit_queue into disk_release (Ming Lei) [2083917]
- block: move q_usage_counter release into blk_queue_release (Ming Lei) [2083917]
- block: don't remove hctx debugfs dir from blk_mq_exit_queue (Ming Lei) [2083917]
- block: move blkcg initialization/destroy into disk allocation/release handler (Ming Lei) [2083917]
- sr: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- sd: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- blk-mq: handle already freed tags gracefully in blk_mq_free_rqs (Ming Lei) [2083917]
- blk-mq: do not include passthrough requests in I/O accounting (Ming Lei) [2083917]
- blk-mq: manage hctx map via xarray (Ming Lei) [2083917]
- blk-mq: prepare for implementing hctx table via xarray (Ming Lei) [2083917]
- block: mtip32xx: don't touch q->queue_hw_ctx (Ming Lei) [2083917]
- blk-mq: reconfigure poll after queue map is changed (Ming Lei) [2083917]
- blk-mq: simplify reallocation of hw ctxs a bit (Ming Lei) [2083917]
- blk-mq: figure out correct numa node for hw queue (Ming Lei) [2083917]
- Revert "Revert "block, bfq: honor already-setup queue merges"" (Ming Lei) [2083917]
- block: remove bio_devname (Ming Lei) [2083917]
- raid5-ppl: stop using bio_devname (Ming Lei) [2083917]
- raid1: stop using bio_devname (Ming Lei) [2083917]
- md-multipath: stop using bio_devname (Ming Lei) [2083917]
- dm-integrity: stop using bio_devname (Ming Lei) [2083917]
- dm-crypt: stop using bio_devname (Ming Lei) [2083917]
- pktcdvd: remove a pointless debug check in pkt_submit_bio (Ming Lei) [2083917]
- block: remove handle_bad_sector (Ming Lei) [2083917]
- block: fix and cleanup bio_check_ro (Ming Lei) [2083917]
- bfq: fix use-after-free in bfq_dispatch_request (Ming Lei) [2083917]
- blk-crypto: show crypto capabilities in sysfs (Ming Lei) [2083917]
- block: don't delete queue kobject before its children (Ming Lei) [2083917]
- block: simplify calling convention of elv_unregister_queue() (Ming Lei) [2083917]
- block: remove redundant semicolon (Ming Lei) [2083917]
- block: default BLOCK_LEGACY_AUTOLOAD to y (Ming Lei) [2083917]
- block, bfq: don't move oom_bfqq (Ming Lei) [2083917]
- block, bfq: avoid moving bfqq to it's parent bfqg (Ming Lei) [2083917]
- block, bfq: cleanup bfq_bfqq_to_bfqg() (Ming Lei) [2083917]
- block/bfq_wf2q: correct weight to ioprio (Ming Lei) [2083917]
- blk-mq: avoid extending delays of active hctx from blk_mq_delay_run_hw_queues (Ming Lei) [2083917]
- virtio_blk: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: fix handling of read-only devices (Ming Lei) [2083917]
- memstick/ms_block: simplify refcounting (Ming Lei) [2083917]
- block: add a ->free_disk method (Ming Lei) [2083917]
- block: revert 4f1e9630afe6 ("blk-throtl: optimize IOPS throttle for large IO scenarios") (Ming Lei) [2083917]
- block: don't try to throttle split bio if iops limit isn't set (Ming Lei) [2083917]
- block: throttle split bio in case of iops limit (Ming Lei) [2083917]
- block: merge submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- block: don't check bio in blk_throtl_dispatch_work_fn (Ming Lei) [2083917]
- block: don't declare submit_bio_checks in local header (Ming Lei) [2083917]
- block: move blk_crypto_bio_prep() out of blk-mq.c (Ming Lei) [2083917]
- block: move submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- dm: remove dm_dispatch_clone_request (Ming Lei) [2083917]
- dm: remove useless code from dm_dispatch_clone_request (Ming Lei) [2083917]
- blk-mq: remove the request_queue argument to blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: fold blk_cloned_rq_check_limits into blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: make the blk-mq stacking code optional (Ming Lei) [2083917]
- blk-cgroup: set blkg iostat after percpu stat aggregation (Ming Lei) [2083917]
- blk-lib: don't check bdev_get_queue() NULL check (Ming Lei) [2083917]
- block: remove biodoc.rst (Ming Lei) [2083917]
- docs: block: biodoc.rst: Drop the obsolete and incorrect content (Ming Lei) [2083917]
- block: partition include/linux/blk-cgroup.h (Ming Lei) [2083917]
- block: move initialization of q->blkg_list into blkcg_init_queue (Ming Lei) [2083917]
- block: remove THROTL_IOPS_MAX (Ming Lei) [2083917]
- block: introduce block_rq_error tracepoint (Ming Lei) [2083917]
- sbitmap: Delete old sbitmap_queue_get_shallow() (Ming Lei) [2083917]
- block: pass a block_device to bio_clone_fast (Ming Lei) [2083917]
- block: initialize the target bio in __bio_clone_fast (Ming Lei) [2083917]
- dm: use bio_clone_fast in alloc_io/alloc_tio (Ming Lei) [2083917]
- block: clone crypto and integrity data in __bio_clone_fast (Ming Lei) [2083917]
- dm-cache: remove __remap_to_origin_clear_discard (Ming Lei) [2083917]
- dm: simplify the single bio fast path in __send_duplicate_bios (Ming Lei) [2083917]
- dm: retun the clone bio from alloc_tio (Ming Lei) [2083917]
- dm: pass the bio instead of tio to __map_bio (Ming Lei) [2083917]
- dm: move cloning the bio into alloc_tio (Ming Lei) [2083917]
- dm: fold __send_duplicate_bios into __clone_and_map_simple_bio (Ming Lei) [2083917]
- dm: fold clone_bio into __clone_and_map_data_bio (Ming Lei) [2083917]
- dm: add a clone_to_tio helper (Ming Lei) [2083917]
- drbd: set ->bi_bdev in drbd_req_new (Ming Lei) [2083917]
- block: call bio_associate_blkg from bio_reset (Ming Lei) [2083917]
- scsi: use BLK_STS_OFFLINE for not fully online devices (Ming Lei) [2083917]
- block: return -ENODEV for BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: introduce BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: fix boolreturn.cocci warning (Ming Lei) [2083917]
- MAINTAINERS: add bio.h to the block section (Ming Lei) [2083917]
- block: fix the kerneldoc for bio_end_io_acct (Ming Lei) [2083917]
- block: check that there is a plug in blk_flush_plug (Ming Lei) [2083917]
- block: remove blk_needs_flush_plug (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_reset (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_init (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_kiocb (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_bioset (Ming Lei) [2083917]
- block: pass a block_device and opf to blk_next_bio (Ming Lei) [2083917]
- block: move blk_next_bio to bio.c (Ming Lei) [2083917]
- xen-blkback: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- rnbd-srv: remove struct rnbd_dev_blk_io (Ming Lei) [2083917]
- rnbd-srv: simplify bio mapping in process_rdma (Ming Lei) [2083917]
- drbd: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- dm-thin: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-snap: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-crypt: remove clone_init (Ming Lei) [2083917]
- dm: bio_alloc can't fail if it is allowed to sleep (Ming Lei) [2083917]
- nfs/blocklayout: remove bl_alloc_init_bio (Ming Lei) [2083917]
- nilfs2: remove nilfs_alloc_seg_bio (Ming Lei) [2083917]
- fs: remove mpage_alloc (Ming Lei) [2083917]
- block: remove genhd.h (Ming Lei) [2083917]
- block: move blk_drop_partitions to blk.h (Ming Lei) [2083917]
- block: move disk_{block,unblock,flush}_events to blk.h (Ming Lei) [2083917]
- block: deprecate autoloading based on dev_t (Ming Lei) [2083917]
- zram_drv: allow reclaim on bio_alloc (Ming Lei) [2083917]
- block: Add bio_for_each_folio_all() (Ming Lei) [2083917]
- block: Add bio_add_folio() (Ming Lei) [2083917]
- [s390] s390/zcrypt: Filter admin CPRBs on custom devices (Mete Durlu) [2076921]
- [s390] s390/zcrypt: CCA control CPRB sending (Mete Durlu) [2076921]
- [s390] s390/zcrypt: Add admask to zcdn (Mete Durlu) [2076921]
- ntb: intel: fix port config status offset for SPR (John W. Linville) [2048751]
- NTB/msi: Use struct_size() helper in devm_kzalloc() (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix a minor issue in config_req_id_table() (John W. Linville) [2048751]
- ntb_hw_switchtec: Remove code for disabling ID protection (John W. Linville) [2048751]
- ntb_hw_switchtec: Update the way of getting VEP instance ID (John W. Linville) [2048751]
- ntb_hw_switchtec: AND with the part_map for a valid tpart_vec (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix bug with more than 32 partitions (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix pff ioread to read into mmio_part_cfg_all (John W. Linville) [2048751]
- ntb_hw_switchtec: fix the spelling of "its" (John W. Linville) [2048751]
- NTB/msi: Fix ntbm_msi_request_threaded_irq() kernel-doc comment (John W. Linville) [2048751]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (John W. Linville) [2048751]
- NTB: switch from 'pci_' to 'dma_' API (John W. Linville) [2048751]
- ntb: ntb_pingpong: remove redundant initialization of variables msg_data and spad_data (John W. Linville) [2048751]
- NTB: perf: Fix an error code in perf_setup_inbuf() (John W. Linville) [2048751]
- NTB: Fix an error code in ntb_msit_probe() (John W. Linville) [2048751]
- ntb: intel: remove invalid email address in header comment (John W. Linville) [2048751]
- redhat: spec: trigger dracut when modules are installed separately (Jan Stancek) [2062518]

* Fri Jun 24 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-119.el9]
- revert bus: Make remove callback return void (Steve Best) [2097921]
- [s390] s390/ism: switch from 'pci_' to 'dma_' API (Tobias Huschle) [2044294]
- [s390] net/smc: Fix sock leak when release after smc_shutdown() (Tobias Huschle) [2044294]
- [s390] net/smc: Fix af_ops of child socket pointing to released memory (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereference in smc_pnet_find_ib() (Tobias Huschle) [2044294]
- [s390] net/smc: use memcpy instead of snprintf to avoid out of bounds read (Tobias Huschle) [2044294]
- [s390] net/smc: Send out the remaining data in sndbuf before close (Tobias Huschle) [2044294]
- [s390] net/smc: fix a memory leak in smc_sysctl_net_exit() (Tobias Huschle) [2044294]
- [s390] net/smc: fix -Wmissing-prototypes warning when CONFIG_SYSCTL not set (Tobias Huschle) [2044294]
- [s390] net/smc: fix compile warning for smc_sysctl (Tobias Huschle) [2044294]
- [s390] Revert "net/smc: don't req_notify until all CQEs drained" (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error cause by server (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error generated by client (Tobias Huschle) [2044294]
- [s390] net: smc: fix different types in min() (Tobias Huschle) [2044294]
- [s390] net/smc: don't send in the BH context if sock_owned_by_user (Tobias Huschle) [2044294]
- [s390] net/smc: don't req_notify until all CQEs drained (Tobias Huschle) [2044294]
- [s390] net/smc: correct settings of RMB window update limit (Tobias Huschle) [2044294]
- [s390] net/smc: send directly on setting TCP_NODELAY (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl for autocorking (Tobias Huschle) [2044294]
- [s390] net/smc: add autocorking support (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl interface for SMC (Tobias Huschle) [2044294]
- [s390] net/smc: Call trace_smc_tx_sendmsg when data corked (Tobias Huschle) [2044294]
- [s390] net/smc: Fix cleanup when register ULP fails (Tobias Huschle) [2044294]
- [s390] net/smc: fix connection leak (Tobias Huschle) [2044294]
- [s390] net/smc: Use a mutex for locking "struct smc_pnettable" (Tobias Huschle) [2044294]
- [s390] net/smc: unlock on error paths in __smc_setsockopt() (Tobias Huschle) [2044294]
- [s390] net/smc: return ETIMEDOUT when smc_connect_clc() timeout (Tobias Huschle) [2044294]
- [s390] net/smc: Add comment for smc_tx_pending (Tobias Huschle) [2044294]
- [s390] net/smc: Add global configure for handshake limitation by netlink (Tobias Huschle) [2044294]
- [s390] net/smc: Dynamic control handshake limitation by socket options (Tobias Huschle) [2044294]
- [s390] net/smc: Limit SMC visits when handshake workqueue congested (Tobias Huschle) [2044294]
- [s390] net/smc: Limit backlog connections (Tobias Huschle) [2044294]
- [s390] net/smc: Make smc_tcp_listen_work() independent (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid overwriting the copies of clcsock callback functions (Tobias Huschle) [2044294]
- [s390] Partially revert "net/smc: Add netlink net namespace support" (Tobias Huschle) [2044294]
- [s390] net/smc: Cork when sendpage with MSG_SENDPAGE_NOTLAST flag (Tobias Huschle) [2044294]
- [s390] net/smc: Remove corked dealyed work (Tobias Huschle) [2044294]
- [s390] net/smc: Send directly when TCP_CORK is cleared (Tobias Huschle) [2044294]
- [s390] net/smc: Forward wakeup to smc socket waitqueue after fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Transitional solution for clcsock race issue (Tobias Huschle) [2044294]
- [s390] net/smc: Fix hung_task when removing SMC-R devices (Tobias Huschle) [2044294]
- [s390] net/smc: Remove unused function declaration (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between SMC-R link access and clear (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce a new conn->lgr validity check helper (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between link group access and termination (Tobias Huschle) [2044294]
- [s390] net/smc: Reset conn->lgr when link group registration fails (Tobias Huschle) [2044294]
- [s390] net/smc: add comments for smc_link_{usable|sendable} (Tobias Huschle) [2044294]
- [s390] net/smc: remove redundant re-assignment of pointer link (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce TCP ULP support (Tobias Huschle) [2044294]
- [s390] net/smc: Add net namespace for tracepoints (Tobias Huschle) [2044294]
- [s390] net/smc: Print net namespace in log (Tobias Huschle) [2044294]
- [s390] net/smc: Add netlink net namespace support (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce net namespace support for linkgroup (Tobias Huschle) [2044294]
- [s390] net/smc: Use the bitmap API when applicable (Tobias Huschle) [2044294]
- [s390] net/smc: fix kernel panic caused by race of smc_sock (Tobias Huschle) [2044294]
- [s390] net/smc: don't send CDC/LLC message if link not ready (Tobias Huschle) [2044294]
- [s390] net/smc: fix using of uninitialized completions (Tobias Huschle) [2044294]
- [s390] net/smc: Prevent smc_release() from long blocking (Tobias Huschle) [2044294]
- [s390] net/smc: Clear memory when release and reuse buffer (Tobias Huschle) [2044294]
- [s390] net/smc: Keep smc_close_final rc during active close (Tobias Huschle) [2044294]
- [s390] net/smc: fix wrong list_del in smc_lgr_cleanup_early (Tobias Huschle) [2044294]
- [s390] net/smc: Don't call clcsock shutdown twice when smc shutdown (Tobias Huschle) [2044294]
- [s390] net/smc: Fix loop in smc_listen (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereferencing in smc_vlan_by_tcpsk() (Tobias Huschle) [2044294]
- [s390] net/smc: Ensure the active closing peer first closes clcsock (Tobias Huschle) [2044294]
- [s390] net/smc: Clean up local struct sock variables (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid warning of possible recursive locking (Tobias Huschle) [2044294]
- [s390] net/smc: Make sure the link_id is unique (Tobias Huschle) [2044294]
- [s390] net/smc: Transfer remaining wait queue entries during fallback (Tobias Huschle) [2044294]
- [s390] net/smc: fix sk_refcnt underflow on linkdown and fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Print function name in smcr_link_down tracepoint (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for smcr link down (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoints for tx and rx msg (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Correct spelling mistake to TCPF_SYN_RECV (Tobias Huschle) [2044294]
- [s390] net/smc: Fix smc_link->llc_testlink_time overflow (Tobias Huschle) [2044294]
- [s390] net/smc: stop links when their GID is removed (Tobias Huschle) [2044294]
- [s390] net/smc: add netlink support for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: extend LLC layer for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 support to the work request layer (Tobias Huschle) [2044294]
- [s390] net/smc: retrieve v2 gid from IB device (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 format of CLC decline message (Tobias Huschle) [2044294]
- [s390] net/smc: add listen processing for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add SMC-Rv2 connection establishment (Tobias Huschle) [2044294]
- [s390] net/smc: prepare for SMC-Rv2 connection (Tobias Huschle) [2044294]
- [s390] net/smc: save stack space and allocate smc_init_info (Tobias Huschle) [2044294]
- [s390] net/smc: add generic netlink support for system EID (Tobias Huschle) [2044294]
- [s390] net/smc: keep static copy of system EID (Tobias Huschle) [2044294]
- [s390] net/smc: add support for user defined EIDs (Tobias Huschle) [2044294]
- [s390] net/smc: Allow SMC-D 1MB DMB allocations (Tobias Huschle) [2044294]
- revert bus: Make remove callback return void (Steve Best) [2096865]
- mt76: mt7921: Fix the error handling path of mt7921_pci_probe() (Íñigo Huguet) [2096777]
- redhat/configs: Add CONFIG_S390_UV_UAPI (Claudio Imbrenda) [2001936]
- [s390] s390/uv_uapi: depend on CONFIG_S390 (Claudio Imbrenda) [2001936]
- [s390] drivers/s390/char: Add Ultravisor io device (Claudio Imbrenda) [2001936]
- tg3: Remove redundant assignments (Ken Cox) [2043793]
- ethernet: Remove redundant statement (Ken Cox) [2043793]
- ethernet: tg3: remove direct netdev->dev_addr writes (Ken Cox) [2043793]
- net: tg3: fix redundant check of true expression (Ken Cox) [2043793]
- net: tg3: fix obsolete check of !err (Ken Cox) [2043793]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2043793]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2043793]
- powerpc/doc: Fix htmldocs errors (Gustavo Walbon) [1873825]
- powerpc/pseries: Add support for FORM2 associativity (Gustavo Walbon) [1873825]
- powerpc/pseries: Consolidate different NUMA distance update code paths (Gustavo Walbon) [1873825]
- powerpc/pseries: Rename TYPE1_AFFINITY to FORM1_AFFINITY (Gustavo Walbon) [1873825]
- powerpc/pseries: rename min_common_depth to primary_domain_index (Gustavo Walbon) [1873825]
- powerpc/pseries: Add a helper for form1 cpu distance (Gustavo Walbon) [1873825]
- config: wireless: MT7921U=n (Íñigo Huguet) [2059999]
- rfkill: uapi: fix RFKILL_IOCTL_MAX_SIZE ioctl request definition (Íñigo Huguet) [2059999]
- nl80211: fix locking in nl80211_set_tx_bitrate_mask() (Íñigo Huguet) [2059999]
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU protection (Íñigo Huguet) [2059999]
- mac80211_hwsim: fix RCU protected chanctx access (Íñigo Huguet) [2059999]
- mac80211: Reset MBSSID parameters upon connection (Íñigo Huguet) [2059999]
- cfg80211: retrieve S1G operating channel number (Íñigo Huguet) [2059999]
- nl80211: validate S1G channel width (Íñigo Huguet) [2059999]
- mac80211: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2059999]
- ath11k: reduce the wait time of 11d scan and hw scan while add interface (Íñigo Huguet) [2059999]
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Flush recovery worker during freeze (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Add missing poweroff() PM callback (Íñigo Huguet) [2059999]
- mac80211: fix ht_capa printout in debugfs (Íñigo Huguet) [2059999]
- cfg80211: hold bss_lock while updating nontrans_list (Íñigo Huguet) [2059999]
- nl80211: correctly check NL80211_ATTR_REG_ALPHA2 size (Íñigo Huguet) [2059999]
- ath9k: Fix usage of driver-private space in tx_info (Íñigo Huguet) [2059999]
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- mt76: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- Revert "ath11k: mesh: add support for 256 bitmap in blockack frames in 11ax" (Íñigo Huguet) [2059999]
- ath9k: Properly clear TX status area before reporting to mac80211 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't fail if PPAG isn't supported (Íñigo Huguet) [2059999]
- ar5523: fix typo "to short" -> "too short" (Íñigo Huguet) [2059999]
- bus: mhi: Make mhi_state_str[] array static inline and move to common.h (Íñigo Huguet) [2059999]
- bus: mhi: Move common MHI definitions out of host directory (Íñigo Huguet) [2059999]
- bus: mhi: host: Rename "struct mhi_tre" to "struct mhi_ring_element" (Íñigo Huguet) [2059999]
- bus: mhi: Cleanup the register definitions used in headers (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for handling DWORDs of ring elements (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for register read and write (Íñigo Huguet) [2059999]
- bus: mhi: Move host MHI code to "host" directory (Íñigo Huguet) [2059999]
- bus: mhi: Fix MHI DMA structure endianness (Íñigo Huguet) [2059999]
- bus: mhi: Fix pm_state conversion to string (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Quectel EM1xx series (Íñigo Huguet) [2059999]
- rfkill: make new event layout opt-in (Íñigo Huguet) [2059999]
- rtw89: implement stop and resume channels transmission v1 (Íñigo Huguet) [2059999]
- rtw89: extend mac tx_en bits from 16 to 32 (Íñigo Huguet) [2059999]
- rtw89: change value assignment style of rtw89_mac_cfg_gnt() (Íñigo Huguet) [2059999]
- rtw89: 8852c: add mac_ctrl_path and mac_cfg_gnt APIs (Íñigo Huguet) [2059999]
- rtw89: disable FW and H2C function if CPU disabled (Íñigo Huguet) [2059999]
- rtw89: initialize preload window of D-MAC (Íñigo Huguet) [2059999]
- rtw89: modify MAC enable functions (Íñigo Huguet) [2059999]
- rtw89: add config_rf_reg_v1 to configure RF parameter tables (Íñigo Huguet) [2059999]
- rtw89: 8852c: add read/write rf register function (Íñigo Huguet) [2059999]
- rtw89: 8852c: add setting of TB UL TX power offset (Íñigo Huguet) [2059999]
- rtw89: 8852c: add write/read crystal function in CFO tracking (Íñigo Huguet) [2059999]
- rtw89: modify dcfo_comp to share with chips (Íñigo Huguet) [2059999]
- rtw89: Fix spelling mistake "Mis-Match" -> "Mismatch" (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Fix spelling mistake "Comback" -> "Comeback" (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix building iwlmei (Íñigo Huguet) [2059999]
- mt76: fix monitor rx FCS error in DFS channel (Íñigo Huguet) [2059999]
- mt76: mt7921: don't enable beacon filter when IEEE80211_CONF_CHANGE_MONITOR is set (Íñigo Huguet) [2059999]
- mt76: fix wrong HE data rate in sniffer tool (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce 802.11ax multi-bss support (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_init_hw in a dedicated work (Íñigo Huguet) [2059999]
- mt76: mt7921: add mt7921u driver (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_status_data in mac common code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_complete_skb in common mac code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_prepare_skb in common mac code (Íñigo Huguet) [2059999]
- mt76: mt7921: update mt7921_skb_add_usb_sdio_hdr to support usb (Íñigo Huguet) [2059999]
- mt76: mt7921: disable runtime pm for usb (Íñigo Huguet) [2059999]
- mt76: usb: introduce __mt76u_init utility routine (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_wr signature (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_rr signature (Íñigo Huguet) [2059999]
- mt76: mt7915: fix typos in comments (Íñigo Huguet) [2059999]
- mt76: mt7915: fix phy cap in mt7915_set_stream_he_txbf_caps() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix beamforming mib stats (Íñigo Huguet) [2059999]
- mt76: mt7915: set band1 TGID field in tx descriptor (Íñigo Huguet) [2059999]
- mt76: fix invalid rssi report (Íñigo Huguet) [2059999]
- mt76: use le32/16_get_bits() whenever possible (Íñigo Huguet) [2059999]
- mt76: connac: make read-only array ba_range static const (Íñigo Huguet) [2059999]
- mt76: mt7915: check for devm_pinctrl_get() failure (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_wait_for_mcu_init declaration (Íñigo Huguet) [2059999]
- mt76: mt7915: add txpower init for 6GHz (Íñigo Huguet) [2059999]
- mt76: mt7915: fix eeprom fields of txpower init values (Íñigo Huguet) [2059999]
- mt76: mt7915: add 6 GHz support (Íñigo Huguet) [2059999]
- mt76: connac: add 6 GHz support for wtbl and starec configuration (Íñigo Huguet) [2059999]
- mt76: mt7915: allow beaconing on all chains (Íñigo Huguet) [2059999]
- mt76: fix monitor mode crash with sdio driver (Íñigo Huguet) [2059999]
- mt76: mt7921: fix mt7921_queues_acq implementation (Íñigo Huguet) [2059999]
- mt76: mt7921: fix xmit-queue dump for usb and sdio (Íñigo Huguet) [2059999]
- mt76: mt7921: make mt7921_init_tx_queues static (Íñigo Huguet) [2059999]
- mt76: split single ldpc cap bit into bits (Íñigo Huguet) [2059999]
- mt76: mt7915: fix DFS no radar detection event (Íñigo Huguet) [2059999]
- mt76: mt7921: use mt76_hw instead of open coding it (Íñigo Huguet) [2059999]
- mt76: mt7921: fix up the monitor mode (Íñigo Huguet) [2059999]
- mt76: mt7663u: introduce mt7663u_mcu_power_on routine (Íñigo Huguet) [2059999]
- mt76: mt7615: honor ret from mt7615_mcu_restart in mt7663u_mcu_init (Íñigo Huguet) [2059999]
- rtw89: fix uninitialized variable of rtw89_append_probe_req_ie() (Íñigo Huguet) [2059999]
- airo: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8821ae: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192cu: Add On Networks N150 (Íñigo Huguet) [2059999]
- zd1201: use kzalloc (Íñigo Huguet) [2059999]
- mwifiex: make read-only array wmm_oui static const (Íñigo Huguet) [2059999]
- mac80211: update bssid_indicator in ieee80211_assign_beacon (Íñigo Huguet) [2059999]
- mac80211: MBSSID channel switch (Íñigo Huguet) [2059999]
- mac80211: MBSSID beacon handling in AP mode (Íñigo Huguet) [2059999]
- mac80211: always have ieee80211_sta_restart() (Íñigo Huguet) [2059999]
- mac80211: Add support to trigger sta disconnect on hardware restart (Íñigo Huguet) [2059999]
- mac80211: fix potential double free on mesh join (Íñigo Huguet) [2059999]
- mac80211: correct legacy rates check in ieee80211_calc_rx_airtime (Íñigo Huguet) [2059999]
- nl80211: fix typo of NL80211_IF_TYPE_OCB in documentation (Íñigo Huguet) [2059999]
- mac80211: Use GFP_KERNEL instead of GFP_ATOMIC when possible (Íñigo Huguet) [2059999]
- mac80211: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Íñigo Huguet) [2059999]
- rtw89: 8852c: process logic efuse map (Íñigo Huguet) [2059999]
- rtw89: 8852c: process efuse of phycap (Íñigo Huguet) [2059999]
- rtw89: support DAV efuse reading operation (Íñigo Huguet) [2059999]
- rtw89: 8852c: add chip::dle_mem (Íñigo Huguet) [2059999]
- rtw89: add page_regs to handle v1 chips (Íñigo Huguet) [2059999]
- rtw89: add chip_info::{h2c,c2h}_reg to support more chips (Íñigo Huguet) [2059999]
- rtw89: add hci_func_en_addr to support variant generation (Íñigo Huguet) [2059999]
- rtw89: add power_{on/off}_func (Íñigo Huguet) [2059999]
- rtw89: read chip version depends on chip ID (Íñigo Huguet) [2059999]
- rtw89: pci: use a struct to describe all registers address related to DMA channel (Íñigo Huguet) [2059999]
- rtw89: pci: add V1 of PCI channel address (Íñigo Huguet) [2059999]
- rtw89: pci: add struct rtw89_pci_info (Íñigo Huguet) [2059999]
- rtw89: 8852c: add 8852c empty files (Íñigo Huguet) [2059999]
- brcmfmac: make the read-only array pktflags static const (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192ce: remove duplicated function '_rtl92ce_phy_set_rf_sleep' (Íñigo Huguet) [2059999]
- cw1200: use time_is_after_jiffies() instead of open coding it (Íñigo Huguet) [2059999]
- carl9170: devres-ing input_allocate_device (Íñigo Huguet) [2059999]
- carl9170: devres-ing hwrng_register usage (Íñigo Huguet) [2059999]
- carl9170: replace GFP_ATOMIC in ampdu_action, it can sleep (Íñigo Huguet) [2059999]
- ath10k: Fix error handling in ath10k_setup_msa_resources (Íñigo Huguet) [2059999]
- ath11k: remove unneeded flush_workqueue (Íñigo Huguet) [2059999]
- ath6kl: add device ID for WLU5150-D81 (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 72 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: acpi: move ppag code from mvm to fw/acpi (Íñigo Huguet) [2059999]
- iwlwifi: dbg: check trigger data before access (Íñigo Huguet) [2059999]
- iwlwifi: dbg: in sync mode don't call schedule (Íñigo Huguet) [2059999]
- iwlwifi: use 4k queue size for Bz A-step (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix SW error MSI-X mapping (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: dump IMR DRAM only for HW and FW error (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for IMR based on platform (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: disable IMR DRAM region if IMR is disabled (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove cipher scheme support (Íñigo Huguet) [2059999]
- iwlwifi: Configure FW debug preset via module param. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add a flag to reduce power command. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 71 for AX devices (Íñigo Huguet) [2059999]
- ath9k: make array voice_priority static const (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_aplist_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_disconnect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_connect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_channel_list_reply (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_start_scan_cmd (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_begin_scan_cmd (Íñigo Huguet) [2059999]
- rtw89: declare HE capabilities in 6G band (Íñigo Huguet) [2059999]
- rtw89: fix HE PHY bandwidth capability (Íñigo Huguet) [2059999]
- rtw89: add tx_wake notify for low ps mode (Íñigo Huguet) [2059999]
- rtw89: 8852a: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- Revert "ath: add support for special 0x0 regulatory domain" (Íñigo Huguet) [2059999]
- rtw89: get channel parameters of 160MHz bandwidth (Íñigo Huguet) [2059999]
- mt76: fix dfs state issue with 160 MHz channels (Íñigo Huguet) [2059999]
- mt76: mt7915: simplify conditional (Íñigo Huguet) [2059999]
- mt76: mt7921: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- mt76: mt7915e: Enable thermal management by default (Íñigo Huguet) [2059999]
- mt76: mt7915e: Add a hwmon attribute to get the actual throttle state. (Íñigo Huguet) [2059999]
- mt76: mt7915e: Fix degraded performance after temporary overheat (Íñigo Huguet) [2059999]
- mt76: improve signal strength reporting (Íñigo Huguet) [2059999]
- mt76: mt7915: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the muru tlv issue (Íñigo Huguet) [2059999]
- mt76: mt7915: check band idx for bcc event (Íñigo Huguet) [2059999]
- mt76: mt7615: Fix assigning negative values to unsigned variable (Íñigo Huguet) [2059999]
- mt76: connac: adjust wlan_idx size from u8 to u16 (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_mac_tx_free() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_debugfs_rx_fw_monitor (Íñigo Huguet) [2059999]
- mt76: mt7615: fix compiler warning on frame size (Íñigo Huguet) [2059999]
- mt76: mt7915: initialize smps mode in mt7915_mcu_sta_rate_ctrl_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce band_idx in mt7915_phy (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for MT7986 (Íñigo Huguet) [2059999]
- ath10k: fix pointer arithmetic error in trace call (Íñigo Huguet) [2059999]
- carl9170: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: add dbring debug support (Íñigo Huguet) [2059999]
- ath11k: translate HE status to radiotap format (Íñigo Huguet) [2059999]
- ath11k: decode HE status tlv (Íñigo Huguet) [2059999]
- ath11k: switch to using ieee80211_tx_status_ext() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix missing fc type/sub-type for 802.11 pkts (Íñigo Huguet) [2059999]
- mt76: mt7915: fix potential memory leak of fw monitor packets (Íñigo Huguet) [2059999]
- mt76: mt7915: Fix channel state update error issue (Íñigo Huguet) [2059999]
- mt76: fix endianness errors in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt7615: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- rtw88: change rtw_info() to proper message level (Íñigo Huguet) [2059999]
- rtw89: Limit the CFO boundaries of x'tal value (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 6G band (Íñigo Huguet) [2059999]
- ath11k: Fix frames flush failure caused by deadlock (Íñigo Huguet) [2059999]
- ath11k: Handle failure in qmi firmware ready (Íñigo Huguet) [2059999]
- ath11k: Invalidate cached reo ring entry before accessing it (Íñigo Huguet) [2059999]
- ath: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath6kl: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath10k: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- ath9k: use hw_random API instead of directly dumping into random.c (Íñigo Huguet) [2059999]
- ath11k: configure RDDM size to mhi for recovery by firmware (Íñigo Huguet) [2059999]
- ath11k: fix invalid m3 buffer address (Íñigo Huguet) [2059999]
- ath11k: add ath11k_qmi_free_resource() for recovery (Íñigo Huguet) [2059999]
- rtw89: core.h: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- brcmfmac: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: fix RCU usage in rtw89_core_txq_push() (Íñigo Huguet) [2059999]
- rtw88: coex: Update rtl8822c COEX version to 22020720 (Íñigo Huguet) [2059999]
- rtw88: coex: Add C2H/H2C handshake with BT mailbox for asking HID Info (Íñigo Huguet) [2059999]
- rtw88: coex: Add WLAN MIMO power saving for Bluetooth gaming controller (Íñigo Huguet) [2059999]
- rtw88: coex: update BT PTA counter regularly (Íñigo Huguet) [2059999]
- rtw88: coex: Improve WLAN throughput when HFP COEX (Íñigo Huguet) [2059999]
- rtw88: 8822ce: add support for TX/RX 1ss mode (Íñigo Huguet) [2059999]
- iwlwifi: dbg_ini: Split memcpy() to avoid multi-field write (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (Íñigo Huguet) [2059999]
- iwlwifi: Fix -EIO error code that is never returned (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: use kmemdup() to replace kzalloc + memcpy (Íñigo Huguet) [2059999]
- iwlwifi: Fix syntax errors in comments (Íñigo Huguet) [2059999]
- iwlwifi: dvm: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi/fw: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: Make use of the helper macro LIST_HEAD() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix off by one in iwl_mvm_stat_iterator_all_macs() (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: send hcmd to fw after dump collection completes. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: move only to an enabled channel (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update BAID allocation command again (Íñigo Huguet) [2059999]
- iwlwifi: api: remove ttl field from TX command (Íñigo Huguet) [2059999]
- iwlwifi: support new queue allocation command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support dump policy for the dump size (Íñigo Huguet) [2059999]
- iwlwifi: pcie: iwlwifi: fix device id 7F70 struct (Íñigo Huguet) [2059999]
- iwlwifi: tlc: Add logs in rs_fw_rate_init func to print TLC configuration (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove iwl_mvm_disable_txq() flags argument (Íñigo Huguet) [2059999]
- iwlwifi: remove command ID argument from queue allocation (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_txq_dyn_alloc_dma() return the txq (Íñigo Huguet) [2059999]
- iwlwifi: fix small doc mistake for iwl_fw_ini_addr_val (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always remove the session protection after association (Íñigo Huguet) [2059999]
- iwlwifi: mvm: make iwl_mvm_reconfig_scd() static (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor setting PPE thresholds in STA_HE_CTXT_CMD (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Disable WiFi bands selectively with BIOS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send BAID removal to the FW during hw_restart (Íñigo Huguet) [2059999]
- iwlwifi: don't dump_stack() when we get an unexpected interrupt (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: handle deactivation notification (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Consider P2P GO operation during scan (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 70 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Unify the scan iteration functions (Íñigo Huguet) [2059999]
- iwlwifi: mei: use C99 initializer for device IDs (Íñigo Huguet) [2059999]
- iwlwifi: debugfs: remove useless double condition (Íñigo Huguet) [2059999]
- iwlwifi: remove unused macros (Íñigo Huguet) [2059999]
- iwlwifi: eeprom: clean up macros (Íñigo Huguet) [2059999]
- iwlwifi: drv: load tlv debug data earlier (Íñigo Huguet) [2059999]
- iwlwifi: pcie: Adapt rx queue write pointer for Bz family (Íñigo Huguet) [2059999]
- iwlwifi: pcie: adjust to Bz completion descriptor (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Passively scan non PSC channels only when requested so (Íñigo Huguet) [2059999]
- iwlwifi: scan: Modify return value of a function (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: Avoid using dram data if allocation failed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Correctly set fragmented EBS (Íñigo Huguet) [2059999]
- iwlwifi: nvm: Correct HE capability (Íñigo Huguet) [2059999]
- iwlwifi: mei: avoid -Wpointer-arith and -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: make some functions friendly to sparse (Íñigo Huguet) [2059999]
- iwlwifi: avoid variable shadowing (Íñigo Huguet) [2059999]
- iwlwifi: remove unused DC2DC_CONFIG_CMD definitions (Íñigo Huguet) [2059999]
- iwlwifi: dbg-tlv: clean up iwl_dbg_tlv_update_drams() (Íñigo Huguet) [2059999]
- iwlwifi: move symbols into a separate namespace (Íñigo Huguet) [2059999]
- iwlwifi: fw: make dump_start callback void (Íñigo Huguet) [2059999]
- iwlwifi: pcie: make sure iwl_rx_packet_payload_len() will not underflow (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use debug print instead of WARN_ON() (Íñigo Huguet) [2059999]
- iwlwifi: read and print OTP minor version (Íñigo Huguet) [2059999]
- iwlwifi: add support for BZ-U and BZ-L HW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for CT-KILL notification version 2 (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: remove DBGI_SRAM address reset writing (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support v3 of station HE context command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: add IMR DRAM dump support (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGC allocation flow (Íñigo Huguet) [2059999]
- iwlwifi: pcie: add support for MS devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: align locking in D3 test debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't iterate unadded vifs when handling FW SMPS req (Íñigo Huguet) [2059999]
- iwlwifi: advertise support for HE - DCM BPSK RX/TX (Íñigo Huguet) [2059999]
- iwlwifi: mvm: only enable HE DCM if we also support TX (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGI_SRAM ini dump header. (Íñigo Huguet) [2059999]
- iwlwifi: dbg: add infra for tracking free buffer size (Íñigo Huguet) [2059999]
- iwlwifi: mvm: starting from 22000 we have 32 Rx AMPDU sessions (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support new BAID allocation command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor iwl_mvm_sta_rx_agg() (Íñigo Huguet) [2059999]
- iwlwifi: cfg: add support for 1K BA queue (Íñigo Huguet) [2059999]
- iwlwifi: avoid void pointer arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: fix various more -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: propagate (const) type qualifier (Íñigo Huguet) [2059999]
- iwlwifi: de-const properly where needed (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_fw_lookup_cmd_ver() take a cmd_id (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fw: clean up hcmd struct creation (Íñigo Huguet) [2059999]
- iwlwifi: prefer WIDE_ID() over iwl_cmd_id() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: allow enabling UHB TAS in the USA via ACPI setting (Íñigo Huguet) [2059999]
- iwlwifi: mvm: offload channel switch timing to FW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't call iwl_mvm_sta_from_mac80211() with NULL sta (Íñigo Huguet) [2059999]
- mac80211_hwsim: Advertise support for EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: parse AddBA request with extended AddBA element (Íñigo Huguet) [2059999]
- mac80211: calculate max RX NSS for EHT mode (Íñigo Huguet) [2059999]
- mac80211: Add support for storing station EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: Handle station association response with EHT (Íñigo Huguet) [2059999]
- mac80211: Add EHT capabilities to association/probe request (Íñigo Huguet) [2059999]
- mac80211: Add initial support for EHT and 320 MHz channels (Íñigo Huguet) [2059999]
- mac80211: Support parsing EHT elements (Íñigo Huguet) [2059999]
- cfg80211: Support configuration of station EHT capabilities (Íñigo Huguet) [2059999]
- cfg80211: add NO-EHT flag to regulatory (Íñigo Huguet) [2059999]
- nl80211: add support for 320MHz channel limitation (Íñigo Huguet) [2059999]
- nl80211: add EHT MCS support (Íñigo Huguet) [2059999]
- cfg80211: Add support for EHT 320 MHz channel width (Íñigo Huguet) [2059999]
- cfg80211: Add data structures to capture EHT capabilities (Íñigo Huguet) [2059999]
- ieee80211: add EHT 1K aggregation definitions (Íñigo Huguet) [2059999]
- ieee80211: Add EHT (802.11be) definitions (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add custom regulatory for 6GHz (Íñigo Huguet) [2059999]
- mac80211_hwsim: don't shadow a global variable (Íñigo Huguet) [2059999]
- mac80211_hwsim: check TX and STA bandwidth (Íñigo Huguet) [2059999]
- nl80211: accept only HE capability elements with valid size (Íñigo Huguet) [2059999]
- mac80211: parse only HE capability elements with valid size (Íñigo Huguet) [2059999]
- ieee80211: add helper to check HE capability element size (Íñigo Huguet) [2059999]
- nl80211: use RCU to read regdom in reg get/dump (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add debugfs to control rx status RSSI (Íñigo Huguet) [2059999]
- ieee80211: use tab to indent struct ieee80211_neighbor_ap_info (Íñigo Huguet) [2059999]
- rtw89: handle TX/RX 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: declare if chip support 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: add 6G support to rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: extend subband for 6G band (Íñigo Huguet) [2059999]
- rtw89: refine naming of rfk helpers with prefix (Íñigo Huguet) [2059999]
- rtw89: make rfk helpers common across chips (Íñigo Huguet) [2059999]
- brcmfmac: Add BCM43454/6 support (Íñigo Huguet) [2059999]
- wcn36xx: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- ath11k: fix destination monitor ring out of sync (Íñigo Huguet) [2059999]
- ath11k: fix radar detection in 160 Mhz (Íñigo Huguet) [2059999]
- ath11k: fix WARN_ON during ath11k_mac_update_vif_chan (Íñigo Huguet) [2059999]
- ath11k: fix uninitialized rate_idx in ath11k_dp_tx_update_txcompl() (Íñigo Huguet) [2059999]
- brcmfmac: of: remove redundant variable len (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Replace one-element arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: coex: set EN bit to PLT register (Íñigo Huguet) [2059999]
- rtw89: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw88: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: declare AP mode support (Íñigo Huguet) [2059999]
- rtw89: debug: add stations entry to show ID assignment (Íñigo Huguet) [2059999]
- rtw89: implement ieee80211_ops::start_ap and stop_ap (Íñigo Huguet) [2059999]
- rtw89: maintain assoc/disassoc STA states of firmware and hardware (Íñigo Huguet) [2059999]
- rtw89: only STA mode change vif_type mapping dynamically (Íñigo Huguet) [2059999]
- rtw89: add addr_cam field to sta to support AP mode (Íñigo Huguet) [2059999]
- rtw89: extend role_maintain to support AP mode (Íñigo Huguet) [2059999]
- rtw88: fix use after free in rtw_hw_scan_update_probe_req() (Íñigo Huguet) [2059999]
- mac80211: Remove redundent assignment channel_type (Íñigo Huguet) [2059999]
- mac80211: remove useless ieee80211_vif_is_mesh() check (Íñigo Huguet) [2059999]
- mac80211: fix struct ieee80211_tx_info size (Íñigo Huguet) [2059999]
- mac80211: mlme: validate peer HE supported rates (Íñigo Huguet) [2059999]
- mac80211: remove unused macros (Íñigo Huguet) [2059999]
- cfg80211: pmsr: remove useless ifdef guards (Íñigo Huguet) [2059999]
- mac80211: airtime: avoid variable shadowing (Íñigo Huguet) [2059999]
- mac80211: mlme: add documentation from spec to code (Íñigo Huguet) [2059999]
- mac80211: vht: use HE macros for parsing HE capabilities (Íñigo Huguet) [2059999]
- ieee80211: radiotap: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- ieee80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: don't add non transmitted BSS to 6GHz scanned channels (Íñigo Huguet) [2059999]
- cfg80211/mac80211: assume CHECKSUM_COMPLETE includes SNAP (Íñigo Huguet) [2059999]
- mac80211: consider RX NSS in UHB connection (Íñigo Huguet) [2059999]
- mac80211: limit bandwidth in HE capabilities (Íñigo Huguet) [2059999]
- mt76: redefine mt76_for_each_q_rx to adapt mt7986 changes (Íñigo Huguet) [2059999]
- mt76: dma: initialize skip_unmap in mt76_dma_rx_fill (Íñigo Huguet) [2059999]
- mt76: do not always copy ethhdr in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt76x02: use mt76_phy_dfs_state to determine radar detector state (Íñigo Huguet) [2059999]
- mt76: mt7615: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt7915: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt76x02: improve tx hang detection (Íñigo Huguet) [2059999]
- mt76x02: improve mac error check/reset reliability (Íñigo Huguet) [2059999]
- mt76: mt7921s: run sleep mode by default (Íñigo Huguet) [2059999]
- mt76: sdio: honor the largest Tx buffer the hardware can support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the nss setting in bitrates (Íñigo Huguet) [2059999]
- mt76: mt7915: update max_mpdu_size in mt7915_mcu_sta_amsdu_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix mcs_map in mt7915_mcu_set_sta_he_mcs() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix a possible memory leak in mt7921_load_patch (Íñigo Huguet) [2059999]
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_sta (Íñigo Huguet) [2059999]
- mt76: stop the radar detector after leaving dfs channel (Íñigo Huguet) [2059999]
- mt76: mt7615: check sta_rates pointer in mt7615_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7603: check sta_rates pointer in mt7603_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7663s: flush runtime-pm queue after waking up the device (Íñigo Huguet) [2059999]
- mt76: mt7615: add support for LG LGSBWAC02 (MT7663BUN) (Íñigo Huguet) [2059999]
- mt76: mt7921: remove duplicated code in mt7921_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: mt7915: add missing DATA4_TB_SPTL_REUSE1 to mt7915_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_lmac_mapping in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar background detection (Íñigo Huguet) [2059999]
- mt76: mt7915: report radar pattern if detected by rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce rdd_monitor debugfs node (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar trigger on rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt7915_set_radar_background routine (Íñigo Huguet) [2059999]
- mt76: mt7915: set bssinfo/starec command when adding interface (Íñigo Huguet) [2059999]
- mt76: mt7921: toggle runtime-pm adding a monitor vif (Íñigo Huguet) [2059999]
- mt76: mt7921: fix endianness issues in mt7921_mcu_set_tx() (Íñigo Huguet) [2059999]
- mt76: sdio: disable interrupt in mt76s_sdio_irq (Íñigo Huguet) [2059999]
- mt76: mt7921: fix crash when startup fails. (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix mt7921s_mcu_[fw|drv]_pmctrl (Íñigo Huguet) [2059999]
- mt76: mt7921: fix ht mcs in mt7921_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix ht mcs in mt7915_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: do not always disable fw runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for passing chip/firmware debug data to user space (Íñigo Huguet) [2059999]
- mt76: mt7615e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7915: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: mt7615: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: connac: add support for passing the cipher field in bss_info (Íñigo Huguet) [2059999]
- mt76: mt7921e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: set EDCA parameters with the MCU CE command (Íñigo Huguet) [2059999]
- mt76: mt76_connac: fix MCU_CE_CMD_SET_ROC definition error (Íñigo Huguet) [2059999]
- mt76: mt7921: forbid the doze mode when coredump is in progress (Íñigo Huguet) [2059999]
- mt76: mt7921e: make dev->fw_assert usage consistent (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_rdd_cmd in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_set_rts_thresh (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_gen_dl_mode in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_init_download (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_patch_sem_ctrl/mt76_connac_mcu_start_patch (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_restart in common module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_start_firmware (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_mcu_get_eeprom (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_set_pm in connac module (Íñigo Huguet) [2059999]
- mt76: connac: introduce is_connac_v1 utility routine (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_wtbl_update_hdr_trans in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_hdr_trans_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ht_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_smps_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_uapsd (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_generic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ba_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba_tlv (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_basic_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_ext_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_omac_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: remove duplicated defs in mcu.h (Íñigo Huguet) [2059999]
- mt76: mt7915: move pci specific code back to pci.c (Íñigo Huguet) [2059999]
- mt76: mt7921s: update mt7921s_wfsys_reset sequence (Íñigo Huguet) [2059999]
- mt76: mt7921s: clear MT76_STATE_MCU_RUNNING immediately after reset (Íñigo Huguet) [2059999]
- mt76: sdio: lock sdio when it is needed (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_wtbl_generic_tlv in sta mode (Íñigo Huguet) [2059999]
- mt76: make mt76_sar_capa static (Íñigo Huguet) [2059999]
- mt76: mt7915: add device id for mt7916 (Íñigo Huguet) [2059999]
- mt76: set wlan_idx_hi on mt7916 (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_add_key in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_get_phy utilities (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_chan_bw in common code (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_get_cipher in common code (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_add_tlv routine (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_wtbl_req (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_sta_req (Íñigo Huguet) [2059999]
- mt76: connac: fix sta_rec_wtbl tag len (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7916 calibrated data support (Íñigo Huguet) [2059999]
- mt76: mt7915: update mt7915_chan_mib_offs for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: update rx rate reporting for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: add txfree event v3 (Íñigo Huguet) [2059999]
- mt76: mt7915: enlarge wcid size to 544 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework eeprom.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: mt7915: add firmware support for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework dma.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: add MT_RXQ_MAIN_WA for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: refine register definition (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7915_mmio_probe() as a common probing function (Íñigo Huguet) [2059999]
- mt76: mt7915: fix polling firmware-own status (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Read the console on init and shutdown (Íñigo Huguet) [2059999]
- brcmfmac: fwil: Constify iovar name arguments (Íñigo Huguet) [2059999]
- brcmfmac: of: Use devm_kstrdup for board_type & check for errors (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Fix crashes due to early IRQs (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with memcpy_toio (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Declare missing firmware files in pcie.c (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Allocate space for default boardrev in nvram (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup error path (Íñigo Huguet) [2059999]
- rtlwifi: remove redundant initialization of variable ul_encalgo (Íñigo Huguet) [2059999]
- ray_cs: Check ioremap return value (Íñigo Huguet) [2059999]
- ath11k: add debugfs for TWT debug calls (Íñigo Huguet) [2059999]
- ath11k: add WMI calls to manually add/del/pause/resume TWT dialogs (Íñigo Huguet) [2059999]
- ath11k: Add debugfs interface to configure firmware debug log level (Íñigo Huguet) [2059999]
- cw1200: wsm: make array queue_id_to_wmm_aci static const (Íñigo Huguet) [2059999]
- wilc1000: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- rtw88: rtw8821c: enable rfe 6 devices (Íñigo Huguet) [2059999]
- rtw88: fix memory overrun and memory leak during hw_scan (Íñigo Huguet) [2059999]
- rtw88: fix idle mode flow for hw scan (Íñigo Huguet) [2059999]
- rtw88: check for validity before using a pointer (Íñigo Huguet) [2059999]
- carl9170: fix missing bit-wise or operator for tx_params (Íñigo Huguet) [2059999]
- wcn36xx: Differentiate wcn3660 from wcn3620 (Íñigo Huguet) [2059999]
- ath11k: mhi: use mhi_sync_power_up() (Íñigo Huguet) [2059999]
- ath11k: pci: fix crash on suspend if board file is not found (Íñigo Huguet) [2059999]
- ath11k: Fix missing rx_desc_get_ldpc_support in wcn6855_ops (Íñigo Huguet) [2059999]
- ath11k: Fix uninitialized symbol 'rx_buf_sz' (Íñigo Huguet) [2059999]
- ath11k: fix kernel panic during unload/load ath11k modules (Íñigo Huguet) [2059999]
- ath11k: Rename ath11k_ahb_ext_irq_config (Íñigo Huguet) [2059999]
- brcmfmac: add CYW43570 PCIE device (Íñigo Huguet) [2059999]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on some devices (Íñigo Huguet) [2059999]
- rtw89: use pci_read/write_config instead of dbi read/write (Íñigo Huguet) [2059999]
- rtw89: refine DIG feature to support 160M and CCK PD (Íñigo Huguet) [2059999]
- rtw89: fix maybe uninitialized `qempty` variable (Íñigo Huguet) [2059999]
- rtw89: include subband type in channel params (Íñigo Huguet) [2059999]
- rtw89: handle 6G band if supported by a chipset (Íñigo Huguet) [2059999]
- rtw89: separate {init,deinit}_addr_cam functions (Íñigo Huguet) [2059999]
- rtw89: set mac_id and port ID to TXWD (Íñigo Huguet) [2059999]
- rtw89: send broadcast/multicast packets via HIQ if STAs are in sleep mode (Íñigo Huguet) [2059999]
- rtw89: configure mac port HIQ registers (Íñigo Huguet) [2059999]
- rtw89: rename vif_maintain to role_maintain (Íñigo Huguet) [2059999]
- rtw89: extend firmware commands on states of sta_assoc and sta_disconnect (Íñigo Huguet) [2059999]
- rtw89: allocate mac_id for each station in AP mode (Íñigo Huguet) [2059999]
- rtw89: implement mac80211_ops::set_tim to indicate STA to receive packets (Íñigo Huguet) [2059999]
- rtw89: add C2H handle of BCN_CNT (Íñigo Huguet) [2059999]
- rtw89: download beacon content to firmware (Íñigo Huguet) [2059999]
- rtw89: use hardware SSN to TX management frame (Íñigo Huguet) [2059999]
- rtw89: configure rx_filter according to FIF_PROBE_REQ (Íñigo Huguet) [2059999]
- rtw89: correct use of BA CAM (Íñigo Huguet) [2059999]
- rtw89: encapsulate RX handlers to single function (Íñigo Huguet) [2059999]
- rtw89: Add RX counters of VHT MCS-10/11 to debugfs (Íñigo Huguet) [2059999]
- rtw89: remove duplicate definition of hardware port number (Íñigo Huguet) [2059999]
- rtw89: extract modules by chipset (Íñigo Huguet) [2059999]
- ath11k: avoid firmware crash when reg set for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: set WMI_PEER_40MHZ while peer assoc for 6 GHz (Íñigo Huguet) [2059999]
- ath9k_htc: fix uninit value bugs (Íñigo Huguet) [2059999]
- wcn36xx: Implement get_snr() (Íñigo Huguet) [2059999]
- ath10k: abstract htt_rx_desc structure (Íñigo Huguet) [2059999]
- wcn36xx: Use platform_get_irq_byname() to get the interrupt (Íñigo Huguet) [2059999]
- ath9k: remove redundant status variable (Íñigo Huguet) [2059999]
- ath11k: Reconfigure hardware rate for WCN6855 after vdev is started (Íñigo Huguet) [2059999]
- ath: dfs_pattern_detector: Avoid open coded arithmetic in memory allocation (Íñigo Huguet) [2059999]
- ath10k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2059999]
- ath5k: fix ah_txq_isr_txok_all setting (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_txurn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcborn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcburn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qtrig member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath11k: fix error code in ath11k_qmi_assign_target_mem_chunk() (Íñigo Huguet) [2059999]
- ath11k: move function ath11k_dp_rx_process_mon_status (Íñigo Huguet) [2059999]
- ath11k: enable RX PPDU stats in monitor co-exist mode (Íñigo Huguet) [2059999]
- ath5k: fix OOB in ath5k_eeprom_read_pcal_info_5111 (Íñigo Huguet) [2059999]
- ath11k: free peer for station when disconnect from AP for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: add LDPC FEC type in 802.11 radiotap header (Íñigo Huguet) [2059999]
- ath11k: Refactor the fallback routine when peer create fails (Íñigo Huguet) [2059999]
- ath11k: fix workqueue not getting destroyed after rmmod (Íñigo Huguet) [2059999]
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern (Íñigo Huguet) [2059999]
- ath11k: add missing of_node_put() to avoid leak (Íñigo Huguet) [2059999]
- Revert "ath10k: drop beacon and probe response which leak from other channel" (Íñigo Huguet) [2059999]
- iwlwifi: mvm: return value for request_ownership (Íñigo Huguet) [2059999]
- nl80211: Update bss channel on channel switch for P2P_CLIENT (Íñigo Huguet) [2059999]
- config: wireless: IWLMEI=n (Íñigo Huguet) [2059999]
- iwlwifi: fix build error for IWLMEI (Íñigo Huguet) [2059999]
- mac80211: treat some SAE auth steps as final (Íñigo Huguet) [2059999]
- nl80211: Handle nla_memdup failures in handle_nan_filter (Íñigo Huguet) [2059999]
- iwlwifi: mvm: check debugfs_dir ptr before use (Íñigo Huguet) [2059999]
- iwlwifi: don't advertise TWT support (Íñigo Huguet) [2059999]
- rfkill: define rfill_soft_blocked() if !RFKILL (Íñigo Huguet) [2059999]
- mac80211: fix forwarded mesh frames AC & queue selection (Íñigo Huguet) [2059999]
- mac80211: refuse aggregations sessions before authorized (Íñigo Huguet) [2059999]
- mac80211: fix EAPoL rekey fail in 802.3 rx path (Íñigo Huguet) [2059999]
- iwlwifi: fix use-after-free (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Cinterion MV31-W (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Foxconn SDX55 (Íñigo Huguet) [2059999]
- cfg80211: fix race in netlink owner interface destruction (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send SAR GEO command for 3160 devices (Íñigo Huguet) [2059999]
- iwlwifi: remove deprecated broadcast filtering feature (Íñigo Huguet) [2059999]
- iwlwifi: mei: report RFKILL upon register when needed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't feed the hardware RFKILL into iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: retry mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix the pskb_may_pull check in ipv4 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: gen2: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: fix iwl_legacy_rate_to_fw_idx (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix condition which checks the version of rate_n_flags (Íñigo Huguet) [2059999]
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work (Íñigo Huguet) [2059999]
- mac80211_hwsim: report NOACK frames in tx_status (Íñigo Huguet) [2059999]
- mac80211: mlme: check for null after calling kmemdup (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Fix crash in brcm_alt_fw_path (Íñigo Huguet) [2059999]
- mac80211: use ieee80211_bss_get_elem() (Íñigo Huguet) [2059999]
- nl80211: clarify comment for mesh PLINK_BLOCKED state (Íñigo Huguet) [2059999]
- mac80211: Add stations iterator where the iterator function may sleep (Íñigo Huguet) [2059999]
- mac80211: allow non-standard VHT MCS-10/11 (Íñigo Huguet) [2059999]
- codel: remove unnecessary pkt_sched.h include (Íñigo Huguet) [2059999]
- codel: remove unnecessary sock.h include (Íñigo Huguet) [2059999]
- wilc1000: Add reset/enable GPIO support to SPI driver (Íñigo Huguet) [2059999]
- wilc1000: Convert static "chipid" variable to device-local variable (Íñigo Huguet) [2059999]
- rtw88: don't consider deep PS mode when transmitting packet (Íñigo Huguet) [2059999]
- ath11k: add support of firmware logging for WCN6855 (Íñigo Huguet) [2059999]
- ath10k: replace strlcpy with strscpy (Íñigo Huguet) [2059999]
- rtw88: support SAR via kernel common API (Íñigo Huguet) [2059999]
- rtw88: 8822c: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- iwlwifi: mei: wait before mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: clear the ownership when the driver goes down (Íñigo Huguet) [2059999]
- iwlwifi: fw: fix some scan kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove card state notification code (Íñigo Huguet) [2059999]
- iwlwifi: mvm: drop too short packets silently (Íñigo Huguet) [2059999]
- iwlwifi: return op_mode only in case the failure is from MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support Bz TX checksum offload (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add US/CA to TAS block list if OEM isn't allowed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set schedule scan profiles (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set channel flags (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always store the PPAG table as the latest version. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 69 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support TLV-based firmware reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: change old-SN drop threshold (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't trust hardware queue number (Íñigo Huguet) [2059999]
- iwlwifi: mvm: handle RX checksum on Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use a define for checksum flags mask (Íñigo Huguet) [2059999]
- iwlwifi: remove module loading failure message (Íñigo Huguet) [2059999]
- iwlwifi: mvm: isolate offload assist (checksum) calculation (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for OCE scan (Íñigo Huguet) [2059999]
- iwlwifi: dump RCM error tables (Íñigo Huguet) [2059999]
- iwlwifi: dump both TCM error tables if present (Íñigo Huguet) [2059999]
- iwlwifi: dump CSR scratch from outer function (Íñigo Huguet) [2059999]
- iwlwifi: parse error tables from debug TLVs (Íñigo Huguet) [2059999]
- iwlwifi: recognize missing PNVM data and then log filename (Íñigo Huguet) [2059999]
- iwlwifi: rs: add support for TLC config command ver 4 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: update rfi table (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add list of OEMs allowed to use TAS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support revision 1 of WTAS table (Íñigo Huguet) [2059999]
- iwlwifi: fw: remove dead error log code (Íñigo Huguet) [2059999]
- iwlwifi: do not use __unused as variable name (Íñigo Huguet) [2059999]
- iwlwifi: iwl-eeprom-parse: mostly dvm only (Íñigo Huguet) [2059999]
- iwlwifi: mvm: clean up indenting in iwl_mvm_tlc_update_notif() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a stray tab (Íñigo Huguet) [2059999]
- ath11k: add regdb.bin download for regdb offload (Íñigo Huguet) [2059999]
- rtl8xxxu: Improve the A-MPDU retransmission rate with RTS/CTS protection (Íñigo Huguet) [2059999]
- rtw88: don't check CRC of VHT-SIG-B in 802.11ac signal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix imbalanced locking in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add dbg_time_point to debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add missing min_size to kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix W=1 warnings (Íñigo Huguet) [2059999]
- ath11k: add support for hardware rfkill for QCA6390 (Íñigo Huguet) [2059999]
- ath11k: report tx bitrate for iw wlan station dump (Íñigo Huguet) [2059999]
- ath11k: fix warning of RCU usage for ath11k_mac_get_arvif_by_vdev_id() (Íñigo Huguet) [2059999]
- ath11k: add signal report to mac80211 for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: report rssi of each chain to mac80211 for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- cfg80211: Enable regulatory enforcement checks for drivers supporting mesh iface (Íñigo Huguet) [2059999]
- rfkill: allow to get the software rfkill state (Íñigo Huguet) [2059999]
- cfg80211: refactor cfg80211_get_ies_channel_number() (Íñigo Huguet) [2059999]
- nl82011: clarify interface combinations wrt. channels (Íñigo Huguet) [2059999]
- nl80211: Add support to offload SA Query procedures for AP SME device (Íñigo Huguet) [2059999]
- nl80211: Add support to set AP settings flags with single attribute (Íñigo Huguet) [2059999]
- mac80211: add more HT/VHT/HE state logging (Íñigo Huguet) [2059999]
- cfg80211: Use the HE operation IE to determine a 6GHz BSS channel (Íñigo Huguet) [2059999]
- cfg80211: rename offchannel_chain structs to background_chain to avoid confusion with ETSI standard (Íñigo Huguet) [2059999]
- mac80211: Notify cfg80211 about association comeback (Íñigo Huguet) [2059999]
- cfg80211: Add support for notifying association comeback (Íñigo Huguet) [2059999]
- mac80211: introduce channel switch disconnect function (Íñigo Huguet) [2059999]
- cfg80211: Fix order of enum nl80211_band_iftype_attr documentation (Íñigo Huguet) [2059999]
- cfg80211: simplify cfg80211_chandef_valid() (Íñigo Huguet) [2059999]
- mac80211: Remove a couple of obsolete TODO (Íñigo Huguet) [2059999]
- mac80211: use coarse boottime for airtime fairness code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix cmd timeout in throughput test (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix suspend error with enlarging mcu timeout value (Íñigo Huguet) [2059999]
- mt76: mt7921s: make pm->suspended usage consistent (Íñigo Huguet) [2059999]
- mt76: mt7921: clear pm->suspended in mt7921_mac_reset_work (Íñigo Huguet) [2059999]
- mt76: connac: rely on le16_add_cpu in mt76_connac_mcu_add_nested_tlv (Íñigo Huguet) [2059999]
- mt76: mt7921: remove dead definitions (Íñigo Huguet) [2059999]
- mt76: mt7915: add mu-mimo and ofdma debugfs knobs (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt76_vif in mt7915_vif (Íñigo Huguet) [2059999]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac definitions (Íñigo Huguet) [2059999]
- mt76: connac: rely on MCU_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_CE_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_UNI_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: remove MCU_FW_PREFIX bit (Íñigo Huguet) [2059999]
- mt76: connac: align MCU_EXT definitions with 7915 driver (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_EXT macros (Íñigo Huguet) [2059999]
- mt76: mt7615: in debugfs queue stats, skip wmm index 3 on mt7663 (Íñigo Huguet) [2059999]
- mt76: mt7915: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: allow drivers to drop rx packets early (Íñigo Huguet) [2059999]
- mt76: mt7663: disable 4addr capability (Íñigo Huguet) [2059999]
- mt76: only access ieee80211_hdr after mt76_insert_ccmp_hdr (Íñigo Huguet) [2059999]
- mt76: move sar_capa configuration in common code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix possible kernel crash due to invalid Rx count (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix bus hang with wrong privilege (Íñigo Huguet) [2059999]
- mt76: eeprom: tolerate corrected bit-flips (Íñigo Huguet) [2059999]
- mt76: mt7603: improve reliability of tx powersave filtering (Íñigo Huguet) [2059999]
- mt76: clear sta powersave flag after notifying driver (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7603: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7615: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix the device cannot sleep deeply in suspend (Íñigo Huguet) [2059999]
- mt76: mt7615: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt7915: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt76x02: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: move sar utilities to mt76-core module (Íñigo Huguet) [2059999]
- mt76: mt7921: honor mt76_connac_mcu_set_rate_txpower return value in mt7921_config (Íñigo Huguet) [2059999]
- mt76: do not pass the received frame with decryption error (Íñigo Huguet) [2059999]
- mt76: connac: remove PHY_MODE_AX_6G configuration in mt76_connac_get_phy_mode (Íñigo Huguet) [2059999]
- mt76: mt7615: remove dead code in get_omac_idx (Íñigo Huguet) [2059999]
- mt76: mt7921: introduce 160 MHz channel bandwidth support (Íñigo Huguet) [2059999]
- mt76: mt7921: add support for PCIe ID 0x0608/0x0616 (Íñigo Huguet) [2059999]
- mt76: testmode: add support to set MAC (Íñigo Huguet) [2059999]
- mt76: mt7915: add default calibrated data support (Íñigo Huguet) [2059999]
- mt76: only set rx radiotap flag from within decoder functions (Íñigo Huguet) [2059999]
- mt76: reverse the first fragmented frame to 802.11 (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Introduce Sierra EM919X support (Íñigo Huguet) [2059999]
- bus: mhi: core: Add an API for auto queueing buffers for DL channel (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Simplify code and axe the use of a deprecated API (Íñigo Huguet) [2059999]
- bus: mhi: core: Use macros for execution environment features (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add new device ID support for T99W175 (Íñigo Huguet) [2059999]
- ath11k: Use reserved host DDR addresses from DT for PCI devices (Íñigo Huguet) [2059999]
- wilc1000: Improve WILC TX performance when power_save is off (Íñigo Huguet) [2059999]
- wilc1000: Rename workqueue from "WILC_wq" to "NETDEV-wq" (Íñigo Huguet) [2059999]
- wilc1000: Rename tx task from "K_TXQ_TASK" to NETDEV-tx (Íñigo Huguet) [2059999]
- wilc1000: Rename irq handler from "WILC_IRQ" to netdev name (Íñigo Huguet) [2059999]
- wilc1000: Rename SPI driver from "WILC_SPI" to "wilc1000_spi" (Íñigo Huguet) [2059999]
- wilc1000: Remove misleading USE_SPI_DMA macro (Íñigo Huguet) [2059999]
- ath11k: Change qcn9074 fw to operate in mode-2 (Íñigo Huguet) [2059999]
- ath11k: add ab to TARGET_NUM_VDEVS & co (Íñigo Huguet) [2059999]
- brcmfmac: Fix incorrect type assignments for keep-alive (Íñigo Huguet) [2059999]
- ath11k: Avoid false DEADLOCK warning reported by lockdep (Íñigo Huguet) [2059999]
- ath11k: set DTIM policy to stick mode for station interface (Íñigo Huguet) [2059999]
- ath11k: support MAC address randomization in scan (Íñigo Huguet) [2059999]
- ath10k: wmi: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: htt: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: drop beacon and probe response which leak from other channel (Íñigo Huguet) [2059999]
- ath11k: Process full monitor mode rx support (Íñigo Huguet) [2059999]
- ath11k: add software monitor ring descriptor for full monitor (Íñigo Huguet) [2059999]
- ath11k: Add htt cmd to enable full monitor mode (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS for WCN6855 (Íñigo Huguet) [2059999]
- wilc1000: Add id_table to spi_driver (Íñigo Huguet) [2059999]
- rtw88: refine tx_pwr_tbl debugfs to show channel and bandwidth (Íñigo Huguet) [2059999]
- rtw88: add debugfs to fix tx rate (Íñigo Huguet) [2059999]
- ath: regdom: extend South Korea regulatory domain support (Íñigo Huguet) [2059999]
- ath11k: add wait operation for tx management packets for flush from mac80211 (Íñigo Huguet) [2059999]
- ath11k: add 11d scan offload support (Íñigo Huguet) [2059999]
- ath11k: add configure country code for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: avoid deadlock by change ieee80211_queue_work for regd_update_work (Íñigo Huguet) [2059999]
- iwlwifi: work around reverse dependency on MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: optionally suppress assert log (Íñigo Huguet) [2059999]
- iwlwifi: fw: correctly detect HW-SMEM region subtype (Íñigo Huguet) [2059999]
- iwlwifi: implement reset flow for Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: dbg: disable ini debug in 8000 family and below (Íñigo Huguet) [2059999]
- iwlwifi: support SAR GEO Offset Mapping override via BIOS (Íñigo Huguet) [2059999]
- iwlwifi: pcie: retake ownership after reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always use 4K RB size by default (Íñigo Huguet) [2059999]
- iwlwifi: mvm/api: define system control command (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 68 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add some missing command strings (Íñigo Huguet) [2059999]
- iwlwifi: fw: add support for splitting region type bits (Íñigo Huguet) [2059999]
- iwlwifi: swap 1650i and 1650s killer struct names (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support for DBGC4 for dram (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update rate scale in moving back to assoc state (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for statistics update version 15 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add support for a new version of scan request command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove session protection upon station removal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for PHY context command v4 (Íñigo Huguet) [2059999]
- iwlwifi: fw: api: add link to PHY context command struct v1 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support RLC configuration command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: support v12 wowlan status (Íñigo Huguet) [2059999]
- iwlwifi: mvm: parse firmware alive message version 6 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: support Bz suspend/resume trigger (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: move GTK rekeys condition (Íñigo Huguet) [2059999]
- ath11k: change to use dynamic memory for channel list of scan (Íñigo Huguet) [2059999]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2059999]
- ath9k: switch to rate table based lookup (Íñigo Huguet) [2059999]
- iwlwifi: mvm: demote non-compliant kernel-doc header (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a possible NULL pointer deference (Íñigo Huguet) [2059999]
- iwlwifi: mei: Fix spelling mistake "req_ownserhip" -> "req_ownership" (Íñigo Huguet) [2059999]
- iwlwifi: mei: don't rely on the size from the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix linking when tracing is not enabled (Íñigo Huguet) [2059999]
- ath11k: Avoid NULL ptr access during mgmt tx cleanup (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192de: Style clean-ups (Íñigo Huguet) [2059999]
- brcmfmac: Configure keep-alive packet on suspend (Íñigo Huguet) [2059999]
- ieee80211: change HE nominal packet padding value defines (Íñigo Huguet) [2059999]
- cfg80211: use ieee80211_bss_get_elem() instead of _get_ie() (Íñigo Huguet) [2059999]
- wilc1000: remove '-Wunused-but-set-variable' warning in chip_wakeup() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: read the rfkill state and feed it to iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add vendor commands needed for iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: integrate with iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: add debugfs hooks (Íñigo Huguet) [2059999]
- iwlwifi: mei: add the driver to allow cooperation with CSME (Íñigo Huguet) [2059999]
- mwifiex: Ensure the version string from the firmware is 0-terminated (Íñigo Huguet) [2059999]
- mwifiex: Add quirk to disable deep sleep with certain hardware revision (Íñigo Huguet) [2059999]
- mwifiex: Use a define for firmware version string length (Íñigo Huguet) [2059999]
- rtw88: add debugfs to force lowest basic rate (Íñigo Huguet) [2059999]
- rtw88: follow the AP basic rates for tx mgmt frame (Íñigo Huguet) [2059999]
- mac80211: Use memset_after() to clear tx status (Íñigo Huguet) [2059999]
- mac80211: notify non-transmitting BSS of color changes (Íñigo Huguet) [2059999]
- mac80211: minstrel_ht: remove unused SAMPLE_SWITCH_THR define (Íñigo Huguet) [2059999]
- cfg80211: allow continuous radar monitoring on offchannel chain (Íñigo Huguet) [2059999]
- cfg80211: schedule offchan_cac_abort_wk in cfg80211_radar_event (Íñigo Huguet) [2059999]
- cfg80211: delete redundant free code (Íñigo Huguet) [2059999]
- mac80211: add support for .ndo_fill_forward_path (Íñigo Huguet) [2059999]
- mac80211: Remove unused assignment statements (Íñigo Huguet) [2059999]
- cfg80211: fix possible NULL pointer dereference in cfg80211_stop_offchan_radar_detection (Íñigo Huguet) [2059999]
- ath11k: Use memset_startat() for clearing queue descriptors (Íñigo Huguet) [2059999]
- ath11k: Fix spelling mistake "detetction" -> "detection" (Íñigo Huguet) [2059999]
- Revert "ath11k: add read variant from SMBIOS for download board data" (Íñigo Huguet) [2059999]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2059999]
- ath11k: calculate the correct NSS of peer for HE capabilities (Íñigo Huguet) [2059999]
- ath11k: change to treat alpha code na as world wide regdomain (Íñigo Huguet) [2059999]
- wilc1000: copy address before calling wilc_set_mac_address (Íñigo Huguet) [2059999]
- cfg80211: move offchan_cac_event to a dedicated work (Íñigo Huguet) [2059999]
- mac80211_hwsim: Fix spelling mistake "Droping" -> "Dropping" (Íñigo Huguet) [2059999]
- mac80211: introduce set_radar_offchan callback (Íñigo Huguet) [2059999]
- cfg80211: implement APIs for dedicated radar detection HW (Íñigo Huguet) [2059999]
- ath11k: add support for BSS color change (Íñigo Huguet) [2059999]
- ath11k: add trace log support (Íñigo Huguet) [2059999]
- ath11k: Add missing qmi_txn_cancel() (Íñigo Huguet) [2059999]
- ath11k: Disabling credit flow for WMI path (Íñigo Huguet) [2059999]
- ath11k: Increment pending_mgmt_tx count before tx send invoke (Íñigo Huguet) [2059999]
- ath11k: send proper txpower and maxregpower values to firmware (Íñigo Huguet) [2059999]
- ath11k: move peer delete after vdev stop of station for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: remove return for empty tx bitrate in mac_op_sta_statistics (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_VHT_EXT_NSS_BW_CAPABLE if NSS ratio enabled (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary lock contention in tx_completion path (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in dp_tx path (Íñigo Huguet) [2059999]
- ath11k: avoid while loop in ring selection of tx completion interrupt (Íñigo Huguet) [2059999]
- ath11k: remove mod operator in dst ring processing (Íñigo Huguet) [2059999]
- ath11k: allocate HAL_WBM2SW_RELEASE ring from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in process_rx (Íñigo Huguet) [2059999]
- ath11k: remove usage quota while processing rx packets (Íñigo Huguet) [2059999]
- ath11k: avoid active pdev check for each msdu (Íñigo Huguet) [2059999]
- ath11k: avoid additional access to ath11k_hal_srng_dst_num_free (Íñigo Huguet) [2059999]
- ath11k: modify dp_rx desc access wrapper calls inline (Íñigo Huguet) [2059999]
- ath11k: allocate dst ring descriptors from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: disable unused CE8 interrupts for ipq8074 (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary BH disable lock in STA kickout event (Íñigo Huguet) [2059999]
- ath11k: enable 802.11 power save mode in station mode (Íñigo Huguet) [2059999]
- ath11k: convert ath11k_wmi_pdev_set_ps_mode() to use enum wmi_sta_ps_mode (Íñigo Huguet) [2059999]
- ath9k: use swap() to make code cleaner (Íñigo Huguet) [2059999]
- ath10k: fetch (pre-)calibration data via nvmem subsystem (Íñigo Huguet) [2059999]
- Revert "ath11k: add support for WCN6855 hw2.1" (Íñigo Huguet) [2059999]

* Thu Jun 23 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-118.el9]
- ixgbe: ensure IPsec VF<->PF compatibility (Ken Cox) [2037981]
- ixgbe: add improvement for MDD response functionality (Ken Cox) [2037981]
- ixgbe: add the ability for the PF to disable VF link state (Ken Cox) [2037981]
- ixgbe: xsk: change !netif_carrier_ok() handling in ixgbe_xmit_zc() (Ken Cox) [2037981]
- ixgbe: Remove non-inclusive language (Ken Cox) [2037981]
- ixgbe: respect metadata on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: pass bi->xdp to ixgbe_construct_skb_zc() directly (Ken Cox) [2037981]
- ixgbe: Remove useless DMA-32 fallback configuration (Ken Cox) [2037981]
- ixgbe: switch to napi_build_skb() (Ken Cox) [2037981]
- ixgbe: set X550 MDIO speed before talking to PHY (Ken Cox) [2037981]
- ixgbe: Document how to enable NBASE-T support (Ken Cox) [2037981]
- ixgbe: Use irq_update_affinity_hint() (Ken Cox) [2037981]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037981]
- ixgbe: let the xdpdrv work with more than 64 cpus (Ken Cox) [2037981]
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup (Ken Cox) [2037981]
- net: sfc: ef10: fix memory leak in efx_ef10_mtd_probe() (Íñigo Huguet) [2042841]
- net: sfc: fix memory leak due to ptp channel (Íñigo Huguet) [2042841]
- net: sfc: fix using uninitialized xdp tx_queue (Íñigo Huguet) [2042841]
- sfc: Do not free an empty page_ring (Íñigo Huguet) [2042841]
- net: sfc: add missing xdp queue reinitialization (Íñigo Huguet) [2042841]
- sfc: Avoid NULL pointer dereference on systems without numa awareness (Íñigo Huguet) [2042841]
- sfc: extend the locking on mcdi->seqno (Íñigo Huguet) [2042841]
- sfc: set affinity hints in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: default config to 1 channel/core in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: The size of the RX recycle ring should be more flexible (Íñigo Huguet) [2042841]
- sfc: Use swap() instead of open coding it (Íñigo Huguet) [2042841]
- ethernet/sfc: remove redundant rc variable (Íñigo Huguet) [2042841]
- x86/sgx: Free backing memory after faulting the enclave page (Vladis Dronov) [2081354]
- x86/sgx: Fix missing poison handling in reclaimer (Vladis Dronov) [2081354]
- x86/sgx: Silence softlockup detection when releasing large enclaves (Vladis Dronov) [2081354]
- selftests/sgx: Treat CC as one argument (Vladis Dronov) [2081354]
- selftests/x86: Add validity check and allow field splitting (Vladis Dronov) [2081354]
- selftests/sgx: Remove extra newlines in test output (Vladis Dronov) [2081354]
- selftests/sgx: Ensure enclave data available during debug print (Vladis Dronov) [2081354]
- selftests/sgx: Do not attempt enclave build without valid enclave (Vladis Dronov) [2081354]
- selftests/sgx: Fix NULL-pointer-dereference upon early test failure (Vladis Dronov) [2081354]
- x86/sgx: Remove .fixup usage (Vladis Dronov) [2081354]
- x86/sgx: Fix NULL pointer dereference on non-SGX systems (Vladis Dronov) [2081354]
- x86/sgx: Add an attribute for the amount of SGX memory in a NUMA node (Vladis Dronov) [2081354]
- selftests/sgx: Fix corrupted cpuid macro invocation (Vladis Dronov) [2081354]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Vladis Dronov) [2081354]

* Wed Jun 22 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-117.el9]
- powerpc/rtas: rtas_busy_delay() improvements (Gustavo Walbon) [2050890]
- scripts/pahole-flags.sh: use exit instead of return at the top level (Yauheni Kaliuta) [2098127]
- rhel config: Set DMAR_UNITS_SUPPORTED (Jerry Snitselaar) [2094984]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting (Jerry Snitselaar) [2094984]
- xfs: validate inode fork size against fork format (Andrey Albershteyn) [2089441]
- Adding CONFIG_NVME_VERBOSE_ERRORS to nvme (Gopal Tiwari) [2091823]
- nvme: add missing status values to verbose logging (Gopal Tiwari) [2091823]
- nvme: don't print verbose errors for internal passthrough requests (Gopal Tiwari) [2091823]
- nvme: add verbose error logging (Gopal Tiwari) [2091823]
- ionic: fix missing pci_release_regions() on error in ionic_probe() (Jonathan Toppins) [2050903]
- ionic: no transition while stopping (Jonathan Toppins) [2050903]
- ionic: use vmalloc include (Jonathan Toppins) [2050903]
- ionic: clean up comments and whitespace (Jonathan Toppins) [2050903]
- ionic: prefer strscpy over strlcpy (Jonathan Toppins) [2050903]
- ionic: Use vzalloc for large per-queue related buffers (Jonathan Toppins) [2050903]
- ionic: catch transition back to RUNNING with fw_generation 0 (Jonathan Toppins) [2050903]
- ionic: replace set_vf data with union (Jonathan Toppins) [2050903]
- ionic: stretch heartbeat detection (Jonathan Toppins) [2050903]
- ionic: remove the dbid_inuse bitmap (Jonathan Toppins) [2050903]
- ionic: disable napi when ionic_lif_init() fails (Jonathan Toppins) [2050903]
- ionic: Cleanups in the Tx hotpath code (Jonathan Toppins) [2050903]
- ionic: Prevent filter add/del err msgs when the device is not available (Jonathan Toppins) [2050903]
- ionic: Query FW when getting VF info via ndo_get_vf_config (Jonathan Toppins) [2050903]
- ionic: Allow flexibility for error reporting on dev commands (Jonathan Toppins) [2050903]
- ionic: Correctly print AQ errors if completions aren't received (Jonathan Toppins) [2050903]
- ionic: fix up printing of timeout error (Jonathan Toppins) [2050903]
- ionic: better handling of RESET event (Jonathan Toppins) [2050903]
- ionic: add FW_STOPPING state (Jonathan Toppins) [2050903]
- ionic: Don't send reset commands if FW isn't running (Jonathan Toppins) [2050903]
- ionic: separate function for watchdog init (Jonathan Toppins) [2050903]
- ionic: start watchdog after all is setup (Jonathan Toppins) [2050903]
- ionic: fix type complaint in ionic_dev_cmd_clean() (Jonathan Toppins) [2050903]
- [s390] s390/airq: use DMA memory for summary indicators (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Provide target domain for EP11 cprbs to scheduling function (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: change reply buffer size offering (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Support CPRB minor version T7 (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: handle checkstopped cards with new state (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: CEX8S exploitation support (Tobias Huschle) [2044351]
- [s390] s390/ap/zcrypt: debug feature improvements (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: rework of debug feature messages (Tobias Huschle) [2044351]
- PCI: xgene: Revert "PCI: xgene: Fix IB window setup" (Myron Stowe) [2068174]
- PCI: xgene: Revert "PCI: xgene: Use inbound resources for setup" (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add NX1 support (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add SoC data structure (Myron Stowe) [2068174]
- dt-bindings: PCI: uniphier-ep: Add bindings for NX1 SoC (Myron Stowe) [2068174]
- PCI: rcar: Use PCI_SET_ERROR_RESPONSE after read which triggered an exception (Myron Stowe) [2068174]
- PCI: rcar: Finish transition to L1 state in rcar_pcie_config_access() (Myron Stowe) [2068174]
- PCI: qcom: Add SM8450 PCIe support (Myron Stowe) [2068174]
- PCI: qcom: Add ddrss_sf_tbu flag (Myron Stowe) [2068174]
- PCI: qcom: Remove redundancy between qcom_pcie and qcom_pcie_cfg (Myron Stowe) [2068174]
- dt-bindings: pci: qcom: Document PCIe bindings for SM8450 (Myron Stowe) [2068174]
- PCI: mvebu: Implement support for legacy INTx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Fix macro names and comments about legacy interrupts (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Update information about intx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Use child_ops API (Myron Stowe) [2068174]
- PCI: mvebu: Add support for Advanced Error Reporting registers on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Add support for PCI Bridge Subsystem Vendor ID on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Correctly configure x1/x4 mode (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Add num-lanes property (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCI Bridge Subsystem Vendor ID capability (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCIe extended capabilities (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Re-arrange register tests (Myron Stowe) [2068174]
- PCI: mvebu: Fix reporting Data Link Layer Link Active on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCTL register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCAP register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Properly initialize vendor, device and revision of emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Set PCI_BRIDGE_EMUL_NO_IO_FORWARD when IO is unsupported (Myron Stowe) [2068174]
- PCI: mvebu: Remove duplicate nports assignment (Myron Stowe) [2068174]
- PCI: mvebu: Add help string for CONFIG_PCI_MVEBU option (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for new flag PCI_BRIDGE_EMUL_NO_IO_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Rename PCI_BRIDGE_EMUL_NO_PREFETCHABLE_BAR to PCI_BRIDGE_EMUL_NO_PREFMEM_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Make struct pci_bridge_emul_ops as const (Myron Stowe) [2068174]
- MAINTAINERS: Add Pali Rohár as pci-mvebu.c maintainer (Myron Stowe) [2068174]
- sizes.h: Add SZ_1T macro (Myron Stowe) [2068174]
- PCI: imx6: Assert i.MX8MM CLKREQ# even if no device present (Myron Stowe) [2068174]
- PCI: imx6: Invoke the PHY exit function after PHY power off (Myron Stowe) [2068174]
- PCI: imx6: Enable i.MX6QP PCIe power management support (Myron Stowe) [2068174]
- PCI: imx6: Allow to probe when dw_pcie_wait_for_link() fails (Myron Stowe) [2068174]
- PCI: fu740: Force 2.5GT/s for initial device probe (Myron Stowe) [2068174]
- PCI: fu740: Drop redundant '-gpios' from DT GPIO lookup (Myron Stowe) [2068174]
- PCI: endpoint: Fix misused goto label (Myron Stowe) [2068174]
- PCI: endpoint: Fix alignment fault error in copy tests (Myron Stowe) [2068174]
- PCI: dwc: Restore MSI Receiver mask during resume (Myron Stowe) [2068174]
- PCI: aardvark: Update comment about link going down after link-up (Myron Stowe) [2068174]
- PCI: aardvark: Drop __maybe_unused from advk_pcie_disable_phy() (Myron Stowe) [2068174]
- PCI: aardvark: Don't mask irq when mapping (Myron Stowe) [2068174]
- PCI: aardvark: Remove irq_mask_ack() callback for INTx interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Use separate INTA interrupt for emulated root bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for PME requester on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for PME interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Optimize writing PCI_EXP_RTCTL_PMEIE and PCI_EXP_RTSTA_PME on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading PCI_EXP_RTSTA_PME bit on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for ERR interrupt on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Enable MSI-X support (Myron Stowe) [2068174]
- PCI: aardvark: Fix setting MSI address (Myron Stowe) [2068174]
- PCI: aardvark: Add support for masking MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Refactor unmasking summary MSI interrupt (Myron Stowe) [2068174]
- PCI: aardvark: Use dev_fwnode() instead of of_node_to_fwnode(dev->of_node) (Myron Stowe) [2068174]
- PCI: aardvark: Make msi_domain_info structure a static driver structure (Myron Stowe) [2068174]
- PCI: aardvark: Make MSI irq_chip structures static driver structures (Myron Stowe) [2068174]
- PCI: aardvark: Check return value of generic_handle_domain_irq() when processing INTx IRQ (Myron Stowe) [2068174]
- PCI: aardvark: Rewrite IRQ code to chained IRQ handler (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading MSI interrupt number (Myron Stowe) [2068174]
- PCI: aardvark: Replace custom PCIE_CORE_INT_* macros with PCI_INTERRUPT_* (Myron Stowe) [2068174]
- PCI/VGA: Replace full MIT license text with SPDX identifier (Myron Stowe) [2068174]
- PCI/VGA: Use unsigned format string to print lock counts (Myron Stowe) [2068174]
- PCI/VGA: Log bridge control messages when adding devices (Myron Stowe) [2068174]
- PCI/VGA: Remove empty vga_arb_device_card_gone() (Myron Stowe) [2068174]
- PCI/VGA: Move disabled VGA device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move non-legacy VGA detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move firmware default device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Factor out default VGA device selection (Myron Stowe) [2068174]
- PCI/VGA: Factor out vga_select_framebuffer_device() (Myron Stowe) [2068174]
- PCI/VGA: Move vga_arb_integrated_gpu() earlier in file (Myron Stowe) [2068174]
- PCI/P2PDMA: Add Intel 3rd Gen Intel Xeon Scalable Processors to whitelist (Myron Stowe) [2068174]
- PCI: Avoid broken MSI on SB600 USB devices (Myron Stowe) [2068174]
- x86/PCI: Add #includes to asm/pci_x86.h (Myron Stowe) [2068174]
- PCI: ibmphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: cpqphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: fu740: Remove unused assignments (Myron Stowe) [2068174]
- PCI: kirin: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Declare pci_filp_private only when HAVE_PCI_MMAP (Myron Stowe) [2068174]
- PCI/AER: Update aer-inject URL (Myron Stowe) [2068174]
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum (Myron Stowe) [2068174]
- PCI: pciehp: Clear cmd_busy bit in polling mode (Myron Stowe) [2068174]
- PCI: Reduce warnings on possible RW1C corruption (Myron Stowe) [2068174]
- PCI: Support BAR sizes up to 8TB (Myron Stowe) [2068174]
- PCI: iproc: Set all 24 bits of PCI class code (Myron Stowe) [2068174]
- PCI: Add defines for normal and subtractive PCI bridges (Myron Stowe) [2068174]
- PCI/ACPI: Replace acpi_bus_get_device() with acpi_fetch_acpi_dev() (Myron Stowe) [2068174]
- xsk: Do not write NULL in SW ring at allocation failure (Felix Maurer) [2071619]
- selftests, xsk: Fix rx_full stats test (Felix Maurer) [2071619]
- bpf, sockmap: Fix double bpf_prog_put on error case in map_link (Felix Maurer) [2071619]
- bpf, sockmap: Fix return codes from tcp_bpf_recvmsg_parser() (Felix Maurer) [2071619]
- xsk: Initialise xskb free_list_node (Felix Maurer) [2071619]
- netdevsim: Zero-initialize memory for new map's value in function nsim_bpf_map_alloc (Felix Maurer) [2071619]
- bpf, sockmap: Re-evaluate proto ops when psock is removed from sockmap (Felix Maurer) [2071619]
- bpf, sockmap: Attach map progs to psock early for feature probes (Felix Maurer) [2071619]
- selftests/bpf: Fix xdpxceiver failures for no hugepages (Felix Maurer) [2071619]
- page_pool: Revert "page_pool: disable dma mapping support..." (Felix Maurer) [2071619]
- xsk: Fix crash on double free in buffer pool (Felix Maurer) [2071619]
- bpf, sockmap: sk_skb data_end access incorrect when src_reg = dst_reg (Felix Maurer) [2071619]
- bpf: sockmap, strparser, and tls are reusing qdisc_skb_cb and colliding (Felix Maurer) [2071619]
- bpf, sockmap: Fix race in ingress receive verdict with redirect to self (Felix Maurer) [2071619]
- bpf, sockmap: Remove unhash handler for BPF sockmap usage (Felix Maurer) [2071619]
- selftests, bpf: Add one test for sockmap with strparser (Felix Maurer) [2071619]
- selftests, bpf: Fix test_txmsg_ingress_parser error (Felix Maurer) [2071619]
- skmsg: Lose offset info in sk_psock_skb_ingress (Felix Maurer) [2071619]
- xdp: Remove redundant warning (Felix Maurer) [2071619]
- page_pool: disable dma mapping support for 32-bit arch with 64-bit DMA (Felix Maurer) [2071619]
- xsk: Fix clang build error in __xp_alloc (Felix Maurer) [2071619]
- selftests: xsk: Add frame_headroom test (Felix Maurer) [2071619]
- selftests: xsk: Change interleaving of packets in unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Add single packet test (Felix Maurer) [2071619]
- selftests: xsk: Introduce pacing of traffic (Felix Maurer) [2071619]
- selftests: xsk: Fix socket creation retry (Felix Maurer) [2071619]
- selftests: xsk: Put the same buffer only once in the fill ring (Felix Maurer) [2071619]
- selftests: xsk: Fix missing initialization (Felix Maurer) [2071619]
- xsk: Optimize for aligned case (Felix Maurer) [2071619]
- xsk: Batched buffer allocation for the pool (Felix Maurer) [2071619]
- xsk: Get rid of unused entry in struct xdp_buff_xsk (Felix Maurer) [2071619]
- selftests: xsk: Add tests for 2K frame size (Felix Maurer) [2071619]
- selftests: xsk: Add tests for invalid xsk descriptors (Felix Maurer) [2071619]
- selftests: xsk: Eliminate test specific if-statement in test runner (Felix Maurer) [2071619]
- selftests: xsk: Add test for unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Introduce replacing the default packet stream (Felix Maurer) [2071619]
- selftests: xsk: Allow for invalid packets (Felix Maurer) [2071619]
- selftests: xsk: Eliminate MAX_SOCKS define (Felix Maurer) [2071619]
- selftests: xsx: Make pthreads local scope (Felix Maurer) [2071619]
- selftests: xsk: Make xdp_flags and bind_flags local (Felix Maurer) [2071619]
- selftests: xsk: Specify number of sockets to create (Felix Maurer) [2071619]
- selftests: xsk: Replace second_step global variable (Felix Maurer) [2071619]
- selftests: xsk: Introduce rx_on and tx_on in ifobject (Felix Maurer) [2071619]
- selftests: xsk: Add use_poll to ifobject (Felix Maurer) [2071619]
- selftests: xsx: Introduce test name in test spec (Felix Maurer) [2071619]
- selftests: xsk: Make frame_size configurable (Felix Maurer) [2071619]
- selftests: xsk: Move rxqsize into xsk_socket_info (Felix Maurer) [2071619]
- selftests: xsk: Move num_frames and frame_headroom to xsk_umem_info (Felix Maurer) [2071619]
- selftests: xsk: Introduce test specifications (Felix Maurer) [2071619]
- selftests: xsk: Introduce type for thread function (Felix Maurer) [2071619]
- selftests: xsk: Simplify xsk and umem arrays (Felix Maurer) [2071619]

* Tue Jun 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-116.el9]
- net/sched: act_api: fix error code in tcf_ct_flow_table_fill_tuple_ipv6() (Ivan Vecera) [2090410]
- net/sched: act_pedit: sanitize shift argument before usage (Ivan Vecera) [2090410]
- net/sched: act_pedit: really ensure the skb is writable (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2090410]
- net/sched: taprio: Check if socket flags are valid (Ivan Vecera) [2090410]
- net/sched: fix initialization order when updating chain 0 head (Ivan Vecera) [2090410]
- net/sched: flower: fix parsing of ethertype following VLAN header (Ivan Vecera) [2090410]
- net/sched: act_ct: fix ref leak when switching zones (Ivan Vecera) [2090410]
- net/sched: fix incorrect vlan_push_eth dest field (Ivan Vecera) [2090410]
- net/sched: add vlan push_eth and pop_eth action to the hardware IR (Ivan Vecera) [2090410]
- flow_offload: improve extack msg for user when adding invalid filter (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup failure with no originating ifindex (Ivan Vecera) [2090410]
- act_ct: Support GRE offload (Ivan Vecera) [2090410]
- flow_offload: reject offload for all drivers with invalid police parameters (Ivan Vecera) [2090410]
- net: flow_offload: add tc police action parameters (Ivan Vecera) [2090410]
- net: sched: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup after ct clear or switching zones (Ivan Vecera) [2090410]
- net: sched: limit TC_ACT_REPEAT loops (Ivan Vecera) [2090410]
- net_sched: add __rcu annotation to netdev->qdisc (Ivan Vecera) [2090410]
- net/sched: act_police: more accurate MTU policing (Ivan Vecera) [2090410]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Ivan Vecera) [2090410]
- net: sched: fix use-after-free in tc_new_tfilter() (Ivan Vecera) [2090410]
- net: sched: remove qdisc_qlen_cpu() (Ivan Vecera) [2090410]
- net: sched: remove psched_tdiff_bounded() (Ivan Vecera) [2090410]
- sch_htb: Fail on unsupported parameters when offload is requested (Ivan Vecera) [2090410]
- netfilter: nft_ct: fix use after free when attaching zone template (Ivan Vecera) [2090410]
- netfilter: conntrack: remove extension register api (Ivan Vecera) [2090410]
- netfilter: conntrack: handle ->destroy hook via nat_ops instead (Ivan Vecera) [2090410]
- netfilter: conntrack: move extension sizes into core (Ivan Vecera) [2090410]
- netfilter: conntrack: make all extensions 8-byte alignned (Ivan Vecera) [2090410]
- net: sched: Clarify error message when qdisc kind is unknown (Ivan Vecera) [2090410]
- net_sched: restore "mpu xxx" handling (Ivan Vecera) [2090410]
- net: prefer nf_ct_put instead of nf_conntrack_put (Ivan Vecera) [2090410]
- netfilter: conntrack: avoid useless indirection during conntrack destruction (Ivan Vecera) [2090410]
- netfilter: make function op structures const (Ivan Vecera) [2090410]
- netfilter: core: move ip_ct_attach indirection to struct nf_ct_hook (Ivan Vecera) [2090410]
- netfilter: conntrack: convert to refcount_t api (Ivan Vecera) [2090410]
- sch_cake: revise Diffserv docs (Ivan Vecera) [2090410]
- sch_qfq: prevent shift-out-of-bounds in qfq_init_qdisc (Ivan Vecera) [2090410]
- net: openvswitch: Fill act ct extension (Ivan Vecera) [2090410]
- net/sched: act_ct: Fill offloading tuple iifidx (Ivan Vecera) [2090410]
- flow_offload: fix suspicious RCU usage when offloading tc action (Ivan Vecera) [2090410]
- net/sched: use min() macro instead of doing it manually (Ivan Vecera) [2090410]
- selftests: tc-testing: add action offload selftest for action and filter (Ivan Vecera) [2090410]
- flow_offload: validate flags of filter and actions (Ivan Vecera) [2090410]
- flow_offload: add reoffload process to update hw_count (Ivan Vecera) [2090410]
- net: sched: save full flags for tc action (Ivan Vecera) [2090410]
- flow_offload: add process to update action stats from hardware (Ivan Vecera) [2090410]
- flow_offload: rename exts stats update functions with hw (Ivan Vecera) [2090410]
- flow_offload: add skip_hw and skip_sw to control if offload the action (Ivan Vecera) [2090410]
- flow_offload: allow user to offload tc action to net device (Ivan Vecera) [2090410]
- flow_offload: add ops to tc_action_ops for flow action setup (Ivan Vecera) [2090410]
- flow_offload: rename offload functions with offload instead of flow (Ivan Vecera) [2090410]
- flow_offload: add index to flow_action_entry structure (Ivan Vecera) [2090410]
- flow_offload: reject to offload tc actions in offload drivers (Ivan Vecera) [2090410]
- flow_offload: fill flags to action structure (Ivan Vecera) [2090410]
- net/sched: act_ct: Offload only ASSURED connections (Ivan Vecera) [2090410]
- netfilter: nfnetlink_queue: silence bogus compiler warning (Ivan Vecera) [2090410]
- selftests/tc-testing: match any qdisc type (Ivan Vecera) [2090410]
- net: sched: sch_netem: Refactor code in 4-state loss generator (Ivan Vecera) [2090410]
- selftests: forwarding: Fix packet matching in mirroring selftests (Ivan Vecera) [2090410]
- cls_flower: Fix inability to match GRE/IPIP packets (Ivan Vecera) [2090410]
- sch_htb: Add extack messages for EOPNOTSUPP errors (Ivan Vecera) [2090410]
- net: sch: simplify condtion for selecting mini_Qdisc_pair buffer (Ivan Vecera) [2090410]
- net: sch: eliminate unnecessary RCU waits in mini_qdisc_pair_swap() (Ivan Vecera) [2090410]
- net: sched: gred: dynamically allocate tc_gred_qopt_offload (Ivan Vecera) [2090410]
- net: stats: Read the statistics in ___gnet_stats_copy_basic() instead of adding. (Ivan Vecera) [2090410]
- net: sched: Allow statistics reads from softirq. (Ivan Vecera) [2090410]
- net: sch_tbf: Add a graft command (Ivan Vecera) [2090410]
- net: sched: remove one pair of atomic operations (Ivan Vecera) [2090410]
- net: sched: fix logic error in qdisc_run_begin() (Ivan Vecera) [2090410]
- net: sched: Remove Qdisc::running sequence counter (Ivan Vecera) [2090410]
- net: sched: Merge Qdisc::bstats and Qdisc::cpu_bstats data types (Ivan Vecera) [2090410]
- net: sched: Use _bstats_update/set() instead of raw writes (Ivan Vecera) [2090410]
- net: sched: Protect Qdisc::bstats with u64_stats (Ivan Vecera) [2090410]
- u64_stats: Introduce u64_stats_set() (Ivan Vecera) [2090410]
- gen_stats: Move remaining users to gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- mq, mqprio: Use gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add instead Set the value in __gnet_stats_copy_basic(). (Ivan Vecera) [2090410]
- net: sched: Use struct_size() helper in kvmalloc() (Ivan Vecera) [2090410]
- net_sched: Use struct_size() and flex_array_size() helpers (Ivan Vecera) [2090410]
- net: prevent user from passing illegal stab size (Ivan Vecera) [2090410]
- net: sched: move and reuse mq_change_real_num_tx() (Ivan Vecera) [2090410]
- selftests: net: test ethtool -L vs mq (Ivan Vecera) [2090410]
- netdevsim: add ability to change channel count (Ivan Vecera) [2090410]
- net: sched: update default qdisc visibility after Tx queue cnt changes (Ivan Vecera) [2090410]
- fix array-index-out-of-bounds in taprio_change (Ivan Vecera) [2090410]
- net/sched: cls_api, reset flags on replay (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftests for sch_mq (Ivan Vecera) [2090410]
- net_sched: refactor TC action init API (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftest for skbmod SKBMOD_F_ECN option (Ivan Vecera) [2090410]
- net/sched: act_skbmod: Add SKBMOD_F_ECN option support (Ivan Vecera) [2090410]
- qdisc: add new field for qdisc_enqueue tracepoint (Ivan Vecera) [2090410]
- net/sched: Remove unnecessary if statement (Ivan Vecera) [2090410]
- iommu/amd: Enable swiotlb in all cases (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3-sva: Fix mm use-after-free (Jerry Snitselaar) [2072170]
- iommu/dma: Fix iova map result check bug (Jerry Snitselaar) [2072170]
- crypto: qat - remove dma_free_coherent() for RSA (Jerry Snitselaar) [2072170]
- iommu/amd: Do not call sleep while holding spinlock (Jerry Snitselaar) [2072170]
- iommu/amd: Remove redundant check (Jerry Snitselaar) [2072170]
- iommu/amd: Increase timeout waiting for GA log enablement (Jerry Snitselaar) [2072170]
- dma-direct: don't over-decrypt memory (Jerry Snitselaar) [2072170]
- swiotlb: max mapping size takes min align mask into account (Jerry Snitselaar) [2072170]
- dma-debug: change allocation mode from GFP_NOWAIT to GFP_ATIOMIC (Jerry Snitselaar) [2072170]
- dma-direct: don't fail on highmem CMA pages in dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- swiotlb: make swiotlb_exit a no-op if SWIOTLB_FORCE is set (Jerry Snitselaar) [2072170]
- dma-direct: use is_swiotlb_active in dma_direct_map_page (Jerry Snitselaar) [2072170]
- iommu: Make sysfs robust for non-API groups (Jerry Snitselaar) [2072170]
- iommu: arm-smmu: disable large page mappings for Nvidia arm-smmu (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Fix size calculation in arm_smmu_mm_invalidate_range() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop stop marker messages (Jerry Snitselaar) [2072170]
- iommu/vt-d: Calculate mask for non-aligned flushes (Jerry Snitselaar) [2072170]
- dma-direct: avoid redundant memory sync for swiotlb (Jerry Snitselaar) [2072170]
- dma-mapping: move pgprot_decrypted out of dma_pgprot (Jerry Snitselaar) [2072170]
- dma-mapping: benchmark: extract a common header file for map_benchmark definition (Jerry Snitselaar) [2072170]
- dma-debug: fix return value of __setup handlers (Jerry Snitselaar) [2072170]
- dma-mapping: remove CONFIG_DMA_REMAP (Jerry Snitselaar) [2072170]
- swiotlb: simplify array allocation (Jerry Snitselaar) [2072170]
- swiotlb: tidy up includes (Jerry Snitselaar) [2072170]
- swiotlb: simplify debugfs setup (Jerry Snitselaar) [2072170]
- swiotlb: do not zero buffer in set_memory_decrypted() (Jerry Snitselaar) [2072170]
- iommu/amd: Improve amd_iommu_v2_exit() (Jerry Snitselaar) [2072170]
- iommu/amd: Remove unused struct fault.devid (Jerry Snitselaar) [2072170]
- iommu/amd: Clean up function declarations (Jerry Snitselaar) [2072170]
- iommu/amd: Call memunmap in error path (Jerry Snitselaar) [2072170]
- iommu/amd: Improve error handling for amd_iommu_init_pci (Jerry Snitselaar) [2072170]
- iommu/vt-d: Enable ATS for the devices in SATC table (Jerry Snitselaar) [2008729]
- iommu/vt-d: Remove unused function intel_svm_capable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Add missing "__init" for rmrr_sanity_check() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Move intel_iommu_ops to header file (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix indentation of goto labels (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary prototypes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary includes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove DEFER_DEVICE_DOMAIN_INFO (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove domain and devinfo mempool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove iova_cache_get/put() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove finding domain in dmar_insert_one_dev_info() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove intel_iommu::domains (Jerry Snitselaar) [2072170]
- iommu/iova: Improve 32-bit free space estimate (Jerry Snitselaar) [2072170]
- iommu: Split struct iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove unused argument in is_attach_deferred (Jerry Snitselaar) [2072170]
- iommu: Use right way to retrieve iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove apply_resv_region (Jerry Snitselaar) [2072170]
- iommu: Remove aux-domain related interfaces and iommu_ops (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove aux-domain related callbacks (Jerry Snitselaar) [2072170]
- iommu: Remove guest pasid related interfaces and definitions (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove guest pasid related callbacks (Jerry Snitselaar) [2072170]
- iommu/iova: Separate out rcache init (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Account for PMU interrupts (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: fix event handling soft lockup (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Add missing pm_runtime_disable() in qcom_iommu_device_probe (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Simplify memory allocation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Avoid open coded arithmetic in memory allocation (Jerry Snitselaar) [2072170]
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping() (Jerry Snitselaar) [2072170]
- iommu: Fix some W=1 warnings (Jerry Snitselaar) [2072170]
- iommu: Fix potential use-after-free during probe (Jerry Snitselaar) [2072170]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Jerry Snitselaar) [2072170]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Jerry Snitselaar) [2072170]
- iommu/iova: Temporarily include dma-mapping.h from iova.h (Jerry Snitselaar) [2072170]
- iommu: Move flush queue data into iommu_dma_cookie (Jerry Snitselaar) [2072170]
- iommu/iova: Move flush queue code to iommu-dma (Jerry Snitselaar) [2072170]
- iommu/iova: Consolidate flush queue code (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Simplify pagetable freeing (Jerry Snitselaar) [2072170]
- iommu/iova: Squash flush_cb abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Squash entry_dtor abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Fix race between FQ timeout and teardown (Jerry Snitselaar) [2072170]
- iommu/iova: Move fast alloc size roundup into alloc_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting (Jerry Snitselaar) [2072170]
- iommu: Extend mutex lock scope in iommu_probe_device() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused dma_to_mm_pfn function (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop duplicate check in dma_pte_free_pagetable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use bitmap_zalloc() when applicable (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused macros (Jerry Snitselaar) [2072170]
- iommu/amd: Fix typo in *glues … together* in comment (Jerry Snitselaar) [2072170]
- iommu/amd: Remove useless irq affinity notifier (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: re-enable after resume (Jerry Snitselaar) [2072170]
- iommu/amd: Restore GA log/tail pointer on host resume (Jerry Snitselaar) [2072170]
- Revert "iommu/arm-smmu-v3: Decrease the queue size of evtq and priq" (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Constify arm_smmu_mmu_notifier_ops (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-impl: Add SM8450 qcom iommu implementation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Fix TTBR0 read (Jerry Snitselaar) [2072170]
- dma-direct: add a dma_direct_use_pool helper (Jerry Snitselaar) [2072170]
- dma-direct: factor the swiotlb code out of __dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- dma-direct: drop two CONFIG_DMA_RESTRICTED_POOL conditionals (Jerry Snitselaar) [2072170]
- dma-direct: warn if there is no pool for force unencrypted allocations (Jerry Snitselaar) [2072170]
- dma-direct: fail allocations that can't be made coherent (Jerry Snitselaar) [2072170]
- dma-direct: refactor the !coherent checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: factor out a helper for DMA_ATTR_NO_KERNEL_MAPPING allocations (Jerry Snitselaar) [2072170]
- dma-direct: clean up the remapping checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: always leak memory that can't be re-encrypted (Jerry Snitselaar) [2072170]
- dma-direct: don't call dma_set_decrypted for remapped allocations (Jerry Snitselaar) [2072170]
- dma-direct: factor out dma_set_{de,en}crypted helpers (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix an unbalanced rcu_read_lock/rcu_read_unlock() (Jerry Snitselaar) [2072170]
- iommu/amd: Clarify AMD IOMMUv2 initialization messages (Jerry Snitselaar) [2072170]
- dma-mapping: use 'bitmap_zalloc()' when applicable (Jerry Snitselaar) [2072170]
- iommu/dma: Use kvcalloc() instead of kvzalloc() (Jerry Snitselaar) [2072170]
- iommu/dma: Account for min_align_mask w/swiotlb (Jerry Snitselaar) [2072170]
- swiotlb: Support aligned swiotlb buffers (Jerry Snitselaar) [2072170]
- iommu/dma: Check CONFIG_SWIOTLB more broadly (Jerry Snitselaar) [2072170]
- iommu/dma: Fold _swiotlb helpers into callers (Jerry Snitselaar) [2072170]
- iommu/dma: Skip extra sync during unmap w/swiotlb (Jerry Snitselaar) [2072170]
- iommu/dma: Fix arch_sync_dma for map (Jerry Snitselaar) [2072170]
- iommu/dma: Fix sync_sg with swiotlb (Jerry Snitselaar) [2072170]
- iommu/vt-d: Avoid duplicate removing in __domain_mapping() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Convert the return type of first_pte_in_page to bool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Delete dev_has_feat callback (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use second level for GPA->HPA translation (Jerry Snitselaar) [2072170]
- iommu/vt-d: Check FL and SL capability sanity in scalable mode (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove duplicate identity domain flag (Jerry Snitselaar) [2072170]
- iommu/vt-d: Dump DMAR translation structure when DMA fault occurs (Jerry Snitselaar) [1880620]
- iommu/vt-d: Do not falsely log intel_iommu is unsupported kernel option (Jerry Snitselaar) [2072170]
- iommu/amd: Use report_iommu_fault() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Request direct mapping for modem device (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-qcom: Add compatible for QCM2290 (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Add SM6350 SMMU compatible (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Properly handle the return value of arm_smmu_cmdq_build_cmd() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands in arm_smmu_atc_inv_master() (Jerry Snitselaar) [2072170]
- iommu/dma: Unexport IOVA cookie management (Jerry Snitselaar) [2072170]
- iommu/amd: Use struct_group() for memcpy() region (Jerry Snitselaar) [2072170]
- dma-mapping: remove bogus test for pfn_valid from dma_map_resource (Jerry Snitselaar) [2072170]
- swiotlb-xen: ensure to issue well-formed XENMEM_exchange requests (Jerry Snitselaar) [2072170]
- iova: Export alloc_iova_fast() and free_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable: Add DART pagetable format (Jerry Snitselaar) [2072170]

* Mon Jun 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-115.el9]
- video: fbdev: hyperv_fb: Allow resolutions with size > 64 MB for Gen1 (Mohammed Gamal) [2096917]
- hv_balloon: Fix balloon_probe() and balloon_remove() error handling (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: fix typo in comment (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Remove support for Hyper-V 2008 and Hyper-V 2008R2/Win7 (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Refactor the ring-buffer iterator functions (Mohammed Gamal) [2086622]
- hv_sock: Copy packets sent by Hyper-V out of the ring buffer (Mohammed Gamal) [2086622]
- hv_sock: Check hv_pkt_iter_first_raw()'s return value (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Accept hv_sock offers in isolated guests (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce {lock,unlock}_requestor() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_request_addr_match() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_sendpacket_getid() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix handling of messages with transaction ID of zero (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add VMbus IMC device to unsupported list (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Replace smp_store_mb() with virt_store_mb() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Disable balloon and hot-add accordingly (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Support status report for larger page sizes (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Prevent load re-ordering when reading ring buffer (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix potential crash on module unload (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix initialization of device object in vmbus_device_register() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Deactivate sysctl_record_panic_msg by default in isolated guests (Mohammed Gamal) [2086622]
- drivers: hv: log when enabling crash_kexec_post_notifiers (Mohammed Gamal) [2086622]
- Drivers: hv: utils: Make use of the helper macro LIST_HEAD() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Rework use of DMA_BIT_MASK(64) (Mohammed Gamal) [2086622]
- scsi: storvsc: Add Isolation VM support for storvsc driver (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix memory leak in vmbus_add_channel_kobj (Mohammed Gamal) [2086622]
- Drivers: hv: Compare cpumasks and not their weights in init_vp_index() (Mohammed Gamal) [2086622]
- Drivers: hv: Rename 'alloced' to 'allocated' (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Use struct_size() helper in kmalloc() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: account for vmbus packet header in max_pkt_size (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize request offers message for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: Fix definition of hypercall input & output arg variables (Mohammed Gamal) [2086622]
- hv: utils: add PTP_1588_CLOCK to Kconfig to fix build (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Use VMBUS_RING_SIZE() wrapper for dm_ring_size (Mohammed Gamal) [2086622]
- Drivers: hv : vmbus: Adding NULL pointer check (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize VMbus ring buffer for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add SNP support for VMbus channel initiate message (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Mark vmbus ring buffer visible to host in Isolation VM (Mohammed Gamal) [2086622]
- x86/fpu: KVM: Set the base guest FPU uABI size to sizeof(struct kvm_xsave) (Vitaly Kuznetsov) [2092468]
- ixgbevf: clean up some inconsistent indenting (Ken Cox) [2037982]
- ixgbevf: Require large buffers for build_skb on 82599VF (Ken Cox) [2037982]
- ixgbevf: Remove useless DMA-32 fallback configuration (Ken Cox) [2037982]
- ixgbevf: switch to napi_build_skb() (Ken Cox) [2037982]
- ixgbevf: Add support for new mailbox communication between PF and VF (Ken Cox) [2037982]
- ixgbevf: Mailbox improvements (Ken Cox) [2037982]
- ixgbevf: Add legacy suffix to old API mailbox functions (Ken Cox) [2037982]
- ixgbevf: Improve error handling in mailbox (Ken Cox) [2037982]
- ixgbevf: Rename MSGTYPE to SUCCESS and FAILURE (Ken Cox) [2037982]
- net: ixgbevf: Remove redundant initialization of variable ret_val (Ken Cox) [2037982]

* Fri Jun 17 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-114.el9]
- redhat/configs: Move CRYPTO_USER config to match ARK layout (Vladis Dronov) [2096894]
- redhat/configs: Drop outdated CRYPTO_ECDH configs (Vladis Dronov) [2096894]
- perf: Fix sys_perf_event_open() race against self (Michael Petlan) [2087964] {CVE-2022-1729}
- block: ignore RWF_HIPRI hint for sync dio (Ming Lei) [2071243]
- [s390] s390/qdio: clarify logical vs absolute in QIB's kerneldoc (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded sanity check in qdio_do_sqbs() (Mete Durlu) [2044298]
- [s390] s390/qdio: split do_QDIO() (Mete Durlu) [2044298]
- [s390] s390/qdio: split qdio_inspect_queue() (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify handler logic for qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up access to queue in qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: avoid allocating the qdio_irq with GFP_DMA (Mete Durlu) [2044298]
- [s390] s390/qdio: improve handling of CIWs (Mete Durlu) [2044298]
- [s390] s390/qdio: remove QDIO_SBAL_SIZE macro (Mete Durlu) [2044298]
- [s390] scsi: zfcp: fix kernel doc comments (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused support for SLIB parameters (Mete Durlu) [2044298]
- [s390] s390/qdio: consolidate QIB code (Mete Durlu) [2044298]
- [s390] s390/qdio: use dev_info() in qdio_print_subchannel_info() (Mete Durlu) [2044298]
- [s390] s390/qdio: fine-tune the queue sync (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up SIGA capability tracking (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused sync-after-IRQ infrastructure (Mete Durlu) [2044298]
- [s390] s390/qdio: use absolute data address in ESTABLISH ccw (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused macros (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify reporting of errors to the drivers (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded siga-sync for Output Queue (Mete Durlu) [2044298]
- [s390] s390/qdio: remove remaining tasklet & timer code (Mete Durlu) [2044298]
- scsi: lpfc: Correct BDE DMA address assignment for GEN_REQ_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Fix split code for FLOGI on FCoE (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.3 (Dick Kennedy) [2063879]
- scsi: lpfc: Use sg_dma_address() and sg_dma_len() macros for NVMe I/O (Dick Kennedy) [2063879]
- scsi: lpfc: Alter FPIN stat accounting logic (Dick Kennedy) [2063879]
- scsi: lpfc: Rework FDMI initialization after link up (Dick Kennedy) [2063879]
- scsi: lpfc: Change VMID registration to be based on fabric parameters (Dick Kennedy) [2063879]
- scsi: lpfc: Decrement outstanding gidft_inp counter if lpfc_err_lost_link() (Dick Kennedy) [2063879]
- scsi: lpfc: Use list_for_each_entry_safe() in rscn_recovery_check() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix dmabuf ptr assignment in lpfc_ct_reject_event() (Dick Kennedy) [2063879]
- scsi: lpfc: Inhibit aborts if external loopback plug is inserted (Dick Kennedy) [2063879]
- scsi: lpfc: Fix ndlp put following a LOGO completion (Dick Kennedy) [2063879]
- scsi: lpfc: Fill in missing ndlp kref puts in error paths (Dick Kennedy) [2063879]
- scsi: lpfc: Fix element offset in __lpfc_sli_release_iocbq_s4() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant lpfc_sli_prep_wqe() call (Dick Kennedy) [2063879]
- scsi: lpfc: Fix additional reference counting in lpfc_bsg_rport_els() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary null ndlp check in lpfc_sli_prep_wqe() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unneeded variable (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.2 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.2 (Dick Kennedy) [2063879]
- scsi: lpfc: Expand setting ELS_ID field in ELS_REQUEST64_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Update stat accounting for READ_STATUS mbox command (Dick Kennedy) [2063879]
- scsi: lpfc: Refactor cleanup of mailbox commands (Dick Kennedy) [2063879]
- scsi: lpfc: Fix field overload in lpfc_iocbq data structure (Dick Kennedy) [2063879]
- scsi: lpfc: Register for Application Services FC-4 type in Fabric topology (Dick Kennedy) [2063879]
- scsi: lpfc: Remove false FDMI NVMe FC-4 support for NPIV ports (Dick Kennedy) [2063879]
- scsi: lpfc: Revise FDMI reporting of supported port speed for trunk groups (Dick Kennedy) [2063879]
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled (Dick Kennedy) [2063879]
- scsi: lpfc: Correct CRC32 calculation for congestion stats (Dick Kennedy) [2063879]
- scsi: lpfc: Move MI module parameter check to handle dynamic disable (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary NULL pointer assignment for ELS_RDF path (Dick Kennedy) [2063879]
- scsi: lpfc: Transition to NPR state upon LOGO cmpl if link down or aborted (Dick Kennedy) [2063879]
- scsi: lpfc: Update fc_prli_sent outstanding only after guaranteed IOCB submit (Dick Kennedy) [2063879]
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT (Dick Kennedy) [2063879]
- scsi: lpfc: Fix null pointer dereference after failing to issue FLOGI and PLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Clear fabric topology flag before initiating a new FLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock (Dick Kennedy) [2063879]
- scsi: lpfc: Requeue SCSI I/O to upper layer when fw reports link down (Dick Kennedy) [2063879]
- scsi: lpfc: Zero SLI4 fcp_cmnd buffer's fcpCntl0 field (Dick Kennedy) [2063879]
- scsi: lpfc: Fix diagnostic fw logging after a function reset (Dick Kennedy) [2063879]
- scsi: lpfc: Move cfg_log_verbose check before calling lpfc_dmp_dbg() (Dick Kennedy) [2063879]
- scsi: lpfc: Tweak message log categories for ELS/FDMI/NVMe rescan (Dick Kennedy) [2063879]
- scsi: lpfc: Fix locking for lpfc_sli_iocbq_lookup() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix broken SLI4 abort path (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.1 (Dick Kennedy) [2063879]
- scsi: lpfc: Fix queue failures when recovering from PCI parity error (Dick Kennedy) [2063879]
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults (Dick Kennedy) [2063879]
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.0 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.0 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor BSG paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor Abort paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor SCSI paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor CT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor misc ELS paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor VMID paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor FDISC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_RJT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_ACC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor the RSCN/SCR/RDF/EDC/FARPR paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor PLOGI/PRLI/ADISC/LOGO paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor base ELS paths and the FLOGI path (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Introduce lpfc_prep_wqe (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor fast and slow paths to native SLI4 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor lpfc_iocbq (Dick Kennedy) [2063879]
- scsi: lpfc: Use kcalloc() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix typos in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_chk_tgt_mapped() (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_send_taskmgmt() (Dick Kennedy) [2063879]
- scsi: lpfc: Use fc_block_rport() (Dick Kennedy) [2063879]
- scsi: lpfc: Drop lpfc_no_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Kill lpfc_bus_reset_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Reduce log messages seen after firmware download (Dick Kennedy) [2063879]
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant flush_workqueue() call (Dick Kennedy) [2063879]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Dick Kennedy) [2063879]
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write() (Dick Kennedy) [2063879]
- scsi: lpfc: Use irq_set_affinity() (Dick Kennedy) [2063879]
- scsi: lpfc: Add support for optional PLDV handling (Dick Kennedy) [2063879]
- scsi: lpfc: Return NULL rather than a plain 0 integer (Dick Kennedy) [2063879]
- scsi: lpfc: Fix a function name in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Fix mailbox command failure during driver initialization (Dick Kennedy) [2063879]
- jbd2: fix a potential race while discarding reserved buffers after an abort (Lukas Czerner) [2079868]
- ext4: update the cached overhead value in the superblock (Lukas Czerner) [2079868]
- ext4: force overhead calculation if the s_overhead_cluster makes no sense (Lukas Czerner) [2079868]
- ext4: fix overhead calculation to account for the reserved gdt blocks (Lukas Czerner) [2079868]
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole (Lukas Czerner) [2079868]
- ext4: fix use-after-free in ext4_search_dir (Lukas Czerner) [2079868]
- ext4: fix bug_on in start_this_handle during umount filesystem (Lukas Czerner) [2079868]
- ext4: fix symlink file size not match to file content (Lukas Czerner) [2079868]
- ext4: fix fallocate to use file_modified to update permissions consistently (Lukas Czerner) [2085759]
- ext4: fix kernel doc warnings (Lukas Czerner) [2079868]
- ext4: add commit tid info in ext4_fc_commit_start/stop trace events (Lukas Czerner) [2079868]
- ext4: add commit_tid info in jbd debug log (Lukas Czerner) [2079868]
- ext4: add transaction tid info in fc_track events (Lukas Czerner) [2079868]
- ext4: convert ext4_fc_track_dentry type events to use event class (Lukas Czerner) [2079868]
- ext4: fix ext4_fc_stats trace point (Lukas Czerner) [2079868]
- ext4: add new trace event in ext4_fc_cleanup (Lukas Czerner) [2079868]
- ext4: return early for non-eligible fast_commit track events (Lukas Czerner) [2079868]
- ext4: do not call FC trace event in ext4_fc_commit() if FS does not support FC (Lukas Czerner) [2079868]
- ext4: remove unused enum EXT4_FC_COMMIT_FAILED (Lukas Czerner) [2079868]
- ext4: warn when dirtying page w/o buffers in data=journal mode (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan performance mount option work with extents (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan option work with set/unset mount cmd (Lukas Czerner) [2079868]
- ext4: stop using bio_devname (Lukas Czerner) [2079868]
- ext4: don't BUG if someone dirty pages without asking ext4 first (Lukas Czerner) [2079868]
- ext4: remove redundant assignment to variable split_flag1 (Lukas Czerner) [2079868]
- ext4: fix underflow in ext4_max_bitmap_size() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_clear_bb() kernel-doc comment (Lukas Czerner) [2079868]
- ext4: fix fs corruption when tring to remove a non-empty directory with IO error (Lukas Czerner) [2079868]
- ext4: use time_is_before_jiffies() instead of open coding it (Lukas Czerner) [2079868]
- ext4: improve fast_commit performance and scalability (Lukas Czerner) [2079868]
- ext4: add extra check in ext4_mb_mark_bb() to prevent against possible corruption (Lukas Czerner) [2079868]
- ext4: add strict range checks while freeing blocks (Lukas Czerner) [2079868]
- ext4: add ext4_sb_block_valid() refactored out of ext4_inode_block_valid() (Lukas Czerner) [2079868]
- ext4: no need to test for block bitmap bits in ext4_mb_mark_bb() (Lukas Czerner) [2079868]
- ext4: rename ext4_set_bits to mb_set_bits (Lukas Czerner) [2079868]
- ext4: use in_range() for range checking in ext4_fc_replay_check_excluded (Lukas Czerner) [2079868]
- ext4: refactor ext4_free_blocks() to pull out ext4_mb_clear_bb() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_mark_bb() with flex_bg with fast_commit (Lukas Czerner) [2079868]
- ext4: correct cluster len and clusters changed accounting in ext4_mb_mark_bb (Lukas Czerner) [2079868]
- jbd2: remove CONFIG_JBD2_DEBUG to update t_max_wait (Lukas Czerner) [2079868]
- jbd2: kill t_handle_lock transaction spinlock (Lukas Czerner) [2079868]
- fs/ext4: fix comments mentioning i_mutex (Lukas Czerner) [2079868]
- ext4: fix incorrect type issue during replay_del_range (Lukas Czerner) [2079868]
- jbd2: fix kernel-doc descriptions for jbd2_journal_shrink_{scan,count}() (Lukas Czerner) [2079868]
- jbd2: fix use-after-free of transaction_t race (Lukas Czerner) [2079868]
- jbd2: refactor wait logic for transaction updates into a common function (Lukas Czerner) [2079868]
- jbd2: cleanup unused functions declarations from jbd2.h (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_fc_record_modified_inode() (Lukas Czerner) [2079868]
- ext4: remove redundant max inline_size check in ext4_da_write_inline_data_begin() (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_restore_inline_data() (Lukas Czerner) [2079868]
- ext4: fast commit may miss file actions (Lukas Czerner) [2079868]
- ext4: fast commit may not fallback for ineligible commit (Lukas Czerner) [2079868]
- ext4: modify the logic of ext4_mb_new_blocks_simple (Lukas Czerner) [2079868]
- ext4: prevent used blocks from being allocated during fast commit replay (Lukas Czerner) [2079868]
- jbd2: export jbd2_journal_[grab|put]_journal_head (Lukas Czerner) [2079868]
- ext4: simplify ext4_sb_read_encoding (Lukas Czerner) [2079868]
- ext4: flush background discard kwork when retry allocation (Lukas Czerner) [2079868]
- ext4: get discard out of jbd2 commit kthread contex (Lukas Czerner) [2079868]
- ext4: report correct st_size for encrypted symlinks (Lukas Czerner) [2079868]
- fscrypt: add fscrypt_symlink_getattr() for computing st_size (Lukas Czerner) [2079868]

* Thu Jun 16 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-113.el9]
- powerpc/rtas: Keep MSR[RI] set when calling RTAS (Diego Domingos) [2087259]
- netfilter: nat: really support inet nat without l3 address (Phil Sutter) [2092430]
- netfilter: nf_tables: use kfree_rcu(ptr, rcu) to release hooks in clean_net path (Phil Sutter) [2094245]
- netfilter: nf_tables: double hook unregistration in netns path (Phil Sutter) [2094245]
- [s390] s390/dasd: Fix read inconsistency for ESE DASD devices (Mete Durlu) [2094302]
- [s390] s390/dasd: Fix read for ESE with blksize < 4k (Mete Durlu) [2094302]
- redhat/configs: enable CONFIG_SP5100_TCO for x86_64 (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (Sudheesh Mavila) [2078696]
- kernel/resource: Introduce request_mem_region_muxed() (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Move timer initialization into function (Sudheesh Mavila) [2078696]
- watchdog: sp5100_tco: Add support for get_timeleft (Sudheesh Mavila) [2078696]
- redhat/configs: enable ACPI_PCC (Mark Langsdorf) [2067294]
- ACPI: tables: Quiet ACPI table not found warning (Mark Langsdorf) [2067294]
- ACPI/IORT: Check node revision for PMCG resources (Mark Langsdorf) [2067294]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067294]
- ACPI: PM: s2idle: Cancel wakeup before dispatching EC GPE (Mark Langsdorf) [2067294]
- ACPI: PM: Revert "Only mark EC GPE for wakeup on Intel systems" (Mark Langsdorf) [2067294]
- ACPI: require CRC32 to build (Mark Langsdorf) [2067294]
- ACPI: PCC: pcc_ctx can be static (Mark Langsdorf) [2067294]
- ACPI: scan: Rename label in acpi_scan_init() (Mark Langsdorf) [2067294]
- ACPI: scan: Simplify initialization of power and sleep buttons (Mark Langsdorf) [2067294]
- ACPI: scan: Change acpi_scan_init() return value type to void (Mark Langsdorf) [2067294]
- ACPI: SPCR: check if table->serial_port.access_width is too wide (Mark Langsdorf) [2067294]
- ACPI: APD: Check for NULL pointer after calling devm_ioremap() (Mark Langsdorf) [2067294]
- ACPI: APD: Add a fmw property clk-name (Mark Langsdorf) [2067294]
- drivers: acpi: acpi_apd: Remove unused device property "is-rv" (Mark Langsdorf) [2067294]
- x86: clk: clk-fch: Add support for newer family of AMD's SOC (Mark Langsdorf) [2067294]
- ACPI: PCC: Implement OperationRegion handler for the PCC Type 3 subtype (Mark Langsdorf) [2067294]
- ACPI / x86: Skip AC and battery devices on x86 Android tablets with broken DSDTs (Mark Langsdorf) [2067294]
- ACPI / x86: Introduce an acpi_quirk_skip_acpi_ac_and_battery() helper (Mark Langsdorf) [2067294]
- ACPI: processor: thermal: avoid cpufreq_get_policy() (Mark Langsdorf) [2067294]
- ACPI / x86: Add acpi_quirk_skip_[i2c_client|serdev]_enumeration() helpers (Mark Langsdorf) [2067294]
- ACPI: scan: Create platform device for BCM4752 and LNV4752 ACPI nodes (Mark Langsdorf) [2067294]
- ACPI: battery: Add the ThinkPad "Not Charging" quirk (Mark Langsdorf) [2067294]
- acpi: Export acpi_bus_type (Mark Langsdorf) [2067294]
- ACPI: sysfs: use default_groups in kobj_type (Mark Langsdorf) [2067294]
- redhat/configs: enable ACPI_PFRUT (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_telemetry: Fix info leak in pfrt_log_ioctl() (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_update: Fix return value check in pfru_write() (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Telemetry driver (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Update device driver (Mark Langsdorf) [2040058 2067294]
- efi: Introduce EFI_FIRMWARE_MANAGEMENT_CAPSULE_HEADER and corresponding structures (Mark Langsdorf) [2040058 2067294]
- ACPICA: Update version to 20211217 (Mark Langsdorf) [2067294]
- ACPICA: iASL/NHLT table: "Specific Data" field support (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add suppport for AGDI table (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add TDEL table to both compiler/disassembler (Mark Langsdorf) [2067294]
- ACPICA: Fixed a couple of warnings under MSVC (Mark Langsdorf) [2067294]
- ACPICA: Change a return_ACPI_STATUS (AE_BAD_PARAMETER) (Mark Langsdorf) [2067294]
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5 (Mark Langsdorf) [2067294]
- ACPICA: Add support for PCC Opregion special context data (Mark Langsdorf) [2067294]
- ACPICA: Fix wrong interpretation of PCC address (Mark Langsdorf) [2067294]
- ACPICA: Executer: Fix the REFCLASS_REFOF case in acpi_ex_opcode_1A_0T_1R() (Mark Langsdorf) [2067294]
- ACPICA: Utilities: Avoid deleting the same object twice in a row (Mark Langsdorf) [2067294]
- ACPICA: Fix AEST Processor generic resource substructure data field byte length (Mark Langsdorf) [2067294]
- ACPICA: iASL/Disassembler: Additional support for NHLT table (Mark Langsdorf) [2067294]
- ACPICA: Avoid subobject buffer overflow when validating RSDP signature (Mark Langsdorf) [2067294]
- ACPICA: Macros: Remove ACPI_PHYSADDR_TO_PTR (Mark Langsdorf) [2067294]
- ACPICA: Use original pointer for virtual origin tables (Mark Langsdorf) [2067294]
- ACPICA: Use original data_table_region pointer for accesses (Mark Langsdorf) [2067294]
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions (Mark Langsdorf) [2067294]
- ACPI: NFIT: Import GUID before use (Mark Langsdorf) [2067294]
- ACPI: NUMA: Process hotpluggable memblocks when !CONFIG_MEMORY_HOTPLUG (Mark Langsdorf) [2067294]
- ACPI: PM: Remove redundant cache flushing (Mark Langsdorf) [2067294]
- ACPI: Use acpi_fetch_acpi_dev() instead of acpi_bus_get_device() (Mark Langsdorf) [2067294]
- ACPI: tables: Add AEST to the list of known table signatures (Mark Langsdorf) [2067294]
- ACPI: delay enumeration of devices with a _DEP pointing to an INT3472 device (Mark Langsdorf) [2067294]
- ACPI: PM: Avoid CPU cache flush when entering S4 (Mark Langsdorf) [2067294]
- PM: hibernate: Allow ACPI hardware signature to be honoured (Mark Langsdorf) [2067294]
- ACPI: PMIC: xpower: Fix _TMP ACPI errors (Mark Langsdorf) [2067294]
- ACPI: PMIC: allow drivers to provide a custom lpat_raw_to_temp() function (Mark Langsdorf) [2067294]
- ACPI: PMIC: constify all struct intel_pmic_opregion_data declarations (Mark Langsdorf) [2067294]
- ACPI: EC: Mark the ec_sys write_support param as module_param_hw() (Mark Langsdorf) [2067294]
- ACPI: EC: Relocate acpi_ec_create_query() and drop acpi_ec_delete_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Make the event work state machine visible (Mark Langsdorf) [2067294]
- ACPI: EC: Avoid queuing unnecessary work in acpi_ec_submit_event() (Mark Langsdorf) [2067294]
- ACPI: EC: Rename three functions (Mark Langsdorf) [2067294]
- ACPI: EC: Simplify locking in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Rearrange the loop in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Fold acpi_ec_check_event() into acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Pass one argument to acpi_ec_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Call advance_transaction() from acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067294]
- ACPI: EC: Rework flushing of EC work while suspended to idle (Mark Langsdorf) [2067294]
- ACPI / x86: Add PWM2 on the Xiaomi Mi Pad 2 to the always_present list (Mark Langsdorf) [2067294]
- ACPI / x86: Add not-present quirk for the PCI0.SDHB.BRC1 device on the GPD win (Mark Langsdorf) [2067294]
- ACPI / x86: Allow specifying acpi_device_override_status() quirks by path (Mark Langsdorf) [2067294]
- ACPI: Change acpi_device_always_present() into acpi_device_override_status() (Mark Langsdorf) [2067294]
- ACPI / x86: Drop PWM2 device on Lenovo Yoga Book from always present table (Mark Langsdorf) [2067294]
- ACPI: processor idle: Use swap() instead of open coding it (Mark Langsdorf) [2067294]
- ACPI: processor: Replace kernel.h with the necessary inclusions (Mark Langsdorf) [2067294]
- ACPI: DPTF: Update device ID in a comment (Mark Langsdorf) [2067294]
- ACPI: PM: Emit debug messages when enabling/disabling wakeup power (Mark Langsdorf) [2067294]
- ACPI: thermal: drop an always true check (Mark Langsdorf) [2067294]
- ACPI: Add a context argument for table parsing handlers (Mark Langsdorf) [2067294]
- ACPI: Teach ACPI table parsing about the CEDT header format (Mark Langsdorf) [2067294]
- ACPI: Keep sub-table parsing infrastructure available for modules (Mark Langsdorf) [2067294]
- selftests/bpf: Prevent skeleton generation race (Yauheni Kaliuta) [2069045]
- kernel.spec: disable vmlinux.h generation for s390 zfcpdump config (Yauheni Kaliuta) [2069045]
- bpf: Fix possible race in inc_misses_counter (Yauheni Kaliuta) [2069045]
- kbuild: Unify options for BTF generation for vmlinux and modules (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- bpf, x86: Fix "no previous prototype" warning (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add tests for restricted helpers (Yauheni Kaliuta) [2069045]
- selftests/bpf: Check map in map pruning (Yauheni Kaliuta) [2069045]
- bpf: selftest: Trigger a DCE on the whole subprog (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_objects_list (Yauheni Kaliuta) [2069045]
- scripts: documentation-file-ref-check: fix bpf selftests path (Yauheni Kaliuta) [2069045]
- libbpf: Add ability to fetch bpf_program's underlying instructions (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use cpu_number only on arches that have it (Yauheni Kaliuta) [2069045]
- libbpf: Fix skel_internal.h to set errno on loader retval < 0 (Yauheni Kaliuta) [2069045]
- bpf: Document BPF licensing. (Yauheni Kaliuta) [2069045]
- libbpf: Fix gen_loader assumption on number of programs. (Yauheni Kaliuta) [2069045]
- libbpf: Add "bool skipped" to struct bpf_map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip all serial_test_get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf: Fix a btf decl_tag bug when tagging a function (Yauheni Kaliuta) [2069045]
- libbpf: Define BTF_KIND_* constants in btf.h to avoid compilation errors (Yauheni Kaliuta) [2069045]
- libbpf: Use probe_name for legacy kprobe (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use "__se_" prefix on architectures without syscall wrapper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Extract syscall wrapper (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Skip unresolved symbol warning for empty BTF sets (Yauheni Kaliuta) [2069045]
- libbpf: Perform map fd cleanup for gen_loader in case of error (Yauheni Kaliuta) [2069045]
- libbpf: Fix non-C89 loop variable declaration in gen_loader.c (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers for the bootstrap version, too (Yauheni Kaliuta) [2069045]
- tools/runqslower: Fix cross-build (Yauheni Kaliuta) [2069045]
- libbpf: Fix section counting logic (Yauheni Kaliuta) [2069045]
- libbpf: Load global data maps lazily on legacy kernels (Yauheni Kaliuta) [2069045]
- bpftool: Fix error check when calling hashmap__new() (Yauheni Kaliuta) [2069045]
- libbpf: Remove deprecation attribute from struct bpf_prog_prep_result (Yauheni Kaliuta) [2069045]
- bpftool: Fix print error when show bpf map (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_get_next_key method to bloom filter map. (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix racing issue in btf_skc_cls_ingress test (Yauheni Kaliuta) [2069045]
- selftest/bpf: Add a test that reads various addresses. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable address check. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable fixup offset. (Yauheni Kaliuta) [2069045]
- bpf: Make 32->64 bounds propagation slightly more robust (Yauheni Kaliuta) [2069045]
- bpf: Fix signed bounds propagation after mov32 (Yauheni Kaliuta) [2069045]
- bpf, selftests: Update test case for atomic cmpxchg on r0 with pointer (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case for atomic fetch on spilled pointer (Yauheni Kaliuta) [2069045]
- bpf: Fix kernel address leakage in atomic cmpxchg's r0 aux reg (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix OOB write in test_verifier (Yauheni Kaliuta) [2069045]
- selftests/bpf: Tests for state pruning with u32 spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Fix incorrect state pruning for <8B spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Add selftests to cover packet access corner cases (Yauheni Kaliuta) [2069045]
- bpf: Fix the off-by-two error in range markings (Yauheni Kaliuta) [2069045]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Yauheni Kaliuta) [2069045]
- bpf: Fix bpf_check_mod_kfunc_call for built-in modules (Yauheni Kaliuta) [2069045]
- redhat/configs: Add CONFIG_DEBUG_INFO_DWARF5 (Yauheni Kaliuta) [2069045]
- bpf: Make CONFIG_DEBUG_INFO_BTF depend upon CONFIG_BPF_SYSCALL (Yauheni Kaliuta) [2069045]
- Documentation/locking/locktypes: Update migrate_disable() bits. (Yauheni Kaliuta) [2069045]
- bpf: Make sure bpf_disable_instrumentation() is safe vs preemption. (Yauheni Kaliuta) [2069045]
- libbpf: Fix lookup_and_delete_elem_flags error reporting (Yauheni Kaliuta) [2069045]
- selftests/bpf: Verifier test on refill from a smaller spill (Yauheni Kaliuta) [2069045]
- bpf: Do not reject when the stack read size is different from the tracked scalar size (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make netcnt selftests serial to avoid spurious failures (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test RENAME_EXCHANGE and RENAME_NOREPLACE on bpffs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Convert test_bpffs to ASSERT macros (Yauheni Kaliuta) [2069045]
- libfs: Support RENAME_EXCHANGE in simple_rename() (Yauheni Kaliuta) [2069045]
- libfs: Move shmem_exchange to simple_rename_exchange (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate AF_XDP support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a testcase for 64-bit bounds propagation issue. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of signed bounds from 64-bit min/max into 32-bit. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of bounds from 64-bit min/max into 32-bit and var_off. (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix also no-alu32 strobemeta selftest (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_delete_elem method to bloom filter map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom map success test for userspace calls (Yauheni Kaliuta) [2069045]
- bpf: Add alignment padding for "map_extra" + consolidate holes (Yauheni Kaliuta) [2069045]
- bpf: Bloom filter map naming fixups (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test cases for struct_ops prog (Yauheni Kaliuta) [2069045]
- bpf: Add dummy BPF STRUCT_OPS for test purpose (Yauheni Kaliuta) [2069045]
- bpf: Factor out helpers for ctx access checking (Yauheni Kaliuta) [2069045]
- bpf: Factor out a helper to prepare trampoline for struct_ops prog (Yauheni Kaliuta) [2069045]
- cgroup: bpf: Move wrapper for __cgroup_bpf_*() to kernel/bpf/cgroup.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix strobemeta selftest regression (Yauheni Kaliuta) [2069045]
- bpf: Disallow unprivileged bpf by default (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fclose/pclose mismatch in test_progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix memory leak in test_ima (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fd cleanup in sk_lookup test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add weak/typeless ksym test for light skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Use O_CLOEXEC uniformly when opening fds (Yauheni Kaliuta) [2069045]
- libbpf: Ensure that BPF syscall fds are never 0, 1, or 2 (Yauheni Kaliuta) [2069045]
- libbpf: Add weak ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- libbpf: Add typeless ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_kallsyms_lookup_name helper (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmarks for comparing hashmap lookups w/ vs. w/out bloom filter (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmark tests for bloom filter throughput + false positive (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom filter map test cases (Yauheni Kaliuta) [2069045]
- libbpf: Add "map_extra" as a per-map-type extra flag (Yauheni Kaliuta) [2069045]
- bpf: Add bloom filter map implementation (Yauheni Kaliuta) [2069045]
- bpf, tests: Add module parameter test_suite to test_bpf module (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding a namespace reset for tc_redirect (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix attach_probe in parallel mode (Yauheni Kaliuta) [2069045]
- selfetests/bpf: Update vmtest.sh defaults (Yauheni Kaliuta) [2069045]
- bpf: Use u64_stats_t in struct bpf_prog_stats (Yauheni Kaliuta) [2069045]
- bpf: Fixes possible race in update_prog_stats() for 32bit arches (Yauheni Kaliuta) [2069045]
- bpf: Avoid races in __bpf_prog_run() for 32bit arches (Yauheni Kaliuta) [2069045]
- s390: introduce nospec_uses_trampoline() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Guess function end for test_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Fix endianness detection in BPF_CORE_READ_BITFIELD_PROBED() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate ambiguously-named bpf_program__size() API (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate multi-instance bpf_program APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for PIDs/names references (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for programs/maps in BTF listing (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for pinned paths of BPF objects (Yauheni Kaliuta) [2069045]
- bpftool: Do not expose and init hash maps for pinned path in main.c (Yauheni Kaliuta) [2069045]
- bpftool: Remove Makefile dep. on $(LIBBPF) for $(LIBBPF_INTERNAL_HDRS) (Yauheni Kaliuta) [2069045]
- selftests/bpf: Split out bpf_verif_scale selftests into multiple tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Mark tc_redirect selftest as serial (Yauheni Kaliuta) [2069045]
- bpf/selftests: remove .c suffix from prog_tests/rhskip (Yauheni Kaliuta) [2069045]
- selftests/bpf: Support multiple tests per file (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize selftest entry points (Yauheni Kaliuta) [2069045]
- libbpf: Fix BTF header parsing checks (Yauheni Kaliuta) [2069045]
- libbpf: Fix overflow in BTF sanity checks (Yauheni Kaliuta) [2069045]
- docs/bpf: Update documentation for BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef example in tag.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test deduplication for BTF_KIND_DECL_TAG typedef (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef unit tests (Yauheni Kaliuta) [2069045]
- bpf: Add BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix flow dissector tests (Yauheni Kaliuta) [2069045]
- libbpf: Use func name when pinning programs with LIBBPF_STRICT_SEC_NAME (Yauheni Kaliuta) [2069045]
- bpftool: Avoid leaking the JSON writer prepared for program metadata (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new btf__type_cnt/btf__raw_data APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- libbpf: Add btf__type_cnt() and btf__raw_data() APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate btf__finalize_data() and move it into libbpf.c (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in btf__dedup() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make perf_buffer selftests work on 4.9 kernel again (Yauheni Kaliuta) [2069045]
- libbpf: Fix the use of aligned attribute (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to ".bss"/".rodata"/".data" lookups for internal maps (Yauheni Kaliuta) [2069045]
- libbpf: Simplify look up by name of internal maps (Yauheni Kaliuta) [2069045]
- selftests/bpf: Demonstrate use of custom .rodata/.data sections (Yauheni Kaliuta) [2069045]
- libbpf: Support multiple .rodata.* and .data.* BPF maps (Yauheni Kaliuta) [2069045]
- bpftool: Improve skeleton generation for data maps without DATASEC type (Yauheni Kaliuta) [2069045]
- bpftool: Support multiple .rodata/.data internal maps in skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Remove assumptions about uniqueness of .rodata/.data/.bss maps (Yauheni Kaliuta) [2069045]
- libbpf: Use Elf64-specific types explicitly for dealing with ELF (Yauheni Kaliuta) [2069045]
- libbpf: Extract ELF processing state into separate struct (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add verif_stats test (Yauheni Kaliuta) [2069045]
- bpf: Add verified_insns to bpf_prog_info and fdinfo (Yauheni Kaliuta) [2069045]
- libbpf: Fix ptr_is_aligned() usages (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- samples: bpf: Suppress readelf stderr when probing for BTF support (Yauheni Kaliuta) [2069045]
- net: bpf: Switch over to memdup_user() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Some more atomic tests (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping non-aligned __int128 (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping big-endian bitfields (Yauheni Kaliuta) [2069045]
- bpftool: Remove useless #include to <perf-sys.h> from map_perf_ring.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove duplicated include in cgroup_helpers (Yauheni Kaliuta) [2069045]
- bpf/preload: Clean up .gitignore and "clean-files" target (Yauheni Kaliuta) [2069045]
- libbpf: Migrate internal use of bpf_program__get_prog_info_linear (Yauheni Kaliuta) [2069045]
- bpf: Silence Coverity warning for find_kfunc_desc_btf (Yauheni Kaliuta) [2069045]
- bpftool: Turn check on zlib from a phony target into a conditional error (Yauheni Kaliuta) [2069045]
- bpftool: Do not FORCE-build libbpf (Yauheni Kaliuta) [2069045]
- bpftool: Fix install for libbpf's internal header(s) (Yauheni Kaliuta) [2069045]
- libbpf: Remove Makefile warnings on out-of-sync netlink.h/if_link.h (Yauheni Kaliuta) [2069045]
- bpf: Rename BTF_KIND_TAG to BTF_KIND_DECL_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip verifier tests that fail to load with ENOTSUPP (Yauheni Kaliuta) [2069045]
- selfetest/bpf: Make some tests serial (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix pid check in fexit_sleep test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding pid filtering for atomics test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make cgroup_v1v2 use its own port (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix race condition in enable_stats (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add per worker cgroup suffix (Yauheni Kaliuta) [2069045]
- selftests/bpf: Allow some tests to be executed in sequence (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add parallelism to test_progs (Yauheni Kaliuta) [2069045]
- bpf/selftests: Add test for writable bare tracepoint (Yauheni Kaliuta) [2069045]
- libbpf: Support detecting and attaching of writable tracepoint program (Yauheni Kaliuta) [2069045]
- bpf: Support writable context for bare tracepoint (Yauheni Kaliuta) [2069045]
- bpftool: Add install-bin target to install binary only (Yauheni Kaliuta) [2069045]
- selftests/bpf: Better clean up for runqslower in test_bpftool_build.sh (Yauheni Kaliuta) [2069045]
- samples/bpf: Do not FORCE-recompile libbpf (Yauheni Kaliuta) [2069045]
- samples/bpf: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- samples/bpf: Update .gitignore (Yauheni Kaliuta) [2069045]
- bpf: iterators: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpf: preload: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/runqslower: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers instead of including the dir (Yauheni Kaliuta) [2069045]
- bpftool: Remove unused includes to <bpf/bpf_gen_internal.h> (Yauheni Kaliuta) [2069045]
- libbpf: Skip re-installing headers file if source is older than target (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove SEC("version") from test progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip the second half of get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf, tests: Add more LD_IMM64 tests (Yauheni Kaliuta) [2069045]
- bpf, x64: Factor out emission of REX byte in more cases (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_object__unload() API since v0.6 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new bpf_object__next_{map,program} APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_{map,program}__{prev,next} APIs since v0.7 (Yauheni Kaliuta) [2069045]
- libbpf: Add API documentation convention guidelines (Yauheni Kaliuta) [2069045]
- bpf: Use $(pound) instead of \# in Makefiles (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new btf__add_btf() API (Yauheni Kaliuta) [2069045]
- selftests/bpf: Refactor btf_write selftest to reuse BTF generation logic (Yauheni Kaliuta) [2069045]
- libbpf: Add API that copies all BTF types from one BTF object to another (Yauheni Kaliuta) [2069045]
- bpf, x64: Save bytes for DIV by reducing reg copies (Yauheni Kaliuta) [2069045]
- bpf: Avoid retpoline for bpf_for_each_map_elem (Yauheni Kaliuta) [2069045]
- bpf: selftests: Add selftests for module kfunc support (Yauheni Kaliuta) [2069045]
- libbpf: Update gen_loader to emit BTF_KIND_FUNC relocations (Yauheni Kaliuta) [2069045]
- libbpf: Resolve invalid weak kfunc calls with imm = 0, off = 0 (Yauheni Kaliuta) [2069045]
- libbpf: Support kernel module function calls (Yauheni Kaliuta) [2069045]
- bpf: Enable TCP congestion control kfunc from modules (Yauheni Kaliuta) [2069045]
- tools: Allow specifying base BTF file in resolve_btfids (Yauheni Kaliuta) [2069045]
- bpf: btf: Introduce helpers for dynamic BTF set registration (Yauheni Kaliuta) [2069045]
- bpf: Be conservative while processing invalid kfunc calls (Yauheni Kaliuta) [2069045]
- bpf: Introduce BPF support for kernel module function calls (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use BTF-defined key/value for map definitions (Yauheni Kaliuta) [2069045]
- libbpf: Support uniform BTF-defined key/value specification across all BPF maps (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of LDX_MEM with operand aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of ALU shifts with operand register aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Minor restructuring of ALU tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more tests for ALU and ATOMIC register clobbering (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests to check source register zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add zero-extension checks in BPF_ATOMIC tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests of BPF_LDX and BPF_STX with small sizes (Yauheni Kaliuta) [2069045]
- bpf, xdp, docs: Correct some English grammar and spelling (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use kselftest skip code for skipped tests (Yauheni Kaliuta) [2069045]
- bpf: Do not invoke the XDP dispatcher for PROG_RUN with single repeat (Yauheni Kaliuta) [2069045]
- libbpf: Make gen_loader data aligned. (Yauheni Kaliuta) [2069045]
- bpf: selftests: Fix fd cleanup in get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix probe_user test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- bpf: Replace callers of BPF_CAST_CALL with proper function typedef (Yauheni Kaliuta) [2069045]
- bpf: Replace "want address" users of BPF_CAST_CALL with BPF_CALL_IMM (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tail call limit test with external function call (Yauheni Kaliuta) [2069045]
- bpftool: Avoid using "?: " in generated code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch sk_lookup selftests to strict SEC("sk_lookup") use (Yauheni Kaliuta) [2069045]
- libbpf: Add opt-in strict BPF program section name handling logic (Yauheni Kaliuta) [2069045]
- libbpf: Complete SEC() table unification for BPF_APROG_SEC/BPF_EAPROG_SEC (Yauheni Kaliuta) [2069045]
- libbpf: Refactor ELF section handler definitions (Yauheni Kaliuta) [2069045]
- libbpf: Reduce reliance of attach_fns on sec_def internals (Yauheni Kaliuta) [2069045]
- libbpf: Refactor internal sec_def handling to enable pluggability (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize all the rest SEC() uses (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch SEC("classifier*") usage to a strict SEC("tc") (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize XDP section names in selftests (Yauheni Kaliuta) [2069045]
- libbpf: Add "tc" SEC_DEF which is a better name for "classifier" (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more BPF_END byte order conversion tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Expand branch conversion JIT test (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with degenerate conditional (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with small offsets (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test case flag for verifier zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive test of LD_IMM64 immediate magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add staggered JMP and JMP32 tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of JMP operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU shift values (Yauheni Kaliuta) [2069045]
- bpf/tests: Reduce memory footprint of test suite (Yauheni Kaliuta) [2069045]
- bpf/tests: Allow different number of runs per test case (Yauheni Kaliuta) [2069045]
- bpf: selftest: Add verifier tests for <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: selftest: A bpf prog that has a 32bit scalar spill (Yauheni Kaliuta) [2069045]
- bpf: Support <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: Check the other end of slot_type for STACK_SPILL (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix btf_dump __int128 test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- libbpf: Add legacy uprobe attaching support (Yauheni Kaliuta) [2069045]
- libbpf: Refactor and simplify legacy kprobe code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adopt attach_probe selftest to work on old kernels (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in legacy kprobe attach logic (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert ARP table network order fields into readable format (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert route table network order fields into readable format (Yauheni Kaliuta) [2069045]
- libbpf: Add doc comments in libbpf.h (Yauheni Kaliuta) [2069045]
- bpf: Clarify data_len param in bpf_snprintf and bpf_seq_printf comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add trace_vprintk test prog (Yauheni Kaliuta) [2069045]
- selftests/bpf: Migrate prog_tests/trace_printk CHECKs to ASSERTs (Yauheni Kaliuta) [2069045]
- bpftool: Only probe trace_vprintk feature in 'full' mode (Yauheni Kaliuta) [2069045]
- libbpf: Use static const fmt string in __bpf_printk (Yauheni Kaliuta) [2069045]
- libbpf: Modify bpf_printk to choose helper based on arg count (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_trace_vprintk helper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using bpf_program__load (Yauheni Kaliuta) [2069045]
- bpf: Merge printk and seq_printf VARARG max macros (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix a few compiler warnings (Yauheni Kaliuta) [2069045]
- libbpf: Constify all high-level program attach APIs (Yauheni Kaliuta) [2069045]
- libbpf: Schedule open_opts.attach_prog_fd deprecation since v0.7 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch fexit_bpf2bpf selftest to set_attach_target() API (Yauheni Kaliuta) [2069045]
- libbpf: Allow skipping attach_func_name in bpf_program__set_attach_target() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecated bpf_object_open_opts.relaxed_core_relocs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using relaxed_core_relocs which has no effect (Yauheni Kaliuta) [2069045]
- libbpf: Use pre-setup sec_def in libbpf_find_attach_btf_id() (Yauheni Kaliuta) [2069045]
- bpf: Update bpf_get_smp_processor_id() documentation (Yauheni Kaliuta) [2069045]
- libbpf: Add sphinx code documentation comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip btf_tag test if btf_tag attribute not supported (Yauheni Kaliuta) [2069045]
- docs/bpf: Add documentation for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a test with a bpf program with btf_tag attributes (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test BTF_KIND_TAG for deduplication (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_TAG unit tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Change NAME_NTH/IS_NAME_NTH for BTF_KIND_TAG format (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test libbpf API function btf__add_tag() (Yauheni Kaliuta) [2069045]
- bpftool: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Rename btf_{hash,equal}_int to btf_{hash,equal}_int_tag (Yauheni Kaliuta) [2069045]
- bpf: Support for new btf kind BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- btf: Change BTF_KIND_* macros to enums (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix .gitignore to not ignore test_progs.c (Yauheni Kaliuta) [2069045]
- bpf,x64 Emit IMUL instead of MUL for x86-64 (Yauheni Kaliuta) [2069045]
- libbpf: Minimize explicit iterator of section definition array (Yauheni Kaliuta) [2069045]
- libbpf: Simplify BPF program auto-attach code (Yauheni Kaliuta) [2069045]
- libbpf: Ensure BPF prog types are set before relocations (Yauheni Kaliuta) [2069045]
- selftests/bpf: Update selftests to always provide "struct_ops" SEC (Yauheni Kaliuta) [2069045]
- libbpf: Introduce legacy kprobe events support (Yauheni Kaliuta) [2069045]
- bpf, selftests: Replicate tailcall limit test for indirect call case (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test for bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- bpf: Introduce helper bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new __sk_buff field hwtstamp (Yauheni Kaliuta) [2069045]
- bpf: Permit ingress_ifindex in bpf_prog_test_run_xattr (Yauheni Kaliuta) [2069045]
- bpf: Add hardware timestamp field to __sk_buff (Yauheni Kaliuta) [2069045]
- libbpf: Make libbpf_version.h non-auto-generated (Yauheni Kaliuta) [2069045]
- libbpf: Add LIBBPF_DEPRECATED_SINCE macro for scheduling API deprecations (Yauheni Kaliuta) [2069045]
- libbpf: Fix build with latest gcc/binutils with LTO (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add checks for X__elf_bytes() skeleton helper (Yauheni Kaliuta) [2069045]
- bpftool: Provide a helper method for accessing skeleton's embedded ELF data (Yauheni Kaliuta) [2069045]
- libbpf: Change bpf_object_skeleton data field to const pointer (Yauheni Kaliuta) [2069045]
- libbpf: Don't crash on object files with no symbol tables (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix spelling mistake "tained" -> "tainted" (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case trying to taint map value pointer (Yauheni Kaliuta) [2069045]

* Wed Jun 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-112.el9]
- redhat: configs: Update configs for vmware (Cathy Avery) [2087134]
- VMCI: Add support for ARM64 (Cathy Avery) [2079153]
- VMCI: Release notification_bitmap in error path (Cathy Avery) [2079153]
- VMCI: Check exclusive_vectors when freeing interrupt 1 (Cathy Avery) [2079153]
- VMCI: Fix some error handling paths in vmci_guest_probe_device() (Cathy Avery) [2079153]
- VMCI: No need to clear memory after a dma_alloc_coherent() call (Cathy Avery) [2079153]
- VMCI: Fix the description of vmci_check_host_caps() (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams receive (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams sends (Cathy Avery) [2079153]
- VMCI: dma dg: allocate send and receive buffers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: register dummy IRQ handlers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: set OS page size (Cathy Avery) [2079153]
- VMCI: dma dg: whitespace formatting change for vmci register defines (Cathy Avery) [2079153]
- VMCI: dma dg: detect DMA datagram capability (Cathy Avery) [2079153]
- VMCI: dma dg: add MMIO access to registers (Cathy Avery) [2079153]
- misc: vmw_vmci: Switch to kvfree_rcu() API (Cathy Avery) [2079153]
- VMCI: fix NULL pointer dereference when unmapping queue pair (Cathy Avery) [2079153]
- [s390] s390/dasd: prevent double format of tracks for ESE devices (Mete Durlu) [2094295]
- [s390] s390/dasd: fix data corruption for ESE devices (Mete Durlu) [2094295]
- iio: Turn off kernel configs for iios added by this patch set (Steve Best) [2071780]
- iio:dac:ad3552r: Fix an IS_ERR() vs NULL check (Steve Best) [2071780]
- iio: sx9324: Fix default precharge internal resistance register (Steve Best) [2071780]
- iio:proximity:sx9324: Fix hardware gain read/write (Steve Best) [2071780]
- iio:proximity:sx_common: Fix device property parsing on DT systems (Steve Best) [2071780]
- iio:filter:admv8818: select REGMAP_SPI for ADMV8818 (Steve Best) [2071780]
- iio: scd4x: check return of scd4x_write_and_fetch (Steve Best) [2071780]
- iio: dac: ad3552r: fix signedness bug in ad3552r_reset() (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fix single channel switching sequence (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed wrong sequencer register settings (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed missing PS channels (Steve Best) [2071780]
- iio: accel: mma8452: use the correct logic to get mma8452_data (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: use dev_to_iio_dev() to get iio_dev struct (Steve Best) [2071780]
- iio: buffer: Fix file related error handling in IIO_BUFFER_GET_FD_IOCTL (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: wait for settling time in st_lsm6dsx_read_oneshot (Steve Best) [2071780]
- iio: adc: cpcap-adc: remove redundant assignment to variable cal_data_diff (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Make use of device properties (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Check ACPI companion directly (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Drop wrong use of ACPI_PTR() (Steve Best) [2071780]
- iio: accel: adxl355: Replace custom definitions with generic from units.h (Steve Best) [2071780]
- iio: temperature: maxim_thermocouple: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: temperature: mlx90632: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: humidity: dht11: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: frequency: adf4350: Make use of device properties (Steve Best) [2071780]
- iio: amplifiers: hmc425a: Make use of device properties (Steve Best) [2071780]
- iio: chemical: bme680: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: dac: ad5592r: Drop leftover header inclusion (Steve Best) [2071780]
- iio: Fix error handling for PM (Steve Best) [2071780]
- iio: afe: rescale: reorder includes (Steve Best) [2071780]
- iio: afe: rescale: use s64 for temporary scale calculations (Steve Best) [2071780]
- iio: inkern: make a best effort on offset calculation (Steve Best) [2071780]
- iio: inkern: apply consumer scale when no channel scale is available (Steve Best) [2071780]
- iio: inkern: apply consumer scale on IIO_VAL_INT cases (Steve Best) [2071780]
- iio: addac: ad74413r: correct comparator gpio getters mask usage (Steve Best) [2071780]
- iio: addac: ad74413r: use ngpio size when iterating over mask (Steve Best) [2071780]
- iio: addac: ad74413r: Do not reference negative array offsets (Steve Best) [2071780]
- iio: adc: men_z188_adc: Fix a resource leak in an error handling path (Steve Best) [2071780]
- iio: humidity: hdc100x: Add ACPI HID table (Steve Best) [2071780]
- iio: pressure: dps310: Add ACPI HID table (Steve Best) [2071780]
- iio: sx9360: fix iio event generation (Steve Best) [2071780]
- iio: adc: qcom-vadc-common: Re-use generic struct u32_fract (Steve Best) [2071780]
- iio: adc: twl4030-madc: Re-use generic struct s16_fract (Steve Best) [2071780]
- iio: adc: rn5t618: Re-use generic struct u16_fract (Steve Best) [2071780]
- iio: frequency: admv1013: remove the always true condition (Steve Best) [2071780]
- iio: accel: fxls8962af: add padding to regmap for SPI (Steve Best) [2071780]
- iio:imu:adis16480: fix buffering for devices with no burst mode (Steve Best) [2071780]
- iio: adc: ad7124: fix mask used for setting AIN_BUFP & AIN_BUFM bits (Steve Best) [2071780]
- iio: adc: tsc2046: fix memory corruption by preventing array overflow (Steve Best) [2071780]
- iio: adc: tsc2046: add sanity check to avoid to big allocations (Steve Best) [2071780]
- iio: adc: tsc2046: add .read_raw support (Steve Best) [2071780]
- iio: hw_consumer: Use struct_size() helper in kzalloc() (Steve Best) [2071780]
- iio: adis: stylistic changes (Steve Best) [2071780]
- iio: sps30: Use sysfs_emit() (Steve Best) [2071780]
- iio: scd4x: Use sysfs_emit() (Steve Best) [2071780]
- iio: ms_sensors: Use sysfs_emit() (Steve Best) [2071780]
- iio: max9611: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31865: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31856: Use sysfs_emit() (Steve Best) [2071780]
- iio: lm3533: Use sysfs_emit() (Steve Best) [2071780]
- iio: ina2xx-adc: sysfs_emit() (Steve Best) [2071780]
- iio: as3935: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad9523: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad7192: Use sysfs_emit() (Steve Best) [2071780]
- iio: dmaengine-buffer: Use sysfs_emit() (Steve Best) [2071780]
- iio: adc: tsc2046: rework the trigger state machine (Steve Best) [2071780]
- iio: adc: mt8186: Add compatible node for mt8186 (Steve Best) [2071780]
- iio: st_sensors: don't always auto-enable I2C and SPI interface drivers (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix typo (Steve Best) [2071780]
- iio:accel:dmard09: Tidy up white space around {} in id table (Steve Best) [2071780]
- iio:proximity:vl53l0x: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:light:tsl2722: Fix inconsistent spacing before } in id table (Steve Best) [2071780]
- iio:adc:ti-adc084s021: Tidy up white space around {} (Steve Best) [2071780]
- iio:adc:hi8435: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:adc:mt6577_auxadc: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:frequency:admv1013: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf08: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf04: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:rfd77402: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:ping: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:ltr501: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:us5182: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:vcnl4035: Trivial whitespace cleanup to add space before } (Steve Best) [2071780]
- iio:light:pa12203001: Tidy up white space change to add spaces after { and before } (Steve Best) [2071780]
- iio:chemical:atlas: Trivial white space cleanup to add space before } (Steve Best) [2071780]
- iio:proximity:sx9360: Add dt-binding support (Steve Best) [2071780]
- iio:proximity:sx9360: Add sx9360 support (Steve Best) [2071780]
- iio:proximity:sx9324: Add dt_binding support (Steve Best) [2071780]
- iio:proximity:sx9324: Add SX9324 support (Steve Best) [2071780]
- iio:proximity:sx9310: Extract common Semtech sensor logic (Steve Best) [2071780]
- iio:proximity:sx9310: Add frequency in read_avail (Steve Best) [2071780]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Steve Best) [2071780]
- iio: pressure: bmp280: Use new PM macros (Steve Best) [2071780]
- iio: chemical: sunrise_co2: set val parameter only on success (Steve Best) [2071780]
- iio: frequency: admv1013: add support for ADMV1013 (Steve Best) [2071780]
- iio: adc: ti-adc081c: Partial revert of removal of ACPI IDs (Steve Best) [2071780]
- iio:addac:ad74413r: Fix uninitialized ret in a path that won't be hit. (Steve Best) [2071780]
- iio: adc: Add Xilinx AMS driver (Steve Best) [2071780]
- iio:accel:kxcjk-1013: Mark struct __maybe_unused to avoid warning. (Steve Best) [2071780]
- iio:accel:bmc150: Mark structure __maybe_unused as only needed with for pm ops. (Steve Best) [2071780]
- iio:dummy: Drop set but unused variable len. (Steve Best) [2071780]
- iio:magn:ak8975: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_mpu6050: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_icm42600: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:dac:mcp4725: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:amplifiers:hmc425a: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ti-ads1015: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:rcar: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ina2xx-adc: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:accel:bma180: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- drivers:iio:dac: Add AD3552R driver support (Steve Best) [2071780]
- iio:filter:admv8818: add support for ADMV8818 (Steve Best) [2071780]
- iio: add filter subfolder (Steve Best) [2071780]
- iio: vz89x: Remove unnecessary cast (Steve Best) [2071780]
- iio: in2xx-adc: Remove unnecessary cast (Steve Best) [2071780]
- iio: as3935: Remove unnecessary cast (Steve Best) [2071780]
- iio: stmpe-adc: Use correctly sized arguments for bit field (Steve Best) [2071780]
- iio:adc:ti-ads8688:: remove redundant ret variable (Steve Best) [2071780]
- iio: addac: ad74413r: fix off by one in ad74413r_parse_channel_config() (Steve Best) [2071780]
- iio: adc: ad7606: Fix syntax errors in comments (Steve Best) [2071780]
- iio: iio_device_alloc(): Remove unnecessary self drvdata (Steve Best) [2071780]
- iio:adc/dac:Kconfig: Update to drop OF dependencies. (Steve Best) [2071780]
- iio:adc:ti-ads124s08: Drop dependency on OF. (Steve Best) [2071780]
- iio:adc:envelope-detector: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio:adc:ti-adc12138: Switch to generic firmware properties and drop of_match_ptr (Steve Best) [2071780]
- iio:adc:mcp3911: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:adc:max9611: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:light:cm3605: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:pot:mcp41010: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:dac:lpc18xx_dac: Swap from of* to mod_devicetable.h (Steve Best) [2071780]
- iio:dac:dpot-dac: Swap of.h for mod_devicetable.h (Steve Best) [2071780]
- iio:dac:ad5758: Drop unused of specific headers. (Steve Best) [2071780]
- iio:dac:ad5755: Switch to generic firmware properties and drop pdata (Steve Best) [2071780]
- iio: trigger: Fix a scheduling whilst atomic issue seen on tsc2046 (Steve Best) [2071780]
- iio: addac: add AD74413R driver (Steve Best) [2071780]
- iio: add addac subdirectory (Steve Best) [2071780]
- iio:dac:ad7293: add support for AD7293 (Steve Best) [2071780]
- iio: trigger: stm32-timer: fix MODULE_ALIAS (Steve Best) [2071780]
- iio: ltr501: Export near level property for proximity sensor (Steve Best) [2071780]
- iio:adc:axp20x: add support for NTC thermistor (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: add dts property to disable sensor-hub (Steve Best) [2071780]
- iio: test: Add test for IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: test: Add check against NULL for buffer in tests. (Steve Best) [2071780]
- iio: expose shared parameter in IIO_ENUM_AVAILABLE (Steve Best) [2071780]
- iio: adc: stm32: fix null pointer on defer_probe error (Steve Best) [2071780]
- iio: buffer-dma: Use round_down() instead of rounddown() (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect sign extension (Steve Best) [2071780]
- iio: adc: axp20x_adc: fix charging current reporting on AXP22x (Steve Best) [2071780]
- iio: gyro: adxrs290: fix data signedness (Steve Best) [2071780]
- iio: buffer: Use dedicated variable in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: ad7768-1: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: itg3200: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: imx8qxp-adc: fix dependency to the intended ARCH_MXC config (Steve Best) [2071780]
- iio: dln2: Check return value of devm_iio_trigger_register() (Steve Best) [2071780]
- iio: trigger: Fix reference counting (Steve Best) [2071780]
- iio: dln2-adc: Fix lockdep complaint (Steve Best) [2071780]
- iio: adc: stm32: fix a current leak by resetting pcsel before disabling vdda (Steve Best) [2071780]
- iio: mma8452: Fix trigger reference couting (Steve Best) [2071780]
- iio: stk3310: Don't return error code in interrupt handler (Steve Best) [2071780]
- iio: kxsd9: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: ltr501: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: accel: kxcjk-1013: Fix possible memory leak in probe and remove (Steve Best) [2071780]
- iio: light: ltr501: Added ltr303 driver support (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Remove unnecessary print function dev_err() (Steve Best) [2071780]
- iio: mpl3115: Use scan_type.shift and realbit in mpl3115_read_raw (Steve Best) [2071780]
- iio: xilinx-xadc-core: Use local variable in xadc_read_raw (Steve Best) [2071780]
- iio: ti-ads1015: Remove shift variable ads1015_read_raw (Steve Best) [2071780]
- iio: mag3110: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ti-adc12138: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ad7266: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8ba50: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8312: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: sca3000: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: mma7455: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: kxcjk-1013: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: bma220: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: at91-sama5d2: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect cast to platform_device (Steve Best) [2071780]
- iio: mma8452: Use correct type for return variable in IRQ handler (Steve Best) [2071780]
- iio: lmp91000: Remove no-op trigger ops (Steve Best) [2071780]
- iio: gp2ap020a00f: Remove no-op trigger ops (Steve Best) [2071780]
- iio: atlas-sensor: Remove no-op trigger ops (Steve Best) [2071780]
- iio: as3935: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4404: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4403: Remove no-op trigger ops (Steve Best) [2071780]
- iio: ad_sigma_delta: Remove no-op trigger ops (Steve Best) [2071780]
- iio: sysfs-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: interrupt-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: Mark iio_device_type as const (Steve Best) [2071780]
- iio/scmi: Add reading "raw" attribute. (Steve Best) [2071780]
- iio: core: Introduce IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: adc: ina2xx: Avoid double reference counting from get_task_struct/put_task_struct() (Steve Best) [2071780]
- iio: adc: ina2xx: Make use of the helper macro kthread_run() (Steve Best) [2071780]
- iio: ms5611: Simplify IO callback parameters (Steve Best) [2071780]
- iio: imx7d_adc: Don't pass IIO device to imx7d_adc_{enable,disable}() (Steve Best) [2071780]
- iio: st-sensors: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: adc: stm32-adc: Fix of_node_put() issue in stm32-adc (Steve Best) [2071780]
- iio: xilinx-xadc: Make IRQ optional (Steve Best) [2071780]
- iio: accel: mma7660: Warn about failure to put device in stand-by in .remove() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Reorder clk_get_rate() function call (Steve Best) [2071780]
- iio: frequency: adrf6780: Fix adrf6780_spi_{read,write}() (Steve Best) [2071780]
- iio: frequency: adrf6780: add support for ADRF6780 (Steve Best) [2071780]
- iio: chemical: scd4x: Add a scale for the co2 concentration reading (Steve Best) [2071780]
- iio: adc: adc128s052: Simplify adc128_probe() (Steve Best) [2071780]
- iio: multiplexer: iio-mux: Support settle-time-us property (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: adc: stm32-adc: use generic binding for sample-time (Steve Best) [2071780]
- iio: adc: stm32-adc: add vrefint calibration support (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of internal channels (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of generic channels binding (Steve Best) [2071780]
- iio: adc: stm32-adc: split channel init into several routines (Steve Best) [2071780]
- iio: accel: sca3000: Use sign_extend32() instead of opencoding sign extension. (Steve Best) [2071780]
- iio: xilinx-xadc: Remove `irq` field from state struct (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: Avoid potential array overflow in st_lsm6dsx_set_odr() (Steve Best) [2071780]
- iio: light: gp2ap002: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm3605: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ti-ads7950: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: qcom-pm8xxx-xoadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: meson_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1241: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1118: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: imx7d_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ab8500-gpadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: buffer: Fix uninitialized variable ret (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Convert probe to device managed version (Steve Best) [2071780]
- iio: light: ltr501: Add of_device_id table (Steve Best) [2071780]
- iio: light: ltr501: Add rudimentary regulator support (Steve Best) [2071780]
- iio: imx8qxp-adc: mark PM functions as __maybe_unused (Steve Best) [2071780]
- iio: pressure: ms5611: Make ms5611_remove() return void (Steve Best) [2071780]
- iio: potentiometer: max5487: Don't return an error in .remove() (Steve Best) [2071780]
- iio: magn: hmc5843: Make hmc5843_common_remove() return void (Steve Best) [2071780]
- iio: health: afe4403: Don't return an error in .remove() (Steve Best) [2071780]
- iio: dac: ad5686: Make ad5686_remove() return void (Steve Best) [2071780]
- iio: dac: ad5592r: Make ad5592r_remove() return void (Steve Best) [2071780]
- iio: dac: ad5446: Make ad5446_remove() return void (Steve Best) [2071780]
- iio: dac: ad5380: Make ad5380_remove() return void (Steve Best) [2071780]
- iio: accel: mma7455: Make mma7455_core_remove() return void (Steve Best) [2071780]
- iio: accel: kxsd9: Make kxsd9_common_remove() return void (Steve Best) [2071780]
- iio: accel: bmi088: Make bmi088_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bmc150: Make bmc150_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bma400: Make bma400_remove() return void (Steve Best) [2071780]
- drivers:iio:dac:ad5766.c: Add trigger buffer (Steve Best) [2071780]
- iio: triggered-buffer: extend support to configure output buffers (Steve Best) [2071780]
- iio: kfifo-buffer: Add output buffer support (Steve Best) [2071780]
- iio: Add output buffer support (Steve Best) [2071780]
- drivers: iio: chemical: Add support for Sensirion SCD4x CO2 sensor (Steve Best) [2071780]
- iio: light: noa1305: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm36651: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4404: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4403: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_lsm9ds0: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_sensors: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ti-dac7311: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: mcp4922: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: max5821: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ds4424: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ltc1660: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: lpc18xx_dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ad8801: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ad799x: Implement selecting external reference voltage input on AD7991, AD7995 and AD7999. (Steve Best) [2071780]
- iio: adc: max1027: fix error code in max1027_wait_eoc() (Steve Best) [2071780]
- iio: imu: adis16400: Fix buffer alignment requirements. (Steve Best) [2071780]
- iio: gyro: mpu3050: Fix alignment and size issues with buffers. (Steve Best) [2071780]
- iio: adc: ti-adc108s102: Fix alignment of buffer pushed to iio buffers. (Steve Best) [2071780]
- iio: core: Introduce iio_push_to_buffers_with_ts_unaligned() (Steve Best) [2071780]
- iio: chemical: SENSEAIR_SUNRISE_CO2 depends on I2C (Steve Best) [2071780]
- iio: adc: aspeed: Fix spelling mistake "battey" -> "battery" (Steve Best) [2071780]
- iio: adc: ad7291: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: Kconfig: add COMPILE_TEST dep for berlin2-adc (Steve Best) [2071780]
- iio: adc: berlin2-adc: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: rn5t618-adc: use devm_iio_map_array_register() function (Steve Best) [2071780]
- iio: adc: nau7802: convert probe to full device-managed (Steve Best) [2071780]
- iio: adis16460: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis16475: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis: handle devices that cannot unmask the drdy pin (Steve Best) [2071780]
- iio: adis: do not disabe IRQs in 'adis_init()' (Steve Best) [2071780]
- iio: adc: da9150-gpadc: convert probe to full-device managed (Steve Best) [2071780]
- iio: adc: axp288_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: adc: intel_mrfld_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: inkern: introduce devm_iio_map_array_register() short-hand function (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: initialize regulators as needed (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: move max_fifo_size in st_lsm6dsx_fifo_ops (Steve Best) [2071780]
- iio: adc: max1027: Don't reject external triggers when there is no IRQ (Steve Best) [2071780]
- iio: adc: max1027: Allow all kind of triggers to be used (Steve Best) [2071780]
- iio: adc: max1027: Use the EOC IRQ when populated for single reads (Steve Best) [2071780]
- iio: adc: max1027: Stop requesting a threaded IRQ (Steve Best) [2071780]
- iio: adc: max1027: Introduce an end of conversion helper (Steve Best) [2071780]
- iio: adc: max1027: Separate the IRQ handler from the read logic (Steve Best) [2071780]
- iio: adc: max1027: Prevent single channel accesses during buffer reads (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to configure the channels to scan (Steve Best) [2071780]
- iio: adc: max1027: Ensure a default cnvst trigger configuration (Steve Best) [2071780]
- iio: adc: max1027: Simplify the _set_trigger_state() helper (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to enable/disable the cnvst trigger (Steve Best) [2071780]
- iio: adc: max1027: Rename a helper (Steve Best) [2071780]
- iio: adc: max1027: Minimize the number of converted channels (Steve Best) [2071780]
- iio: adc: max1027: Drop useless debug messages (Steve Best) [2071780]
- iio: adc: max1027: Drop extra warning message (Steve Best) [2071780]
- iio: adc: max1027: Fix style (Steve Best) [2071780]
- iio: imx8qxp-adc: Add driver support for NXP IMX8QXP ADC (Steve Best) [2071780]
- iio: accel: fxls8962af: add wake on event (Steve Best) [2071780]
- iio: accel: fxls8962af: add threshold event handling (Steve Best) [2071780]
- iio: adc: aspeed: Get and set trimming data. (Steve Best) [2071780]
- iio: adc: aspeed: Support battery sensing. (Steve Best) [2071780]
- iio: adc: aspeed: Add compensation phase. (Steve Best) [2071780]
- iio: adc: aspeed: Add func to set sampling rate. (Steve Best) [2071780]
- iio: adc: aspeed: Fix the calculate error of clock. (Steve Best) [2071780]
- iio: adc: aspeed: Support ast2600 adc. (Steve Best) [2071780]
- iio: adc: aspeed: Use devm_add_action_or_reset. (Steve Best) [2071780]
- iio: adc: aspeed: Use model_data to set clk scaler. (Steve Best) [2071780]
- iio: adc: aspeed: Add vref config function (Steve Best) [2071780]
- iio: adc: aspeed: Restructure the model data (Steve Best) [2071780]
- iio: adc: aspeed: Keep model data to driver data. (Steve Best) [2071780]
- iio: chemical: Add Senseair Sunrise 006-0-007 driver (Steve Best) [2071780]
- iio: adc: tsc2046: fix scan interval warning (Steve Best) [2071780]
- iio: core: fix double free in iio_device_unregister_sysfs() (Steve Best) [2071780]
- iio: core: check return value when calling dev_set_name() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffer_register_legacy_sysfs_groups() (Steve Best) [2071780]
- iio: buffer: Fix double-free in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in __iio_buffer_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: check return value of kstrdup_const() (Steve Best) [2071780]
- iio: dac: ad5446: Fix ad5622_write() return value (Steve Best) [2071780]
- iio: adc: exynos: describe drivers in KConfig (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: accel: mma7660: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: light: max44000: use device-managed functions in probe (Steve Best) [2071780]
- iio: gyro: adis16080: use devm_iio_device_register() in probe (Steve Best) [2071780]
- iio: dac: ad5064: convert probe to full device-managed (Steve Best) [2071780]
- iio: dac: ad7303: convert probe to full device-managed (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: ep93xx: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- drivers: iio: dac: ad5766: Fix dt property name (Steve Best) [2071780]
- iio: st_pressure_spi: Add missing entries SPI to device ID table (Steve Best) [2071780]
- iio/test-format: build kunit tests without structleak plugin (Steve Best) [2071780]
- iio: light: opt3001: Fixed timeout error when 0 lux (Steve Best) [2071780]
- iio: common: cros_ec_sensors: simplify getting .driver_data (Steve Best) [2071780]
- iio: adis16480: fix devices that do not support sleep mode (Steve Best) [2071780]
- iio: mtk-auxadc: fix case IIO_CHAN_INFO_PROCESSED (Steve Best) [2071780]
- iio: adis16475: fix deadlock on frequency set (Steve Best) [2071780]
- iio: ssp_sensors: add more range checking in ssp_parse_dataframe() (Steve Best) [2071780]
- iio: ssp_sensors: fix error code in ssp_print_mcu_debug() (Steve Best) [2071780]
- iio: adc: ad7793: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7780: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7192: Add IRQ flag (Steve Best) [2071780]
- iio: adc: aspeed: set driver data when adc probe. (Steve Best) [2071780]
- iio: adc: rzg2l_adc: add missing clk_disable_unprepare() in rzg2l_adc_pm_runtime_resume() (Steve Best) [2071780]
- iio: adc: max1027: Fix the number of max1X31 channels (Steve Best) [2071780]
- iio: adc: max1027: Fix wrong shift with 12-bit devices (Steve Best) [2071780]
- iio: adc128s052: Fix the error handling path of 'adc128_probe()' (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix -EBUSY timeout error return (Steve Best) [2071780]
- iio: accel: fxls8962af: return IRQ_HANDLED when fifo is flushed (Steve Best) [2071780]
- iio: dac: ti-dac5571: fix an error code in probe() (Steve Best) [2071780]
- iio: accel: adxl355: Add triggered buffer support (Steve Best) [2071780]
- iio: accel: adxl355: use if(ret) in place of ret < 0 (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL313 (Steve Best) [2071780]
- iio: adc: aspeed: completes the bitfield declare. (Steve Best) [2071780]
- iio: adc: ti-ads8344: convert probe to device-managed (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: update copyright and authors information (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for sama7g5 device (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add helper for COR register (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for separate end of conversion registers (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: convert to platform specific data structures (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: remove unused definition (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: initialize hardware after clock is started (Steve Best) [2071780]
- iio: magnetometer: ak8975: add AK09116 support (Steve Best) [2071780]
- iio: temperature: Add MAX31865 RTD Support (Steve Best) [2071780]
- iio: adc: twl6030-gpadc: Use the defined variable to clean code (Steve Best) [2071780]
- iio: ltc2983: fail probe if no channels are given (Steve Best) [2071780]
- iio: ltc2983: add support for optional reset gpio (Steve Best) [2071780]
- iio: ad5770r: make devicetree property reading consistent (Steve Best) [2071780]
- iio: gyro: remove dead config dependencies on INPUT_MPU3050 (Steve Best) [2071780]
- iio: st_sensors: remove reference to parent device object on st_sensor_data (Steve Best) [2071780]
- iio: st_sensors: remove all driver remove functions (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_power_disable() function (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_deallocate_trigger() function (Steve Best) [2071780]
- iio: magn: st_magn: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: gyro: st_gyro: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: accel: st_accel: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: pressure: st_pressure: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: st_sensors: disable regulators after device unregistration (Steve Best) [2071780]
- iio: adc: ad7949: use devm managed functions (Steve Best) [2071780]
- iio: adc: ad7949: add vref selection support (Steve Best) [2071780]
- iio: adc: ad7949: enable use with non 14/16-bit controllers (Steve Best) [2071780]
- iio: adc: ad7949: define and use bitfield names (Steve Best) [2071780]
- drivers/iio: Remove all strcpy() uses (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL355 (Steve Best) [2071780]
- iio/drivers/hid-sensor: use HZ macros (Steve Best) [2071780]
- units: add the HZ macros (Steve Best) [2071780]
- iio/drivers/as73211: use HZ macros (Steve Best) [2071780]
- iio: adc: Add driver for Renesas RZ/G2L A/D converter (Steve Best) [2071780]
- iio: pressure: hp03: update device probe to register with devm functions (Steve Best) [2071780]
- iio: adc: rockchip_saradc: add voltage notifier so get referenced voltage once at probe (Steve Best) [2071780]
- iio: ltc2983: fix device probe (Steve Best) [2071780]
- iio: potentiometer: Add driver support for AD5110 (Steve Best) [2071780]
- iio: adc: rn5t618: Add iio map (Steve Best) [2071780]
- iio: hid-sensor-press: Add timestamp channel (Steve Best) [2071780]
- iio: accel: bmc150: Add support for BMC156 (Steve Best) [2071780]
- iio: accel: bmc150: Make it possible to configure INT2 instead of INT1 (Steve Best) [2071780]
- iio: light: cm3323: Add of_device_id table (Steve Best) [2071780]
- iio: chemical: Add driver support for sgp40 (Steve Best) [2071780]
- iio: ep93xx: Prepare clock before using it (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: adjust irq check to match docs and simplify code (Steve Best) [2071780]
- iio: dac: max5821: convert device register to device managed function (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760B support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760 support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: rename has_aux2 to has_aux_md (Steve Best) [2071780]
- iio: sx9310: Support ACPI property (Steve Best) [2071780]
- PCI: hv: Remove unused hv_set_msi_entry_from_desc() (Mohammed Gamal) [2086678]
- PCI: hv: Avoid the retarget interrupt hypercall in irq_unmask() on ARM64 (Mohammed Gamal) [2086678]
- PCI: hv: Fix NUMA node assignment when kernel boots with custom NUMA topology (Mohammed Gamal) [2086678]
- net: mana: Reuse XDP dropped page (Mohammed Gamal) [2086676]
- net: mana: Add counter for XDP_TX (Mohammed Gamal) [2086676]
- net: mana: Add counter for packet dropped by XDP (Mohammed Gamal) [2086676]
- net: mana: Use struct_size() helper in mana_gd_create_dma_region() (Mohammed Gamal) [2086676]

* Tue Jun 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-111.el9]
- pinctrl: alderlake: Fix register offsets for ADL-N variant (David Arcari) [2049966]
- pinctrl: alderlake: Add Intel Alder Lake-N pin controller support (David Arcari) [2049966]
- netfilter: nf_tables: disallow non-stateful expression in sets earlier (Phil Sutter) [2092995] {CVE-2022-1966}
- block, loop: support partitions without scanning (Ming Lei) [2089698]
- scsi: fnic: Finish scsi_cmnd before dropping the spinlock (John Meneghini) [2063226]
- ipv4: do not use per netns icmp sockets (Hangbin Liu) [2089118]
- remoteproc: Fix a memory leak in an error handling path in 'rproc_handle_vdev()' (Steve Best) [2071773]
- remoteproc: imx_rproc: Change to ioremap_wc for dram (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Create platform device for BAM-DMUX (Steve Best) [2071773]
- remoteproc: qcom: q6v5_wpss: Add support for sc7280 WPSS (Steve Best) [2071773]
- remoteproc: k3-dsp: Add support for IPC-only mode for all K3 DSPs (Steve Best) [2071773]
- remoteproc: k3-dsp: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: k3-r5: Add support for IPC-only mode for all R5Fs (Steve Best) [2071773]
- remoteproc: k3-r5: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: Change rproc_shutdown() to return a status (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Add interconnect path proxy vote (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8186 scp (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Fix some leaks in q6v5_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom_wcnss: Add missing of_node_put() in wcnss_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom: Fix missing of_node_put in adsp_alloc_memory_region (Steve Best) [2071773]
- remoteproc: move rproc_da_to_va declaration to remoteproc.h (Steve Best) [2071773]
- remoteproc: wkup_m3: Set sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Introduce sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Fix count check in rproc_coredump_write() (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM8450 remoteproc support (Steve Best) [2071773]
- remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2071773]
- soc: qcom: mdt_loader: Allow hash segment to be split out (Steve Best) [2071773]
- remoteproc: mtk_scp: Use dev_err_probe() where possible (Steve Best) [2071773]
- remoteproc: mtk_scp: Reorder scp_probe() sequence (Steve Best) [2071773]
- remoteproc: mtk_scp: Use devm variant of rproc_alloc() (Steve Best) [2071773]
- remoteproc: qcom: q6v5: fix service routines build errors (Steve Best) [2071773]
- remoteproc: stm32: Improve crash recovery time (Steve Best) [2071773]
- remoteproc: rcar_rproc: Remove trailing semicolon (Steve Best) [2071773]
- remoteproc: rcar_rproc: Fix pm_runtime_get_sync error check (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 CDSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 ADSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 MPSS support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add missing power-domain "mxc" for CDSP (Steve Best) [2071773]
- remoteproc: imx_rproc: correct firmware reload (Steve Best) [2071773]
- remoteproc: qcom: pil_info: Don't memcpy_toio more than is provided (Steve Best) [2071773]
- remoteproc: Add Renesas rcar driver (Steve Best) [2071773]
- remoteproc: Fix remaining wrong return formatting in documentation (Steve Best) [2071773]
- remoteproc: ingenic: Request IRQ disabled (Steve Best) [2071773]
- remoteproc: k3-r5: Extend support for R5F clusters on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: k3-dsp: Extend support for C71x DSPs on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: coredump: Correct argument 2 type for memcpy_fromio (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix a resource leak in the remove function (Steve Best) [2071773]
- remoteproc: Use %%pe format string to print return error code (Steve Best) [2071773]
- remoteproc: Remove vdev_to_rvdev and vdev_to_rproc from remoteproc API (Steve Best) [2071773]
- remoteproc: omap_remoteproc: simplify getting .driver_data (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Use devm_platform_ioremap_resource_byname() to simplify code (Steve Best) [2071773]
- remoteproc: Fix spelling mistake "atleast" -> "at least" (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: mark PM functions as __maybe_unused (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Correct the comment style of copyright (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Add remoteproc driver for DSP on i.MX (Steve Best) [2071773]
- remoteproc: imx_rproc: Add IMX_RPROC_SCU_API method (Steve Best) [2071773]
- remoteproc: imx_rproc: Move common structure to header file (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: fix a bit test (Steve Best) [2071773]
- remoteproc: mss: q6v5-mss: Add modem support on SC7280 (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SC7280 Modem support (Steve Best) [2071773]
- remoteproc: qcom: pas: Use the same init resources for MSM8996 and MSM8998 (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8195 scp (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: Add a driver for the AO ARC remote procesor (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix rsc-table name (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix ignoring mapping vdev regions (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix TCM io memory type (Steve Best) [2071773]
- remoteproc: Fix the wrong default value of is_iomem (Steve Best) [2071773]
- remoteproc: elf_loader: Fix loading segment when is_iomem true (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Use qmp_send to update co-processor load state (Steve Best) [2071773]
- remoteproc: qcom: Loosen dependency on RPMSG_QCOM_SMD (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Drop unused smd include (Steve Best) [2071773]
- remoteproc: q6v5_pas: Add sdm660 ADSP PIL compatible (Steve Best) [2071773]
- remoteproc: use freezable workqueue for crash notifications (Steve Best) [2071773]
- remoteproc: fix an typo in fw_elf_get_class code comments (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Fix race with iris probe (Steve Best) [2071773]
- perf/x86/uncore: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/uncore: Clean up uncore_pci_ids[] (Michael Petlan) [2088832]
- perf/x86/uncore: Add Raptor Lake uncore support (Michael Petlan) [2088832]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2088832]
- perf/x86/cstate: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/cstate: Add Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add Raptor Lake CPU support (Michael Petlan) [2088832]
- perf/x86: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86: Add Intel Raptor Lake support (Michael Petlan) [2088832]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (Michael Petlan) [2088832]
- turbostat: fix PC6 displaying on some systems (David Arcari) [2040079]

* Mon Jun 13 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-110.el9]
- net/core: disable NET_RX_BUSY_POLL on PREEMPT_RT (Petr Oros) [2090412]
- ACPI: sysfs: Fix BERT error region memory mapping (Aristeu Rozanski) [2026959]
- hv_utils: Add comment about max VMbus packet size in VSS driver (Mohammed Gamal) [2088365]
- x86/hyperv: fix root partition faults when writing to VP assist page MSR (Mohammed Gamal) [2088365]
- x86/coco: Explicitly declare type of confidential computing platform (Mohammed Gamal) [2088365]
- x86/hyper-v: Add hyperv Isolation VM check in the cc_platform_has() (Mohammed Gamal) [2088365]
- x86/sev: Use CC_ATTR attribute to generalize string I/O unroll (Mohammed Gamal) [2088365]
- x86/hyperv: add comment describing TSC_INVARIANT_CONTROL MSR setting bit 0 (Mohammed Gamal) [2088365]
- x86/hyperv: Fix definition of hv_ghcb_pg variable (Mohammed Gamal) [2088365]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Mohammed Gamal) [2088365]
- hyper-v: Enable swiotlb bounce buffer for Isolation VM (Mohammed Gamal) [2088365]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Mohammed Gamal) [2088365]
- x86/hyperv: Refactor hv_msi_domain_free_irqs() (Mohammed Gamal) [2088365]
- x86/hyperv: Move required MSRs check to initial platform probing (Mohammed Gamal) [2088365]
- x86/hyperv: Fix NULL deref in set_hv_tscchange_cb() if Hyper-V setup fails (Mohammed Gamal) [2088365]
- x86/hyperv: Protect set_hv_tscchange_cb() against getting preempted (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicate include (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicated include in hv_init (Mohammed Gamal) [2088365]
- x86/hyperv: Add ghcb hvcall support for SNP VM (Mohammed Gamal) [2088365]
- x86/hyperv: Add Write/Read MSR registers via ghcb page (Mohammed Gamal) [2088365]
- x86/hyperv: Add new hvcall guest address host visibility support (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize shared memory boundary in the Isolation VM. (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize GHCB page in Isolation VM (Mohammed Gamal) [2088365]
- x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV (Mohammed Gamal) [2088365]
- x86/sev: Carve out HV call's return value verification (Mohammed Gamal) [2088365]
- x86/sev: Return an error on a returned non-zero SW_EXITINFO1[31:0] (Mohammed Gamal) [2088365]
- x86/sev: Fix noinstr for vc_ghcb_invalidate() (Mohammed Gamal) [2088365]
- topology: make core_mask include at least cluster_siblings (Mark Salter) [2047951]
- KVM: x86: Fix the intel_pt PMI handling wrongly considered from guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't rebuild page when the page is synced and no tlb flushing is required (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Verify the pmu event filter matches the correct event (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add the helper function create_pmu_event_filter (Vitaly Kuznetsov) [2074832]
- kvm: x86/pmu: Fix the compare function used by the pmu event filter (Vitaly Kuznetsov) [2074832]
- KVM: Free new dirty bitmap if creating a new memslot fails (Vitaly Kuznetsov) [2074832]
- KVM: Initialize debugfs_dentry when a VM is created to avoid NULL deref (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Exit to userspace if vCPU has injected exception and invalid state (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of vcpu->lock (Vitaly Kuznetsov) [2074832]
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has architectural PMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Account for family 17h event renumberings in amd_pmc_perf_hw_id (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use atomic XCHG to write TDP MMU SPTEs with volatile bits (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move shadow-present check out of spte_has_volatile_bits() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't treat fully writable SPTEs as volatile (modulo A/D) (Vitaly Kuznetsov) [2074832]
- Revert "x86/mm: Introduce lookup_address_in_mm()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: work around QEMU issue with synthetic CPUID leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: fix potential races when walking host page table (Vitaly Kuznetsov) [2074832]
- Documentation: KVM: Update documentation to indicate KVM is arm64-only (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do not create SPTEs for GFNs that exceed host.MAXPHYADDR (Vitaly Kuznetsov) [2074832]
- kvm: selftests: introduce and use more page size-related constants (Vitaly Kuznetsov) [2074832]
- kvm: selftests: do not use bitfields larger than 32-bits for PTEs (Vitaly Kuznetsov) [2074832]
- KVM: SEV: add cache flush to solve SEV cache incoherency issues (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Flush when freeing encrypted pages even on SME_COHERENT CPUs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Simplify and harden helper to flush SEV guest page(s) (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Silence compiler warning in the kvm_page_table_test (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Update AMD PMC sample period to fix guest NMI-watchdog (Vitaly Kuznetsov) [2074832]
- x86/kvm: Preserve BSP MSR_KVM_POLL_CONTROL across suspend/resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip KVM_GUESTDBG_BLOCKIRQ APICv update if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pend KVM_REQ_APICV_UPDATE during vCPU creation to fix a race (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Defer APICv updates while L2 is active until L1 is active (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tag APICv DISABLE inhibit, not ABSENT, if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wrap vcpu->srcu_idx and yell if it's abused (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't re-acquire SRCU lock in complete_emulated_io() (Vitaly Kuznetsov) [2074832]
- tools arch: Update arch/x86/lib/mem{cpy,set}_64.S copies used in 'perf bench mem memcpy' (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for various modes with 16kB page size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Check for supported page sizes (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Initialise default guest mode at test startup time (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for VM_MODE_P36V48_{4K,64K} (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Introduce a variable default IPA size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Rework TCR_EL1 configuration (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid writing to TSC page without an active vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Do not activate AVIC for SEV-enabled guest (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add tsc_scaling_sync to .gitignore (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Don't leak GIC FD across dirty log test iterations (Vitaly Kuznetsov) [2074832]
- KVM: Don't create VM debugfs files outside of the VM directory (Vitaly Kuznetsov) [2074832]
- KVM: selftests: get-reg-list: Add KVM_REG_ARM_FW_REG(3) (Vitaly Kuznetsov) [2074832]
- KVM: avoid NULL pointer dereference in kvm_dirty_ring_push (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: remove unnecessary flush_workqueue() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Resolve nx_huge_pages when kvm.ko is loaded (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add cond_resched() to loop in sev_clflush_pages() (Vitaly Kuznetsov) [2074832]
- KVM: x86: fix sending PV IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user address (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove redundant vm_entry_controls_clearbit() call (Vitaly Kuznetsov) [2074832]
- KVM: x86: cleanup enter_rmode() (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix tsc scaling when the host doesn't support it (Vitaly Kuznetsov) [2074832]
- kvm: x86: SVM: remove unused defines (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move tsc ratio definitions to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix avic spec based definitions again (Vitaly Kuznetsov) [2074832]
- KVM: x86: Only do MSR filtering when access MSR by rdmsr/wrmsr (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Emulate RDPID only if it is enabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix and isolate TSX-specific performance event logic (Vitaly Kuznetsov) [2074832]
- KVM: x86: mmu: trace kvm_mmu_set_spte after the new SPTE was set (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Clear reserved bits written to PerfEvtSeln MSRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Trace all APICv inhibit changes and capture overall status (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add wrappers for setting/clearing APICv inhibits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make APICv inhibit reasons an enum and cleanup naming (Vitaly Kuznetsov) [2074832]
- KVM: X86: Handle implicit supervisor access with SMAP (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename variable smap to not_smap in permission_fault() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comments in update_permission_bitmask (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change the type of access u32 to u64 (Vitaly Kuznetsov) [2074832]
- KVM: Remove dirty handling from gfn_to_pfn_cache completely (Vitaly Kuznetsov) [2074832]
- KVM: Use enum to track if cached PFN will be used in guest and/or host (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Fix kvm_cache_regs.h inclusions for is_guest_mode() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use different raw event masks for AMD and Intel (Vitaly Kuznetsov) [2074832]
- KVM: Don't actually set a request when evicting vCPUs for GFN cache invd (Vitaly Kuznetsov) [2074832]
- KVM: avoid double put_page with gfn-to-pfn cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in zap range and mmu_notifier unmap (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix panic on out-of-bounds guest IRQ (Vitaly Kuznetsov) [2074832]
- KVM: MMU: propagate alloc_workqueue failure (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't activated (Vitaly Kuznetsov) [2074832]
- KVM: x86: Avoid theoretical NULL pointer dereference in kvm_irq_delivery_to_apic_fast() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check lapic_in_kernel() before attempting to set a SynIC irq (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix clang -Wimplicit-fallthrough in do_host_cpuid() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: set owner of cpu and vm file operations" (Vitaly Kuznetsov) [2074832]
- KVM: Prevent module exit until all VMs are freed (Vitaly Kuznetsov) [2074832]
- KVM: use kvcalloc for array allocations (Vitaly Kuznetsov) [2074832]
- KVM: x86: Introduce KVM_CAP_DISABLE_QUIRKS2 (Vitaly Kuznetsov) [2074832]
- kvm: x86: Require const tsc for RT (Vitaly Kuznetsov) [2074832]
- KVM: x86: synthesize CPUID leaf 0x80000021h if useful (Vitaly Kuznetsov) [2074832]
- KVM: x86: add support for CPUID leaf 0x80000021 (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not use KVM_X86_OP_OPTIONAL_RET0 for get_mt_mask (Vitaly Kuznetsov) [2074832]
- Revert "KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range()" (Vitaly Kuznetsov) [2074832]
- kvm: x86/mmu: Flush TLB before zap_gfn_range releases RCU (Vitaly Kuznetsov) [2074832]
- kvm/emulate: Fix SETcc emulation function offsets with SLS (Vitaly Kuznetsov) [2074832]
- KVM: compat: riscv: Prevent KVM_COMPAT from being selected (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to populate a VM with the max possible guest mem (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Define cpu_relax() helpers for s390 and x86 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Split out helper to allocate guest mem via memfd (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move raw KVM_SET_USER_MEMORY_REGION helper to utils (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN on any attempt to atomically update REMOVED SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for a REMOVED leaf SPTE before making the SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap defunct roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap roots in two passes to avoid inducing RCU stalls (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Allow yielding when zapping GFNs for defunct TDP MMU root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap invalidated roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Defer TLB flush to caller when freeing TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do remote TLB flush before dropping RCU in TDP MMU resched (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write to zap TDP MMU range (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add dedicated helper to zap TDP MMU root shadow page (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip remote TLB flush when zapping all of TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only the target TDP MMU shadow page in NX recovery (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor low-level TDP MMU set SPTE helper to take raw values (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN if old _or_ new SPTE is REMOVED in non-atomic path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add helpers to read/write TDP MMU SPTEs and document RCU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop RCU after processing each root in MMU notifier hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Batch TLB flushes from TDP MMU for MMU notifier change_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for !leaf=>leaf, not PFN change, in TDP MMU SP removal (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not allow readers to acquire references to invalid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: only perform eager page splitting on valid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write in unyielding root iter (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document that zapping invalidated roots doesn't need to flush (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Formalize TDP MMU's (unintended?) deferred TLB flush logic (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix wrong/misleading comments in TDP MMU fast zap (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for present SPTE when clearing dirty bit in TDP MMU (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add generated file to the .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: x86: pull kvm->srcu read-side to kvm_arch_vcpu_ioctl_run (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Passing up the error state of mmu_alloc_shadow_roots() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Disable preemption across AVIC load/put during APICv refresh (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Exit to userspace on ENOMEM/EFAULT GHCB errors (Vitaly Kuznetsov) [2074832]
- KVM: WARN if is_unsync_root() is called on a root without a shadow page (Vitaly Kuznetsov) [2074832]
- KVM: Drop KVM_REQ_MMU_RELOAD and update vcpu-requests.rst documentation (Vitaly Kuznetsov) [2074832]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only obsolete roots if a root shadow page is zapped (Vitaly Kuznetsov) [2074832]
- KVM: Drop kvm_reload_remote_mmus(), open code request in x86 users (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_mmu_unload() directly on CR4.PCIDE change (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Move the unhandled outer privilege level logic of far return into __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Fix wrong privilege check for code segment in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Defer not-present segment check in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify KVM handling of ICR (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_set_reg() a "private" xAPIC helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Treat x2APIC's ICR as a 64-bit register, not two 32-bit regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add helpers to handle 64-bit APIC MSR read/writes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_reg_{read,write}() static (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN if KVM emulates an IPI without clearing the BUSY flag (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't rewrite guest ICR on AVIC IPI virtualization failure (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use common kvm_apic_write_nodecode() for AVIC write traps (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "raw" APIC register read for handling APIC-write VM-Exit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle APIC-write offset wrangling in VMX code (Vitaly Kuznetsov) [2074832]
- KVM: x86: Do not change ICR on write to APIC_SELF_IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix emulation in writing cr8 (Vitaly Kuznetsov) [2074832]
- KVM: x86: flush TLB separately from MMU reset (Vitaly Kuznetsov) [2074832]
- KVM: x86: Yield to IPI target vCPU only if it is busy (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use PV TLB/yield when mwait is advertised (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clear MMIO cache when unloading the MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Always use current mmu's role when loading new PGD (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: load new PGD after the shadow MMU is initialized (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: look for a cached PGD when going from 32-bit to 64-bit (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not pass vcpu to root freeing functions (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not consult levels when freeing roots (Vitaly Kuznetsov) [2074832]
- KVM: x86: use struct kvm_mmu_root_info for mmu->root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: avoid NULL-pointer dereference on page freeing bugs (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not deliver asynchronous page faults if CR0.PG=0 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reinitialize context if host userspace toggles EFER.LME (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Verify disabling PMU virtualization via KVM_CAP_CONFIG_PMU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Carve out helper to create "default" VM without vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Provide per VM capability for disabling PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix pointer mistmatch warning when patching RET0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: Move VM's worker kthreads back to the original cgroup before exiting. (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove scratch 'cpu' variable that shadows an identical scratch var (Vitaly Kuznetsov) [2074832]
- kvm: vmx: Fix typos comment in __loaded_vmcs_clear() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Make setup/unsetup under the same conditions (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: HVCALL_SEND_IPI_EX is an XMM fast hypercall (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Fix the maximum number of sparse banks for XMM fast TLB flush hypercalls (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_flush_tlb() (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_send_ipi() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest()" (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: disallow userspace setting of MSR_AMD64_TSC_RATIO to non default value when tsc scaling disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: make apf token non-zero to fix bug (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Add the uapi headers include variable (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add EXTRA_CFLAGS in top-level Makefile (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove MMU auditing (Vitaly Kuznetsov) [2074832]
- KVM: x86: allow defining return-0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: x86: make several APIC virtualization callbacks optional (Vitaly Kuznetsov) [2074832]
- KVM: x86: warn on incorrectly NULL members of kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove KVM_X86_OP_NULL and mark optional kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: use static_call_cond for optional callbacks (Vitaly Kuznetsov) [2074832]
- KVM: x86: return 1 unconditionally for availability of KVM_CAP_VAPIC (Vitaly Kuznetsov) [2074832]
- selftests: KVM: allow sev_migrate_tests on machines without SEV-ES (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Allow SEV intra-host migration of VM with mirrors (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use pv tlb/ipi/sched_yield if on 1 vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Fix compilation warning in non-x86_64 builds (Vitaly Kuznetsov) [2074832]
- kvm: x86: Disable KVM_HC_CLOCK_PAIRING if tsc is in always catchup mode (Vitaly Kuznetsov) [2074832]
- KVM: Fix lockdep false negative during host resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add KVM_CAP_ENABLE_CAP to x86 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename AVIC helpers to use "avic" prefix instead of "svm" (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use AMD64_RAW_EVENT_MASK for PERF_TYPE_RAW (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Don't truncate the PerfEvtSeln MSR when creating a perf event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Replace memset() "optimization" with normal per-field writes (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix race between interrupt delivery and AVIC inhibition (Vitaly Kuznetsov) [2074832]
- KVM: SVM: set IRR in svm_deliver_interrupt (Vitaly Kuznetsov) [2074832]
- KVM: SVM: extract avic_ring_doorbell (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Remove absent target file (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use local pointer to vcpu_vmx in vmx_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Update 'struct vmcb_control_area' definition (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Set up MSR-Bitmap for SVM guests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Properly deal with 'hv_clean_fields' (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Adapt hyperv_cpuid test to the newly introduced Enlightened MSR-Bitmap (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Implement Enlightened MSR-Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Split off common definitions for Hyper-V on KVM and KVM on Hyper-V (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_hv_hypercall_enabled() static inline (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add an option to disable MANUAL_PROTECT_ENABLE and INITIALLY_SET (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add tracepoint for splitting huge pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU during KVM_CLEAR_DIRTY_LOG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU when dirty logging is enabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Separate TDP MMU shadow page allocation and initialization (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Derive page role for TDP MMU shadow pages from parent (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove redundant role overrides for TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor TDP MMU iterators to take kvm_mmu_page root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move restore_acc_track_spte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop new_spte local variable from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unnecessary warnings from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate logic to atomically install a new TDP MMU page table (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename handle_removed_tdp_mmu_page() to handle_removed_pt() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename TDP MMU functions that handle shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Change tdp_mmu_{set,zap}_spte_atomic() to return 0/-EBUSY (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Automatically update iter->old_spte if cmpxchg fails (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename __rmap_write_protect() to rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename rmap_write_protect() to kvm_vcpu_write_protect_gfn() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add checks for reserved-to-zero Hyper-V hypercall fields (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reject fixeds-size Hyper-V hypercalls with non-zero "var_cnt" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Shove vp_bitmap handling down into sparse_set_to_vcpu_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't bother reading sparse banks that end up being ignored (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to get the sparse VP_SET for IPIs and TLB flushes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor kvm_hv_flush_tlb() to reduce indentation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get the number of Hyper-V sparse banks from the VARHEAD field (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate comments about {Host,MMU}-writable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename DEFAULT_SPTE_MMU_WRITEABLE to DEFAULT_SPTE_MMU_WRITABLE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move is_writable_pte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check SPTE writable invariants when setting leaf SPTEs (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move SPTE writable invariant checks to a helper function (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Enable timer posted-interrupt only when mwait/hlt is advertised (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Dont' send posted IRQ if vCPU == this vCPU and vCPU is IN_GUEST_MODE (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename hook implementations to conform to kvm_x86_ops' names (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename SEV implemenations to conform to kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use more verbose names for mem encrypt kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unused MAX_INST_SIZE #define (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename svm_flush_tlb() to svm_flush_tlb_current() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move get_cs_db_l_bits() helper to SVM (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename VMX functions to conform to kvm_x86_ops names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for copy/move encryption context ioctls() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: Uninline and export hv_track_root_tdp() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Refactor PMU refresh to avoid referencing kvm_x86_ops.pmu_ops (Vitaly Kuznetsov) [2074832]
- KVM: xen: Use static_call() for invoking kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for .vcpu_deliver_sipi_vector() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Call vmx_get_cpl() directly in handle_dr() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_x86_ops pointers to align w/ preferred vendor names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop export for .tlb_flush_current() static_call key (Vitaly Kuznetsov) [2074832]
- KVM: x86: skip host CPUID call for hypervisor leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "flags" of kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2074832]
- KVM: Remove unused "kvm" of kvm_make_vcpu_request() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "vcpu" of kvm_scale_tsc() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "tss_selector" of task_switch_{16, 32}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "ctxt" of setup_syscalls_segments() (Vitaly Kuznetsov) [2074832]
- KVM: x86/ioapic: Remove unused "addr" and "length" of ioapic_read_indirect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/i8259: Remove unused "addr" of elcr_ioport_{read,write}() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: improve split between svm_prepare_guest_switch and sev_es_prepare_guest_switch (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Remove unused "vcpu" of svm_check_exit_valid() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu_audit: Remove unused "level" of audit_spte_after_sync() (Vitaly Kuznetsov) [2074832]
- KVM: x86/tdp_mmu: Remove unused "kvm" of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "vcpu" of reset_{tdp,ept}_shadow_zero_bits_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of __rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of kvm_mmu_unlink_parents() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip APICv update if APICv is disable at the module level (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop NULL check on kvm_x86_ops.check_apicv_inhibit_reasons (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport __kvm_request_apicv_update() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap _all_ roots when unmapping gfn range in TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move "invalid" check out of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use common TDP MMU zap helper for MMU notifier unmap hook (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Fix runstate updates to be atomic when preempting vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move avic definitions from AMD's spec to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: lapic: don't touch irr_pending in kvm_apic_update_apicv when inhibiting it (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: deal with L1 hypervisor that intercepts interrupts but lets L2 control them (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: expose clean bit support to the guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM/nVMX: set nested_run_pending on VM entry which is a result of RSM (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: mark vmcb01 as dirty when restoring SMM saved state (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: fix potential NULL derefernce on nested migration (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: don't passthrough SMAP/SMEP/PKE bits in !NPT && !gCR0.PG case (Vitaly Kuznetsov) [2074832]
- Revert "svm: Add warning message for AVIC IPI invalid target" (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add vgic initialization for dirty log perf test for ARM (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Test OS lock behavior (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add OSLSR_EL1 to the list of blessed regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use ERR_PTR_USR() to return -EFAULT as a __user pointer (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report deprecated x87 features in supported CPUID (Vitaly Kuznetsov) [2074832]
- KVM: x86: use the KVM side max supported fixed counter (Vitaly Kuznetsov) [2074832]
- x86: Share definition of __is_canonical_address() (Vitaly Kuznetsov) [2074832]
- perf/x86/intel/pt: Relax address filter validation (Vitaly Kuznetsov) [2074832]
- kvm/x86: rework guest entry logic (Vitaly Kuznetsov) [2074832]
- kvm: add guest_state_{enter,exit}_irqoff() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move delivery of non-APICv interrupt into vendor code (Vitaly Kuznetsov) [2074832]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2074832]
- selftests: kvm: check dynamic bits against KVM_X86_XCOMP_GUEST_SUPP (Vitaly Kuznetsov) [2074832]
- KVM: x86: add system attribute to retrieve full set of supported xsave states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to retrieve userspace address from kvm_device_attr (Vitaly Kuznetsov) [2074832]
- selftests: kvm: move vm_xsave_req_perm call to amx_test (Vitaly Kuznetsov) [2074832]
- KVM: x86: Sync the states size with the XCR0/IA32_XSS at, any time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vCPU's runtime CPUID on write to MSR_IA32_XSS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Keep MSR_IA32_XSS unchanged for INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: Free kvm_cpuid_entry2 array on post-KVM_RUN KVM_SET_CPUID{,2} (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: WARN on any attempt to allocate shadow VMCS for vmcs02 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Don't skip L2's VMCALL in SMM test for SVM guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check .flags in kvm_cpuid_check_equal() too (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forcibly leave nested virt when SMM state is toggled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: drop unnecessary code in svm_hv_vmcb_dirty_nested_enlightenments() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: hyper-v: Enable Enlightened MSR-Bitmap support for real (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't kill SEV guest if SMAP erratum triggers in usermode (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't apply SEV+SMAP workaround on code fetch or PT access (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Inject #UD on attempted emulation for SEV guest w/o insn buffer (Vitaly Kuznetsov) [2074832]
- KVM: SVM: WARN if KVM attempts emulation on #UD or #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pass emulation type to can_emulate_instruction() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Explicitly require DECODEASSISTS to enable SEV support (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't intercept #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- Revert "KVM: SVM: avoid infinite loop on NPF from bad address" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Never reject emulation due to SMAP errata for !SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: skip eax alignment check for non-SVM instructions (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Also cancel preemption timer during SET_LAPIC (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vmcs_config.order (Vitaly Kuznetsov) [2074832]
- KVM/X86: Make kvm_vcpu_reload_apic_access_page() static (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Re-enable access_tracking_perf_test (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set vmcs.PENDING_DBG.BS on #DB in STI/MOVSS blocking shadow (Vitaly Kuznetsov) [2074832]
- KVM: remove async parameter of hva_to_pfn_remapped() (Vitaly Kuznetsov) [2074832]
- x86,kvm/xen: Remove superfluous .fixup usage (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Zero host's SYSENTER_ESP iff SYSENTER is NOT used (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in lib/x86_64/processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in pmu_event_filter_test.c (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Do not indent with spaces (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Nullify vcpu_(un)blocking() hooks if AVIC is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move svm_hardware_setup() and its helpers below svm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Drop AVIC's intermediate avic_set_running() helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when handling posted interrupt wakeup (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Fold fallback path into triggering posted IRQ helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Pass desired vector instead of bool for triggering posted IRQ (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when triggering posted interrupt "fails" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Skip AVIC and IRTE updates when loading blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use kvm_vcpu_is_blocking() in AVIC load to handle preemption (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unnecessary APICv/AVIC update in vCPU unblocking path (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't bother checking for "running" AVIC when kicking for IPIs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Signal AVIC doorbell iff vCPU is in guest mode (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct pre_block/post_block kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport LAPIC's switch_to_{hv,sw}_timer() helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move preemption timer <=> hrtimer dance to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: Move x86 VMX's posted interrupt list_head to vcpu_vmx (Vitaly Kuznetsov) [2074832]
- KVM: Drop unused kvm_vcpu.pre_pcpu field (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle PI descriptor updates during vcpu_put/load (Vitaly Kuznetsov) [2074832]
- KVM: avoid warning on s390 in mark_page_dirty (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add a test to force emulation with a pending exception (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Reject KVM_RUN if emulation is required with pending exception (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add test for KVM_SET_PMU_EVENT_FILTER (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce x86_model() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Export x86_family() for use outside of processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce is_amd_cpu() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Parameterize the CPUID vendor string check (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use binary search to check filtered events (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Improve TLB flush comment in kvm_mmu_slot_remove_write_access() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document and enforce MMU-writable and Host-writable invariants (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Clear MMU-writable during changed_pte notifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix write-protection of PTs mapped by the TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Making the module parameter of vPMU more common (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Test KVM_SET_CPUID2 after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Rename 'get_cpuid_test' to 'cpuid_test' (Vitaly Kuznetsov) [2074832]
- KVM: x86: Partially allow KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix available_event_types check for REF_CPU_CYCLES event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check for rmaps allocation (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of kvm->lock (Vitaly Kuznetsov) [2074832]
- KVM: SVM: include CR3 in initial VMSA state for SEV-ES guests (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Provide vmread version using asm-goto-with-outputs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix wall clock writes in Xen shared_info not to mark page dirty (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Add KVM_IRQ_ROUTING_XEN_EVTCHN and event channel delivery (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Maintain valid mapping of Xen shared_info page (Vitaly Kuznetsov) [2074832]
- KVM: Reinstate gfn_to_pfn_cache with invalidation support (Vitaly Kuznetsov) [2074832]
- KVM: Warn if mark_page_dirty() is called without an active vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Silence per-cpu pr_info noise about KVM clocks and steal time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring branch instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Add pmc->intr to refactor kvm_perf_overflow{_intr}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Reuse pmc_perf_hw_id() and drop find_fixed_event() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Refactoring find_arch_event() to pmc_perf_hw_id() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Setup pmc->eventsel for fixed PMCs (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid out of bounds indices for fixed performance counters (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_CR3 dirty when !CR0_PG -> CR0_PG if EPT + !URG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Reconstruct shadow page root if the guest PDPTEs is changed (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: X86: Update mmu->pdptrs only when it is changed" (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Add mirror command tests (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix sev_ioctl() (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix test_sev_mirror() (Vitaly Kuznetsov) [2074832]
- x86/mtrr: Remove the mtrr_bp_init() stub (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Wake vCPU when delivering posted IRQ even if vCPU == this vCPU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify TRIPLE_FAULT on invalid L2 guest state (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Synthesize TRIPLE_FAULT for L2 if emulation is required (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Always clear vmx->fail on emulation_required (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Fix non-x86 compiling (Vitaly Kuznetsov) [2074832]
- KVM: x86: Always set kvm_run->if_flag (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove PMU FIXED_CTR3 from msrs_to_save_all (Vitaly Kuznetsov) [2074832]
- KVM: x86: Retry page fault if MMU reload is pending and root has no sp (Vitaly Kuznetsov) [2074832]
- KVM: selftests: vmx_pmu_msrs_test: Drop tests mangling guest visible CPUIDs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop guest CPUID check for host initiated writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test to verify KVM doesn't explode on "bad" I/O (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't WARN if userspace mucks with RCX during string I/O exit (Vitaly Kuznetsov) [2074832]
- KVM: X86: Raise #GP when clearing CR0_PG in 64 bit mode (Vitaly Kuznetsov) [2074832]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2074832]
- KVM: x86: Ignore sparse banks size for an "all CPUs", non-sparse IPI req (Vitaly Kuznetsov) [2074832]
- KVM: Add Makefile.kvm for common files, use it for x86 (Vitaly Kuznetsov) [2074832]
- KVM: Introduce CONFIG_HAVE_KVM_DIRTY_RING (Vitaly Kuznetsov) [2074832]
- KVM: x86: selftests: svm_int_ctl_test: fix intercept calculation (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Clean up PI pre/post-block WARNs (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Ensure vCPU honors event request if posting nested IRQ fails (Vitaly Kuznetsov) [2074832]
- KVM: x86: add a tracepoint for APICv/AVIC interrupt delivery (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Implement Enlightened MSR Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Introduce vmx_msr_bitmap_l01_changed() helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Exit to userspace if emulation prepared a completion callback (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Don't use Enlightened MSR Bitmap for L3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use different callback if msr access comes from the emulator (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add an emulation type to handle completion of user exits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Handle 32-bit wrap of EIP for EMULTYPE_SKIP with flat code seg (Vitaly Kuznetsov) [2074832]
- KVM: Clear pv eoi pending bit only when it is set (Vitaly Kuznetsov) [2074832]
- KVM: x86: don't print when fail to read/write pv eoi memory (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu parameter from load_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename gpte_is_8_bytes to has_4_byte_gpte and invert the direction (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use ept_caps_to_lpage_level() in hardware_setup() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter huge_page_level to kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add huge_page_level to __reset_rsvds_bits_mask_ept() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu->translate_gpa (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter struct kvm_mmu *mmu into mmu->gva_to_gpa() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Calculate quadrant when !role.gpte_is_8_bytes (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove useless code to set role.gpte_is_8_bytes when role.direct (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove unused declaration of __kvm_mmu_free_some_pages() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comment in __kvm_mmu_create() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Skip allocating pae_root for vcpu->arch.guest_mmu when !tdp_enabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Allocate sd->save_area with __GFP_ZERO (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename get_max_npt_level() to get_npt_level() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Change comments about vmx_get_msr() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use kvm_set_msr_common() for MSR_IA32_TSC_ADJUST in the default way (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update msr value after kvm_set_user_return_msr() succeeds (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Avoid to rdmsrl(MSR_IA32_SYSENTER_ESP) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Update mmu->pdptrs only when it is changed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_register_clear_available() (Vitaly Kuznetsov) [2074832]
- KVM: vmx, svm: clean up mass updates to regs_avail/regs_dirty bits (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update vmcs.GUEST_CR3 only when the guest CR3 is dirty (Vitaly Kuznetsov) [2074832]
- KVM: X86: Mark CR3 dirty when vcpu->arch.cr3 is changed (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove references to VCPU_EXREG_CR3 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove outdated comment in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move CR0 pdptr_bits into header file as X86_CR0_PDPTR_BITS (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_PDPTR_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_TLBFLUSH_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Track dirtiness of PDPTRs even if NPT is disabled (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_PDPTR available in ept_save_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Ensure that dirty PDPTRs are loaded (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Add module param to control PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vCPU from PI wakeup list before updating PID.NV (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move Posted Interrupt ndst computation out of write loop (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Read Posted Interrupt "control" exactly once per loop iteration (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save/restore IRQs (instead of CLI/STI) during PI pre/post block (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop pointless PI.NDST update when blocking (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use boolean returns for Posted Interrupt "test" helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop unnecessary PI logic to handle impossible conditions (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Skip Posted Interrupt updates if APICv is hard disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wake/query blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_vcpu_block() directly for non-HALTED wait states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Directly block (instead of "halting") UNINITIALIZED vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Don't redo ktime_get() when calculating halt-polling stop/deadline (Vitaly Kuznetsov) [2074832]
- KVM: stats: Add stat to detect if vcpu is currently blocking (Vitaly Kuznetsov) [2074832]
- KVM: Split out a kvm_vcpu_block() helper from kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Rename kvm_vcpu_block() => kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Drop obsolete kvm_arch_vcpu_block_finish() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tweak halt emulation helper names to free up kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Don't block+unblock when halt-polling is successful (Vitaly Kuznetsov) [2074832]
- KVM: Reconcile discrepancies in halt-polling stats (Vitaly Kuznetsov) [2074832]
- KVM: Refactor and document halt-polling stats update helper (Vitaly Kuznetsov) [2074832]
- KVM: Update halt-polling stats if and only if halt-polling was attempted (Vitaly Kuznetsov) [2074832]
- KVM: Force PPC to define its own rcuwait object (Vitaly Kuznetsov) [2074832]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Ensure target pCPU is read once when signalling AVIC doorbell (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't unblock vCPU w/ Posted IRQ if IRQs are disabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: change TLB flush indicator to bool (Vitaly Kuznetsov) [2074832]
- KVM: Avoid atomic operations when kicking the running vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86/MMU: Simplify flow of vmx_get_mt_mask (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Propagate memslot const qualifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from kvm_slot_page_track_is_active (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use shadow page role to detect PML-unfriendly pages for L2 (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce struct vmcb_ctrl_area_cached (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: split out __nested_vmcb_check_controls (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use svm->nested.save to load vmcb12 registers and avoid TOC/TOU races (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use vmcb_save_area_cached in nested_vmcb_valid_sregs() (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: rename nested_load_control_from_vmcb12 in nested_copy_vmcb_control_to_cache (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce svm->nested.save to cache save area before checks (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: move nested_vmcb_check_cr3_cr4 logic in nested_vmcb_valid_sregs (Vitaly Kuznetsov) [2074832]
- KVM: Dynamically allocate "new" memslots from the get-go (Vitaly Kuznetsov) [2074832]
- KVM: Wait 'til the bitter end to initialize the "new" memslot (Vitaly Kuznetsov) [2074832]
- KVM: Optimize overlapping memslots check (Vitaly Kuznetsov) [2074832]
- KVM: Optimize gfn lookup in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: Call kvm_arch_flush_shadow_memslot() on the old slot in kvm_invalidate_memslot() (Vitaly Kuznetsov) [2074832]
- KVM: Keep memslots in tree-based structures instead of array-based ones (Vitaly Kuznetsov) [2074832]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Add a routine for setting userspace CPU state (Vitaly Kuznetsov) [2074832]
- KVM: Use interval tree to do fast hva lookup in memslots (Vitaly Kuznetsov) [2074832]
- KVM: Resolve memslot ID via a hash table instead of via a static array (Vitaly Kuznetsov) [2074832]
- KVM: Move WARN on invalid memslot index to update_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use nr_memslot_pages to avoid traversing the memslots array (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't call kvm_mmu_change_mmu_pages() if the count hasn't changed (Vitaly Kuznetsov) [2074832]
- KVM: Don't make a full copy of the old memslot in __kvm_set_memory_region() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't assume old/new memslots are non-NULL at memslot commit (Vitaly Kuznetsov) [2074832]
- KVM: Use prepare/commit hooks to handle generic memslot metadata updates (Vitaly Kuznetsov) [2074832]
- KVM: Stop passing kvm_userspace_memory_region to arch memslot hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: arm64: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: Let/force architectures to deal with arch specific memslot data (Vitaly Kuznetsov) [2074832]
- KVM: Use "new" memslot's address space ID instead of dedicated param (Vitaly Kuznetsov) [2074832]
- KVM: Resync only arch fields when slots_arch_lock gets reacquired (Vitaly Kuznetsov) [2074832]
- KVM: Open code kvm_delete_memslot() into its only caller (Vitaly Kuznetsov) [2074832]
- KVM: Require total number of memslot pages to fit in an unsigned long (Vitaly Kuznetsov) [2074832]
- KVM: Convert kvm_for_each_vcpu() to using xa_for_each_range() (Vitaly Kuznetsov) [2074832]
- KVM: arm64: vgic-v3: Fix vcpu index comparison (Vitaly Kuznetsov) [2074832]
- KVM: Use 'unsigned long' as kvm_for_each_vcpu()'s index (Vitaly Kuznetsov) [2074832]
- KVM: Convert the kvm->vcpus array to a xarray (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Vitaly Kuznetsov) [2074832]
- KVM: Move wiping of the kvm->vcpus array to common code (Vitaly Kuznetsov) [2074832]
- KVM: MMU: update comment on the number of page role combinations (Vitaly Kuznetsov) [2074832]
- KVM: Drop stale kvm_is_transparent_hugepage() declaration (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Retry page fault if root is invalidated by memslot update (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set failure code in prepare_vmcs02() (Vitaly Kuznetsov) [2074832]
- KVM: ensure APICv is considered inactive if there is no APIC (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix reserved bits for AMD PerfEvtSeln register (Vitaly Kuznetsov) [2074832]
- entry: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- x86: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- thread_info: Add helpers to snapshot thread flags (Vitaly Kuznetsov) [2074832]
- KVM: fix avic_set_running for preemptable kernels (Vitaly Kuznetsov) [2074832]
- KVM: VMX: clear vmx_x86_ops.sync_pir_to_irr if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SEV: accept signals in sev_lock_two_vms (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not take kvm->lock when destroying (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Prohibit migration of a VM that has mirrors (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Do COPY_ENC_CONTEXT_FROM with both VMs locked (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: add tests for KVM_CAP_VM_COPY_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: move mirror status to destination of KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: initialize regions_list of a mirror VM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: cleanup locking for KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not use list_replace_init on an empty list (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use a stable condition around all VT-d PI paths (Vitaly Kuznetsov) [2074832]
- KVM: x86: check PIR even for vCPUs with disabled APICv (Vitaly Kuznetsov) [2074832]
- KVM: VMX: prepare sync_pir_to_irr for running with APICv disabled (Vitaly Kuznetsov) [2074832]
- KVM: selftests: page_table_test: fix calculation of guest_test_phys_mem (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Handle "default" period when selectively waking kthread (Vitaly Kuznetsov) [2074832]
- KVM: MMU: shadow nested paging does not have PKU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove spurious TLB flushes in TDP MMU zap collapsible path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use yield-safe TDP MMU root iter in MMU notifier unmapping (Vitaly Kuznetsov) [2074832]
- KVM: X86: Use vcpu->arch.walk_mmu for kvm_mmu_invlpg() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Make sure kvm_create_max_vcpus test won't hit RLIMIT_NOFILE (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Avoid KVM_SET_CPUID2 after KVM_RUN in hyperv_features test (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Emulate guest TLB flush on nested VM-Enter with new vpid12 (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Abide to KVM_REQ_TLB_FLUSH_GUEST request on nested vmentry/vmexit (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Flush current VPID (L1 vs. L2) for KVM_REQ_TLB_FLUSH_GUEST (Vitaly Kuznetsov) [2074832]
- KVM: SEV: expose KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM capability (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: free all VMs (Vitaly Kuznetsov) [2074832]
- selftests: fix check for circular KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: x86: ignore APICv if LAPIC is not enabled (Vitaly Kuznetsov) [2074832]
- KVM: downgrade two BUG_ONs to WARN_ON_ONCE (Vitaly Kuznetsov) [2074832]
- KVM: VMX: do not use uninitialized gfn_to_hva_cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass parameter flush as false in kvm_tdp_mmu_zap_collapsible_sptes() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip tlb flush if it has been done in zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- x86/kvm: remove unused ack_notifier callbacks (Vitaly Kuznetsov) [2074832]
- KVM: Disallow user memslot with size that exceeds "unsigned long" (Vitaly Kuznetsov) [2074832]
- KVM: Ensure local memslot copies operate on up-to-date arch-specific data (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix TLB flush range when handling disconnected pt (Vitaly Kuznetsov) [2074832]
- KVM: x86: Cap KVM_CAP_NR_VCPUS by KVM_CAP_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Assume a 64-bit hypercall for guests with protected state (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add /x86_64/sev_migrate_tests to .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Fix typo in and tweak name of cmd_allowed_from_miror() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Drop a redundant setting of sev->asid during initialization (Vitaly Kuznetsov) [2074832]
- KVM: SEV: WARN if SEV-ES is marked active but SEV is not (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Set sev_info.active after initial checks in sev_guest_init() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Disallow COPY_ENC_CONTEXT_FROM if target has created vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Kill kvm_map_gfn() / kvm_unmap_gfn() and gfn_to_pfn_cache (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use a gfn_to_hva_cache for vmptrld (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_read_guest_offset_cached() for nested VMCS check (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Use sizeof_field() instead of open-coding it (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_{read,write}_guest_cached() for shadow_vmcs12 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: include EFER.LMA in extended mmu role (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: don't use vcpu->arch.efer when checking host state on nested state load (Vitaly Kuznetsov) [2074832]
- KVM: Fix steal time asm constraints (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix uninitialized eoi_exit_bitmap usage in vcpu_load_eoi_exitmap() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf_test_destroy_vm in memslot_modification_stress_test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Wait for all vCPU to be created before entering guest mode (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move vCPU thread creation and joining to common helpers (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Start at iteration 0 instead of -1 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Sync perf_test_args to guest during VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fill per-vCPU struct during "perf_test" VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Create VM with adjusted number of guest pages for perf tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Remove perf_test_args.host_page_size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move per-VM GPA into perf_test_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf util's per-vCPU GPA/pages in demand paging test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Capture per-vCPU GPA in perf_test_vcpu_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use shorthand local var to access struct perf_tests_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Require GPA to be aligned when backed by hugepages (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Assert mmap HVA is aligned when using HugeTLB (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Expose align() helpers to tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Explicitly state indicies for vm_guest_mode_params array (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add event channel upcall support to xen_shinfo_test (Vitaly Kuznetsov) [2074832]
- KVM: SEV: unify cgroup cleanup code for svm_vm_migrate_from (Vitaly Kuznetsov) [2074832]
- KVM: x86: move guest_pv_has out of user_access section (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop arbitrary KVM_SOFT_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: Move INVPCID type check from vmx and svm to the common kvm_handle_invpcid() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add a helper function to retrieve the GPR index for INVPCID, INVVPID, and INVEPT (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Clean up x2APIC MSR handling for L2 (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Macrofy the MSR bitmap getters and setters (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Handle dynamic MSR intercept toggling (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps are in use (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't update vcpu->arch.pv_eoi.msr_val when a bogus value was written to MSR_KVM_PV_EOI_EN (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_lapic_enable_pv_eoi() (Vitaly Kuznetsov) [2074832]
- kvm: mmu: Use fast PF path for access tracking of huge pages when possible (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Properly dereference rcu-protected TDP MMU sptep iterator (Vitaly Kuznetsov) [2074832]
- kvm: x86: Convert return type of *is_valid_rdpmc_ecx() to bool (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix recording of guest steal time / preempted status (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add intra host migration tests (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add open sev dev helper (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV-ES intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: provide helpers to charge/uncharge misc_cg (Vitaly Kuznetsov) [2074832]
- KVM: generalize "bugged" VM to "dead" VM (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add kexec support for SEV Live Migration. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add guest support for detecting and enabling SEV Live Migration feature. (Vitaly Kuznetsov) [2074832]
- mm: x86: Invoke hypercall when page encryption status is changed (Vitaly Kuznetsov) [2074832]
- EFI: Introduce the new AMD Memory Encryption GUID. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add AMD SEV specific Hypercall3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: SGX must obey the KVM_INTERNAL_ERROR_EMULATION protocol (Vitaly Kuznetsov) [2074832]
- KVM: x86: On emulation failure, convey the exit reason, etc. to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get exit_reason as part of kvm_x86_ops.get_exit_info (Vitaly Kuznetsov) [2074832]
- KVM: x86: Clarify the kvm_run.emulation_failure structure layout (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix nested SVM tests when built with clang (Vitaly Kuznetsov) [2074832]
- kvm: x86: Remove stale declaration of kvm_no_apic_vcpu (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move SVM's APICv sanity check to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Extract zapping of rmaps for gfn range to separate helper (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unload MMU in kvm_vcpu_flush_tlb_guest() (Vitaly Kuznetsov) [2074832]
- KVM: X86: pair smp_wmb() of mmu_try_to_unsync_pages() with smp_rmb() (Vitaly Kuznetsov) [2074832]
- KVM: emulate: Comment on difference between RDPMC implementation and manual (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add vendor name to kvm_x86_ops, use it for error messages (Vitaly Kuznetsov) [2074832]
- kvm: x86: mmu: Make NX huge page recovery period configurable (Vitaly Kuznetsov) [2074832]
- KVM: vPMU: Fill get_msr MSR_CORE_PERF_GLOBAL_OVF_CTRL w/ 0 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename slot_handle_leaf to slot_handle_level_4k (Vitaly Kuznetsov) [2074832]
- KVM: VMX: RTIT_CTL_BRANCH_EN has no dependency on other CPUID bit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename pt_desc.addr_range to pt_desc.num_address_ranges (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use precomputed vmx->pt_desc.addr_range (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Restore host's MSR_IA32_RTIT_CTL when it's not zero (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clean up prefetch/prefault/speculative naming (Vitaly Kuznetsov) [2074832]
- KVM: cleanup allocation of rmaps and page tracking data (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Introduce system counter offset test (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add helpers for vCPU device attributes (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test for KVM_{GET,SET}_CLOCK (Vitaly Kuznetsov) [2074832]
- tools: arch: x86: pull in pvclock headers (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose TSC offset controls to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor tsc synchronization code (Vitaly Kuznetsov) [2074832]
- kvm: x86: protect masterclock with a seqcount (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report host tsc and realtime values in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid warning with -Wbitwise-instead-of-logical (Vitaly Kuznetsov) [2074832]
- KVM: x86: only allocate gfn_track when necessary (Vitaly Kuznetsov) [2074832]
- KVM: x86: add config for non-kvm users of page tracking (Vitaly Kuznetsov) [2074832]
- nSVM: Check for reserved encodings of TLB_CONTROL in nested VMCB (Vitaly Kuznetsov) [2074832]
- kvm: use kvfree() in kvm_arch_free_vm() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose Predictive Store Forwarding Disable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in make_spte and mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass struct kvm_page_fault to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass kvm_mmu_page struct to make_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: set ad_disabled in TDP MMU role (Vitaly Kuznetsov) [2074832]
- KVM: MMU: remove unnecessary argument to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: clean up make_spte return value (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in FNAME(sync_page) (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in page_fault_handle_page_track (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass the memslot around via struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: unify tdp_mmu_map_set_spte_atomic and tdp_mmu_set_spte_atomic_no_dirty_log (Vitaly Kuznetsov) [2074832]
- KVM: MMU: mark page dirty in make_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fold rmap_recycle into rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Verify shadow walk doesn't terminate early in page faults (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tracepoints arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change disallowed_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_mmu_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change fast_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tdp_mmu_map_handle_target_level() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_tdp_mmu_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change FNAME(fetch)() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change __direct_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change handle_abnormal_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_faultin_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change page_fault_handle_page_track() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change direct_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change mmu->page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: Introduce struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass unadulterated gpa to direct_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix potential race in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: extract KVM_GET_CLOCK/KVM_SET_CLOCK to separate functions (Vitaly Kuznetsov) [2074832]
- kvm: x86: abstract locking around pvclock_update_vm_gtod_copy (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move PTE present check from loop body to __shadow_walk_next() (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: implement nested TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control LBR virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: don't copy pause related settings (Vitaly Kuznetsov) [2074832]
- kvm: irqfd: avoid update unmodified entries of the routing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't check unsync if the original spte is writible (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unsync pagetables when speculative (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove FNAME(update_pte) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Zap the invalid list after remote tlb flushing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change kvm_sync_page() to return true when remote flush is needed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't flush current tlb on shadow page modification (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix kvm_vm_free() in cr4_cpuid_sync and vmx_tsc_adjust tests (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Fix spelling mistake "missmatch" -> "mismatch" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Manually retrieve CPUID.0x1 when getting FMS for RESET/INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN on non-zero CRs at RESET to detect improper initalization (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move RESET emulation to svm_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move RESET emulation to vmx_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop explicit zeroing of MSR guest values at vCPU creation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fold fx_init() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of XCR0 for guest during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of CR0.ET for guests during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Simplify retrieving the page offset when loading PDTPRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Subsume nested GPA read helper into load_pdptrs() (Vitaly Kuznetsov) [2074832]
- kvm: rename KVM_MAX_VCPU_ID to KVM_MAX_VCPU_IDS (Vitaly Kuznetsov) [2074832]
- KVM: Make kvm_make_vcpus_request_mask() use pre-allocated cpu_kick_mask (Vitaly Kuznetsov) [2074832]
- KVM: Pre-allocate cpumasks for kvm_make_all_cpus_request_except() (Vitaly Kuznetsov) [2074832]
- KVM: Drop 'except' parameter from kvm_make_vcpus_request_mask() (Vitaly Kuznetsov) [2074832]
- KVM: Optimize kvm_make_vcpus_request_mask() a bit (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid calling kvm_make_vcpus_request_mask() with vcpu_mask==NULL (Vitaly Kuznetsov) [2074832]
- KVM: use vma_pages() helper (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Reset vmxon_ptr upon VMXOFF emulation. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline to_svm() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline vmload() / vmsave() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline sev_*guest() (Vitaly Kuznetsov) [2074832]

* Fri Jun 10 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-109.el9]
- [s390] s390/perf: obtain sie_block from the right address (Claudio Imbrenda) [2094788]
- redhat/configs: Remove duplicates from ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/debug/s390x/zfcpdump/ configs to ark/debug/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/generic/s390x/zfcpdump/ configs to ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- net: Remove netif_rx_any_context() and netif_rx_ni(). (Petr Oros) [2089703]
- phonet: Use netif_rx(). (Petr Oros) [2089703]
- bluetooth: Use netif_rx(). (Petr Oros) [2089703]
- batman-adv: Use netif_rx(). (Petr Oros) [2089703]
- tipc: Use netif_rx(). (Petr Oros) [2089703]
- tun: vxlan: Use netif_rx(). (Petr Oros) [2089703]
- staging: Use netif_rx(). (Petr Oros) [2089703]
- s390: net: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Marvell: Use netif_rx(). (Petr Oros) [2089703]
- wireless: brcmfmac: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Atheros: Use netif_rx(). (Petr Oros) [2089703]
- slip/plip: Use netif_rx(). (Petr Oros) [2089703]
- can: Use netif_rx(). (Petr Oros) [2089703]
- net: phy: Use netif_rx(). (Petr Oros) [2089703]
- net: dev: Use netif_rx(). (Petr Oros) [2089703]
- net: bridge: Use netif_rx(). (Petr Oros) [2089703]
- net: macvlan: Use netif_rx(). (Petr Oros) [2089703]
- net: ethernet: Use netif_rx(). (Petr Oros) [2089703]
- net: dsa: Use netif_rx(). (Petr Oros) [2089703]
- net: caif: Use netif_rx(). (Petr Oros) [2089703]
- net: sgi-xp: Use netif_rx(). (Petr Oros) [2089703]
- net: xtensa: Use netif_rx(). (Petr Oros) [2089703]
- docs: networking: Use netif_rx(). (Petr Oros) [2089703]
- net: Correct wrong BH disable in hard-interrupt. (Petr Oros) [2089703]
- net: dev: Make rps_lock() disable interrupts. (Petr Oros) [2089703]
- net: dev: Makes sure netif_rx() can be invoked in any context. (Petr Oros) [2089703]
- net: dev: Remove preempt_disable() and get_cpu() in netif_rx_internal(). (Petr Oros) [2089703]
- powerpc/papr_scm: Fix buffer overflow issue with CONFIG_FORTIFY_SOURCE (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Fix build failure when (Gustavo Walbon) [1873830]
- drivers/nvdimm: Fix build failure when CONFIG_PERF_EVENTS is not set (Gustavo Walbon) [1873830]
- docs: ABI: sysfs-bus-nvdimm: Document sysfs event format entries for nvdimm pmu (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Add perf interface support (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add perf interface to expose nvdimm performance stats (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add nvdimm pmu structure (Gustavo Walbon) [1873830]
- redhat/configs: enable interconnect for NXP i.MX 8M (Steve Best) [2092404]
- x86/split_lock: Enable the split lock feature on Raptor Lake (David Arcari) [2076739]
- [s390] s390/cpumf: add new extended counter set for IBM z16 (Mete Durlu) [2047724]
- mptcp: add more offered MIBs counter (Paolo Abeni) [2089885]
- mptcp: never shrink offered window (Paolo Abeni) [2089885]
- tcp: allow MPTCP to update the announced window (Paolo Abeni) [2089885]
- mptcp: add mib for xmit window sharing (Paolo Abeni) [2089885]
- mptcp: really share subflow snd_wnd (Paolo Abeni) [2089885]
- KVM: s390: vsie/gmap: reduce gmap_rmap overhead (Thomas Huth) [2072041]
- KVM: s390x: fix SCK locking (Thomas Huth) [2072041]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Thomas Huth) [2072041]
- KVM: s390: Clarify SIGP orders versus STOP/RESTART (Thomas Huth) [2044299]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Thomas Huth) [2072041]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Thomas Huth) [2072041]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Thomas Huth) [2072041]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Thomas Huth) [2072041]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Thomas Huth) [2072041]
- KVM: s390: add debug statement for diag 318 CPNC data (Thomas Huth) [2072041]
- KVM: s390: pv: properly handle page flags for protected guests (Thomas Huth) [2072041]
- KVM: s390: Add a routine for setting userspace CPU state (Thomas Huth) [2044299]
- openvswitch: fix OOB access in reserve_sfa_size() (Antoine Tenart) [2082155]
- net: openvswitch: don't send internal clone attribute to the userspace. (Antoine Tenart) [2082155 2085881]
- openvswitch: Add recirc_id to recirc warning (Antoine Tenart) [2082155]
- openvswitch: Fixed nd target mask field in the flow dump. (Antoine Tenart) [2082155]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Antoine Tenart) [2082155]
- openvswitch: always update flow key after nat (Antoine Tenart) [2082155]
- net: openvswitch: Remove redundant if statements (Antoine Tenart) [2082155]

* Thu Jun 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-108.el9]
- net: add netif_set_real_num_queues() for device reconfig (Ivan Vecera) [2094002]
- spmi: spmi-pmic-arb: fix irq_set_type race condition (Steve Best) [2071751]
- spmi: mediatek: Add support for MT8195 (Steve Best) [2071751]
- spmi: mediatek: Add support for MT6873/8192 (Steve Best) [2071751]
- spmi: pmic-arb: Add sid and address to error messages (Steve Best) [2071751]
- bus: Make remove callback return void (Steve Best) [2071751]
- rpmsg: core: add API to get MTU (Steve Best) [2071771]
- RISC-V: configs: Configs that had RPMSG_CHAR now get RPMSG_CTRL (Steve Best) [2071771]
- rpmsg: ctrl: Introduce new RPMSG_CREATE/RELEASE_DEV_IOCTL controls (Steve Best) [2071771]
- rpmsg: char: Introduce the "rpmsg-raw" channel (Steve Best) [2071771]
- rpmsg: char: Add possibility to use default endpoint of the rpmsg device (Steve Best) [2071771]
- rpmsg: char: Refactor rpmsg_chrdev_eptdev_create function (Steve Best) [2071771]
- rpmsg: Update rpmsg_chrdev_register_device function (Steve Best) [2071771]
- rpmsg: Move the rpmsg control device from rpmsg_char to rpmsg_ctrl (Steve Best) [2071771]
- rpmsg: Create the rpmsg class in core instead of in rpmsg char (Steve Best) [2071771]
- rpmsg: char: Export eptdev create and destroy functions (Steve Best) [2071771]
- rpmsg: char: treat rpmsg_trysend() ENOMEM as EAGAIN (Steve Best) [2071771]
- rpmsg: qcom_smd: Fix redundant channel->registered assignment (Steve Best) [2071771]
- rpmsg: use struct_size over open coded arithmetic (Steve Best) [2071771]
- rpmsg: smd: allow opening rpm_requests even if already opened (Steve Best) [2071771]
- rpmsg: qcom_smd: Promote to arch_initcall (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_eptdev and cdev (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_ctrldev and cdev (Steve Best) [2071771]
- rpmsg: core: Clean up resources on announce_create failure. (Steve Best) [2071771]
- rpmsg: Fix documentation return formatting (Steve Best) [2071771]
- rpmsg: char: Add pr_fmt() to prefix messages (Steve Best) [2071771]
- rpmsg: glink: Send READ_NOTIFY command in FIFO full case (Steve Best) [2071771]
- rpmsg: glink: Remove channel decouple from rpdev release (Steve Best) [2071771]
- rpmsg: glink: Remove the rpmsg dev in close_ack (Steve Best) [2071771]
- rpmsg: glink: Add TX_DATA_CONT command while sending (Steve Best) [2071771]
- rpmsg: virtio_rpmsg_bus: use dev_warn_ratelimited for msg with no recipient (Steve Best) [2071771]
- rpmsg: virtio: Remove unused including <linux/of_device.h> (Steve Best) [2071771]
- rpmsg: char: Remove useless include (Steve Best) [2071771]
- rpmsg: Change naming of mediatek rpmsg property (Steve Best) [2071771]
- rpmsg: glink: Replace strncpy() with strscpy_pad() (Steve Best) [2071771]
- bus: Make remove callback return void (Steve Best) [2071771]
- interconnect: Restore sync state by ignoring ipa-virt in provider count (Steve Best) [2071778]
- interconnect: qcom: sdx55: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: sc7180: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: msm8939: Remove snoc_mm specific regmap (Steve Best) [2071778]
- interconnect: imx: Add imx_icc_get_bw function to set initial avg and peak (Steve Best) [2071778]
- interconnect: qcom: Add QCM2290 driver support (Steve Best) [2071778]
- interconnect: icc-rpm: Support child NoC device probe (Steve Best) [2071778]
- interconnect: icc-rpm: Add QNOC type QoS support (Steve Best) [2071778]
- interconnect: icc-rpm: Define ICC device type (Steve Best) [2071778]
- interconnect: qcom: Add SM8450 interconnect provider driver (Steve Best) [2071778]
- interconnect: qcom: rpm: Prevent integer overflow in rate (Steve Best) [2071778]
- interconnect: icc-rpm: Use NOC_QOS_MODE_INVALID for qos_mode check (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: qcom: Add MSM8996 interconnect provider driver (Steve Best) [2071778]
- interconnect: icc-rpm: Add support for bus power domain (Steve Best) [2071778]
- interconnect: qcom: Add EPSS L3 support on SC7280 (Steve Best) [2071778]
- interconnect: samsung: describe drivers in KConfig (Steve Best) [2071778]
- interconnect: qcom: drop DEFINE_QNODE macro (Steve Best) [2071778]
- interconnect: qcs404: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8939: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8939: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8916: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8916: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: add support for QoS reg offset (Steve Best) [2071778]
- interconnect: sdm660: merge common code into icc-rpm (Steve Best) [2071778]
- interconnect: sdm660: drop default/unused values (Steve Best) [2071778]
- interconnect: sdm660: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: move bus clocks handling into qnoc_probe (Steve Best) [2071778]
- interconnect: qcom: sdm660: Add missing a2noc qos clocks (Steve Best) [2071778]
- interconnect: qcom: sdm660: Correct NOC_QOS_PRIORITY shift and mask (Steve Best) [2071778]
- interconnect: qcom: sdm660: Fix id of slv_cnoc_mnoc_cfg (Steve Best) [2071778]
- Revert "interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate" (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Use driver-specific naming (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Add sc8180x support (Steve Best) [2071778]
- interconnect: qcom: Add SC8180x providers (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: Sanity check that node isn't already on list (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Consolidate probe functions (Steve Best) [2071778]
- regulator: Turn off kernel configs for regulators added by this patch set (Steve Best) [2071777]
- regulator: qcom_smd: fix for_each_child.cocci warnings (Steve Best) [2071777]
- regulator: rohm-generic: iniline stub function (Steve Best) [2071777]
- regulator: Add regulator_err2notif() helper (Steve Best) [2071777]
- regulator: fix bullet lists of regulator_ops comment (Steve Best) [2071777]
- regulator: Minor regulator documentation fixes. (Steve Best) [2071777]
- regulator: atc260x: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rtq2134: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rt4831: Add active_discharge_on to fix discharge API (Steve Best) [2071777]
- regulator: rt4831: Add bypass mask to fix set_bypass API work (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for SDX65 (Steve Best) [2071777]
- regulator: rt5190a: Add support for Richtek RT5190A PMIC (Steve Best) [2071777]
- regulator: cleanup comments (Steve Best) [2071777]
- regulator: virtual: add devicetree support (Steve Best) [2071777]
- regulator: virtual: warn against production use (Steve Best) [2071777]
- regulator: virtual: use dev_err_probe() (Steve Best) [2071777]
- regulator: da9121: Remove surplus DA9141 parameters (Steve Best) [2071777]
- regulator: da9121: Fix DA914x voltage value (Steve Best) [2071777]
- regulator: core: fix false positive in regulator_late_cleanup() (Steve Best) [2071777]
- regulator: MAX20086: add gpio/consumer.h (Steve Best) [2071777]
- regulator: max20086: fix error code in max20086_parse_regulators_dt() (Steve Best) [2071777]
- regulator: Add MAX20086-MAX20089 driver (Steve Best) [2071777]
- regulator: qcom_smd: Align probe function with rpmh-regulator (Steve Best) [2071777]
- regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-labibb: OCP interrupts are not a failure while disabled (Steve Best) [2071777]
- regulator: Introduce tps68470-regulator driver (Steve Best) [2071777]
- drivers/regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for PM8450 regulators (Steve Best) [2071777]
- regulator: da9121: Add DA914x support (Steve Best) [2071777]
- regulator: da9121: Prevent current limit change when enabled (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PMG1110 regulators (Steve Best) [2071777]
- regulator: qcom_spmi: Add pm8226 regulators (Steve Best) [2071777]
- regulator: irq_helper: Provide helper for trivial IRQ notifications (Steve Best) [2071777]
- regulator: bd718x7: Use rohm generic restricted voltage setting (Steve Best) [2071777]
- regulator: rohm-regulator: add helper for restricted voltage setting (Steve Best) [2071777]
- regulator: Don't error out fixed regulator in regulator_sync_voltage() (Steve Best) [2071777]
- regulator: tps80031: Remove driver (Steve Best) [2071777]
- regulator: Fix SY7636A breakage (Steve Best) [2071777]
- regulator: uniphier: Add USB-VBUS compatible string for NX1 SoC (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PM6350 regulators (Steve Best) [2071777]
- regulator: sy7636a: Remove requirement on sy7636a mfd (Steve Best) [2071777]
- regulator: tps62360: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: lp872x: Remove lp872x_dvs_state (Steve Best) [2071777]
- regulator: lp872x: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: s5m8767: do not use reset value as DVS voltage if GPIO DVS is disabled (Steve Best) [2071777]
- mfd: hi6421-spmi-pmic: Cleanup drvdata to only include regmap (Steve Best) [2071777]
- regulator: bd71815: Use defined mask values (Steve Best) [2071777]
- regulator: qcom_smd: Add PM2250 regulators (Steve Best) [2071777]
- regulator: Lower priority of logging when setting supply (Steve Best) [2071777]
- regulator: dummy: Use devm_regulator_register() (Steve Best) [2071777]
- regulator: pwm-regulator: Make use of the helper function dev_err_probe() (Steve Best) [2071777]
- regulator: fix typo in Kconfig and max8973-regulator (Steve Best) [2071777]
- regulator: max14577: Revert "regulator: max14577: Add proper module aliases strings" (Steve Best) [2071777]
- regulator: qcom-rpmh-regulator: fix pm8009-1 ldo7 resource name (Steve Best) [2071777]
- regulator: vctrl: Avoid lockdep warning in enable/disable ops (Steve Best) [2071777]
- regulator: vctrl: Use locked regulator_get_voltage in probe path (Steve Best) [2071777]
- regulator: Documentation fix for regulator error notification helper (Steve Best) [2071777]
- regulator: sy7636a: Use the regmap directly (Steve Best) [2071777]
- regulator: sy7636a: Store the epd-pwr-good GPIO locally (Steve Best) [2071777]
- regulator: sy7636a: Use the parent driver data (Steve Best) [2071777]
- regulator: sy7636a: Remove the poll_enable_time (Steve Best) [2071777]
- regulator: sy8827n: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: sy8824x: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: rtq2134: Fix coding style (Steve Best) [2071777]
- regulator: hi6421v600: rename voltage range arrays (Steve Best) [2071777]
- regulator: hi6421v600: use lowercase for ldo (Steve Best) [2071777]
- regulator: fixed: use dev_err_probe for register (Steve Best) [2071777]
- regulator: rtq2134: Add support for Richtek RTQ2134 SubPMIC (Steve Best) [2071777]
- regulator: Fix a couple of spelling mistakes in Kconfig (Steve Best) [2071777]
- regulator: rtq6752: fix reg reset behavior (Steve Best) [2071777]
- regulator: da9063: Add support for full-current mode. (Steve Best) [2071777]
- regulator: rt6245: make a const array func_base static, makes object smaller (Steve Best) [2071777]
- regulator: rtq6752: Fix the typo for reg define and author name (Steve Best) [2071777]
- regulator: Replace symbolic permissions with octal permissions (Steve Best) [2071777]
- regulator: rt6752: Add support for Richtek RTQ6752 (Steve Best) [2071777]
- regulator: rt5033: Use linear ranges to map all voltage selection (Steve Best) [2071777]
- regulator: tps65910: Silence deferred probe error (Steve Best) [2071777]
- regulator: mt6397: Remove modeset_shift from struct mt6397_regulator_info (Steve Best) [2071777]
- regulator: mt6359: Remove shift fields from struct mt6359_regulator_info (Steve Best) [2071777]
- regulator: mt6358: Remove shift fields from struct mt6358_regulator_info (Steve Best) [2071777]
- regulator: devres: unexport devm_regulator_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_bulk_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_unregister() function (Steve Best) [2071777]
- regulator: hi6421v600-regulator: add a missing dot at copyright (Steve Best) [2071777]
- scsi: scsi_dh_alua: Properly handle the ALUA transitioning state (Ewan D. Milne) [2085105]
- bnx2x: fix napi API usage sequence (Manish Chopra) [2080677]

* Wed Jun 08 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-107.el9]
- NFSv4: Fix free of uninitialized nfs4_label on referral lookup. (Benjamin Coddington) [2086367]
- sched/tracing: Append prev_state to tp args instead (Phil Auld) [2078906]
- sched/pelt: Fix attach_entity_load_avg() corner case (Phil Auld) [2078906]
- timers: Fix warning condition in __run_timers() (Phil Auld) [2078906]
- sched: Teach the forced-newidle balancer about CPU affinity limitation. (Phil Auld) [2078906]
- sched/core: Fix forceidle balancing (Phil Auld) [2078906]
- tick/sched: Fix non-kernel-doc comment (Phil Auld) [2078906]
- prlimit: do not grab the tasklist_lock (Phil Auld) [2078906]
- prlimit: make do_prlimit() static (Phil Auld) [2078906]
- timekeeping: Really make sure wall_to_monotonic isn't positive (Phil Auld) [2078906]
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation (Phil Auld) [2078906]
- posix-cpu-timers: Clear task::posix_cputimers_work in copy_process() (Phil Auld) [2078906]
- timers/nohz: Last resort update jiffies on nohz_full IRQ entry (Phil Auld) [2078906]
- vdpa: mlx5: synchronize driver status with CVQ (Laurent Vivier) [2059799]
- vdpa: mlx5: prevent cvq work from hogging CPU (Laurent Vivier) [2059799]
- vdpa/mlx5: Avoid processing works if workqueue was destroyed (Laurent Vivier) [2059799]
- selftests/bpf: Fix btf_dump test under new clang (Yauheni Kaliuta) [2090982]
- ahci: Add a generic 'controller2' RAID id (Tomas Henzl) [2078880]
- net/af_packet: make sure to pull mac header (Hangbin Liu) [2089566]
- net/af_packet: add VLAN support for AF_PACKET SOCK_RAW GSO (Hangbin Liu) [2089566]
- net: openvswitch: fix leak of nested actions (Eelco Chaudron) [2076588]

* Tue Jun 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-106.el9]
- mm, compaction: fast_find_migrateblock() should return pfn in the target zone (Rafael Aquini) [2092667]
- [s390] s390/net: sort out physical vs virtual pointers usage (Mete Durlu) [2044295]
- [s390] s390/qeth: remove check for packing mode in qeth_check_outbound_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: fine-tune .ndo_select_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: don't offer .ndo_bridge_* ops for OSA devices (Mete Durlu) [2044295]
- [s390] s390/qeth: split up L2 netdev_ops (Mete Durlu) [2044295]
- [s390] s390/qeth: simplify qeth_receive_skb() (Mete Durlu) [2044295]
- [s390] s390/lcs: add braces around empty function body (Mete Durlu) [2044295]
- [s390] s390/ctcm: add __printf format attribute to ctcm_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/ctcm: fix format string (Mete Durlu) [2044295]
- [s390] s390/qeth: allocate RX queue at probe time (Mete Durlu) [2044295]
- [s390] s390/qeth: update kerneldoc for qeth_add_hw_header() (Mete Durlu) [2044295]
- [s390] s390/qeth: fix kernel doc comments (Mete Durlu) [2044295]
- [s390] s390/qeth: add __printf format attribute to qeth_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/qeth: fix various format strings (Mete Durlu) [2044295]
- [s390] s390/qeth: don't keep track of Input Queue count (Mete Durlu) [2044295]
- [s390] s390/qeth: clarify remaining dev_kfree_skb_any() users (Mete Durlu) [2044295]
- [s390] s390/qeth: move qdio's QAOB cache into qeth (Mete Durlu) [2044295]
- [s390] s390/qeth: remove .do_ioctl() callback from driver discipline (Mete Durlu) [2044295]
- [s390] s390/qeth: improve trace entries for MAC address (un)registration (Mete Durlu) [2044295]
- [s390] s390/netiucv: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/lcs: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/ctcm: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up device_type management (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up QETH_PROT_* naming (Mete Durlu) [2044295]
- Documentation/sysctl: document max_rcu_stall_to_panic (Joel Savitz) [2063060]
- Documentation: add description for net.core.gro_normal_batch (Xin Long) [2068580]
- dmaengine: idxd: make idxd_wq_enable() return 0 if wq is already enabled (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Remove unnecessary synchronize_irq() before free_irq() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: add missing callback function to support DMA_INTERRUPT (Jerry Snitselaar) [2083415]
- dmaengine: idxd: skip irq free when wq type is not kernel (Jerry Snitselaar) [2083415]
- dmaengine: idxd: make idxd_register/unregister_dma_channel() static (Jerry Snitselaar) [2083415]
- dmaengine: idxd: remove redudant idxd_wq_disable_cleanup() call (Jerry Snitselaar) [2083415]
- dmaengine: idxd: free irq before wq type is reset (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix lockdep warning on device driver removal (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2083415]
- dmaengine: idxd: refactor wq driver enable/disable operations (Jerry Snitselaar) [2083415]
- dmaengine: idxd: move wq irq enabling to after device enable (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set max_xfer and max_batch for RO device (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Fix the error handling path in idxd_cdev_register() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set DMA_INTERRUPT cap bit (Jerry Snitselaar) [2083415]
- dmaengine: add verification of DMA_INTERRUPT capability for dmatest (Jerry Snitselaar) [2083415]
- Dmaengine: idxd: remove trailing white space on input str for wq name (Jerry Snitselaar) [2083415]
- dmaengine: idxd: don't load pasid config until needed (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix retry value to be constant for duration of function call (Jerry Snitselaar) [2075706]
- dmaengine: idxd: match type for retries var in idxd_enqcmds() (Jerry Snitselaar) [2075706]
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (Scott Mayhew) [2059729]
- NFSv4: nfs_atomic_open() can race when looking up a non-regular file (Scott Mayhew) [2059729]
- NFSv4: Handle case where the lookup of a directory fails (Scott Mayhew) [2059729]
- net: phy: Kconfig: micrel_phy: fix dependency issue (Hangbin Liu) [2066451]
- ptp: add getcrosststamp() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: add gettimex64() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: increase maximum adjustment of virtual clocks. (Hangbin Liu) [2066451]
- ptp: unregister virtual clocks when unregistering physical clock. (Hangbin Liu) [2066451]
- net: fix sock_timestamping_bind_phc() to release device (Hangbin Liu) [2066451]
- net: fix SOF_TIMESTAMPING_BIND_PHC to work with multiple sockets (Hangbin Liu) [2066451]
- ptp: fix code indentation issues (Hangbin Liu) [2066451]
- ptp: free 'vclock_index' in ptp_clock_release() (Hangbin Liu) [2066451]
- ptp: Fix possible memory leak in ptp_clock_register() (Hangbin Liu) [2066451]
- ptp: fix error print of ptp_kvm on X86_64 platform (Hangbin Liu) [2066451]
- ptp: Fix ptp_kvm_getcrosststamp issue for x86 ptp_kvm (Hangbin Liu) [2066451]
- ethernet: fix PTP_1588_CLOCK dependencies (Hangbin Liu) [2066451]
- drivers/char: fix unused variable warning in mem.c (Joel Savitz) [2081150]
- clk: qcom: rpmhcc: add sc8280xp support to the RPMh clock controller (Adrien Thierry) [2078618]
- dt-bindings: clock: Add sc8280xp to the RPMh clock controller binding (Adrien Thierry) [2078618]

* Fri Jun 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-105.el9]
- NFSv4.2: Fix up an invalid combination of memory allocation flags (Benjamin Coddington) [2089076]
- Documentation/sysctl: document page_lock_unfairness (Joel Savitz) [2063044]
- iommu/virtio: Fix typo in a comment (Eric Auger) [2083111]
- iommu/virtio: Support identity-mapped domains (Eric Auger) [2083111]
- iommu/virtio: Pass end address to viommu_add_mapping() (Eric Auger) [2083111]
- iommu/virtio: Sort reserved regions (Eric Auger) [2083111]
- iommu/virtio: Support bypass domains (Eric Auger) [2083111]
- iommu/virtio: Add definitions for VIRTIO_IOMMU_F_BYPASS_CONFIG (Eric Auger) [2083111]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (David Arcari) [2040020 2040060]
- skbuff: fix coalescing for page_pool fragment recycling (Jiri Benc) [2071618]
- af_unix: fix regression in read after shutdown (Jiri Benc) [2071618]
- tcp_bpf: Fix one concurrency problem in the tcp_bpf_send_verdict function (Jiri Benc) [2071618]
- af_unix: Rename UNIX-DGRAM to UNIX to maintain backwards compatability (Jiri Benc) [2071618]
- selftests/bpf: Use recv_timeout() instead of retries (Jiri Benc) [2071618]
- net: Implement ->sock_is_readable() for UDP and AF_UNIX (Jiri Benc) [2071618]
- skmsg: Extract and reuse sk_msg_is_readable() (Jiri Benc) [2071618]
- net: Rename ->stream_memory_read to ->sock_is_readable (Jiri Benc) [2071618]
- unix: Fix an issue in unix_shutdown causing the other end read/write failures (Jiri Benc) [2071618]
- bpf, test, cgroup: Use sk_{alloc,free} for test cases (Jiri Benc) [2071618]
- bpf, cgroup: Assign cgroup in cgroup_sk_alloc when called from interrupt (Jiri Benc) [2071618]
- bpf, selftests: Add test case for mixed cgroup v1/v2 (Jiri Benc) [2071618]
- bpf, selftests: Add cgroup v1 net_cls classid helpers (Jiri Benc) [2071618]
- bpf, cgroups: Fix cgroup v2 fallback on v1/v2 mixed mode (Jiri Benc) [2071618]
- af_unix: fix potential NULL deref in unix_dgram_connect() (Jiri Benc) [2071618]
- page_pool: use relaxed atomic for release side accounting (Jiri Benc) [2071618]
- af_unix: Fix NULL pointer bug in unix_shutdown (Jiri Benc) [2071618]
- selftests/bpf: Reduce more flakyness in sockmap_listen (Jiri Benc) [2071618]
- selftests/bpf: Adding delay in socketmap_listen to reduce flakyness (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SK_MSG (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SOCK_OPS (Jiri Benc) [2071618]
- selftest/bpf: Add new tests in sockmap for unix stream to tcp. (Jiri Benc) [2071618]
- selftest/bpf: Change udp to inet in some function names (Jiri Benc) [2071618]
- selftest/bpf: Add tests for sockmap with unix stream type. (Jiri Benc) [2071618]
- af_unix: Add unix_stream_proto for sockmap (Jiri Benc) [2071618]
- af_unix: Add read_sock for stream socket types (Jiri Benc) [2071618]
- selftest/bpf: Implement sample UNIX domain socket iterator program. (Jiri Benc) [2071618]
- bpf: af_unix: Implement BPF iterator for UNIX domain socket. (Jiri Benc) [2071618]
- net: in_irq() cleanup (Jiri Benc) [2071618]
- page_pool: add frag page recycling support in page pool (Jiri Benc) [2071618]
- page_pool: add interface to manipulate frag count in page pool (Jiri Benc) [2071618]
- page_pool: keep pp info as long as page pool owns the page (Jiri Benc) [2071618]
- bpf, unix: Check socket type in unix_bpf_update_proto() (Jiri Benc) [2071618]
- selftests/bpf: Test XDP bonding nest and unwind (Jiri Benc) [2071618]
- bonding: Fix negative jump label count on nested bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix running of XDP bonding tests (Jiri Benc) [2071618]
- net, bonding: Disallow vlan+srcmac with XDP (Jiri Benc) [2071618]
- selftests/bpf: Add tests for XDP bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix xdp_tx.c prog section name (Jiri Benc) [2071618]
- net, core: Allow netdev_lower_get_next_private_rcu in bh context (Jiri Benc) [2071618]
- bpf, devmap: Exclude XDP broadcast to master device (Jiri Benc) [2071618]
- net, bonding: Add XDP support to the bonding driver (Jiri Benc) [2071618]
- net, core: Add support for XDP redirection to slave device (Jiri Benc) [2071618]
- bpf: selftests: Add dctcp fallback test (Jiri Benc) [2071618]
- bpf: selftests: Add connect_to_fd_opts to network_helpers (Jiri Benc) [2071618]
- bpf: selftests: Add sk_state to bpf_tcp_helpers.h (Jiri Benc) [2071618]
- bpf: tcp: Allow bpf-tcp-cc to call bpf_(get|set)sockopt (Jiri Benc) [2071618]
- selftests/bpf: Add tests for {set|get} socket option from setsockopt BPF (Jiri Benc) [2071618]
- bpf: Add support for {set|get} socket options from setsockopt BPF (Jiri Benc) [2071618]
- bpf: selftest: Test batching and bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Support bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Bpf iter batching and lock_sock (Jiri Benc) [2071618]
- tcp: seq_file: Replace listening_hash with lhash2 (Jiri Benc) [2071618]
- tcp: seq_file: Add listening_get_first() (Jiri Benc) [2071618]
- bpf: tcp: seq_file: Remove bpf_seq_afinfo from tcp_iter_state (Jiri Benc) [2071618]
- flow_dissector: Fix out-of-bounds warnings (Jiri Benc) [2071618]
- unix_bpf: Fix a potential deadlock in unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- netdevsim: Add multi-queue support (Jiri Benc) [2071618]
- selftests/bpf: Add test cases for redirection between udp and unix (Jiri Benc) [2071618]
- selftests/bpf: Add a test case for unix sockmap (Jiri Benc) [2071618]
- selftests/bpf: Factor out add_to_sockmap() (Jiri Benc) [2071618]
- selftests/bpf: Factor out udp_socketpair() (Jiri Benc) [2071618]
- af_unix: Implement unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- af_unix: Implement ->psock_update_sk_prot() (Jiri Benc) [2071618]
- af_unix: Add a dummy ->close() for sockmap (Jiri Benc) [2071618]
- af_unix: Set TCP_ESTABLISHED for datagram sockets too (Jiri Benc) [2071618]
- af_unix: Implement ->read_sock() for sockmap (Jiri Benc) [2071618]
- sock_map: Lift socket state restriction for datagram sockets (Jiri Benc) [2071618]
- sock_map: Relax config dependency to CONFIG_NET (Jiri Benc) [2071618]
- thermal: Replace acpi_bus_get_device() (David Arcari) [2064829]
- ACPI: scan: Introduce acpi_fetch_acpi_dev() (David Arcari) [2064829]
- ACPI: DPTF: Support Raptor Lake (David Arcari) [2064829]
- thermal: int340x: Update OS policy capability handshake (David Arcari) [2064829]
- thermal: int340x: Increase bitmap size (David Arcari) [2064829]
- thermal: int340x: fix memory leak in int3400_notify() (David Arcari) [2064829]
- thermal: int340x: Check for NULL after calling kmemdup() (David Arcari) [2064829]
- thermal: int340x: Add Raptor Lake PCI device id (David Arcari) [2064829]
- thermal: int340x: Support Raptor Lake (David Arcari) [2064829]
- thermal/drivers/int340x: Fix RFIM mailbox write commands (David Arcari) [2064829]
- Bluetooth: hci_sync: Fix not processing all entries on cmd_sync_work (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix unbalanced unlock in set_device_flags() (Gopal Tiwari) [2066188]
- Bluetooth: Fix bt_skb_sendmmsg not allocating partial chunks (Gopal Tiwari) [2066188]
- Bluetooth: Fix not checking MGMT cmd pending queue (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not using conn_timeout (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix hci_update_accept_list_sync (Gopal Tiwari) [2066188]
- Bluetooth: fix data races in smp_unregister(), smp_del_chan() (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix leaking sent_cmd skb (Gopal Tiwari) [2066188]
- Bluetooth: assign len after null check (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: fix endian bug in hci_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: uninitialized variables in l2cap_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: btqca: sequential validation (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn QCA 0xe0d0 (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix broken LED quirk for legacy ROM devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Rework hci_inquiry_result_with_rssi_evt (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for MacBook Air 8,1 and 8,2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Fix NULL vs IS_ERR_OR_NULL check in qca_serdev_probe (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Check for error irq (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix spelling mistake "simultanous" -> "simultaneous" (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Set HCI_QUIRK_VALID_LE_STATES (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add support for waiting specific LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix LE simultaneous roles UUID if not supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Wait for proper events when connecting LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add check simultaneous roles support (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add hci_le_create_conn_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use skb_pull_data when processing inquiry results (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Push sync command cancellation to workqueue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn MT7922A (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add missing quirks and msft ext for legacy bootloader (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add two more Bluetooth parts for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix using wrong mode (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not always pausing advertising when necessary (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_CONNECTED (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_FOUND (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Return error code when getting patch status failed (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Introduce mgmt_alloc_skb and mgmt_send_event_skb (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Handle download_firmware failure cases (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: add quirk disabling LE Read Transmit Power (Gopal Tiwari) [2066188]
- Bluetooth: msft: Fix compilation when CONFIG_BT_MSFTEXT is not set (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Set Privacy Mode when updating the resolving list (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for some Macs with the T2 Security chip (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for queuing during polling interval (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Use hci_dev_test_and_{set,clear}_flag (Gopal Tiwari) [2066188]
- Bluetooth: Introduce HCI_CONN_FLAG_DEVICE_PRIVACY device flag (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Rework hci_conn_params flags (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable AOSP extension for MT7921 (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable msft opcode (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Status (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Complete (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Direct Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle HCI events (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Extended Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result with RSSI event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Number of Complete Packets event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Ext Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Metaevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Command Complete event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse BR/EDR events (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: fix resume failure (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: handle runtime pm only when sdio_func is available (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Cancel sync commands for certain URB errors (Gopal Tiwari) [2066188]
- Bluetooth: Add hci_cmd_sync_cancel to public API (Gopal Tiwari) [2066188]
- Bluetooth: Reset more state when cancelling a sync command (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Cancel sync command if sending a frame failed (Gopal Tiwari) [2066188]
- Bluetooth: Send device found event on name resolve failure (Gopal Tiwari) [2066188]
- Bluetooth: Limit duration of Remote Name Resolve (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_delete_stored_link_key (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_read_stored_link_key (Gopal Tiwari) [2066188]
- tty: remove file from tty_ldisc_ops::ioctl and compat_ioctl (Gopal Tiwari) [2066188]
- Bluetooth: refactor malicious adv data check (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: drop the unnecessary variable created (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add support of processing firmware coredump and log (Gopal Tiwari) [2066188]
- Bluetooth: btusb: enable Mediatek to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Attempt to clear HCI_LE_ADV on adv set terminated error event (Gopal Tiwari) [2066188]
- Bluetooth: Ignore HCI_ERROR_CANCELLED_BY_HOST on adv set terminated event (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_CONNECTABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_request: Remove bg_scan_update work (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_DISCOVERABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_main: repair a non-kernel-doc comment (Gopal Tiwari) [2066188]
- Bluetooth: Don't initialize msft/aosp when using user channel (Gopal Tiwari) [2066188]
- Bluetooth: fix uninitialized variables notify_evt (Gopal Tiwari) [2066188]
- Bluetooth: stop proccessing malicious adv data (Gopal Tiwari) [2066188]
- Bluetooth: hci_h4: Fix padding calculation error within h4_recv_buf() (Gopal Tiwari) [2066188]
- Bluetooth: aosp: Support AOSP Bluetooth Quality Report (Gopal Tiwari) [2066188]
- Bluetooth: Add struct of reading AOSP vendor capabilities (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not setting adv set duration (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix missing static warnings (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework hci_suspend_notifier (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework init stages (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SSP (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert adv_expire (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_ADVERTISING (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_PHY_CONFIGURATION (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LOCAL_NAME (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_START_DISCOVERY (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CLOCK_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_SECURE_CONN (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CONN_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable synch'd set_bredr (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_FAST_CONNECTABLE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework background scan (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_SET_POWERED (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable advertising when LL privacy is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 3 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 1 (Gopal Tiwari) [2066188]
- Bluetooth: Add helper for serialized HCI command execution (Gopal Tiwari) [2066188]
- Bluetooth: Fix removing adv when processing cmd complete (Gopal Tiwari) [2066188]
- bluetooth: use dev_addr_set() (Gopal Tiwari) [2066188]
- bluetooth: use eth_hw_addr_set() (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add MT7921s Bluetooth support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: update register CSDIOCSR operation (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: transmit packet according to status TX_EMPTY (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: use register CRPLR to read packet length (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: move interrupt service to work (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: explicitly set WHISR as write-1-clear (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add .set_bdaddr support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksido: rely on BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: mediatek: add BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Remove duplicated entry in OF table (Gopal Tiwari) [2066188]
- Bluetooth: bfusb: fix division by zero in send path (Gopal Tiwari) [2066188]
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets() fails (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Fix checking of msft_opcode (Gopal Tiwari) [2066188]
- Bluetooth: btsdio: Do not bind to non-removable BCM4345 and BCM43455 (Gopal Tiwari) [2066188]
- Bluetooth: virtio_bt: fix memory leak in virtbt_rx_handle() (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Add support for setting msft_opcode and aosp_capable (Gopal Tiwari) [2066188]
- Bluetooth: btusb: fix memory leak in btusb_mtk_submit_wmt_recv_urb() (Gopal Tiwari) [2066188]
- Bluetooth: Fix memory leak of hci device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix bdaddress comparison with garbage value (Gopal Tiwari) [2066188]
- Bluetooth: Fix debugfs entry leak in hci_register_dev() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix application of sizeof to pointer (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix not initializing sk_peer_pid (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: purge socket queues in the destruct() callback (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix Experimental Feature Changed event (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix to set the force_wakeup value (Gopal Tiwari) [2066188]
- Bluetooth: Read codec capabilities only if supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix calling hci_{suspend,resume}_dev (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of SUSPEND_DISCONNECTING (Gopal Tiwari) [2066188]
- Bluetooth: Rename driver .prevent_wake to .wakeup (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Ask ic_info to drop firmware (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for TP-Link UB500 Adapter (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Add support for MSFT extension to rtl8821c devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_prevent_wake entry (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_suspend entry (Gopal Tiwari) [2066188]
- Bluetooth: Make use of hci_{suspend,resume}_dev on suspend notifier (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: remove superfluous header files from btrsi.c (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set VsMsftOpCode based on device table (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for quality reports (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for codec offload (Gopal Tiwari) [2066188]
- Bbluetooth: btusb: Add another Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: enable Realtek 8822C/8852A to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: enable Qualcomm WCN399x for AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Fix wrong opcode when LL privacy enabled (Gopal Tiwari) [2066188]
- Bluetooth: Fix Advertisement Monitor Suspend/Resume (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: directly return hci_uart_register_device() ret-val (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Fix (runtime)suspend issues on RTL8723BS HCIs (Gopal Tiwari) [2066188]
- tty: remove file from tty_mode_ioctl (Gopal Tiwari) [2066188]
- tty: remove file from n_tty_ioctl_helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Move all debugfs handling to hci_debugfs.c (Gopal Tiwari) [2066188]
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_ldisc: require CAP_NET_ADMIN to attach N_HCI ldisc (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add gpio reset way for qca btsoc in cmd_timeout (Gopal Tiwari) [2066188]
- Bluetooth: Fix passing NULL to PTR_ERR (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Add support for BT_{SND,RCV}BUF (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Fix sco_send_frame returning skb->len (Gopal Tiwari) [2066188]
- Bluetooth: eir: Move EIR/Adv Data functions to its own file (Gopal Tiwari) [2066188]
- Bluetooth: RFCOMM: Replace use of memcpy_from_msg with bt_skb_sendmmsg (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: hci_uart: fix GPF in h5_recv (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix incorrect out of memory check (Gopal Tiwari) [2066188]
- Bluetooth: Keep MSFT ext info throughout a hci_dev's life cycle (Gopal Tiwari) [2066188]
- Bluetooth: Allow usb to auto-suspend when SCO use non-HCI transport (Gopal Tiwari) [2066188]
- Bluetooth: Add offload feature under experimental flag (Gopal Tiwari) [2066188]
- Bluetooth: Add support for Read Local Supported Codecs V2 (Gopal Tiwari) [2066188]
- Bluetooth: Configure codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add support for offload codecs over SCO (Gopal Tiwari) [2066188]
- Bluetooth: Add support for msbc coding format (Gopal Tiwari) [2066188]
- Bluetooth: Add support for HCI_Enhanced_Setup_Synchronous_Connection command (Gopal Tiwari) [2066188]
- Bluetooth: Allow setting of codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: Enumerate local supported codec and cache details (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define a callback to fetch codec config data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define callback to fetch data_path_id (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read supported offload use cases (Gopal Tiwari) [2066188]
- Bluetooth: Allow querying of supported offload codecs over SCO socket (Gopal Tiwari) [2066188]
- Bluetooth: call sock_hold earlier in sco_conn_del (Gopal Tiwari) [2066188]
- Bluetooth: fix init and cleanup of sco_conn.timeout_work (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add the new support ID for Realtek RTL8852A (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support public address configuration for MediaTek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add protocol for MediaTek bluetooth devices(MT7922) (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read boot address irrespective of controller mode (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix boot address (Gopal Tiwari) [2066188]
- Bluetooth: Fix using RPA when address has been resolved (Gopal Tiwari) [2066188]
- Bluetooth: Fix using address type from events (Gopal Tiwari) [2066188]
- Bluetooth: Fix enabling advertising for central role (Gopal Tiwari) [2066188]
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg() (Gopal Tiwari) [2066188]
- Bluetooth: set quality report callback for Intel (Gopal Tiwari) [2066188]
- Bluetooth: Support the quality report events (Gopal Tiwari) [2066188]
- Bluetooth: refactor set_exp_feature with a feature table (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Disallow legacy MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: btintel: support link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: reorganize functions from hci_sock_sendmsg() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: disable Intel link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: Fix return value in hci_dev_do_close() (Gopal Tiwari) [2066188]
- Bluetooth: add timeout sanity check to hci_inquiry (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Remove WAKEUP_DISABLE and add WAKEUP_AUTOSUSPEND for Realtek devices (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Pessimize compile-time bounds-check (Gopal Tiwari) [2066188]
- Bluetooth: Fix race condition in handling NOP command (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: add patch ram for bluetooth (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of LE Enhanced Connection Complete (Gopal Tiwari) [2066188]
- Bluetooth: Store advertising handle so it can be re-enabled (Gopal Tiwari) [2066188]
- Bluetooth: Move shutdown callback before flushing tx and rx queue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: check conditions before enabling USB ALT 3 for WBS (Gopal Tiwari) [2066188]
- Bluetooth: fix repeated calls to sco_sock_kill (Gopal Tiwari) [2066188]
- Bluetooth: schedule SCO timeouts with delayed_work (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in RFCOMM (Gopal Tiwari) [2066188]
- Bluetooth: avoid circular locks in sco_sock_connect (Gopal Tiwari) [2066188]
- Bluetooth: serialize calls to sco_sock_{set,clear}_timer (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in SCO (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix fall-through warnings (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the legacy bootloader returns tlv based version (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Combine setting up MSFT extension (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Move hci quirks to setup routine (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Clean the exported function to static (Gopal Tiwari) [2066188]
- Bluetooth: Add support hdev to allocate private data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for bootloader devices (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined set_diag functions (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the LED is not turning off immediately (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the first HCI command not work with ROM device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add btintel data struct (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for legacy ROM sku (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined setup and shutdown functions (Gopal Tiwari) [2066188]
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential buffer overflow (Gopal Tiwari) [2066188]
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support Bluetooth Reset for Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Record debug log for Mediatek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Fix kernel doc comments (Gopal Tiwari) [2066188]
- Bluetooth: Fix not generating RPA when required (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Add proper tracking for enable status of adv instances (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Mediatek Chip (MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Make the CSR clone chip force-suspend workaround more generic (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Intel next generation controllers (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for WCN6855 controller (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Load Broadcom firmware for Dell device 413c:8197 (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_sdio: Remove all strcpy() uses (Gopal Tiwari) [2066188]
- Bluetooth: skip invalid hci_sync_conn_complete_evt (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv cmd (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add valid le states quirk (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Add runtime suspend (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: btrtl: Maintain flow control if wakeup is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: add WAKEUP_DISABLE flag (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: use non-kernel-doc comment for copyright (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set MSFT opcode for RTL8852 (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for LG LGSBWAC92/TWCM-K505D (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix a unspported condition to set available debug features (Gopal Tiwari) [2066188]
- Bluetooth: sco: prevent information leak in sco_conn_defer_accept() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Disable the hci_suspend_notifier for btrtl devices (Gopal Tiwari) [2066188]
- Bluetooth: Bluetooth: defer cleanup of resources in hci_unregister_dev() (Gopal Tiwari) [2066188]

* Thu Jun 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-104.el9]
- bonding: fix missed rcu protection (Jonathan Toppins) [2089774]
- bonding: do not discard lowest hash bit for non layer3+4 hashing (Jonathan Toppins) [2089774]
- bonding: helper macro __ATTR_RO to make code more clear (Jonathan Toppins) [2089774]
- bonding: add new option ns_ip6_target (Jonathan Toppins) [1951971]
- bonding: add new parameter ns_targets (Jonathan Toppins) [1951971]
- bonding: add extra field for bond_opt_value (Jonathan Toppins) [1951971]
- Bonding: split bond_handle_vlan from bond_arp_send (Jonathan Toppins) [1951971]
- bonding: force carrier update when releasing slave (Jonathan Toppins) [2089774]
- bonding: fix data-races around agg_select_timer (Jonathan Toppins) [2089774]
- bonding: switch bond_net_exit() to batch mode (Jonathan Toppins) [2089774]
- bonding: pair enable_port with slave_arr_updates (Jonathan Toppins) [2089774]
- net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode (Jonathan Toppins) [2089774]
- bonding: use rcu_dereference_rtnl when get bonding active slave (Jonathan Toppins) [2089774]
- net: bonding: fix bond_xmit_broadcast return value error bug (Jonathan Toppins) [2089774]
- Bonding: return HWTSTAMP_FLAG_BONDED_PHC_INDEX to notify user space (Jonathan Toppins) [2019670]
- Bonding: force user to add HWTSTAMP_FLAG_BONDED_PHC_INDEX when get/set HWTSTAMP (Jonathan Toppins) [2019670]
- bond: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to active device (Jonathan Toppins) [2019670]
- net: bonding: debug: avoid printing debug logs when bond is not notifying peers (Jonathan Toppins) [2089774]
- net: remove bond_slave_has_mac_rcu() (Jonathan Toppins) [2089774]
- Bonding: add arp_missed_max option (Jonathan Toppins) [1952053]
- net: bonding: constify and use dev_addr_set() (Jonathan Toppins) [2089774]
- bonding: remove extraneous definitions from bonding.h (Jonathan Toppins) [2089774]
- redhat: enable CONFIG_NET_ACT_CTINFO (as a module) (Davide Caratti) [2027894]
- selftests: mptcp: add subflow limits test-cases (Paolo Abeni) [2076832]
- mptcp: fix subflow accounting on close (Paolo Abeni) [2076832]
- scsi: qedi: Remove redundant flush_workqueue() calls (Nilesh Javali) [2046624]
- scsi: qedi: Fix SYSFS_FLAG_FW_SEL_BOOT formatting (Nilesh Javali) [2046624]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Nilesh Javali) [2046624]
- scsi: qedi: Remove set but unused 'page' variable (Nilesh Javali) [2046624]
- scsi: qedi: Fix error codes in qedi_alloc_global_queues() (Nilesh Javali) [2046624]
- scsi: qedi: Add support for fastpath doorbell recovery (Nilesh Javali) [2046624]

* Wed Jun 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-103.el9]
- ipc/mqueue: use get_tree_nodev() in mqueue_get_tree() (Waiman Long) [1924181]
- selftests/powerpc/pmu: Add interface test for mmcra register fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr3_src fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_fcs_fch fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_l2l3 field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr1_comb field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmc56 using pmc5 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_fc56 field using pmc1 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmcjce field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmccext bit (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_cc56run field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0 exception bits (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr3 and mmcra fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr0/mmcr1 fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to extract mmcr fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add event_init_sampling function (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add utility functions to post process the mmap buffer (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to parse event codes (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add support for perf sampling tests (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Include mmap_buffer field as part of struct event (Desnes A. Nunes do Rosario) [2071110]
- xfs: return errors in xfs_fs_sync_fs (Andrey Albershteyn) [2087995]
- vfs: make sync_filesystem return errors from ->sync_fs (Andrey Albershteyn) [2087995]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (David Arcari) [2042590]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (David Arcari) [2042590]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (David Arcari) [2042590]
- Watchdog: sp5100_tco: Move timer initialization into function (David Arcari) [2042590]
- i2c: piix4: Enable EFCH MMIO for Family 17h+ (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support for SMBus port select (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to SMBus base address detect (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to region request and release (David Arcari) [2042590]
- i2c: piix4: Move SMBus port selection into function (David Arcari) [2042590]
- i2c: piix4: Move SMBus controller base address detect into function (David Arcari) [2042590]
- i2c: piix4: Move port I/O region request/release code into functions (David Arcari) [2042590]
- i2c: piix4: Replace hardcoded memory map size with a #define (David Arcari) [2042590]
- kernel/resource: Introduce request_mem_region_muxed() (David Arcari) [2042590]
- [s390] RDMA/mlx5: Fix number of allocated XLT entries (Mete Durlu) [2088360]
- treewide: Replace zero-length arrays with flexible-array members (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.68.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update the copyright year (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update MPI3 headers (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix formatting problems in some kernel-doc comments (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix some spelling mistakes (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.61.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add io_uring interface support in I/O-polled mode (Tomas Henzl) [2049670]
- scsi: mpi3mr: Print cable mngnt and temp threshold events (Tomas Henzl) [2049670]
- scsi: mpi3mr: Support Prepare for Reset event (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add Event acknowledgment logic (Tomas Henzl) [2049670]
- scsi: mpi3mr: Gracefully handle online FW update operation (Tomas Henzl) [2049670]
- scsi: mpi3mr: Detect async reset that occurred in firmware (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add IOC reinit function (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle offline FW activation in graceful manner (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part2 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part1 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fault IOC when internal command gets timeout (Tomas Henzl) [2049670]
- scsi: mpi3mr: Display IOC firmware package version (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle unaligned PLL in unmap cmnds (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add support for PCIe Managed Switch SES device (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix duplicate device entries when scanning through sysfs (Tomas Henzl) [2049670]
- [s390] s390/cio: verify the driver availability for path_event call (Mete Durlu) [2058622]
- [s390] s390/hypfs: include z/VM guests with access control group set (Mete Durlu) [2058616]
- scsi: mpt3sas: Fix junk chars displayed while printing ChipName (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use cached ATA Information VPD page (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix adapter replyPostRegisterIndex declaration (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix event callback log_code value handling (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix ioc->base_readl() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix writel() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix _ctl_set_task_mid() TaskMID check (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fail reset operation if config request timed out (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix use after free in _scsih_expander_node_remove() (Tomas Henzl) [2049634]
- scsi: mpt3sas: Page fault in reply q processing (Tomas Henzl) [2049634]
- scsi: mpt3sas: Convert to flexible arrays (Tomas Henzl) [2049634]
- scsi: mpt3sas: Update persistent trigger pages from sysfs interface (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049634]
- [s390] s390/tape: fix timer initialization in tape_std_assign() (Mete Durlu) [2085419]
- powerpc/pseries/vas: Use QoS credits from the userspace (Steve Best) [2075175]
- tracing/osnoise: Force quiescent states while tracing (Jerome Marchand) [2069708]
- tracing/osnoise: Do not unregister events twice (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_main to sleep for microseconds (Jerome Marchand) [2069708]
- tracing/osnoise: Properly unhook events if start_per_cpu_kthreads() fails (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_instances static (Jerome Marchand) [2069708]
- tracing/osnoise: Remove PREEMPT_RT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Remove STACKTRACE ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Allow multiple instances of the same tracer (Jerome Marchand) [2069708]
- tracing/osnoise: Remove TIMERLAT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Support a list of trace_array *tr (Jerome Marchand) [2069708]
- tracing/osnoise: Use start/stop_per_cpu_kthreads() on osnoise_cpus_write() (Jerome Marchand) [2069708]
- tracing/osnoise: Split workload start from the tracer start (Jerome Marchand) [2069708]
- tracing/osnoise: Improve comments about barrier need for NMI callbacks (Jerome Marchand) [2069708]
- tracing/osnoise: Do not follow tracing_cpumask (Jerome Marchand) [2069708]
- trace/timerlat: Add migrate-disabled field to the timerlat header (Jerome Marchand) [2069708]
- trace/osnoise: Add migrate-disabled field to the osnoise header (Jerome Marchand) [2069708]
- tracing/doc: Fix typos on the timerlat tracer documentation (Jerome Marchand) [2069708]
- trace/osnoise: Fix an ifdef comment (Jerome Marchand) [2069708]
- tracing: Disable "other" permission bits in the tracefs files (Jerome Marchand) [2069708]
- tracing/osnoise: Fix missed cpus_read_unlock() in start_per_cpu_kthreads() (Jerome Marchand) [2069708]
- dlm: fix plock invalid read (Alexander Aring) [2053070]
- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT (Paolo Abeni) [2079411]
- tcp: ensure to use the most recently sent skb when filling the rate sample (Paolo Abeni) [2079411]
- tcp: make sure treq->af_specific is initialized (Paolo Abeni) [2079411]
- tcp: md5: incorrect tcp_header_len for incoming connections (Paolo Abeni) [2079411]
- inet: fully convert sk->sk_rx_dst to RCU rules (Paolo Abeni) [2079411]

* Mon May 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-102.el9]
- thunderx nic: mark device as unmaintained (Íñigo Huguet) [2060285]
- livepatch: Fix missing unlock on error in klp_enable_patch() (C. Erastus Toe) [2069362]
- livepatch: Fix kobject refcount bug on klp_init_patch_early failure path (C. Erastus Toe) [2069362]
- Documentation: livepatch: Add livepatch API page (C. Erastus Toe) [2069362]
- xfs: Fix the free logic of state in xfs_attr_node_hasname (Carlos Maiolino) [2037525]
- perf tests: Fix coresight `perf test` failure. (Michael Petlan) [2069073]
- perf unwind: Don't show unwind error messages when augmenting frame pointer stack (Michael Petlan) [2069073]
- perf test arm64: Test unwinding using fame-pointer (fp) mode (Michael Petlan) [2069073]
- perf parse-events: Move slots only with topdown (Michael Petlan) [2069073]
- libperf tests: Fix typo in perf_evlist__open() failure error messages (Michael Petlan) [2069073]
- arm64: perf: Don't register user access sysctl handler multiple times (Michael Petlan) [2069073]
- perf/x86/intel: Update the FRONTEND MSR mask on Sapphire Rapids (Michael Petlan) [2069073]
- perf/x86/intel: Don't extend the pseudo-encoding to GP counters (Michael Petlan) [2069073]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069073]
- perf parse-events: Ignore case in topdown.slots check (Michael Petlan) [2069073]
- perf evlist: Avoid iteration for empty evlist. (Michael Petlan) [2069073]
- perf parse: Fix event parser error for hybrid systems (Michael Petlan) [2069073]
- perf bench: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf parse-events: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf script: Fix error when printing 'weight' field (Michael Petlan) [2069073]
- perf data: Fix double free in perf_session__delete() (Michael Petlan) [2069073]
- perf evlist: Fix failed to use cpu list for uncore events (Michael Petlan) [2069073]
- perf test: Skip failing sigtrap test for arm+aarch64 (Michael Petlan) [2069073]
- perf bpf: Defer freeing string after possible strlen() on it (Michael Petlan) [2069073]
- perf test: Fix arm64 perf_event_attr tests wrt --call-graph initialization (Michael Petlan) [2069073]
- libsubcmd: Fix use-after-free for realloc(..., 0) (Michael Petlan) [2069073]
- libperf: Fix perf_cpu_map__for_each_cpu macro (Michael Petlan) [2069073]
- perf cs-etm: Fix corrupt inject files when only last branch option is enabled (Michael Petlan) [2069073]
- perf cs-etm: No-op refactor of synth opt usage (Michael Petlan) [2069073]
- libperf: Fix 32-bit build for tests uint64_t printf (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Michael Petlan) [2069073]
- perf trace: Avoid early exit due SIGCHLD from non-workload processes (Michael Petlan) [2069073]
- perf ftrace: system_wide collection is not effective by default (Michael Petlan) [2069073]
- libperf: Add arm64 support to perf_mmap__read_self() (Michael Petlan) [2069073]
- perf stat: Fix display of grouped aliased events (Michael Petlan) [2069073]
- perf tools: Apply correct label to user/kernel symbols in branch mode (Michael Petlan) [2069073]
- perf bpf: Fix a typo in bpf_counter_cgroup.c (Michael Petlan) [2069073]
- perf synthetic-events: Return error if procfs isn't mounted for PID namespaces (Michael Petlan) [2069073]
- perf session: Check for NULL pointer before dereference (Michael Petlan) [2069073]
- perf annotate: Set error stream of objdump process for TUI (Michael Petlan) [2069073]
- perf tools: Add missing branch_sample_type to perf_event_attr__fprintf() (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Michael Petlan) [2069073]
- perf beauty: Make the prctl arg regexp more strict to cope with PR_SET_VMA (Michael Petlan) [2069073]
- perf tools: Remove redundant err variable (Michael Petlan) [2069073]
- perf test: Add parse-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf test: Add pmu-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf parse-events: Support event alias in form foo-bar-baz (Michael Petlan) [2069073]
- perf evsel: Override attr->sample_period for non-libpfm4 events (Michael Petlan) [2069073]
- perf cpumap: Remove duplicate include in cpumap.h (Michael Petlan) [2069073]
- perf cpumap: Migrate to libperf cpumap api (Michael Petlan) [2069073]
- perf python: Fix cpu_map__item() building (Michael Petlan) [2069073]
- perf script: Fix printing 'phys_addr' failure issue (Michael Petlan) [2069073]
- perf machine: Use path__join() to compose a path instead of snprintf(dir, '/', filename) (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when disabling events for pid targets (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when enabling events for pid targets (Michael Petlan) [2069073]
- perf stat: No need to setup affinities when starting a workload (Michael Petlan) [2069073]
- perf affinity: Allow passing a NULL arg to affinity__cleanup() (Michael Petlan) [2069073]
- perf probe: Fix ppc64 'perf probe add events failed' case (Michael Petlan) [2069073]
- perf record: Disable debuginfod by default (Michael Petlan) [2069073]
- perf evlist: No need to do any affinity setup when profiling pids (Michael Petlan) [2069073]
- perf cpumap: Add is_dummy() method (Michael Petlan) [2069073]
- perf metric: Fix metric_leader (Michael Petlan) [2069073]
- perf cputopo: Fix CPU topology reading on s/390 (Michael Petlan) [2069073]
- perf metricgroup: Fix use after free in metric__new() (Michael Petlan) [2069073]
- libperf tests: Update a use of the new cpumap API (Michael Petlan) [2069073]
- perf arm: Fix off-by-one directory path (Michael Petlan) [2069073]
- perf pmu-events: Don't lower case MetricExpr (Michael Petlan) [2069073]
- perf expr: Add debug logging for literals (Michael Petlan) [2069073]
- perf tools: Probe non-deprecated sysfs path 1st (Michael Petlan) [2069073]
- perf tools: Fix SMT fallback with large core counts (Michael Petlan) [2069073]
- perf cpumap: Give CPUs their own type (Michael Petlan) [2069073]
- perf stat: Correct first_shadow_cpu to return index (Michael Petlan) [2069073]
- perf script: Fix flipped index and cpu (Michael Petlan) [2069073]
- perf c2c: Use more intention revealing iterator (Michael Petlan) [2069073]
- perf bpf: Rename 'cpu' to 'cpu_map_idx' (Michael Petlan) [2069073]
- libperf: Sync evsel documentation (Michael Petlan) [2069073]
- perf stat: Swap variable name cpu to index (Michael Petlan) [2069073]
- perf stat: Correct check_per_pkg() cpu (Michael Petlan) [2069073]
- perf test: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf evsel: Rename variable cpu to index (Michael Petlan) [2069073]
- perf evsel: Reduce scope of evsel__ignore_missing_thread (Michael Petlan) [2069073]
- perf evsel: Rename CPU around get_group_fd (Michael Petlan) [2069073]
- perf stat: Correct variable name for read counter (Michael Petlan) [2069073]
- perf evsel: Pass cpu not cpu map index to synthesize (Michael Petlan) [2069073]
- perf evlist: Refactor evlist__for_each_cpu() (Michael Petlan) [2069073]
- libperf: Allow NULL in perf_cpu_map__idx() (Michael Petlan) [2069073]
- perf script: Use for each cpu to aid readability (Michael Petlan) [2069073]
- perf stat: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf stat: Rename aggr_data cpu to imply it's an index (Michael Petlan) [2069073]
- perf counts: Switch name cpu to cpu_map_idx (Michael Petlan) [2069073]
- libperf: Use cpu not index for evsel mmap (Michael Petlan) [2069073]
- libperf: Switch cpu to more accurate cpu_map_idx (Michael Petlan) [2069073]
- perf evsel: Derive CPUs and threads in alloc_counts (Michael Petlan) [2069073]
- perf stat-display: Avoid use of core for CPU (Michael Petlan) [2069073]
- perf cpumap: Add CPU to aggr_cpu_id (Michael Petlan) [2069073]
- perf stat: Fix memory leak in check_per_pkg() (Michael Petlan) [2069073]
- perf cpumap: Trim the cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Add some comments to cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Move 'has' function to libperf (Michael Petlan) [2069073]
- perf cpumap: Rename cpu_map__get_X_aggr_by_cpu functions (Michael Petlan) [2069073]
- perf cpumap: Refactor cpu_map__build_map() (Michael Petlan) [2069073]
- perf cpumap: Remove cpu_map__cpu(), use libperf function (Michael Petlan) [2069073]
- perf cpumap: Remove map from function names that don't use a map (Michael Petlan) [2069073]
- perf cpumap: Document cpu__get_node() and remove redundant function (Michael Petlan) [2069073]
- perf cpumap: Rename empty functions (Michael Petlan) [2069073]
- perf cpumap: Simplify equal function name (Michael Petlan) [2069073]
- perf cpumap: Remove unused cpu_map__socket() (Michael Petlan) [2069073]
- perf cpumap: Add comments to aggr_cpu_id() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_node() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_core() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_die() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_socket() (Michael Petlan) [2069073]
- perf cpumap: Switch cpu_map__build_map() to cpu function (Michael Petlan) [2069073]
- perf stat: Switch to cpu version of cpu_map__get() (Michael Petlan) [2069073]
- perf stat: Switch aggregation to use for_each loop (Michael Petlan) [2069073]
- perf stat: Correct aggregation CPU map (Michael Petlan) [2069073]
- perf stat: Add aggr creators that are passed a cpu (Michael Petlan) [2069073]
- libperf: Add comments to 'struct perf_cpu_map' (Michael Petlan) [2069073]
- perf evsel: Improve error message for uncore events (Michael Petlan) [2069073]
- perf script: Fix hex dump character output (Michael Petlan) [2069073]
- perf test: Enable system wide for metricgroups test (Michael Petlan) [2069073]
- perf annotate: Avoid TUI crash when navigating in the annotation of recursive functions (Michael Petlan) [2069073]
- perf arm64: Inject missing frames when using 'perf record --call-graph=fp' (Michael Petlan) [2069073]
- perf tools: Refactor SMPL_REG macro in perf_regs.h (Michael Petlan) [2069073]
- perf callchain: Enable dwarf_callchain_users on arm64 (Michael Petlan) [2069073]
- perf script: Use callchain_param_setup() instead of open coded equivalent (Michael Petlan) [2069073]
- perf machine: Add a mechanism to inject stack frames (Michael Petlan) [2069073]
- perf tools: Record ARM64 LR register automatically (Michael Petlan) [2069073]
- perf test: Use 3 digits for test numbering now we can have more tests (Michael Petlan) [2069073]
- perf arm-spe: Synthesize SPE instruction events (Michael Petlan) [2069073]
- perf test: Test 73 Sig_trap fails on s390 (Michael Petlan) [2069073]
- perf ftrace: Implement cpu and task filters in BPF (Michael Petlan) [2069073]
- perf ftrace: Add -b/--use-bpf option for latency subcommand (Michael Petlan) [2069073]
- perf ftrace: Add 'latency' subcommand (Michael Petlan) [2069073]
- perf ftrace: Move out common code from __cmd_ftrace (Michael Petlan) [2069073]
- perf ftrace: Add 'trace' subcommand (Michael Petlan) [2069073]
- perf arch: Support register names from all archs (Michael Petlan) [2069073]
- perf arm64: Rename perf_event_arm_regs for ARM64 registers (Michael Petlan) [2069073]
- perf namespaces: Add helper nsinfo__is_in_root_namespace() (Michael Petlan) [2069073]
- libperf tests: Fix a spelling mistake "Runnnig" -> "Running" (Michael Petlan) [2069073]
- perf bpf-loader: Use IS_ERR_OR_NULL() to clean code and fix check (Michael Petlan) [2069073]
- perf cs-etm: Remove duplicate and incorrect aux size checks (Michael Petlan) [2069073]
- perf vendor events: Rename arm64 arch std event files (Michael Petlan) [2069073]
- perf vendor events: For the Arm Neoverse N2 (Michael Petlan) [2069073]
- perf dlfilter: Drop unused variable (Michael Petlan) [2069073]
- perf arm-spe: Add SPE total latency as PERF_SAMPLE_WEIGHT (Michael Petlan) [2069073]
- perf bench: Use unbuffered output when pipe/tee'ing to a file (Michael Petlan) [2069073]
- perf vendor events arm64: Fix JSON indentation to 4 spaces standard (Michael Petlan) [2069073]
- perf stat: Support --cputype option for hybrid events (Michael Petlan) [2069073]
- perf tools: Drop requirement for libstdc++.so for libopencsd check (Michael Petlan) [2069073]
- perf parse-events: Architecture specific leader override (Michael Petlan) [2069073]
- perf evlist: Allow setting arbitrary leader (Michael Petlan) [2069073]
- perf metric: Reduce multiplexing with duration_time (Michael Petlan) [2069073]
- perf trace: Enable ignore_missing_thread for trace (Michael Petlan) [2069073]
- perf docs: Update link to AMD documentation (Michael Petlan) [2069073]
- perf docs: Add info on AMD raw event encoding (Michael Petlan) [2069073]
- libperf tests: Add test_stat_multiplexing test (Michael Petlan) [2069073]
- libperf: Remove scaling process from perf_mmap__read_self() (Michael Petlan) [2069073]
- libperf: Adopt perf_counts_values__scale() from tools/perf/util (Michael Petlan) [2069073]
- tools build: Enable warnings through HOSTCFLAGS (Michael Petlan) [2069073]
- perf test sigtrap: Print errno string when failing (Michael Petlan) [2069073]
- perf test sigtrap: Add basic stress test for sigtrap handling (Michael Petlan) [2069073]
- tools/perf: Add '__rel_loc' event field parsing support (Michael Petlan) [2069073]
- libtraceevent: Add __rel_loc relative location attribute support (Michael Petlan) [2069073]
- tools/perf: Stop using bpf_object__find_program_by_title API. (Michael Petlan) [2069073]
- perf: Mute libbpf API deprecations temporarily (Michael Petlan) [2069073]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Michael Petlan) [2069073]
- perf trace: Avoid early exit due to running SIGCHLD handler before it makes sense to (Michael Petlan) [2069073]
- perf top: Fix TUI exit screen refresh race condition (Michael Petlan) [2069073]
- perf pmu: Fix alias events list (Michael Petlan) [2069073]
- perf scripts python: intel-pt-events.py: Fix printing of switch events (Michael Petlan) [2069073]
- perf script: Fix CPU filtering of a script's switch events (Michael Petlan) [2069073]
- perf intel-pt: Fix parsing of VM time correlation arguments (Michael Petlan) [2069073]
- perf expr: Fix return value of ids__new() (Michael Petlan) [2069073]
- perf inject: Fix segfault due to perf_data__fd() without open (Michael Petlan) [2069073]
- perf inject: Fix segfault due to close without open (Michael Petlan) [2069073]
- perf expr: Fix missing check for return value of hashmap__new() (Michael Petlan) [2069073]
- perf python: Fix NULL vs IS_ERR_OR_NULL() checking (Michael Petlan) [2069073]
- perf intel-pt: Fix error timestamp setting on the decoder error path (Michael Petlan) [2069073]
- perf intel-pt: Fix missing 'instruction' events with 'q' option (Michael Petlan) [2069073]
- perf intel-pt: Fix next 'err' value, walking trace (Michael Petlan) [2069073]
- perf intel-pt: Fix state setting when receiving overflow (OVF) packet (Michael Petlan) [2069073]
- perf intel-pt: Fix intel_pt_fup_event() assumptions about setting state type (Michael Petlan) [2069073]
- perf intel-pt: Fix sync state when a PSB (synchronization) packet is found (Michael Petlan) [2069073]
- perf intel-pt: Fix some PGE (packet generation enable/control flow packets) usage (Michael Petlan) [2069073]
- perf tools: Prevent out-of-bounds access to registers (Michael Petlan) [2069073]
- perf bpf_skel: Do not use typedef to avoid error on old clang (Michael Petlan) [2069073]
- perf bpf: Fix building perf with BUILD_BPF_SKEL=1 by default in more distros (Michael Petlan) [2069073]
- perf header: Fix memory leaks when processing feature headers (Michael Petlan) [2069073]
- perf test: Reset shadow counts before loading (Michael Petlan) [2069073]
- perf test: Fix 'Simple expression parser' test on arch without CPU die topology info (Michael Petlan) [2069073]
- tools build: Remove needless libpython-version feature check that breaks test-all fast path (Michael Petlan) [2069073]
- perf tools: Fix SMT detection fast read path (Michael Petlan) [2069073]
- perf inject: Fix itrace space allowed for new attributes (Michael Petlan) [2069073]
- tools: sync uapi/linux/if_link.h header (Michael Petlan) [2069073]
- perf evsel: Fix memory leaks relating to unit (Michael Petlan) [2069073]
- perf report: Fix memory leaks around perf_tip() (Michael Petlan) [2069073]
- perf hist: Fix memory leak of a perf_hpp_fmt (Michael Petlan) [2069073]
- tools build: Fix removal of feature-sync-compare-and-swap feature detection (Michael Petlan) [2069073]
- perf inject: Fix ARM SPE handling (Michael Petlan) [2069073]
- perf test sample-parsing: Fix branch_stack entry endianness check (Michael Petlan) [2069073]
- perf tools: Set COMPAT_NEED_REALLOCARRAY for CONFIG_AUXTRACE=1 (Michael Petlan) [2069073]
- perf tests wp: Remove unused functions on s390 (Michael Petlan) [2069073]
- perf tests: Remove bash constructs from stat_all_pmu.sh (Michael Petlan) [2069073]
- perf tests: Remove bash construct from record+zstd_comp_decomp.sh (Michael Petlan) [2069073]
- perf test: Remove bash construct from stat_bpf_counters.sh test (Michael Petlan) [2069073]
- perf bench futex: Fix memory leak of perf_cpu_map__new() (Michael Petlan) [2069073]
- perf tools: Add more weak libbpf functions (Michael Petlan) [2069073]
- perf bpf: Avoid memory leak from perf_env__insert_btf() (Michael Petlan) [2069073]
- perf symbols: Factor out annotation init/exit (Michael Petlan) [2069073]
- perf symbols: Bit pack to save a byte (Michael Petlan) [2069073]
- perf symbols: Add documentation to 'struct symbol' (Michael Petlan) [2069073]
- perf test bpf: Use ARRAY_CHECK() instead of ad-hoc equivalent, addressing array_size.cocci warning (Michael Petlan) [2069073]
- perf arm-spe: Support hardware-based PID tracing (Michael Petlan) [2069073]
- perf arm-spe: Save context ID in record (Michael Petlan) [2069073]
- perf arm-spe: Update --switch-events docs in 'perf record' (Michael Petlan) [2069073]
- perf arm-spe: Track task context switch for cpu-mode events (Michael Petlan) [2069073]
- perf design.txt: Synchronize the definition of enum perf_hw_id with code (Michael Petlan) [2069073]
- perf arm-spe: Print size using consistent format (Michael Petlan) [2069073]
- perf cs-etm: Print size using consistent format (Michael Petlan) [2069073]
- perf arm-spe: Snapshot mode test (Michael Petlan) [2069073]
- perf arm-spe: Implement find_snapshot callback (Michael Petlan) [2069073]
- perf arm-spe: Add snapshot mode support (Michael Petlan) [2069073]
- perf expr: Add source_count for aggregating events (Michael Petlan) [2069073]
- perf expr: Move ID handling to its own function (Michael Petlan) [2069073]
- perf expr: Add metric literals for topology. (Michael Petlan) [2069073]
- perf expr: Add literal values starting with # (Michael Petlan) [2069073]
- perf cputopo: Match thread_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Match die_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Update to use pakage_cpus (Michael Petlan) [2069073]
- perf test: Add expr test for events with hyphens (Michael Petlan) [2069073]
- perf test: Remove skip_if_fail (Michael Petlan) [2069073]
- perf test: Remove is_supported function (Michael Petlan) [2069073]
- perf test: TSC test, remove is_supported use (Michael Petlan) [2069073]
- perf test: BP tests, remove is_supported use (Michael Petlan) [2069073]
- perf test: Remove non test case style support. (Michael Petlan) [2069073]
- perf test: Convert time to tsc test to test case. (Michael Petlan) [2069073]
- perf test: bp tests use test case (Michael Petlan) [2069073]
- perf test: Remove now unused subtest helpers (Michael Petlan) [2069073]
- perf test: Convert llvm tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert bpf tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert clang tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert watch point tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pmu event tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pfm tests to use test cases. (Michael Petlan) [2069073]
- perf test: Add skip reason to test case. (Michael Petlan) [2069073]
- perf test: Add test case struct. (Michael Petlan) [2069073]
- perf test: Add helper functions for abstraction. (Michael Petlan) [2069073]
- perf test: Rename struct test to test_suite (Michael Petlan) [2069073]
- perf test: Move each test suite struct to its test (Michael Petlan) [2069073]
- perf test: Make each test/suite its own struct. (Michael Petlan) [2069073]
- perf test: Use macro for "suite" definitions (Michael Petlan) [2069073]
- perf test: Use macro for "suite" declarations (Michael Petlan) [2069073]
- perf beauty: Add socket level scnprintf that handles ARCH specific SOL_SOCKET (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of setsockopt (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of getsockopt (Michael Petlan) [2069073]
- perf beauty socket: Add generator for socket level (SOL_*) string table (Michael Petlan) [2069073]
- perf beauty socket: Sort the ipproto array entries (Michael Petlan) [2069073]
- perf beauty socket: Rename 'regex'  to 'ipproto_regex' (Michael Petlan) [2069073]
- perf beauty socket: Prep to receive more input header files (Michael Petlan) [2069073]
- perf beauty socket: Rename header_dir to uapi_header_dir (Michael Petlan) [2069073]
- perf beauty: Rename socket_ipproto.sh to socket.sh to hold more socket table generators (Michael Petlan) [2069073]
- perf beauty: Make all sockaddr files use a common naming scheme (Michael Petlan) [2069073]
- Add 'tools/perf/libbpf/' to ignored files (Michael Petlan) [2069073]
- perf build: Install libbpf headers locally when building (Michael Petlan) [2069073]
- perf MANIFEST: Add bpftool files to allow building with BUILD_BPF_SKEL=1 (Michael Petlan) [2069073]
- perf metric: Fix memory leaks (Michael Petlan) [2069073]
- perf parse-event: Add init and exit to parse_event_error (Michael Petlan) [2069073]
- perf parse-events: Rename parse_events_error functions (Michael Petlan) [2069073]
- perf stat: Fix memory leak on error path (Michael Petlan) [2069073]
- perf tools: Use __BYTE_ORDER__ (Michael Petlan) [2069073]
- perf inject: Add vmlinux and ignore-vmlinux arguments (Michael Petlan) [2069073]
- perf tools: Check vmlinux/kallsyms arguments in all tools (Michael Petlan) [2069073]
- perf tools: Refactor out kernel symbol argument sanity checking (Michael Petlan) [2069073]
- perf symbols: Ignore $a/$d symbols for ARM modules (Michael Petlan) [2069073]
- perf evsel: Don't set exclude_guest by default (Michael Petlan) [2069073]
- perf evsel: Fix missing exclude_{host,guest} setting (Michael Petlan) [2069073]
- perf bpf: Add missing free to bpf_event__print_bpf_prog_info() (Michael Petlan) [2069073]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069073]
- perf clang: Fixes for more recent LLVM/clang (Michael Petlan) [2069073]
- perf bpf: Pull in bpf_program__get_prog_info_linear() (Michael Petlan) [2069073]
- perf test sample-parsing: Add endian test for struct branch_flags (Michael Petlan) [2069073]
- perf evsel: Add bitfield_swap() to handle branch_stack endian issue (Michael Petlan) [2069073]
- perf script: Support instruction latency (Michael Petlan) [2069073]
- perf script: Show binary offsets for userspace addr (Michael Petlan) [2069073]
- perf bench futex: Call the futex syscall from a function (Michael Petlan) [2069073]
- perf intel-pt: Support itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf auxtrace: Add itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf dlfilter: Add dlfilter-show-cycles (Michael Petlan) [2069073]
- perf intel-pt: Support itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add missing Z option to ITRACE_HELP (Michael Petlan) [2069073]
- tools build: Drop needless slang include path in test-all (Michael Petlan) [2069073]
- perf tests: Improve temp file cleanup in test_arm_coresight.sh (Michael Petlan) [2069073]
- perf tests: Fix trace+probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf test: Fix record+script_probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf jevents: Fix some would-be warnings (Michael Petlan) [2069073]
- perf dso: Fix /proc/kcore access on 32 bit systems (Michael Petlan) [2069073]
- perf list: Display hybrid PMU events with cpu type (Michael Petlan) [2069073]
- perf session: Introduce reader EOF function (Michael Petlan) [2069073]
- perf session: Introduce reader return codes (Michael Petlan) [2069073]
- perf session: Move the event read code to a separate function (Michael Petlan) [2069073]
- perf session: Move unmap code to reader__mmap (Michael Petlan) [2069073]
- perf session: Move reader map code to a separate function (Michael Petlan) [2069073]
- perf session: Move init/release code to separate functions (Michael Petlan) [2069073]
- perf session: Introduce decompressor in reader object (Michael Petlan) [2069073]
- perf session: Move all state items to reader object (Michael Petlan) [2069073]
- perf intel-pt: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf tools: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf vendor events arm64: Categorise the Neoverse V1 counters (Michael Petlan) [2069073]
- perf vendor events arm64: Add new armv8 pmu events (Michael Petlan) [2069073]
- perf vendor events: Syntax corrections in Neoverse N1 json (Michael Petlan) [2069073]
- perf metric: Allow modifiers on metrics (Michael Petlan) [2069073]
- perf parse-events: Identify broken modifiers (Michael Petlan) [2069073]
- perf metric: Switch fprintf() to pr_err() (Michael Petlan) [2069073]
- perf metrics: Modify setup and deduplication (Michael Petlan) [2069073]
- perf expr: Add subset_of_ids() utility (Michael Petlan) [2069073]
- perf metric: Encode and use metric-id as qualifier (Michael Petlan) [2069073]
- perf parse-events: Allow config on kernel PMU events (Michael Petlan) [2069073]
- perf parse-events: Add new "metric-id" term (Michael Petlan) [2069073]
- perf parse-events: Add const to evsel name (Michael Petlan) [2069073]
- perf metric: Simplify metric_refs calculation (Michael Petlan) [2069073]
- perf metric: Document the internal 'struct metric' (Michael Petlan) [2069073]
- perf metric: Comment data structures (Michael Petlan) [2069073]
- perf metric: Modify resolution and recursion check (Michael Petlan) [2069073]
- perf metric: Only add a referenced metric once (Michael Petlan) [2069073]
- perf metric: Add metric new() and free() methods (Michael Petlan) [2069073]
- perf metric: Add documentation and rename a variable. (Michael Petlan) [2069073]
- perf metric: Move runtime value to the expr context (Michael Petlan) [2069073]
- perf pmu: Make pmu_event tables const. (Michael Petlan) [2069073]
- perf pmu: Make pmu_sys_event_tables const. (Michael Petlan) [2069073]
- perf pmu: Add const to pmu_events_map. (Michael Petlan) [2069073]
- tools lib: Adopt list_sort() from the kernel sources (Michael Petlan) [2069073]
- perf kmem: Improve man page for record options (Michael Petlan) [2069073]
- perf tools: Enable strict JSON parsing (Michael Petlan) [2069073]
- perf tools: Make the JSON parser more conformant when in strict mode (Michael Petlan) [2069073]
- perf vendor-events: Fix all remaining invalid JSON files (Michael Petlan) [2069073]
- perf daemon: Remove duplicate sys/file.h include (Michael Petlan) [2069073]
- perf test evlist-open-close: Use inline func to convert timeval to usec (Michael Petlan) [2069073]
- perf mmap: Introduce mmap_cpu_mask__duplicate() (Michael Petlan) [2069073]
- libperf cpumap: Use binary search in perf_cpu_map__idx() as array are sorted (Michael Petlan) [2069073]
- perf srcline: Use long-running addr2line per DSO (Michael Petlan) [2069073]
- perf metric: Avoid events for an 'if' constant result (Michael Petlan) [2069073]
- perf metric: Don't compute unused events (Michael Petlan) [2069073]
- perf expr: Propagate constants for binary operations (Michael Petlan) [2069073]
- perf expr: Merge find_ids and regular parsing (Michael Petlan) [2069073]
- perf metric: Allow metrics with no events (Michael Petlan) [2069073]
- perf metric: Add utilities to work on ids map. (Michael Petlan) [2069073]
- perf metric: Rename expr__find_other. (Michael Petlan) [2069073]
- perf expr: Move actions to the left. (Michael Petlan) [2069073]
- perf expr: Use macros for operators (Michael Petlan) [2069073]
- perf expr: Separate token declataion from type (Michael Petlan) [2069073]
- perf expr: Remove unused headers and inline d_ratio (Michael Petlan) [2069073]
- perf metric: Use NAN for missing event IDs. (Michael Petlan) [2069073]
- perf metric: Restructure struct expr_parse_ctx. (Michael Petlan) [2069073]
- perf vendor events arm64: Revise hip08 uncore events (Michael Petlan) [2069073]
- perf test: Add pmu-event test for event described as "config=" (Michael Petlan) [2069073]
- perf test: Verify more event members in pmu-events test (Michael Petlan) [2069073]
- perf jevents: Support ConfigCode (Michael Petlan) [2069073]
- perf parse-events: Set numeric term config (Michael Petlan) [2069073]
- perf tools: Add define for libtracefs version (Michael Petlan) [2069073]
- perf tools: Add define for libtraceevent version (Michael Petlan) [2069073]
- perf tools: Enable libtracefs dynamic linking (Michael Petlan) [2069073]
- perf test: Workload test of all PMUs (Michael Petlan) [2069073]
- perf test: Workload test of metric and metricgroups (Michael Petlan) [2069073]
- perf jevents: Add __maybe_unused attribute to unused function arg (Michael Petlan) [2069073]
- perf annotate: Add riscv64 support (Michael Petlan) [2069073]
- perf list: Display pmu prefix for partially supported hybrid cache events (Michael Petlan) [2069073]
- perf parse-events: Remove unnecessary #includes (Michael Petlan) [2069073]
- perf daemon: Avoid msan warnings on send_cmd (Michael Petlan) [2069073]
- perf record: Add --synth option (Michael Petlan) [2069073]
- perf tools: Allow controlling synthesizing PERF_RECORD_ metadata events during record (Michael Petlan) [2069073]
- perf parse-events: Avoid enum forward declaration. (Michael Petlan) [2069073]
- perf bpf: Deprecate bpf_map__resize() in favor of bpf_map_set_max_entries() (Michael Petlan) [2069073]
- perf annotate: Add fusion logic for AMD microarchs (Michael Petlan) [2069073]
- perf: Fix list corruption in perf_cgroup_switch() (Michael Petlan) [2069073]
- perf/x86/intel/pt: Fix crash with stop filters in single-range mode (Michael Petlan) [2069073]
- perf: uapi: Document perf_event_attr::sig_data truncation on 32 bit architectures (Michael Petlan) [2069073]
- perf: Copy perf_event_attr::sig_data on modification (Michael Petlan) [2069073]
- x86/perf: Default set FREEZE_ON_SMI for all (Michael Petlan) [2069073]
- perf/core: Fix cgroup event list management (Michael Petlan) [2069073]
- perf: Always wake the parent event (Michael Petlan) [2069073]
- x86/perf: Avoid warning for Arch LBR without XSAVE (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Add static_branch for LBR INFO flags (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Support LBR format V7 (Michael Petlan) [2069073]
- perf/x86/rapl: fix AMD event handling (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix CAS_COUNT_WRITE issue for ICX (Michael Petlan) [2069073]
- perf/x86/intel: Add a quirk for the calculation of the number of counters on Alder Lake (Michael Petlan) [2069073]
- perf: Fix perf_event_read_local() time (Michael Petlan) [2069073]
- perf: Drop guest callback (un)register stubs (Michael Petlan) [2069073]
- KVM: arm64: Drop perf.c and fold its tiny bits of code into arm.c (Michael Petlan) [2069073]
- KVM: arm64: Hide kvm_arm_pmu_available behind CONFIG_HW_PERF_EVENTS=y (Michael Petlan) [2069073]
- KVM: arm64: Convert to the generic perf callbacks (Michael Petlan) [2069073]
- KVM: x86: Move Intel Processor Trace interrupt handler to vmx.c (Michael Petlan) [2069073]
- KVM: Move x86's perf guest info callbacks to generic KVM (Michael Petlan) [2069073]
- KVM: x86: More precisely identify NMI from guest when handling PMI (Michael Petlan) [2069073]
- KVM: x86: Drop current_vcpu for kvm_running_vcpu + kvm_arch_vcpu variable (Michael Petlan) [2069073]
- perf/core: Use static_call to optimize perf_guest_info_callbacks (Michael Petlan) [2069073]
- perf: Force architectures to opt-in to guest callbacks (Michael Petlan) [2069073]
- perf: Add wrappers for invoking guest callbacks (Michael Petlan) [2069073]
- perf/core: Rework guest callbacks to prepare for static_call support (Michael Petlan) [2069073]
- perf: Drop dead and useless guest "support" from arm, csky, nds32 and riscv (Michael Petlan) [2069073]
- perf: Stop pretending that perf can handle multiple guest callbacks (Michael Petlan) [2069073]
- KVM: x86: Register Processor Trace interrupt hook iff PT enabled in guest (Michael Petlan) [2069073]
- KVM: x86: Register perf callbacks after calling vendor's hardware_setup() (Michael Petlan) [2069073]
- perf: Protect perf_guest_cbs with RCU (Michael Petlan) [2069073]
- x86/events/amd/iommu: Remove redundant assignment to variable shift (Michael Petlan) [2069073]
- perf: Add a counter for number of user access events in context (Michael Petlan) [2069073]
- arm64: perf: Enable PMU counter userspace access for perf event (Michael Petlan) [2069073]
- arm64: perf: Add userspace counter access disable switch (Michael Petlan) [2069073]
- x86: perf: Move RDPMC event flag to a common definition (Michael Petlan) [2069073]
- perf: Ignore sigtrap for tracepoints destined for other tasks (Michael Petlan) [2069073]
- x86/perf: Fix snapshot_branch_stack warning in VM (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Snowridge (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Skylake Server (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on Skylake Server (Michael Petlan) [2069073]
- perf/core: Avoid put_page() when GUP fails (Michael Petlan) [2069073]
- perf/x86/vlbr: Add c->flags to vlbr event constraints (Michael Petlan) [2069073]
- perf/x86/lbr: Reset LBR_SELECT during vlbr reset (Michael Petlan) [2069073]
- perf: Enable branch record for software events (Michael Petlan) [2069073]
- tracing/perf: Add interrupt_context_level() helper (Michael Petlan) [2069073]
- tracing: Reuse logic from perf's get_recursion_context() (Michael Petlan) [2069073]
- x86/insn: Use get_unaligned() instead of memcpy() (Michael Petlan) [2069073]
- x86/insn, tools/x86: Fix undefined behavior due to potential unaligned accesses (Michael Petlan) [2069073]
- x86/pkru: Remove useless include (Michael Petlan) [2069073]
- perf/x86/intel: Fix ICL/SPR INST_RETIRED.PREC_DIST encodings (Michael Petlan) [2069073]
- perf/core: Allow ftrace for functions in kernel/event/core.c (Michael Petlan) [2069073]
- perf/x86: Add new event for AUX output counter index (Michael Petlan) [2069073]
- perf/x86: Add compiler barrier after updating BTS (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix invalid unit check (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake server (Michael Petlan) [2069073]
- tools/power/x86/intel-speed-select: fix build failure when using -Wl,--as-needed (David Arcari) [2040063]
- Spec fixes for intel-speed-select (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.12 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: HFI support (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: OOB daemon mode (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.11 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: Update max frequency (David Arcari) [2040063]
- Add BuildRequires libnl3-devel for intel-speed-select (David Arcari) [2040063]
- platform/x86: ISST: Fix possible circular locking dependency detected (David Arcari) [2040063]
- platform/x86: ISST: use semi-colons instead of commas (David Arcari) [2040063]
- platform/x86: intel_speed_select_if: Move to intel sub-directory (David Arcari) [2040063]
- platform/x86: ISST: Fix optimization with use of numa (David Arcari) [2040063]
- redhat/configs enable CONFIG_INTEL_HFI_THERMAL for x86 (David Arcari) [2040063]
- thermal: intel: hfi: INTEL_HFI_THERMAL depends on NET (David Arcari) [2040063]
- thermal: netlink: Fix parameter type of thermal_genl_cpu_capability_event() stub (David Arcari) [2040063]
- thermal: intel: hfi: Notify user space for HFI events (David Arcari) [2040063]
- thermal: netlink: Add a new event to notify CPU capabilities change (David Arcari) [2040063]
- thermal: intel: hfi: Enable notification interrupt (David Arcari) [2040063]
- thermal: intel: hfi: Handle CPU hotplug events (David Arcari) [2040063]
- thermal: intel: hfi: Minimally initialize the Hardware Feedback Interface (David Arcari) [2040063]
- x86/cpu: Add definitions for the Intel Hardware Feedback Interface (David Arcari) [2040063]
- x86/Documentation: Describe the Intel Hardware Feedback Interface (David Arcari) [2040063]

* Fri May 27 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-101.el9]
- redhat: Exclude cpufreq.h from kernel-headers (Patrick Talbert)
- tools: Add kmem_cache_alloc_lru() (Waiman Long) [2085412]
- tools: Move gfp.h and slab.h from radix-tree to lib (Waiman Long) [2085412]
- mm: workingset: replace IRQ-off check with a lockdep assert. (Waiman Long) [2079537]
- mm/memcg: disable migration instead of preemption in drain_all_stock(). (Waiman Long) [2079537]
- mm/memcg: protect memcg_stock with a local_lock_t (Waiman Long) [2079537]
- mm/memcg: opencode the inner part of obj_cgroup_uncharge_pages() in drain_obj_stock() (Waiman Long) [2079537]
- mm/memcg: protect per-CPU counter by disabling preemption on PREEMPT_RT where needed. (Waiman Long) [2079537]
- mm/memcg: disable threshold event handlers on PREEMPT_RT (Waiman Long) [2079537]
- mm/memcg: revert ("mm/memcg: optimize user context object stock access") (Waiman Long) [2079537]
- zsmalloc: replace get_cpu_var with local_lock (Waiman Long) [2079537]
- zsmalloc: replace per zpage lock with pool->migrate_lock (Waiman Long) [2079537]
- zsmalloc: remove zspage isolation for migration (Waiman Long) [2079537]
- zsmalloc: move huge compressed obj from page to zspage (Waiman Long) [2079537]
- zsmalloc: introduce obj_allocated (Waiman Long) [2079537]
- zsmalloc: decouple class actions from zspage works (Waiman Long) [2079537]
- zsmalloc: rename zs_stat_type to class_stat_type (Waiman Long) [2079537]
- zsmalloc: introduce some helper functions (Waiman Long) [2079537]
- memcg: better bounds on the memcg stats updates (Waiman Long) [2079537]
- mm: unexport {,un}lock_page_memcg (Waiman Long) [2079537]
- mm: unexport folio_memcg_{,un}lock (Waiman Long) [2079537]
- zsmalloc: Stop using slab fields in struct page (Waiman Long) [2079537]

* Thu May 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-100.el9]
- PCI: vmd: Revert 2565e5b69c44 ("PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU.") (Myron Stowe) [2084146]
- PCI: vmd: Assign VMD IRQ domain before enumeration (Myron Stowe) [2084146]
- KVM: s390: Fix lockdep issue in vm memop (Thomas Huth) [2044357]
- RHEL-only: KVM: selftests: Remove unused modes (Thomas Huth) [2073143]
- KVM: s390: selftests: Add error memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add more copy memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add named stages for memop test (Thomas Huth) [2044357]
- KVM: s390: selftests: Add macro as abstraction for MEM_OP (Thomas Huth) [2044357]
- KVM: s390: selftests: Split memop tests (Thomas Huth) [2044357]
- KVM: s390: Add missing vm MEM_OP size check (Thomas Huth) [2044357]
- KVM: s390: Clarify key argument for MEM_OP in api docs (Thomas Huth) [2044357]
- KVM: s390: Update api documentation for memop ioctl (Thomas Huth) [2044357]
- KVM: s390: Add capability for storage key extension of MEM_OP IOCTL (Thomas Huth) [2044357]
- KVM: s390: Rename existing vcpu memop functions (Thomas Huth) [2044357]
- KVM: s390: Add vm IOCTL for key checked guest absolute memory access (Thomas Huth) [2044357]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Thomas Huth) [2044357]
- KVM: s390: Add optional storage key checking to MEMOP IOCTL (Thomas Huth) [2044357]
- KVM: s390: selftests: Test TEST PROTECTION emulation (Thomas Huth) [2044357]
- KVM: s390: handle_tprot: Honor storage keys (Thomas Huth) [2044357]
- KVM: s390: Honor storage keys when accessing guest memory (Thomas Huth) [2044357]
- s390/uaccess: Add copy_from/to_user_key functions (Thomas Huth) [2044357]
- s390/uaccess: fix compile error (Thomas Huth) [2044357]
- s390/uaccess: introduce bit field for OAC specifier (Thomas Huth) [2044357]
- KVM: s390: gaccess: Cleanup access to guest pages (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor access address range check (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor gpa and length calculation (Thomas Huth) [2044357]
- redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf (Jerome Marchand) [2041365]
- samples: bpf: Don't fail for a missing VMLINUX_BTF when VMLINUX_H is provided (Jerome Marchand) [2041365]
- samples: bpf: Fix xdp_sample_user.o linking with Clang (Jerome Marchand) [2041365]
- cgroup: Fix memory leak caused by missing cgroup_bpf_offline (Jerome Marchand) [2041365]
- bpf: Change value of MAX_TAIL_CALL_CNT from 32 to 33 (Jerome Marchand) [2041365]
- bpf,x86: Simplify computing label offsets (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_reloc_mods on big-endian machines (Jerome Marchand) [2041365]
- bpf, doc: Add heading and example for extensions in cbpf (Jerome Marchand) [2041365]
- bpf: Fix a bpf_timer initialization issue (Jerome Marchand) [2041365]
- bpf: Fix crash due to incorrect copy_map_value (Jerome Marchand) [2041365]
- libbpf: Fix compilation warning due to mismatched printf format (Jerome Marchand) [2041365]
- libbpf: Fix signedness bug in btf_dump_array_data() (Jerome Marchand) [2041365]
- bpf: Fix verifier support for validation of async callbacks (Jerome Marchand) [2041365]
- samples: bpf: Fix 'unknown warning group' build warning on Clang (Jerome Marchand) [2041365]
- libbpf: Silence uninitialized warning/error in btf_dump_dump_type_data (Jerome Marchand) [2041365]
- libbpf: update index.rst reference (Jerome Marchand) [2041365]
- bpf: Forbid bpf_ktime_get_coarse_ns and bpf_timer_* in tracing progs (Jerome Marchand) [2041365]
- bpftool: Fix indent in option lists in the documentation (Jerome Marchand) [2041365]
- samples/bpf: Fix incorrect use of strlen in xdp_redirect_cpu (Jerome Marchand) [2041365]
- samples/bpf: Fix application of sizeof to pointer (Jerome Marchand) [2041365]
- samples/bpf: Fix summary per-sec stats in xdp_sample_user (Jerome Marchand) [2041365]
- bpf: Fix inner map state pruning regression. (Jerome Marchand) [2041365]
- libbpf: Fix off-by-one bug in bpf_core_apply_relo() (Jerome Marchand) [2041365]
- bpf/tests: Fix error in tail call limit tests (Jerome Marchand) [2041365]
- bpf: Fix NULL event->prog pointer access in bpf_overflow_handler (Jerome Marchand) [2041365]
- riscv, bpf: Fix potential NULL dereference (Jerome Marchand) [2041365]
- nfp: bpf: relax prog rejection for mtu check through max_pkt_offset (Jerome Marchand) [2041365]
- bpf: Fix potential race in tail call compatibility check (Jerome Marchand) [2041365]
- bpf: Move BPF_MAP_TYPE for INODE_STORAGE and TASK_STORAGE outside of CONFIG_NET (Jerome Marchand) [2041365]
- bpf: Fix error usage of map_fd and fdget() in generic_map_update_batch() (Jerome Marchand) [2041365]
- bpf: Prevent increasing bpf_jit_limit above max (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for arm64 JIT (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for riscv JIT (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Do not emit zero extend instruction for 64-bit BPF_END (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix JMP32_JSET_K (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix ALU32 BPF_ARSH operation (Jerome Marchand) [2041365]
- powerpc/bpf: Emit stf barrier instruction sequences for BPF_NOSPEC (Jerome Marchand) [2041365]
- powerpc/security: Add a helper to query stf_barrier type (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_MOD when imm == 1 (Jerome Marchand) [2041365]
- powerpc/bpf: Validate branch ranges (Jerome Marchand) [2041365]
- powerpc/lib: Add helper to check if offset is within conditional branch range (Jerome Marchand) [2041365]
- bpf, s390: Fix potential memory leak about jit_data (Jerome Marchand) [2041365]
- libbpf: Fix memory leak in strset (Jerome Marchand) [2041365]
- libbpf: Fix segfault in light skeleton for objects without BTF (Jerome Marchand) [2041365]
- bpf, arm: Fix register clobbering in div/mod implementation (Jerome Marchand) [2041365]
- samples/bpf: Relicense bpf_insn.h as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- samples: bpf: Fix vmlinux.h generation for XDP samples (Jerome Marchand) [2041365]
- bpf, x86: Fix bpf mapping of atomic fetch implementation (Jerome Marchand) [2041365]
- libbpf: Fix segfault in static linker for objects without BTF (Jerome Marchand) [2041365]
- bpf: Exempt CAP_BPF from checks against bpf_jit_limit (Jerome Marchand) [2041365]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Jerome Marchand) [2041365]
- s390/bpf: Fix optimizing out zero-extensions (Jerome Marchand) [2041365]
- s390/bpf: Fix 64-bit subtraction of the -0x80000000 constant (Jerome Marchand) [2041365]
- s390/bpf: Fix branch shortening during codegen pass (Jerome Marchand) [2041365]
- bpf: Handle return value of BPF_PROG_TYPE_STRUCT_OPS prog (Jerome Marchand) [2041365]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Jerome Marchand) [2041365]
- perf test: Fix bpf test sample mismatch reporting (Jerome Marchand) [2041365]
- selftests/bpf: Fix build of task_pt_regs test for arm64 (Jerome Marchand) [2041365]
- bpf: Relicense disassembler as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- selftests/bpf: Fix potential unreleased lock (Jerome Marchand) [2041365]
- samples: bpf: Fix uninitialized variable in xdp_redirect_cpu (Jerome Marchand) [2041365]
- bpf: Fix bpf-next builds without CONFIG_BPF_EVENTS (Jerome Marchand) [2041365]
- selftests: xsk: Preface options with opt (Jerome Marchand) [2041365]
- selftests: xsk: Make enums lower case (Jerome Marchand) [2041365]
- selftests: xsk: Generate packets from specification (Jerome Marchand) [2041365]
- selftests: xsk: Simplify cleanup of ifobjects (Jerome Marchand) [2041365]
- selftests: xsk: Validate tx stats on tx thread (Jerome Marchand) [2041365]
- selftests: xsk: Disassociate umem size with packets sent (Jerome Marchand) [2041365]
- selftests: xsk: Simplify the retry code (Jerome Marchand) [2041365]
- selftests: xsk: Return correct error codes (Jerome Marchand) [2041365]
- selftests: xsk: Remove unused variables (Jerome Marchand) [2041365]
- selftests: xsk: Remove the num_tx_packets option (Jerome Marchand) [2041365]
- selftests: xsk: Remove color mode (Jerome Marchand) [2041365]
- bpf: selftests: Add bpf_task_pt_regs() selftest (Jerome Marchand) [2041365]
- bpf: Add bpf_task_pt_regs() helper (Jerome Marchand) [2041365]
- bpf: Extend bpf_base_func_proto helpers with bpf_get_current_task_btf() (Jerome Marchand) [2041365]
- bpf: Consolidate task_struct BTF_ID declarations (Jerome Marchand) [2041365]
- bpf: Add BTF_ID_LIST_GLOBAL_SINGLE macro (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Add vmlinux.h generation support (Jerome Marchand) [2041365]
- samples: bpf: Add devmap_xmit tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for devmap_xmit tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add cpumap tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for cpumap tracepoints (Jerome Marchand) [2041365]
- samples: bpf: Add xdp_exception tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for xdp_exception tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add redirect tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for redirect tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add basic infrastructure for XDP samples (Jerome Marchand) [2041365]
- tools: include: Add ethtool_drvinfo definition to UAPI header (Jerome Marchand) [2041365]
- samples: bpf: Fix a couple of warnings (Jerome Marchand) [2041365]
- bpf: Fix possible out of bound write in narrow load handling (Jerome Marchand) [2041365]
- selftests/bpf: Exit with KSFT_SKIP if no Makefile found (Jerome Marchand) [2041365]
- selftests/bpf: Add missing files required by test_bpftool.sh for installing (Jerome Marchand) [2041365]
- selftests/bpf: Add default bpftool built by selftests to PATH (Jerome Marchand) [2041365]
- selftests/bpf: Make test_doc_build.sh work from script directory (Jerome Marchand) [2041365]
- selftests/bpf: Reduce flakyness in timer_mim (Jerome Marchand) [2041365]
- bpf: Migrate cgroup_bpf to internal cgroup_bpf_attach_type enum (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map keys in syscalls (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map values in syscall (Jerome Marchand) [2041365]
- bpf: Undo off-by-one in interpreter tail call count limit (Jerome Marchand) [2041365]
- libbpf: Rename libbpf documentation index file (Jerome Marchand) [2041365]
- bpf: Remove redundant initialization of variable allow (Jerome Marchand) [2041365]
- selftests/bpf: Fix flaky send_signal test (Jerome Marchand) [2041365]
- selftests/bpf: Replace CHECK with ASSERT_* macros in send_signal.c (Jerome Marchand) [2041365]
- selftests/bpf: Support glob matching for test selector. (Jerome Marchand) [2041365]
- selftests/bpf: Also print test name in subtest status message (Jerome Marchand) [2041365]
- selftests/bpf: Correctly display subtest skip status (Jerome Marchand) [2041365]
- selftests/bpf: Skip loading bpf_testmod when using -l to list tests. (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_delete_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_update_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Test btf__load_vmlinux_btf/btf__load_module_btf APIs (Jerome Marchand) [2041365]
- bpf: Reconfigure libbpf docs to remove unversioned API (Jerome Marchand) [2041365]
- selftests/bpf: Add ref_ctr_offset selftests (Jerome Marchand) [2041365]
- libbpf: Add uprobe ref counter offset support for USDT semaphores (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_cookie selftests for high-level APIs (Jerome Marchand) [2041365]
- Bselftests/bpf: Extract uprobe-related helpers into trace_helpers.{c,h} (Jerome Marchand) [2041365]
- selftests/bpf: Test low-level perf BPF link API (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie to perf_event, kprobe, uprobe, and tp attach APIs (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie support to bpf_link_create() API (Jerome Marchand) [2041365]
- libbpf: Use BPF perf link when supported by kernel (Jerome Marchand) [2041365]
- libbpf: Remove unused bpf_link's destroy operation, but add dealloc (Jerome Marchand) [2041365]
- libbpf: Re-build libbpf.so when libbpf.map changes (Jerome Marchand) [2041365]
- bpf: Add bpf_get_attach_cookie() BPF helper to access bpf_cookie value (Jerome Marchand) [2041365]
- bpf: Allow to specify user-provided bpf_cookie for BPF perf links (Jerome Marchand) [2041365]
- bpf: Implement minimal BPF perf link (Jerome Marchand) [2041365]
- bpf: Refactor perf_event_set_bpf_prog() to use struct bpf_prog input (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN_ARRAY family of macros into functions (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN into a function (Jerome Marchand) [2041365]
- bpf, tests: Fix spelling mistake "shoft" -> "shift" (Jerome Marchand) [2041365]
- selftest/bpf: Extend the bpf_snprintf() test for "%%c". (Jerome Marchand) [2041365]
- bpf: Support "%%c" in bpf_bprintf_prepare(). (Jerome Marchand) [2041365]
- samples/bpf: Define MAX_ENTRIES instead of a magic number in offwaketime (Jerome Marchand) [2041365]
- selftests/bpf: Verify bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_autosize on big-endian machines (Jerome Marchand) [2041365]
- libbpf: Support weak typed ksyms. (Jerome Marchand) [2041365]
- bpf, tests: Add tail call test suite (Jerome Marchand) [2041365]
- bpf, tests: Add tests for BPF_CMPXCHG (Jerome Marchand) [2041365]
- bpf, tests: Add tests for atomic operations (Jerome Marchand) [2041365]
- bpf, tests: Add test for 32-bit context pointer argument passing (Jerome Marchand) [2041365]
- bpf, tests: Add branch conversion JIT test (Jerome Marchand) [2041365]
- bpf, tests: Add word-order tests for load/store of double words (Jerome Marchand) [2041365]
- bpf, tests: Add tests for ALU operations implemented with function calls (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU64 BPF_MUL tests (Jerome Marchand) [2041365]
- bpf, tests: Add more BPF_LSH/RSH/ARSH tests for ALU64 (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU32 tests for BPF_LSH/RSH/ARSH (Jerome Marchand) [2041365]
- bpf, tests: Add more tests of ALU32 and ALU64 bitwise operations (Jerome Marchand) [2041365]
- bpf, tests: Fix typos in test case descriptions (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_MOV tests for zero and sign extension (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_JMP32 test cases (Jerome Marchand) [2041365]
- samples, bpf: Add an explict comment to handle nested vlan tagging. (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Remove forward declaration of ip_fast_csum() (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Make the sample more useful outside the tree (Jerome Marchand) [2041365]
- selftests/bpf: Rename reference_tracking BPF programs (Jerome Marchand) [2041365]
- selftests/bpf: Fix bpf-iter-tcp4 test to print correctly the dest IP (Jerome Marchand) [2041365]
- selftests/bpf: Move netcnt test under test_progs (Jerome Marchand) [2041365]
- bpf, samples: Add missing mprog-disable to xdp_redirect_cpu's optstring (Jerome Marchand) [2041365]
- bpf: Fix off-by-one in tail call count limiting (Jerome Marchand) [2041365]
- tools: bpftool: Complete metrics list in "bpftool prog profile" doc (Jerome Marchand) [2041365]
- tools: bpftool: Document and add bash completion for -L, -B options (Jerome Marchand) [2041365]
- selftests/bpf: Update bpftool's consistency script for checking options (Jerome Marchand) [2041365]
- tools: bpftool: Update and synchronise option list in doc and help msg (Jerome Marchand) [2041365]
- tools: bpftool: Complete and synchronise attach or map types (Jerome Marchand) [2041365]
- selftests/bpf: Check consistency between bpftool source, doc, completion (Jerome Marchand) [2041365]
- tools: bpftool: Slightly ease bash completion updates (Jerome Marchand) [2041365]
- libbpf: Add btf__load_vmlinux_btf/btf__load_module_btf (Jerome Marchand) [2041365]
- tools: bpftool: Support dumping split BTF by id (Jerome Marchand) [2041365]
- libbpf: Add split BTF support for btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Replace btf__get_from_id() with btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Free BTF objects at various locations (Jerome Marchand) [2041365]
- libbpf: Rename btf__get_from_id() as btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- libbpf: Rename btf__load() as btf__load_into_kernel() (Jerome Marchand) [2041365]
- libbpf: Return non-null error on failures in libbpf_find_prog_btf_id() (Jerome Marchand) [2041365]
- bpf: Emit better log message if bpf_iter ctx arg btf_id == 0 (Jerome Marchand) [2041365]
- tools/resolve_btfids: Emit warnings and patch zero id for missing symbols (Jerome Marchand) [2041365]
- bpf: Increase supported cgroup storage value size (Jerome Marchand) [2041365]
- libbpf: Fix race when pinning maps in parallel (Jerome Marchand) [2041365]
- libbpf: Fix comment typo (Jerome Marchand) [2041365]
- samples: bpf: Add the omitted xdp samples to .gitignore (Jerome Marchand) [2041365]
- samples: bpf: Fix tracex7 error raised on the missing argument (Jerome Marchand) [2041365]
- selftests/bpf: Use ping6 only if available in tc_redirect (Jerome Marchand) [2041365]
- libbpf: Split CO-RE logic into relo_core.c. (Jerome Marchand) [2041365]
- libbpf: Move CO-RE types into relo_core.h. (Jerome Marchand) [2041365]
- libbpf: Split bpf_core_apply_relo() into bpf_program independent helper. (Jerome Marchand) [2041365]
- libbpf: Cleanup the layering between CORE and bpf_program. (Jerome Marchand) [2041365]
- bpf/tests: Do not PASS tests without actually testing the result (Jerome Marchand) [2041365]
- bpf/tests: Fix copy-and-paste error in double word test (Jerome Marchand) [2041365]
- selftests/bpf: Document vmtest.sh dependencies (Jerome Marchand) [2041365]
- libbpf: Add bpf_map__pin_path function (Jerome Marchand) [2041365]
- libbpf: Export bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- libbpf: Allow decimal offset for kprobes (Jerome Marchand) [2041365]
- libbpf: Fix func leak in attach_kprobe (Jerome Marchand) [2041365]
- selftests/bpf: Mute expected invalid map creation error msg (Jerome Marchand) [2041365]
- bpf: Remove redundant intiialization of variable stype (Jerome Marchand) [2041365]
- bpf: Fix pointer cast warning (Jerome Marchand) [2041365]
- libbpf: Propagate errors when retrieving enum value for typed data display (Jerome Marchand) [2041365]
- selftests/bpf: Add __int128-specific tests for typed data dump (Jerome Marchand) [2041365]
- libbpf: Avoid use of __int128 in typed dump display (Jerome Marchand) [2041365]
- selftests, bpf: test_tc_tunnel.sh nc: Cannot use -p and -l (Jerome Marchand) [2041365]
- bpf, selftests: Fix test_maps now that sockmap supports UDP (Jerome Marchand) [2041365]
- selftests/bpf: Check inner map deletion (Jerome Marchand) [2041365]
- libbpf: Fix removal of inner map in bpf_object__create_map (Jerome Marchand) [2041365]
- libbpf: Btf typed dump does not need to allocate dump data (Jerome Marchand) [2041365]
- libbpf: Fix compilation errors on ppc64le for btf dump typed data (Jerome Marchand) [2041365]
- libbpf: Clarify/fix unaligned data issues for btf typed dump (Jerome Marchand) [2041365]
- selftests/bpf: Add dump type data tests to btf dump tests (Jerome Marchand) [2041365]
- selftests/bpf: Add ASSERT_STRNEQ() variant for test_progs (Jerome Marchand) [2041365]
- libbpf: BTF dumper support for typed data (Jerome Marchand) [2041365]
- selftests/bpf: Switch existing selftests to using open_opts for custom BTF (Jerome Marchand) [2041365]
- libbpf: Fix the possible memory leak on error (Jerome Marchand) [2041365]
- libbpf: Introduce 'btf_custom_path' to 'bpf_obj_open_opts' (Jerome Marchand) [2041365]
- bpf: Add ambient BPF runtime context stored in current (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip in kprobe+offset probe (Jerome Marchand) [2041365]
- libbpf: Allow specification of "kprobe/function+offset" (Jerome Marchand) [2041365]
- libbpf: Add bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip helper (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for kprobe programs (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for tracing programs (Jerome Marchand) [2041365]
- bpf: Enable BPF_TRAMP_F_IP_ARG for trampolines with call_get_func_ip (Jerome Marchand) [2041365]
- bpf, x86: Store caller's ip in trampoline stack (Jerome Marchand) [2041365]
- selftests/bpf: Add a test with bpf_timer in inner map. (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_timer test. (Jerome Marchand) [2041365]
- bpf: Teach stack depth check about async callbacks. (Jerome Marchand) [2041365]
- bpf: Implement verifier support for validation of async callbacks. (Jerome Marchand) [2041365]
- bpf: Relax verifier recursion check. (Jerome Marchand) [2041365]
- bpf: Remember BTF of inner maps. (Jerome Marchand) [2041365]
- bpf: Prevent pointer mismatch in bpf_timer_init. (Jerome Marchand) [2041365]
- bpf: Add map side support for bpf timers. (Jerome Marchand) [2041365]
- bpf: Introduce bpf timers. (Jerome Marchand) [2041365]
- bpf: Factor out bpf_spin_lock into helpers. (Jerome Marchand) [2041365]
- bpf: Prepare bpf_prog_put() to be called from irq context. (Jerome Marchand) [2041365]
- selftests/bpf: Remove unused variable in tc_tunnel prog (Jerome Marchand) [2041365]
- bpf: Fix potential memleak and UAF in the verifier. (Jerome Marchand) [2041365]
- bpf: Fix a typo of reuseport map in bpf.h. (Jerome Marchand) [2041365]
- bpf: Sync tools/include/uapi/linux/bpf.h (Jerome Marchand) [2041365]
- libbpf: Fix reuse of pinned map on older kernel (Jerome Marchand) [2041365]
- samples/bpf: xdp_redirect_cpu_user: Cpumap qsize set larger default (Jerome Marchand) [2041365]
- bpf: Tidy xdp attach selftests (Jerome Marchand) [2041365]
- bpf: devmap: Implement devmap prog execution for generic XDP (Jerome Marchand) [2041365]
- bpf: cpumap: Implement generic cpumap (Jerome Marchand) [2041365]
- bitops: Add non-atomic bitops for pointers (Jerome Marchand) [2041365]
- net: core: Split out code to run generic XDP prog (Jerome Marchand) [2041365]
- selftests/bpf: Add test for xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support specifying ingress via xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support input xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Add function for XDP meta data length check (Jerome Marchand) [2041365]

* Wed May 25 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-99.el9]
- HID: intel-ish-hid: fix module device-id handling (Tony Camuso) [1921376]
- mod_devicetable: fix kdocs for ishtp_device_id (Tony Camuso) [1921376]
- HID: intel-ish-hid: add support for MODULE_DEVICE_TABLE() (Tony Camuso) [1921376]
- platform/x86: isthp_eclite: only load for matching devices (Tony Camuso) [1921376]
- platform/x86: Add Intel ishtp eclite driver (Tony Camuso) [1921376]
- platform/x86: Add config file for Intel ishtp eclite driver (Tony Camuso) [1921376]
- net: drop_monitor: support drop reason (Hangbin Liu) [2083432]
- drop_monitor: fix data-race in dropmon_net_event / trace_napi_poll_hit (Hangbin Liu) [2083432]
- net: __pskb_pull_tail() & pskb_carve_frag_list() drop_monitor friends (Hangbin Liu) [2083432]
- scsi: megaraid_sas: Remove unnecessary memset (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Target with invalid LUN ID is deleted during scan (Tomas Henzl) [2049680]
- scsi: megasas: Clean up some inconsistent indenting (Tomas Henzl) [2049680]
- scsi: megasas: Stop using the SCSI pointer (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049680]
- selftests: tc-testing: Increase timeout in tdc config file (Hangbin Liu) [2077385]
- selftests/tc-testing: Fix cannot create /sys/bus/netdevsim/new_device: Directory nonexistent (Hangbin Liu) [2077385]
- selftests/tc-testing: add missing config (Hangbin Liu) [2077385]
- selftests/tc-testing: add exit code (Hangbin Liu) [2077385]
- selftests/tc-testings: Be compatible with newer tc output (Hangbin Liu) [2077385]
- selftests: tls: add missing AES256-GCM cipher (Hangbin Liu) [2077385]
- selftests: tls: add missing AES-CCM cipher tests (Hangbin Liu) [2077385]
- selftests: tls: add tests for handling of bad records (Hangbin Liu) [2077385]
- selftests: tls: factor out cmsg send/receive (Hangbin Liu) [2077385]
- selftests: tls: add helper for creating sock pairs (Hangbin Liu) [2077385]
- selftests: netfilter: remove stray bash debug line (Hangbin Liu) [2077385]
- selftests: netfilter: check stateless nat udp checksum fixup (Hangbin Liu) [2077385]
- selftests: netfilter: fix exit value for nft_concat_range (Hangbin Liu) [2077385]
- selftests: netfilter: disable rp_filter on router (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for pedit munge SIP and DIP (Hangbin Liu) [2077385]
- selftests: forwarding: Add Q-in-VNI test for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN symmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN asymmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-aware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-unaware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: vxlan_bridge_1q: Remove unused function (Hangbin Liu) [2077385]
- selftests: net: bridge: Parameterize ageing timeout (Hangbin Liu) [2077385]
- selftests: lib.sh: Add PING_COUNT to allow sending configurable amount of packets (Hangbin Liu) [2077385]
- selftests: net: fix array_size.cocci warning (Hangbin Liu) [2077385]
- selftests: test_vxlan_under_vrf: Fix broken test case (Hangbin Liu) [2077385]
- selftests: net: change fprintf format specifiers (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill nettest processes launched in subshell. (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill tcpdump processes launched by subshell. (Hangbin Liu) [2077385]
- selftests: fib offload: use sensible tos values (Hangbin Liu) [2077385]
- selftests: rtnetlink: Use more sensible tos values (Hangbin Liu) [2077385]
- selftests: fib rule: Don't echo modified sysctls (Hangbin Liu) [2077385]
- selftests: fib rule: Log test description (Hangbin Liu) [2077385]
- selftests: fib rule: Drop erroneous TABLE variable (Hangbin Liu) [2077385]
- selftests: fib rule: Make 'getmatch' and 'match' local variables (Hangbin Liu) [2077385]
- selftests/net: timestamping: Fix bind_phc check (Hangbin Liu) [2077385]
- kselftests/net: adapt the timeout to the largest runtime (Hangbin Liu) [2077385]
- kselftests/net: list all available tests in usage() (Hangbin Liu) [2077385]
- selftests: net/fcnal-test.sh: add exit code (Hangbin Liu) [2077385]
- selftests: net: remove meaningless help option (Hangbin Liu) [2077385]
- selftests: net: fib_nexthops: add test for group refcount imbalance bug (Hangbin Liu) [2077385]
- selftests/net: expand gro with two machine test (Hangbin Liu) [2077385]
- selftests/net: remove ARRAY_SIZE define from individual tests (Hangbin Liu) [2077385]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Hangbin Liu) [2077385]
- cpuidle: intel_idle: Drop redundant backslash at line end (Steve Best) [2072895]
- intel_idle: add core C6 optimization for SPR (Steve Best) [2072895]
- intel_idle: add 'preferred_cstates' module argument (Steve Best) [2072895]
- intel_idle: add SPR support (Steve Best) [2072895]
- intel_idle: enable interrupts before C1 on Xeons (Steve Best) [2072895]
- cpupower: Add "perf" option to print AMD P-State information (Steve Best) [2059367]
- cpupower: Add function to print AMD P-State performance capabilities (Steve Best) [2059367]
- cpupower: Move print_speed function into misc helper (Steve Best) [2059367]
- cpupower: Enable boost state support for AMD P-State module (Steve Best) [2059367]
- cpupower: Add AMD P-State sysfs definition and access helper (Steve Best) [2059367]
- cpupower: Introduce ACPI CPPC library (Steve Best) [2059367]
- cpupower: Add the function to get the sysfs value from specific table (Steve Best) [2059367]
- cpupower: Initial AMD P-State capability (Steve Best) [2059367]
- cpupower: Add the function to check AMD P-State enabled (Steve Best) [2059367]
- cpupower: Add AMD P-State capability flag (Steve Best) [2059367]
- tools/power/cpupower/{ToDo => TODO}: Rename the todo file (Steve Best) [2059367]
- tools: cpupower: fix typo in cpupower-idle-set(1) manpage (Steve Best) [2059367]
- redhat: support virtio-mem on aarch64 as tech-preview (Gavin Shan) [2044155]
- drivers/virtio: Enable virtio mem for ARM64 (Gavin Shan) [2044155]
- virtio: drop default for virtio-mem (Gavin Shan) [2044155]
- arm64/mm: avoid fixmap race condition when create pud mapping (Gavin Shan) [2044155]
- libceph: fix misleading ceph_osdc_cancel_request() comment (Jeffrey Layton) [2071641]
- libceph: fix potential use-after-free on linger ping and resends (Jeffrey Layton) [2071641]
- ceph: fix setting of xattrs on async created inodes (Jeffrey Layton) [2071641]
- ceph: fix possible NULL pointer dereference for req->r_session (Jeffrey Layton) [2071641]
- ceph: remove incorrect session state check (Jeffrey Layton) [2071641]
- ceph: get snap_rwsem read lock in handle_cap_export for ceph_add_cap (Jeffrey Layton) [2071641]
- libceph: disambiguate cluster/pool full log message (Jeffrey Layton) [2071641]
- ceph: remove reliance on bdi congestion (Jeffrey Layton) [2071641]
- ceph: fix memory leak in ceph_readdir when note_last_dentry returns error (Jeffrey Layton) [2071641]
- ceph: use tracked average r/w/m latencies to display metrics in debugfs (Jeffrey Layton) [2071641]
- ceph: include average/stdev r/w/m latency in mds metrics (Jeffrey Layton) [2071641]
- ceph: track average r/w/m latency (Jeffrey Layton) [2071641]
- ceph: use ktime_to_timespec64() rather than jiffies_to_timespec64() (Jeffrey Layton) [2071641]
- ceph: assign the ci only when the inode isn't NULL (Jeffrey Layton) [2071641]
- ceph: fix inode reference leakage in ceph_get_snapdir() (Jeffrey Layton) [2071641]
- ceph: misc fix for code style and logs (Jeffrey Layton) [2071641]
- ceph: allocate capsnap memory outside of ceph_queue_cap_snap() (Jeffrey Layton) [2071641]
- ceph: do not release the global snaprealm until unmounting (Jeffrey Layton) [2071641]
- ceph: remove incorrect and unused CEPH_INO_DOTDOT macro (Jeffrey Layton) [2071641]
- ceph: eliminate the recursion when rebuilding the snap context (Jeffrey Layton) [2071641]
- ceph: do not update snapshot context when there is no new snapshot (Jeffrey Layton) [2071641]
- ceph: zero the dir_entries memory when allocating it (Jeffrey Layton) [2071641]
- ceph: move to a dedicated slabcache for ceph_cap_snap (Jeffrey Layton) [2071641]
- ceph: add getvxattr op (Jeffrey Layton) [2071641]
- libceph: drop else branches in prepare_read_data{,_cont} (Jeffrey Layton) [2071641]
- ceph: fix comments mentioning i_mutex (Jeffrey Layton) [2071641]
- ceph: fail the request directly if handle_reply gets an ESTALE (Jeffrey Layton) [2071641]
- ceph: wake waiters after failed async create (Jeffrey Layton) [2071641]
- ceph: wait for async create reply before sending any cap messages (Jeffrey Layton) [2071641]
- ceph: eliminate req->r_wait_for_completion from ceph_mds_request (Jeffrey Layton) [2071641]
- ceph: switch netfs read ops to use rreq->inode instead of rreq->mapping->host (Jeffrey Layton) [2071641]
- libceph: optionally use bounce buffer on recv path in crc mode (Jeffrey Layton) [2071641]
- libceph: make recv path in secure mode work the same as send path (Jeffrey Layton) [2071641]
- ceph: set pool_ns in new inode layout for async creates (Jeffrey Layton) [2071641]
- ceph: properly put ceph_string reference after async create attempt (Jeffrey Layton) [2071641]
- ceph: put the requests/sessions when it fails to alloc memory (Jeffrey Layton) [2071641]
- ceph: move CEPH_SUPER_MAGIC definition to magic.h (Jeffrey Layton) [2071641]
- ceph: remove redundant Lsx caps check (Jeffrey Layton) [2071641]
- ceph: add new "nopagecache" option (Jeffrey Layton) [2071641]
- ceph: don't check for quotas on MDS stray dirs (Jeffrey Layton) [2071641]
- ceph: drop send metrics debug message (Jeffrey Layton) [2071641]
- rbd: make const pointer spaces a static const array (Jeffrey Layton) [2071641]
- ceph: Fix incorrect statfs report for small quota (Jeffrey Layton) [2071641]
- ceph: mount syntax module parameter (Jeffrey Layton) [2071641]
- ceph: record updated mon_addr on remount (Jeffrey Layton) [2071641]
- ceph: new device mount syntax (Jeffrey Layton) [2071641]
- libceph: rename parse_fsid() to ceph_parse_fsid() and export (Jeffrey Layton) [2071641]
- libceph: generalize addr/ip parsing based on delimiter (Jeffrey Layton) [2071641]
- ceph: fix up non-directory creation in SGID directories (Jeffrey Layton) [2071641]
- ceph: initialize pathlen variable in reconnect_caps_cb (Jeffrey Layton) [2071641]
- ceph: initialize i_size variable in ceph_sync_read (Jeffrey Layton) [2071641]
- ceph: fix duplicate increment of opened_inodes metric (Jeffrey Layton) [2071641]

* Tue May 24 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-98.el9]
- hv_balloon: rate-limit "Unhandled message" warning (Vitaly Kuznetsov) [2088401]
- scsi: qla2xxx: Fix typos in comments (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.400-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Increase max limit of ql2xnvme_queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use correct feature type field during RFF_ID processing (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session of PRLI reject (Nilesh Javali) [2046623]
- scsi: qla2xxx: Reduce false trigger to login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix laggy FC remote port session recovery (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang due to session stuck (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash during module load unload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix loss of NVMe namespaces after driver reload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix incorrect reporting of task management failure (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for q_dev_state (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for port_[d]state_str (Nilesh Javali) [2046623]
- scsi: qla2xxx: Stop using the SCSI pointer (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused qla_sess_op_cmd_list from scsi_qla_host_t (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add qla2x00_async_done() for async routines (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.300-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware dump already collected (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add devids and conditionals for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for 28XX adapters (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning for missing error code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix device reconnect in loop topology (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add ql2xnvme_queues module param to configure number of NVMe queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add retry for exec firmware (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix scheduling while atomic (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix premature hw access after PCI error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning message due to adisc being flushed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session in gpdb (Nilesh Javali) [2046623]
- scsi: qla2xxx: Implement ref count for SRB (Nilesh Javali) [2046623]
- scsi: qla2xxx: Refactor asynchronous command initialization (Nilesh Javali) [2046623]
- scsi: qla2xxx: Synchronize rport dev_loss_tmo setting (Nilesh Javali) [2046623]
- scsi: qla2xxx: Format log strings only if needed (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix off by one bug in qla_edif_app_getfcinfo() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix mailbox direction flags in qla2xxx_get_adapter_id() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF bsg (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix inconsistent check of db_flags (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increase ELS payload (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reduce connection thrash (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Tweak trace message (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Replace list_for_each_safe with list_for_each_entry_safe (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Flush stale events and msgs on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start delay (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start fail (Nilesh Javali) [2046623]
- scsi: qla2xxx: Turn off target reset during issue_lip (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix gnl list corruption (Nilesh Javali) [2046623]
- scsi: qla2xxx: Relogin during fabric disturbance (Nilesh Javali) [2046623]
- qla2xxx: add ->map_queues support for nvme (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unmap of already freed sgl (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Return -ENOMEM if kzalloc() fails (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove a declaration (Nilesh Javali) [2046623]
- scsi: target: qla2xxx: Replace enable attr with ops.enable (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix excessive messages during device logout (Nilesh Javali) [2046623]
- scsi: qla2xxx: Restore initiator in dual mode (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of pointer req (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in eh_abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Move heartbeat handling from DPC thread to workqueue (Nilesh Javali) [2046623]
- scsi: qla2xxx: Call process_response_queue() in Tx path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix kernel crash when accessing port_speed sysfs file (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Use link event to wake up app (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash in NVMe abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware capability before creating QPair (Nilesh Javali) [2046623]
- scsi: qla2xxx: Display 16G only as supported speeds for 3830c card (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add support for mailbox passthru (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_device_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_target_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Do not call fc_block_scsi_eh() during bus reset (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix returnvar.cocci warnings (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe session down detection (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe retry (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang on NVMe command timeouts (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe | FCP personality change (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Do secure PLOGI when auth app is present (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add N2N support for EDIF (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang during NVMe session tear down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF enable flag (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reject AUTH ELS on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix stale session (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress unnecessary log messages during login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NPIV create erroneous error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unsafe removal from linked list (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix port type info (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add debug print of 64G link speed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Show OS name and version in FDMI-1 (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support FCP2 Target (Nilesh Javali) [2046623]
- scsi: qla2xxx: Adjust request/response queue size for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add host attribute to trigger MPI hang (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of variable num_cnt (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in debug code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix spelling mistakes "allloc" -> "alloc" (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.00.107-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increment command and completion counts (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add encryption to I/O path (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add doorbell notification for app (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add detection of secure device (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add authentication pass + fail bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add key update (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add extraction of auth_els from the wire (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add send, receive, and accept for auth_els (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add getfcinfo and statistic bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add start + stop bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused variable 'status' (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant continue statement in a for-loop (Nilesh Javali) [2046623]
- KVM: s390: pv: make use of ultravisor AIV support (Thomas Huth) [2044300]

* Mon May 23 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-97.el9]
- tcp: drop the hash_32() part from the index calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: increase source port perturb table to 2^16 (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: dynamically allocate the perturb table used by source ports (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: add small random increments to the source port (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: resalt the secret every 10 seconds (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: use different parts of the port_offset for index and offset (Guillaume Nault) [2064868] {CVE-2022-1012}
- secure_seq: use the 64 bits of the siphash for port offset calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- esp: limit skb_page_frag_refill use to a single page (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- esp: Fix possible buffer overflow in ESP transformation (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- cifs: truncate the inode and mapping when we simulate fcollapse (Ronnie Sahlberg) [1997367]
- bpf: Fix renaming task_getsecid_subj->current_getsecid_subj. (Ondrej Mosnacek) [2083580]
- selinux: use correct type for context length (Ondrej Mosnacek) [2083580]
- selinux: drop return statement at end of void functions (Ondrej Mosnacek) [2083580]
- selinux: parse contexts for mount options early (Ondrej Mosnacek) [2083580]
- selinux: various sparse fixes (Ondrej Mosnacek) [2083580]
- selinux: try to use preparsed sid before calling parse_sid() (Ondrej Mosnacek) [2083580]
- selinux: Fix selinux_sb_mnt_opts_compat() (Ondrej Mosnacek) [2083580]
- LSM: general protection fault in legacy_parse_param (Ondrej Mosnacek) [2083580]
- selinux: fix a type cast problem in cred_init_security() (Ondrej Mosnacek) [2083580]
- selinux: drop unused macro (Ondrej Mosnacek) [2083580]
- selinux: simplify cred_init_security (Ondrej Mosnacek) [2083580]
- selinux: do not discard const qualifier in cast (Ondrej Mosnacek) [2083580]
- selinux: drop unused parameter of avtab_insert_node (Ondrej Mosnacek) [2083580]
- selinux: drop cast to same type (Ondrej Mosnacek) [2083580]
- selinux: enclose macro arguments in parenthesis (Ondrej Mosnacek) [2083580]
- selinux: declare name parameter of hash_eval const (Ondrej Mosnacek) [2083580]
- selinux: declare path parameters of _genfs_sid const (Ondrej Mosnacek) [2083580]
- selinux: check return value of sel_make_avc_files (Ondrej Mosnacek) [2083580]
- selinux: access superblock_security_struct in LSM blob way (Ondrej Mosnacek) [2083580]
- selinux: fix misuse of mutex_is_locked() (Ondrej Mosnacek) [2050966 2083580]
- selinux: minor tweaks to selinux_add_opt() (Ondrej Mosnacek) [2083580]
- selinux: fix potential memleak in selinux_add_opt() (Ondrej Mosnacek) [2083580]
- security,selinux: remove security_add_mnt_opt() (Ondrej Mosnacek) [2083580]
- selinux: Use struct_size() helper in kmalloc() (Ondrej Mosnacek) [2083580]
- lsm: security_task_getsecid_subj() -> security_current_getsecid_subj() (Ondrej Mosnacek) [2083580]
- selinux: initialize proto variable in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- selinux: fix sleeping function called from invalid context (Ondrej Mosnacek) [2083580]
- selinux: fix a sock regression in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- LSM: Avoid warnings about potentially unused hook variables (Ondrej Mosnacek) [2083580]
- selinux: fix all of the W=1 build warnings (Ondrej Mosnacek) [2083580]
- selinux: make better use of the nf_hook_state passed to the NF hooks (Ondrej Mosnacek) [2083580]
- selinux: fix race condition when computing ocontext SIDs (Ondrej Mosnacek) [2083580]
- selinux: remove unneeded ipv6 hook wrappers (Ondrej Mosnacek) [2083580]
- security: remove unneeded subdir-$(CONFIG_...) (Ondrej Mosnacek) [2083580]
- selinux: return early for possible NULL audit buffers (Ondrej Mosnacek) [2083580]
- quota: make dquot_quota_sync return errors from ->sync_fs (Lukas Czerner) [2083053]
- redhat: Enable VM kselftests (Nico Pache) [2081818]
- selftests/vm: Makefile: s/TARGETS/VMTARGETS/g (Joel Savitz) [2081818]
- redhat: Enable HMM test to be used by the kselftest test suite (Nico Pache) [2081818]
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Nico Pache) [2081818]
- net: bridge: switchdev: check br_vlan_group() return value (Ivan Vecera) [2081601]
- net: bridge: mst: Restrict info size queries to bridge ports (Ivan Vecera) [2081601]
- net: bridge: mst: prevent NULL deref in br_mst_info_size() (Ivan Vecera) [2081601]
- selftests: forwarding: Use same VRF for port and VLAN upper (Ivan Vecera) [2081601]
- selftests: forwarding: Disable learning before link up (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to query a port's MST state (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to check if MST is enabled (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to map an MSTI to a VID set (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST state changes (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of VLAN MSTI migrations (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST mode changes (Ivan Vecera) [2081601]
- net: bridge: mst: Support setting and reporting MST port states (Ivan Vecera) [2081601]
- net: bridge: mst: Allow changing a VLAN's MSTI (Ivan Vecera) [2081601]
- net: bridge: mst: Multiple Spanning Tree (MST) mode (Ivan Vecera) [2081601]
- net: switchdev: remove lag_mod_cb from switchdev_handle_fdb_event_to_device (Ivan Vecera) [2081601]
- selftests: forwarding: tests of locked port feature (Ivan Vecera) [2081601]
- net: bridge: Add support for offloading of locked port flag (Ivan Vecera) [2081601]
- net: bridge: Add support for bridge port in locked mode (Ivan Vecera) [2081601]
- net: switchdev: avoid infinite recursion from LAG to bridge with port object handler (Ivan Vecera) [2081601]
- bridge: switch br_net_exit to batch mode (Ivan Vecera) [2081601]
- net: bridge: multicast: notify switchdev driver whenever MC processing gets disabled (Ivan Vecera) [2081601]
- net: switchdev: introduce switchdev_handle_port_obj_{add,del} for foreign interfaces (Ivan Vecera) [2081601]
- net: switchdev: rename switchdev_lower_dev_find to switchdev_lower_dev_find_rcu (Ivan Vecera) [2081601]
- net: bridge: switchdev: replay all VLAN groups (Ivan Vecera) [2081601]
- net: bridge: make nbp_switchdev_unsync_objs() follow reverse order of sync() (Ivan Vecera) [2081601]
- net: bridge: switchdev: differentiate new VLANs from changed ones (Ivan Vecera) [2081601]
- net: bridge: vlan: notify switchdev only when something changed (Ivan Vecera) [2081601]
- net: bridge: vlan: make __vlan_add_flags react only to PVID and UNTAGGED (Ivan Vecera) [2081601]
- net: bridge: vlan: don't notify to switchdev master VLANs without BRENTRY flag (Ivan Vecera) [2081601]
- net: bridge: vlan: check early for lack of BRENTRY flag in br_vlan_add_existing (Ivan Vecera) [2081601]
- net: bridge: vlan: check for errors from __vlan_del in __vlan_flush (Ivan Vecera) [2081601]
- net/switchdev: use struct_size over open coded arithmetic (Ivan Vecera) [2081601]
- net: bridge: vlan: fix memory leak in __allowed_ingress (Ivan Vecera) [2081601]
- net: bridge: vlan: fix single net device option dumping (Ivan Vecera) [2081601]
- net: bridge: Get SIOCGIFBR/SIOCSIFBR ioctl working in compat mode (Ivan Vecera) [2081601]
- bridge: use __set_bit in __br_vlan_set_default_pvid (Ivan Vecera) [2081601]
- net: bridge: Allow base 16 inputs in sysfs (Ivan Vecera) [2081601]
- net/bridge: replace simple_strtoul to kstrtol (Ivan Vecera) [2081601]
- net: bridge: Slightly optimize 'find_portno()' (Ivan Vecera) [2081601]
- net: bridge: switchdev: fix shim definition for br_switchdev_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: switchdev: consistent function naming (Ivan Vecera) [2081601]
- net: bridge: mdb: move all switchdev logic to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: split out the switchdev portion of br_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: move br_vlan_replay to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: provide shim definition for br_vlan_flags (Ivan Vecera) [2081601]
- net: switchdev: merge switchdev_handle_fdb_{add,del}_to_device (Ivan Vecera) [2081601]
- net: bridge: create a common function for populating switchdev FDB entries (Ivan Vecera) [2081601]
- net: bridge: move br_fdb_replay inside br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: reduce indentation level in fdb_create (Ivan Vecera) [2081601]
- net: bridge: rename br_fdb_insert to br_fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: rename fdb_insert to fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: remove fdb_insert forward declaration (Ivan Vecera) [2081601]
- net: bridge: remove fdb_notify forward declaration (Ivan Vecera) [2081601]
- scsi: ses: Fix unsigned comparison with less than zero (Tomas Henzl) [2065658]
- scsi: ses: Retry failed Send/Receive Diagnostic commands (Tomas Henzl) [2065658]
- redhat/configs: enable GUP_TEST in debug kernel (Joel Savitz) [2079631]

* Thu May 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-96.el9]
- Revert "redhat: disable CONFIG_USB_CHIPIDEA" (Patrick Talbert)
- soc/tegra: Add devm_tegra_core_dev_init_opp_table_common() (Patrick Talbert) [2086164]
- powerps/pseries/dma: Add support for 2M IOMMU page size (Gustavo Walbon) [2036275]
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb() in error path (Chris von Recklinghausen) [2080377] {CVE-2022-28390}
- ibmvnic: schedule failover only if vioctl fails (Diego Domingos) [2051283]
- net/ibmvnic: Cleanup workaround doing an EOI after partition migration (Diego Domingos) [2051283]
- vfio/pci: Fix vf_token mechanism when device-specific VF drivers are used (Alex Williamson) [2076304]
- s390/vfio-ap: fix kernel doc and signature of group notifier functions (Alex Williamson) [2076304]
- vfio-pci: Provide reviewers and acceptance criteria for variant drivers (Alex Williamson) [2076304]
- PCI/IOV: Fix wrong kernel-doc identifier (Alex Williamson) [2076304]
- vfio/pci: Expose vfio_pci_core_aer_err_detected() (Alex Williamson) [2076304]
- vfio: Remove migration protocol v1 documentation (Alex Williamson) [2076304]
- vfio: Extend the device migration protocol with RUNNING_P2P (Alex Williamson) [2076304]
- vfio: Define device migration protocol v2 (Alex Williamson) [2076304]
- vfio: Have the core code decode the VFIO_DEVICE_FEATURE ioctl (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_get_pf_drvdata() to allow VF reaching the drvdata of a PF (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_vf_id() to get VF index (Alex Williamson) [2076304]
- vfio/pci: wake-up devices around reset functions (Alex Williamson) [2076304]
- vfio/pci: fix memory leak during D3hot to D0 transition (Alex Williamson) [2076304]
- vfio/pci: Stub vfio_pci_vga_rw when !CONFIG_VFIO_PCI_VGA (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the vfio_ap_irq_enable function (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the handle_pqap function (Alex Williamson) [2076304]
- s390-vfio-ap: introduces s390 kernel debug feature for vfio_ap device driver (Alex Williamson) [2076304]
- vfio/iommu_type1: replace kfree with kvfree (Alex Williamson) [2076304]
- vfio/pci: Resolve sparse endian warnings in IGD support (Alex Williamson) [2076304]
- s390/vfio-ap: add status attribute to AP queue device's sysfs dir (Alex Williamson) [2076304]
- s390/cio: remove uevent suppress from cio driver (Alex Williamson) [2076304]
- vfio/pci: Fix OpRegion read (Alex Williamson) [2076304]
- vfio: remove all kernel-doc notation (Alex Williamson) [2076304]
- vfio/ccw: Convert to use vfio_register_emulated_iommu_dev() (Alex Williamson) [2076304]
- vfio/ccw: Pass vfio_ccw_private not mdev_device to various functions (Alex Williamson) [2076304]
- vfio/ccw: Use functions for alloc/free of the vfio_ccw_private (Alex Williamson) [2076304]
- vfio/ccw: Remove unneeded GFP_DMA (Alex Williamson) [2076304]
- s390/vfio-ap: s390/crypto: fix all kernel-doc warnings (Alex Williamson) [2076304]
- vfio: Use cdev_device_add() instead of device_create() (Alex Williamson) [2076304]
- vfio: Use a refcount_t instead of a kref in the vfio_group (Alex Williamson) [2076304]
- vfio: Don't leak a group reference if the group already exists (Alex Williamson) [2076304]
- vfio: Do not open code the group list search in vfio_create_group() (Alex Williamson) [2076304]
- vfio: Delete vfio_get/put_group from vfio_iommu_group_notifier() (Alex Williamson) [2076304]
- vfio/pci: Add OpRegion 2.0+ Extended VBT support. (Alex Williamson) [2076304]
- vfio/iommu_type1: remove IS_IOMMU_CAP_DOMAIN_IN_CONTAINER (Alex Williamson) [2076304]
- vfio/iommu_type1: remove the "external" domain (Alex Williamson) [2076304]
- vfio/iommu_type1: initialize pgsize_bitmap in ->open (Alex Williamson) [2076304]
- vfio/spapr_tce: reject mediated devices (Alex Williamson) [2076304]
- vfio: clean up the check for mediated device in vfio_iommu_type1 (Alex Williamson) [2076304]
- RHEL: Kludge mdev iommu_device removal (Alex Williamson) [2076304]
- vfio: move the vfio_iommu_driver_ops interface out of <linux/vfio.h> (Alex Williamson) [2076304]
- vfio: remove unused method from vfio_iommu_driver_ops (Alex Williamson) [2076304]
- vfio: simplify iommu group allocation for mediated devices (Alex Williamson) [2076304]
- vfio: remove the iommudata hack for noiommu groups (Alex Williamson) [2076304]
- vfio: refactor noiommu group creation (Alex Williamson) [2076304]
- vfio: factor out a vfio_group_find_or_alloc helper (Alex Williamson) [2076304]
- vfio: remove the iommudata check in vfio_noiommu_attach_group (Alex Williamson) [2076304]
- vfio: factor out a vfio_iommu_driver_allowed helper (Alex Williamson) [2076304]
- vfio: Move vfio_iommu_group_get() to vfio_register_group_dev() (Alex Williamson) [2076304]
- vfio/fsl-mc: Add per device reset support (Alex Williamson) [2076304]
- bus/fsl-mc: Add generic implementation for open/reset/close commands (Alex Williamson) [2076304]
- vfio/ap_ops: Add missed vfio_uninit_group_dev() (Alex Williamson) [2076304]
- vfio/pci: add missing identifier name in argument of function prototype (Alex Williamson) [2076304]
- vfio/pci: Introduce vfio_pci_core.ko (Alex Williamson) [2076304]
- vfio: Use kconfig if XX/endif blocks instead of repeating 'depends on' (Alex Williamson) [2076304]
- vfio: Use select for eventfd (Alex Williamson) [2076304]
- PCI / VFIO: Add 'override_only' support for VFIO PCI sub system (Alex Williamson) [2076304]
- PCI: Add 'override_only' field to struct pci_device_id (Alex Williamson) [2076304]
- vfio/pci: Move module parameters to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Move igd initialization to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Split the pci_driver code out of vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/pci: Include vfio header in vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename ops functions to fit core namings (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_device to vfio_pci_core_device (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_private.h to vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci.c to vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/ap_ops: Convert to use vfio_register_group_dev() (Alex Williamson) [2076304]
- s390/crypto: fix all kernel-doc warnings in vfio_ap_ops.c (Alex Williamson) [2076304]
- vfio/type1: Fix vfio_find_dma_valid return (Alex Williamson) [2076304]
- vfio-pci/zdev: Remove repeated verbose license text (Alex Williamson) [2076304]
- vfio: platform: reset: Convert to SPDX identifier (Alex Williamson) [2076304]
- vfio: Remove struct vfio_device_ops open/release (Alex Williamson) [2076304]
- vfio/gvt: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/ap,ccw: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/mbochs: Fix close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/pci: Reorganize VFIO_DEVICE_PCI_HOT_RESET to use the device set (Alex Williamson) [2076304]
- vfio/pci: Change vfio_pci_try_bus_reset() to use the dev_set (Alex Williamson) [2076304]
- vfio/pci: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/platform: Use open_device() instead of open coding a refcnt scheme (Alex Williamson) [2076304]
- vfio/fsl: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/samples: Delete useless open/close (Alex Williamson) [2076304]
- vfio: Provide better generic support for open/release vfio_device_ops (Alex Williamson) [2076304]
- vfio: Introduce a vfio_uninit_group_dev() API call (Alex Williamson) [2076304]
- vfio/mbochs: Fix missing error unwind of mbochs_used_mbytes (Alex Williamson) [2076304]
- vfio/samples: Remove module get/put (Alex Williamson) [2076304]
- vfio/mdev: don't warn if ->request is not set (Alex Williamson) [2076304]
- vfio/mdev: turn mdev_init into a subsys_initcall (Alex Williamson) [2076304]
- vfio/pci: Make vfio_pci_regops->rw() return ssize_t (Alex Williamson) [2076304]
- vfio: Use config not menuconfig for VFIO_NOIOMMU (Alex Williamson) [2076304]

* Wed May 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-95.el9]
- mm: create a new system state and fix core_kernel_text() (Patrick Talbert) [2076713]
- vmxnet3: Remove useless DMA-32 fallback configuration (Kamal Heib) [2083562]
- vmxnet3: fix minimum vectors alloc issue (Kamal Heib) [2083562]
- net: vmxnet3: remove multiple false checks in vmxnet3_ethtool.c (Kamal Heib) [2083562]
- vmxnet3: do not stop tx queues after netif_device_detach() (Kamal Heib) [2083562]
- openvswitch: Fix setting ipv6 fields causing hw csum failure (Eelco Chaudron) [2076582]

* Wed May 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-94.el9]
- md: fix NULL pointer deref with nowait but no mddev->queue (Nigel Croxon) [2079942]
- dm integrity: fix memory corruption when tag_size is less than digest size (Benjamin Marzinski) [2081778]
- selftests: mptcp: functional tests for the userspace PM type (Davide Caratti) [2079368]
- selftests: mptcp: create listeners to receive MPJs (Davide Caratti) [2079368]
- selftests: mptcp: capture netlink events (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_DESTROY (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_CREATE (Davide Caratti) [2079368]
- mptcp: netlink: allow userspace-driven subflow establishment (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: split mptcp_pm_parse_addr into two functions (Davide Caratti) [2079368]
- mptcp: read attributes of addr entries managed by userspace PMs (Davide Caratti) [2079368]
- mptcp: handle local addrs announced by userspace PMs (Davide Caratti) [2079368]
- mptcp: allow ADD_ADDR reissuance by userspace PMs (Davide Caratti) [2079368]
- mptcp: expose server_side attribute in MPTCP netlink events (Davide Caratti) [2079368]
- mptcp: establish subflows from either end of connection (Davide Caratti) [2079368]
- mptcp: reflect remote port (not 0) in ANNOUNCED events (Davide Caratti) [2079368]
- mptcp: store remote id from MP_JOIN SYN/ACK in local ctx (Davide Caratti) [2079368]
- selftests: mptcp: ADD_ADDR echo test with missing userspace daemon (Davide Caratti) [2079368]
- mptcp: bypass in-kernel PM restrictions for non-kernel PMs (Davide Caratti) [2079368]
- selftests: mptcp: Add tests for userspace PM type (Davide Caratti) [2079368]
- mptcp: Add a per-namespace sysctl to set the default path manager type (Davide Caratti) [2079368]
- mptcp: Make kernel path manager check for userspace-managed sockets (Davide Caratti) [2079368]
- mptcp: Bypass kernel PM when userspace PM is enabled (Davide Caratti) [2079368]
- mptcp: Add a member to mptcp_pm_data to track kernel vs userspace mode (Davide Caratti) [2079368]
- mptcp: Remove redundant assignments in path manager init (Davide Caratti) [2079368]
- selftests: mptcp: print extra msg in chk_csum_nr (Davide Caratti) [2079368]
- selftests: mptcp: check MP_FAIL response mibs (Davide Caratti) [2079368]
- mptcp: reset subflow when MP_FAIL doesn't respond (Davide Caratti) [2079368]
- mptcp: add MP_FAIL response support (Davide Caratti) [2079368]
- mptcp: use mptcp_stop_timer (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map testcase (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map mibs check (Davide Caratti) [2079368]
- mptcp: add mib for infinite map sending (Davide Caratti) [2079368]
- mptcp: infinite mapping receiving (Davide Caratti) [2079368]
- mptcp: infinite mapping sending (Davide Caratti) [2079368]
- mptcp: track and update contiguous data status (Davide Caratti) [2079368]
- mptcp: add the fallback check (Davide Caratti) [2079368]
- mptcp: don't send RST for single subflow (Davide Caratti) [2079368]
- selftests/mptcp: add diag listen tests (Davide Caratti) [2079368]
- mptcp: listen diag dump support (Davide Caratti) [2079368]
- mptcp: remove locking in mptcp_diag_fill_info (Davide Caratti) [2079368]
- mptcp: diag: switch to context structure (Davide Caratti) [2079368]
- mptcp: add pm_nl_pernet helpers (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on PRIO change (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on incoming MP_PRIO (Davide Caratti) [2079368]
- mptcp: optimize release_cb for the common case (Davide Caratti) [2079368]
- mptcp: send ADD_ADDR echo before create subflows (Davide Caratti) [2079368]
- mptcp: Fix crash due to tcp_tsorted_anchor was initialized before release skb (Davide Caratti) [2079368]
- selftests: mptcp: join: make it shellcheck compliant (Davide Caratti) [2079368]
- selftests: mptcp: join: avoid backquotes (Davide Caratti) [2079368]
- selftests: mptcp: join: clarify local/global vars (Davide Caratti) [2079368]
- selftests: mptcp: join: helper to filter TCP (Davide Caratti) [2079368]
- selftests: mptcp: join: list failure at the end (Davide Caratti) [2079368]
- selftests: mptcp: join: alt. to exec specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: option to execute specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: reset failing links (Davide Caratti) [2079368]
- selftests: mptcp: join: define tests groups once (Davide Caratti) [2079368]
- selftests: mptcp: drop msg argument of chk_csum_nr (Davide Caratti) [2079368]
- mptcp: add fullmesh flag check for adding address (Davide Caratti) [2079368]
- selftests: mptcp: add implicit endpoint test case (Davide Caratti) [2079368]
- mptcp: strict local address ID selection (Davide Caratti) [2079368]
- mptcp: introduce implicit endpoints (Davide Caratti) [2079368]
- mptcp: more careful RM_ADDR generation (Davide Caratti) [2079368]
- selftests: mptcp: Rename wait function (Davide Caratti) [2079368]
- selftests: mptcp: join: allow running -cCi (Davide Caratti) [2079368]
- mptcp: use MPTCP_SUBFLOW_NODATA (Davide Caratti) [2079368]
- mptcp: add tracepoint in mptcp_sendmsg_frag (Davide Caratti) [2079368]
- selftests: mptcp: update output info of chk_rm_nr (Davide Caratti) [2079368]
- selftests: mptcp: add more arguments for chk_join_nr (Davide Caratti) [2079368]
- selftests: mptcp: add invert check in check_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add fastclose testcase (Davide Caratti) [2079368]
- selftests: mptcp: reuse linkfail to make given size files (Davide Caratti) [2079368]
- selftests: mptcp: add extra_args in do_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_RST mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_RST (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_FASTCLOSE mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_FASTCLOSE (Davide Caratti) [2079368]
- selftests: mptcp: adjust output alignment for more tests (Davide Caratti) [2079368]
- mptcp: Correctly set DATA_FIN timeout when number of retransmits is large (Davide Caratti) [2079368]
- selftests: mptcp: do complete cleanup at exit (Davide Caratti) [2079368]
- mptcp: accurate SIOCOUTQ for fallback socket (Davide Caratti) [2079368]
- selftests: mptcp: Add the uapi headers include variable (Davide Caratti) [2079368]
- selftests: mptcp: be more conservative with cookie MPJ limits (Davide Caratti) [2079368]
- selftests: mptcp: more robust signal race test (Davide Caratti) [2079368]
- mptcp: add mibs counter for ignored incoming options (Davide Caratti) [2079368]
- mptcp: fix race in incoming ADD_ADDR option processing (Davide Caratti) [2079368]
- mptcp: fix race in overlapping signal events (Davide Caratti) [2079368]
- selftests: mptcp: improve 'fair usage on close' stability (Davide Caratti) [2079368]
- selftests: mptcp: fix diag instability (Davide Caratti) [2079368]
- selftests: mptcp: add csum mib check for mptcp_connect (Davide Caratti) [2079368]
- selftests: mptcp: join: check for tools only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: create tmp files only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: remove unused vars (Davide Caratti) [2079368]
- selftests: mptcp: join: exit after usage() (Davide Caratti) [2079368]
- selftests: mptcp: simplify pm_nl_change_endpoint (Davide Caratti) [2079368]
- selftests: mptcp: increase timeout to 20 minutes (Davide Caratti) [2079368]
- mptcp: don't save tcp data_ready and write space callbacks (Davide Caratti) [2079368]
- mptcp: mark ops structures as ro_after_init (Davide Caratti) [2079368]
- mptcp: constify a bunch of of helpers (Davide Caratti) [2079368]
- mptcp: drop port parameter of mptcp_pm_add_addr_signal (Davide Caratti) [2079368]
- mptcp: drop unneeded type casts for hmac (Davide Caratti) [2079368]
- mptcp: drop unused sk in mptcp_get_options (Davide Caratti) [2079368]
- mptcp: mptcp_parse_option is no longer exported (Davide Caratti) [2079368]
- mptcp: add SNDTIMEO setsockopt support (Davide Caratti) [2079368]
- mptcp: netlink: process IPv6 addrs in creating listening sockets (Davide Caratti) [2079368]
- selftests: mptcp: add missing join check (Davide Caratti) [2079368]
- selftests: mptcp: set ip_mptcp in command line (Davide Caratti) [2079368]
- selftests: mptcp: add set_flags tests in pm_netlink.sh (Davide Caratti) [2079368]
- selftests: mptcp: add the id argument for set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for setting flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for showing addrs (Davide Caratti) [2079368]
- selftests: mptcp: add ip mptcp wrappers (Davide Caratti) [2079368]
- selftests: mptcp: add backup with port testcase (Davide Caratti) [2079368]
- selftests: mptcp: add the port argument for set_flags (Davide Caratti) [2079368]
- mptcp: allow to use port and non-signal in set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add fullmesh setting tests (Davide Caratti) [2079368]
- selftests: mptcp: set fullmesh flag in pm_nl_ctl (Davide Caratti) [2079368]
- mptcp: set fullmesh flag in pm_netlink (Davide Caratti) [2079368]
- mptcp: print out reset infos of MP_RST (Davide Caratti) [2079368]
- mptcp: clarify when options can be used (Davide Caratti) [2079368]
- mptcp: reduce branching when writing MP_FAIL option (Davide Caratti) [2079368]
- mptcp: move the declarations of ssk and subflow (Davide Caratti) [2079368]
- mptcp: Use struct_group() to avoid cross-field memset() (Davide Caratti) [2079368]
- selftests: mptcp: fix ipv6 routing setup (Davide Caratti) [2079368]
- mptcp: fix removing ids bitmap setting (Davide Caratti) [2079368]
- mptcp: fix msk traversal in mptcp_nl_cmd_set_flags() (Davide Caratti) [2079368]
- mptcp: reuse __mptcp_make_csum in validate_data_csum (Davide Caratti) [2079368]
- mptcp: change the parameter of __mptcp_make_csum (Davide Caratti) [2079368]
- selftests: mptcp: more stable join tests-cases (Davide Caratti) [2079368]
- mptcp: avoid atomic bit manipulation when possible (Davide Caratti) [2079368]
- mptcp: cleanup MPJ subflow list handling (Davide Caratti) [2079368]
- selftests: mptcp: add tests for subflow creation failure (Davide Caratti) [2079368]
- mptcp: do not block subflows creation on errors (Davide Caratti) [2079368]
- mptcp: keep track of local endpoint still available for each msk (Davide Caratti) [2079368]
- mptcp: clean-up MPJ option writing (Davide Caratti) [2079368]
- selftests: mptcp: add disconnect tests (Davide Caratti) [2079368]
- mptcp: implement support for user-space disconnect (Davide Caratti) [2079368]
- mptcp: cleanup accept and poll (Davide Caratti) [2079368]
- mptcp: full disconnect implementation (Davide Caratti) [2079368]
- mptcp: implement fastclose xmit path (Davide Caratti) [2079368]
- mptcp: keep snd_una updated for fallback socket (Davide Caratti) [2079368]
- SO_ZEROCOPY should return -EOPNOTSUPP rather than -ENOTSUPP (Hangbin Liu) [2081920]
- net: fix up skbs delta_truesize in UDP GRO frag_list (Hangbin Liu) [2081920]
- net: preserve skb_end_offset() in skb_unclone_keeptruesize() (Hangbin Liu) [2081920]
- net: add skb_set_end_offset() helper (Hangbin Liu) [2081920]
- net-timestamp: convert sk->sk_tskey to atomic_t (Hangbin Liu) [2081920]
- net: initialize init_net earlier (Hangbin Liu) [2081920]
- net: gro: avoid re-computing truesize twice on recycle (Hangbin Liu) [2081920]
- rtnetlink: make sure to refresh master_dev/m_ops in __rtnl_newlink() (Hangbin Liu) [2081920]
- net-procfs: show net devices bound packet types (Hangbin Liu) [2081920]
- net: fix information leakage in /proc/net/ptype (Hangbin Liu) [2081920]
- netns: add schedule point in ops_exit_list() (Hangbin Liu) [2081920]
- lwtunnel: Validate RTA_ENCAP_TYPE attribute length (Hangbin Liu) [2081920]
- net: Fix double 0x prefix print in SKB dump (Hangbin Liu) [2081920]
- net, neigh: clear whole pneigh_entry at alloc time (Hangbin Liu) [2081920]
- net: annotate data-races on txq->xmit_lock_owner (Hangbin Liu) [2081920]
- net: multicast: calculate csum of looped-back and forwarded packets (Hangbin Liu) [2081920]
- rtnetlink: fix if_nlmsg_stats_size() under estimation (Hangbin Liu) [2081920]
- pktgen: remove unused variable (Hangbin Liu) [2081920]
- netfilter: nft_socket: only do sk lookups when indev is available (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: re-init for syn packets only (Florian Westphal) [2080138]
- netfilter: conntrack: fix udp offload timeout sysctl (Florian Westphal) [2080138]
- netfilter: nft_set_rbtree: overlap detection with element re-addition after deletion (Florian Westphal) [2080138]
- ipvs: correctly print the memory size of ip_vs_conn_tab (Florian Westphal) [2080138]
- netfilter: nft_socket: make cgroup match work in input too (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp options (Florian Westphal) [2080138]
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Florian Westphal) [2080138]
- netfilter: flowtable: Fix QinQ and pppoe support for inet table (Florian Westphal) [2080138]
- netfilter: fix use-after-free in __nf_register_net_hook() (Florian Westphal) [2080138]
- netfilter: nf_tables: prefer kfree_rcu(ptr, rcu) variant (Florian Westphal) [2080138]
- netfilter: nf_tables: fix memory leak during stateful obj update (Florian Westphal) [2080138]
- netfilter: nft_synproxy: unregister hooks on init error path (Florian Westphal) [2080138]
- netfilter: xt_socket: fix a typo in socket_mt_destroy() (Florian Westphal) [2080138]
- netfilter: ctnetlink: disable helper autoassign (Florian Westphal) [2080138]
- netfilter: nft_payload: don't allow th access for fragments (Florian Westphal) [2080138]
- netfilter: nf_tables: convert pktinfo->tprot_set to flags field (Florian Westphal) [2080138]
- random: document crng_fast_key_erasure() destination possibility (Prarit Bhargava) [2079030]
- wireguard: device: clear keys on VM fork (Prarit Bhargava) [2079030]
- random: Add hook to override device reads and getrandom(2) (Herbert Xu) [2079030]
- selftests/bpf: fix selftest after random: Urandom_read tracepoint removal (Prarit Bhargava) [2079030]
- arm64: random: implement arch_get_random_int/_long based on RNDR (Prarit Bhargava) [2079030]
- random: use memmove instead of memcpy for remaining 32 bytes (Prarit Bhargava) [2079030]
- random: make random_get_entropy() return an unsigned long (Prarit Bhargava) [2079030]
- random: allow partial reads if later user copies fail (Prarit Bhargava) [2079030]
- random: check for signals every PAGE_SIZE chunk of /dev/[u]random (Prarit Bhargava) [2079030]
- random: check for signal_pending() outside of need_resched() check (Prarit Bhargava) [2079030]
- random: do not allow user to keep crng key around on stack (Prarit Bhargava) [2079030]
- random: opportunistically initialize on /dev/urandom reads (Prarit Bhargava) [2079030]
- random: do not split fast init input in add_hwgenerator_randomness() (Prarit Bhargava) [2079030]
- random: mix build-time latent entropy into pool at init (Prarit Bhargava) [2079030]
- random: re-add removed comment about get_random_{u32,u64} reseeding (Prarit Bhargava) [2079030]
- random: treat bootloader trust toggle the same way as cpu trust toggle (Prarit Bhargava) [2079030]
- random: skip fast_init if hwrng provides large chunk of entropy (Prarit Bhargava) [2079030]
- Revert "random: block in /dev/urandom" (Prarit Bhargava) [2079030]
- random: check for signal and try earlier when generating entropy (Prarit Bhargava) [2079030]
- random: reseed more often immediately after booting (Prarit Bhargava) [2079030]
- random: make consistent usage of crng_ready() (Prarit Bhargava) [2079030]
- random: use SipHash as interrupt entropy accumulator (Prarit Bhargava) [2079030]
- random: provide notifier for VM fork (Prarit Bhargava) [2079030]
- random: replace custom notifier chain with standard one (Prarit Bhargava) [2079030]
- random: do not export add_vmfork_randomness() unless needed (Prarit Bhargava) [2079030]
- random: add mechanism for VM forks to reinitialize crng (Prarit Bhargava) [2079030]
- random: don't let 644 read-only sysctls be written to (Prarit Bhargava) [2079030]
- random: give sysctl_random_min_urandom_seed a more sensible value (Prarit Bhargava) [2079030]
- random: block in /dev/urandom (Prarit Bhargava) [2079030]
- random: do crng pre-init loading in worker rather than irq (Prarit Bhargava) [2079030]
- random: unify cycles_t and jiffies usage and types (Prarit Bhargava) [2079030]
- random: cleanup UUID handling (Prarit Bhargava) [2079030]
- random: only wake up writers after zap if threshold was passed (Prarit Bhargava) [2079030]
- random: round-robin registers as ulong, not u32 (Prarit Bhargava) [2079030]
- random: clear fast pool, crng, and batches in cpuhp bring up (Prarit Bhargava) [2079030]
- random: check for crng_init == 0 in add_device_randomness() (Prarit Bhargava) [2079030]
- random: unify early init crng load accounting (Prarit Bhargava) [2079030]
- random: do not take pool spinlock at boot (Prarit Bhargava) [2079030]
- random: defer fast pool mixing to worker (Prarit Bhargava) [2079030]
- random: rewrite header introductory comment (Prarit Bhargava) [2079030]
- random: group sysctl functions (Prarit Bhargava) [2079030]
- random: group userspace read/write functions (Prarit Bhargava) [2079030]
- random: group entropy collection functions (Prarit Bhargava) [2079030]
- random: group entropy extraction functions (Prarit Bhargava) [2079030]
- random: group crng functions (Prarit Bhargava) [2079030]
- random: group initialization wait functions (Prarit Bhargava) [2079030]
- random: remove whitespace and reorder includes (Prarit Bhargava) [2079030]
- random: introduce drain_entropy() helper to declutter crng_reseed() (Prarit Bhargava) [2079030]
- random: deobfuscate irq u32/u64 contributions (Prarit Bhargava) [2079030]
- random: add proper SPDX header (Prarit Bhargava) [2079030]
- random: remove unused tracepoints (Prarit Bhargava) [2079030]
- random: remove ifdef'd out interrupt bench (Prarit Bhargava) [2079030]
- random: tie batched entropy generation to base_crng generation (Prarit Bhargava) [2079030]
- random: fix locking for crng_init in crng_reseed() (Prarit Bhargava) [2079030]
- random: zero buffer after reading entropy from userspace (Prarit Bhargava) [2079030]
- random: remove outdated INT_MAX >> 6 check in urandom_read() (Prarit Bhargava) [2079030]
- random: make more consistent use of integer types (Prarit Bhargava) [2079030]
- random: use hash function for crng_slow_load() (Prarit Bhargava) [2079030]
- random: use simpler fast key erasure flow on per-cpu keys (Prarit Bhargava) [2079030]
- random: absorb fast pool into input pool after fast load (Prarit Bhargava) [2079030]
- random: do not xor RDRAND when writing into /dev/random (Prarit Bhargava) [2079030]
- random: ensure early RDSEED goes through mixer on init (Prarit Bhargava) [2079030]
- random: inline leaves of rand_initialize() (Prarit Bhargava) [2079030]
- random: get rid of secondary crngs (Prarit Bhargava) [2079030]
- random: use RDSEED instead of RDRAND in entropy extraction (Prarit Bhargava) [2079030]
- random: fix locking in crng_fast_load() (Prarit Bhargava) [2079030]
- random: remove batched entropy locking (Prarit Bhargava) [2079030]
- random: remove use_input_pool parameter from crng_reseed() (Prarit Bhargava) [2079030]
- random: make credit_entropy_bits() always safe (Prarit Bhargava) [2079030]
- random: always wake up entropy writers after extraction (Prarit Bhargava) [2079030]
- random: use linear min-entropy accumulation crediting (Prarit Bhargava) [2079030]
- random: simplify entropy debiting (Prarit Bhargava) [2079030]
- random: use computational hash for entropy extraction (Prarit Bhargava) [2079030]
- random: only call crng_finalize_init() for primary_crng (Prarit Bhargava) [2079030]
- random: access primary_pool directly rather than through pointer (Prarit Bhargava) [2079030]
- random: wake up /dev/random writers after zap (Prarit Bhargava) [2079030]
- random: continually use hwgenerator randomness (Prarit Bhargava) [2079030]
- random: move the random sysctl declarations to its own file (Prarit Bhargava) [2079030]
- sysctl: add a new register_sysctl_init() interface (Prarit Bhargava) [2079030]
- random: simplify arithmetic function flow in account() (Prarit Bhargava) [2079030]
- random: selectively clang-format where it makes sense (Prarit Bhargava) [2079030]
- random: access input_pool_data directly rather than through pointer (Prarit Bhargava) [2079030]
- random: cleanup fractional entropy shift constants (Prarit Bhargava) [2079030]
- random: prepend remaining pool constants with POOL_ (Prarit Bhargava) [2079030]
- random: de-duplicate INPUT_POOL constants (Prarit Bhargava) [2079030]
- random: remove unused OUTPUT_POOL constants (Prarit Bhargava) [2079030]
- random: rather than entropy_store abstraction, use global (Prarit Bhargava) [2079030]
- random: remove unused extract_entropy() reserved argument (Prarit Bhargava) [2079030]
- random: remove incomplete last_data logic (Prarit Bhargava) [2079030]
- random: cleanup integer types (Prarit Bhargava) [2079030]
- random: cleanup poolinfo abstraction (Prarit Bhargava) [2079030]
- random: fix typo in comments (Prarit Bhargava) [2079030]
- random: don't reset crng_init_cnt on urandom_read() (Prarit Bhargava) [2079030]
- random: avoid superfluous call to RDRAND in CRNG extraction (Prarit Bhargava) [2079030]
- random: early initialization of ChaCha constants (Prarit Bhargava) [2079030]
- random: use IS_ENABLED(CONFIG_NUMA) instead of ifdefs (Prarit Bhargava) [2079030]
- random: harmonize "crng init done" messages (Prarit Bhargava) [2079030]
- random: mix bootloader randomness into pool (Prarit Bhargava) [2079030]
- random: do not throw away excess input to crng_fast_load (Prarit Bhargava) [2079030]
- random: do not re-init if crng_reseed completes before primary init (Prarit Bhargava) [2079030]
- random: fix crash on multiple early calls to add_bootloader_randomness() (Prarit Bhargava) [2079030]
- random: do not sign extend bytes for rotation when mixing (Prarit Bhargava) [2079030]
- random: use BLAKE2s instead of SHA1 in extraction (Prarit Bhargava) [2079030]
- random: fix data race on crng init time (Prarit Bhargava) [2079030]
- random: fix data race on crng_node_pool (Prarit Bhargava) [2079030]
- random: remove unused irq_flags argument from add_interrupt_randomness() (Prarit Bhargava) [2079030]
- random: document add_hwgenerator_randomness() with other input functions (Prarit Bhargava) [2079030]
- lib/crypto: add prompts back to crypto libraries (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: avoid indirect calls to compression function for Clang CFI (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: include as built-in (Prarit Bhargava) [2079030]
- crypto: drbg - ignore jitterentropy errors if not in FIPS mode (Prarit Bhargava) [2079030]
- crypto: drbg - reseed 'nopr' drbgs periodically from get_random_bytes() (Prarit Bhargava) [2079030]
- crypto: drbg - make drbg_prepare_hrng() handle jent instantiation errors (Prarit Bhargava) [2079030]
- crypto: drbg - make reseeding from get_random_bytes() synchronous (Prarit Bhargava) [2079030]
- crypto: drbg - move dynamic ->reseed_threshold adjustments to __drbg_seed() (Prarit Bhargava) [2079030]
- crypto: drbg - track whether DRBG was seeded with !rng_is_initialized() (Prarit Bhargava) [2079030]
- crypto: drbg - prepare for more fine-grained tracking of seeding state (Prarit Bhargava) [2079030]
- crypto: drbg - Fix unused value warning in drbg_healthcheck_sanity() (Prarit Bhargava) [2079030]
- Revert "random: Add hook to override device reads and getrandom(2)" (Prarit Bhargava) [2079030]
- locking/lockdep: Iterate lock_classes directly when reading lockdep files (Waiman Long) [2076713]
- lockdep: Correct lock_classes index mapping (Waiman Long) [2076713]
- locking: Enable RT_MUTEXES by default on PREEMPT_RT. (Waiman Long) [2076713]
- locking/local_lock: Make the empty local_lock_*() function a macro. (Waiman Long) [2076713]
- atomics: Fix atomic64_{read_acquire,set_release} fallbacks (Waiman Long) [2076713]
- locking/rwlocks: introduce write_lock_nested (Waiman Long) [2076713]
- locking: Add missing __sched attributes (Waiman Long) [2076713]
- locking/lockdep: Avoid potential access of invalid memory in lock_class (Waiman Long) [2076713]
- locking/rtmutex: Fix incorrect condition in rtmutex_spin_on_owner() (Waiman Long) [2076713]
- locking: Mark racy reads of owner->on_cpu (Waiman Long) [2076713]
- locking: Make owner_on_cpu() into <linux/sched.h> (Waiman Long) [2076713]
- locking: Allow to include asm/spinlock_types.h from linux/spinlock_types_raw.h (Waiman Long) [2076713]
- x86/mm: Include spinlock_t definition in pgtable. (Waiman Long) [2076713]
- lockdep/selftests: Adapt ww-tests for PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Skip the softirq related tests on PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Unbalanced migrate_disable() & rcu_read_lock(). (Waiman Long) [2076713]
- lockdep/selftests: Avoid using local_lock_{acquire|release}(). (Waiman Long) [2076713]
- lockdep: Remove softirq accounting on PREEMPT_RT. (Waiman Long) [2076713]
- locking/rtmutex: Add rt_mutex_lock_nest_lock() and rt_mutex_lock_killable(). (Waiman Long) [2076713]
- locking/rtmutex: Squash self-deadlock check for ww_rt_mutex. (Waiman Long) [2076713]
- kallsyms: remove arch specific text and data check (Waiman Long) [2076713]
- mm: make generic arch_is_kernel_initmem_freed() do what it says (Waiman Long) [2076713]
- locking: Remove spin_lock_flags() etc (Waiman Long) [2076713]
- locking/rwsem: Fix comments about reader optimistic lock stealing conditions (Waiman Long) [2076713]
- locking/rwsem: Disable preemption for spinning region (Waiman Long) [2076713]
- locking: Remove rcu_read_{,un}lock() for preempt_{dis,en}able() (Waiman Long) [2076713]
- rtmutex: Wake up the waiters lockless while dropping the read lock. (Waiman Long) [2076713]
- rtmutex: Check explicit for TASK_RTLOCK_WAIT. (Waiman Long) [2076713]
- locking/rwbase: Optimize rwbase_read_trylock (Waiman Long) [2076713]
- lockdep: Let lock_is_held_type() detect recursive read as read (Waiman Long) [2076713]
- locking/lockdep: Cleanup the repeated declaration (Waiman Long) [2076713]
- lockdep: Improve comments in wait-type checks (Waiman Long) [2076713]
- locking/lockdep: Avoid RCU-induced noinstr fail (Waiman Long) [2076713]
- rcu-tasks: Set ->percpu_enqueue_shift to zero upon contention (Waiman Long) [2076713]
- rcu-tasks: Use order_base_2() instead of ilog2() (Waiman Long) [2076713]
- rcutorture: Enable limited callback-flooding tests of SRCU (Waiman Long) [2076713]
- torture: Change KVM environment variable to RCUTORTURE (Waiman Long) [2076713]
- rcu: Add per-CPU rcuc task dumps to RCU CPU stall warnings (Waiman Long) [2076713]
- rcu: Replace cpumask_weight with cpumask_empty where appropriate (Waiman Long) [2076713]
- rcu: Don't deboost before reporting expedited quiescent state (Waiman Long) [2076713]
- torture: Make kvm-find-errors.sh notice missing vmlinux file (Waiman Long) [2076713]
- rcu: Remove __read_mostly annotations from rcu_scheduler_active externs (Waiman Long) [2076713]
- rcu: Uninline multi-use function: finish_rcuwait() (Waiman Long) [2076713]
- rcutorture: make use of the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- kthread: add the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- rcu: Update documentation regarding kthread_prio cmdline parameter (Waiman Long) [2076713]
- rcu: Elevate priority of offloaded callback threads (Waiman Long) [2076713]
- rcu: Make priority of grace-period thread consistent (Waiman Long) [2076713]
- rcu: Move kthread_prio bounds-check to a separate function (Waiman Long) [2076713]
- rcu: Mark writes to the rcu_segcblist structure's ->flags field (Waiman Long) [2076713]
- torture: Wake up kthreads after storing task_struct pointer (Waiman Long) [2076713]
- rcutorture: Fix rcu_fwd_mutex deadlock (Waiman Long) [2076713]
- rcu: Create per-cpu rcuc kthreads only when rcutree.use_softirq=0 (Waiman Long) [2076713]
- torture: Print only one summary line per run (Waiman Long) [2076713]
- kasan: Record work creation stack trace with interrupts enabled (Waiman Long) [2076713]
- torture: Make kvm-remote.sh try multiple times to download tarball (Waiman Long) [2076713]
- rcu: Inline __call_rcu() into call_rcu() (Waiman Long) [2076713]
- torture: Compress KCSAN as well as KASAN vmlinux files (Waiman Long) [2076713]
- rcutorture: Add end-of-test check to rcu_torture_fwd_prog() loop (Waiman Long) [2076713]
- rcutorture: Make rcu_fwd_cb_nodelay be a counter (Waiman Long) [2076713]
- rcutorture: Increase visibility of forward-progress hangs (Waiman Long) [2076713]
- torture: Distinguish kthread stopping and being asked to stop (Waiman Long) [2076713]
- rcu: Make rcu_barrier() no longer block CPU-hotplug operations (Waiman Long) [2076713]
- rcu: Rework rcu_barrier() and callback-migration logic (Waiman Long) [2076713]
- rcu: Mark ->expmask access in synchronize_rcu_expedited_wait() (Waiman Long) [2076713]
- rcu: Mark accesses to boost_starttime (Waiman Long) [2076713]
- rcu: Remove unused rcu_state.boost (Waiman Long) [2076713]
- rcu/exp: Fix check for idle context in rcu_exp_handler (Waiman Long) [2076713]
- rcu/nocb: Handle concurrent nocb kthreads creation (Waiman Long) [2076713]
- rcu: Refactor rcu_barrier() empty-list handling (Waiman Long) [2076713]
- rcu: Create and use an rcu_rdp_cpu_online() (Waiman Long) [2076713]
- rcu: Add mutex for rcu boost kthread spawning and affinity setting (Waiman Long) [2076713]
- rcutorture: Print message before invoking ->cb_barrier() (Waiman Long) [2076713]
- torture: Indicate which torture.sh runs' bugs are all KCSAN reports (Waiman Long) [2076713]
- torture: Make kvm.sh summaries note runs having only KCSAN reports (Waiman Long) [2076713]
- torture: Output per-failed-run summary lines from torture.sh (Waiman Long) [2076713]
- torture: Allow four-digit repetition numbers for --configs parameter (Waiman Long) [2076713]
- torture: Drop trailing ^M from console output (Waiman Long) [2076713]
- MAINTAINERS:  Add Frederic and Neeraj to their RCU files (Waiman Long) [2076713]
- rcu: Fix description of kvfree_rcu() (Waiman Long) [2076713]
- scftorture: Warn on individual scf_torture_init() error conditions (Waiman Long) [2076713]
- refscale: Warn on individual ref_scale_init() error conditions (Waiman Long) [2076713]
- torture: Make kvm-remote.sh print size of downloaded tarball (Waiman Long) [2076713]
- torture: Allot 1G of memory for scftorture runs (Waiman Long) [2076713]
- tools/rcu: Add an extract-stall script (Waiman Long) [2076713]
- scftorture: Count reschedule IPIs (Waiman Long) [2076713]
- scftorture: Shut down if nonsensical arguments given (Waiman Long) [2076713]
- scftorture: Allow zero weight to exclude an smp_call_function*() category (Waiman Long) [2076713]
- rcu: Kill rnp->ofl_seq and use only rcu_state.ofl_lock for exclusion (Waiman Long) [2076713]
- scsi: target: tcmu: Fix possible page UAF (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Remove struct pscsi_plugin_task (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Make cmd_ring_size changeable via configfs (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Make sure the np under each tpg is unique (Maurizio Lombardi) [2076591]
- scsi: target: configfs: Delete unnecessary checks for NULL (Maurizio Lombardi) [2076591]
- scsi: target: core: Use RCU helpers for INQUIRY t10_alua_tg_pt_gp (Maurizio Lombardi) [2076591]
- scsi: target: core: Remove from tmr_list during LUN unlink (Maurizio Lombardi) [2076591]
- scsi: target: core: Stop using bdevname() (Maurizio Lombardi) [2076591]
- scsi: target: Perform ALUA group changes in one step (Maurizio Lombardi) [2076591]
- scsi: target: Replace lun_tg_pt_gp_lock with rcu in I/O path (Maurizio Lombardi) [2076591]
- scsi: target: Fix alua_tg_pt_gps_count tracking (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered tag handling (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered CMD_T_SENT handling (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Allocate zeroed pages for data area (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Enable Delayed ACK (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Increase max DataSegmentLength (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Use struct_size() helper in kmalloc() (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Replace enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Replace tpg enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: core: Add common tpg/enable attribute (Maurizio Lombardi) [2076591]
- scsi: target: core: Make logs less verbose (Maurizio Lombardi) [2076591]
- scsi: target: Remove unused function arguments (Maurizio Lombardi) [2076591]
- scsi: target: Fix spelling mistake "CONFLIFT" -> "CONFLICT" (Maurizio Lombardi) [2076591]
- scsi: target: Fix sense key for invalid EXTENDED COPY request (Maurizio Lombardi) [2076591]
- scsi: target: Allows backend drivers to fail with specific sense codes (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Fix possible null-pointer dereference in pscsi_complete_cmd() (Maurizio Lombardi) [2076591]
- scsi: target: core: Drop unnecessary se_cmd ASC/ASCQ members (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Drop incorrect ASC/ASCQ usage (Maurizio Lombardi) [2076591]
- scsi: target: core: Avoid using lun_tg_pt_gp after unlock (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Add new feature KEEP_BUF (Maurizio Lombardi) [2076591]
- scsi: target: Remove redundant assignment to variable ret (Maurizio Lombardi) [2076591]
- arch/arm64: Fix topology initialization for core scheduling (Phil Auld) [1992993]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (Sudheesh Mavila) [2037289]
- s390/unwind: recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- powerpc: Fix STACKTRACE=n build (Joe Lawrence) [2069373]
- arm64: Mark start_backtrace() notrace and NOKPROBE_SYMBOL (Joe Lawrence) [2069373]
- arm64: Make some stacktrace functions private (Joe Lawrence) [2069373]
- arm64: Make dump_backtrace() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make profile_pc() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make return_address() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make __get_wchan() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make perf_callchain_kernel() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Mark __switch_to() as __sched (Joe Lawrence) [2069373]
- arm64: Add comment for stack_info::kr_cur (Joe Lawrence) [2069373]
- arch: Make ARCH_STACKWALK independent of STACKTRACE (Joe Lawrence) [2069373]
- arm64: ftrace: use HAVE_FUNCTION_GRAPH_RET_ADDR_PTR (Joe Lawrence) [2069373]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Joe Lawrence) [2069373]
- kprobes: Add a test case for stacktrace from kretprobe handler (Joe Lawrence) [2069373]
- ARM: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- ARM: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- ARM: clang: Do not rely on lr register for stacktrace (Joe Lawrence) [2069373]
- arm64: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- arm64: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- arm64: kprobes: Record frame pointer with kretprobe instance (Joe Lawrence) [2069373]
- x86/unwind: Compile kretprobe fixup code only if CONFIG_KRETPROBES=y (Joe Lawrence) [2069373]
- kprobes: convert tests to kunit (Joe Lawrence) [2069373]
- x86/kprobes: Fixup return address in generic trampoline handler (Joe Lawrence) [2069373]
- tracing: Show kretprobe unknown indicator only for kretprobe_trampoline (Joe Lawrence) [2069373]
- x86/unwind: Recover kretprobe trampoline entry (Joe Lawrence) [2069373]
- x86/kprobes: Push a fake return address at kretprobe_trampoline (Joe Lawrence) [2069373]
- kprobes: Enable stacktrace from pt_regs in kretprobe handler (Joe Lawrence) [2069373]
- arm: kprobes: Make space for instruction pointer on stack (Joe Lawrence) [2069373]
- ia64: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- ARC: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- x86/kprobes: Add UNWIND_HINT_FUNC on kretprobe_trampoline() (Joe Lawrence) [2069373]
- objtool: Ignore unwind hints for ignored functions (Joe Lawrence) [2069373]
- objtool: Add frame-pointer-specific function ignore (Joe Lawrence) [2069373]
- kprobes: Add kretprobe_find_ret_addr() for searching return address (Joe Lawrence) [2069373]
- kprobes: treewide: Make it harder to refer kretprobe_trampoline directly (Joe Lawrence) [2069373]
- kprobes: treewide: Remove trampoline_address from kretprobe_trampoline_handler() (Joe Lawrence) [2069373]
- kprobes: treewide: Replace arch_deref_entry_point() with dereference_symbol_descriptor() (Joe Lawrence) [2069373]
- ia64: kprobes: Fix to pass correct trampoline address to the handler (Joe Lawrence) [2069373]
- kprobes: Use bool type for functions which returns boolean value (Joe Lawrence) [2069373]
- kprobes: treewide: Use 'kprobe_opcode_t *' for the code address in get_optimized_kprobe() (Joe Lawrence) [2069373]
- kprobes: Add assertions for required lock (Joe Lawrence) [2069373]
- kprobes: Use IS_ENABLED() instead of kprobes_built_in() (Joe Lawrence) [2069373]
- kprobes: Fix coding style issues (Joe Lawrence) [2069373]
- kprobes: treewide: Cleanup the error messages for kprobes (Joe Lawrence) [2069373]
- kprobes: Make arch_check_ftrace_location static (Joe Lawrence) [2069373]
- csky: ftrace: Drop duplicate implementation of arch_check_ftrace_location() (Joe Lawrence) [2069373]
- kprobe: Simplify prepare_kprobe() by dropping redundant version (Joe Lawrence) [2069373]
- kprobes: Use helper to parse boolean input from userspace (Joe Lawrence) [2069373]
- kprobes: Do not use local variable when creating debugfs file (Joe Lawrence) [2069373]
- Revert "netfilter: conntrack: tag conntracks picked up in local out hook" (Florian Westphal) [2061850]
- Revert "netfilter: nat: force port remap to prevent shadowing well-known ports" (Florian Westphal) [2061850]
- arm64: enable CONFIG_MEMORY_HOTREMOVE (Baoquan He) [2062054]

* Tue May 17 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-93.el9]
- NFSv4 only print the label when its queried (Benjamin Coddington) [2057327]
- nvme: expose cntrltype and dctype through sysfs (John Meneghini) [2045550]
- nvme: send uevent on connection up (John Meneghini) [2045550]
- xfs: punch out data fork delalloc blocks on COW writeback failure (Andrey Albershteyn) [2039058]
- macvlan: Fix leaking skb in source mode with nodst option (Davide Caratti) [2079415]
- net: macvlan: fix potential UAF problem for lowerdev (Davide Caratti) [2079415]
- net: ipvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- net: macvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- redhat/configs: Set CONFIG_EFI_DISABLE_RUNTIME Kconfig symbol (Javier Martinez Canillas) [2070196]
- efi: Allow to enable EFI runtime services by default on RT (Javier Martinez Canillas) [2070196]
- arm64: Restore forced disabling of KPTI on ThunderX (Mark Salter) [2043737]
- devlink: Clarifies max_macs generic devlink param (Petr Oros) [2073210]
- devlink: Add new "event_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Add new "io_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Simplify devlink resources unregister call (Petr Oros) [2073210]
- devlink: Remove misleading internal_flags from health reporter dump (Petr Oros) [2073210]
- devlink: fix flexible_array.cocci warning (Petr Oros) [2073210]
- devlink: Add 'enable_iwarp' generic device param (Petr Oros) [2073210]
- eth: fwnode: remove the addr len from mac helpers (Íñigo Huguet) [2069566]
- eth: fwnode: change the return type of mac address helpers (Íñigo Huguet) [2069566]
- device property: move mac addr helpers to eth.c (Íñigo Huguet) [2069566]

* Sat May 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-92.el9]
- RDMA/hfi1: Fix use-after-free bug for mm struct (Kamal Heib) [2056772]
- RDMA/siw: Fix a condition race issue in MPA request processing (Kamal Heib) [2056772]
- RDMA/irdma: Fix possible crash due to NULL netdev in notifier (Kamal Heib) [2056772]
- RDMA/irdma: Reduce iWARP QP destroy time (Kamal Heib) [2056772]
- RDMA/irdma: Flush iWARP QP if modified to ERR from RTR state (Kamal Heib) [2056772]
- RDMA/irdma: Fix deadlock in irdma_cleanup_cm_core() (Kamal Heib) [2056772]
- IB/rdmavt: add lock to call to rvt_error_qp to prevent a race condition (Kamal Heib) [2056772]
- IB/cm: Cancel mad on the DREQ event when the state is MRA_REP_RCVD (Kamal Heib) [2056772]
- RDMA/nldev: Prevent underflow in nldev_stat_set_counter_dynamic_doit() (Kamal Heib) [2056772]
- IB/iser: Fix error flow in case of registration failure (Kamal Heib) [2056772]
- IB/iser: Generalize map/unmap dma tasks (Kamal Heib) [2056772]
- IB/iser: Use iser_fr_desc as registration context (Kamal Heib) [2056772]
- IB/iser: Remove iser_reg_data_sg helper function (Kamal Heib) [2056772]
- RDMA/irdma: Add support for address handle re-use (Kamal Heib) [2056772]
- Revert "RDMA/core: Fix ib_qp_usecnt_dec() called when error" (Kamal Heib) [2056772]
- RDMA/irdma: Prevent some integer underflows (Kamal Heib) [2056772]
- RDMA/core: Fix ib_qp_usecnt_dec() called when error (Kamal Heib) [2056772]
- IB/hfi1: Allow larger MTU without AIP (Kamal Heib) [2056772]
- RDMA/core: Remove unnecessary statements (Kamal Heib) [2056772]
- RDMA/irdma: Remove incorrect masking of PD (Kamal Heib) [2056772]
- RDMA/irdma: Fix Passthrough mode in VM (Kamal Heib) [2056772]
- RDMA/irdma: Fix netdev notifications for vlan's (Kamal Heib) [2056772]
- RDMA/irdma: Make irdma_create_mg_ctx return a void (Kamal Heib) [2056772]
- RDMA/irdma: Move union irdma_sockaddr to header file (Kamal Heib) [2056772]
- RDMA/irdma: Remove the unnecessary variable saddr (Kamal Heib) [2056772]
- RDMA/irdma: Use net_type to check network type (Kamal Heib) [2056772]
- RDMA/irdma: Remove excess error variables (Kamal Heib) [2056772]
- RDMA/irdma: Propagate error codes (Kamal Heib) [2056772]
- RDMA/irdma: Remove enum irdma_status_code (Kamal Heib) [2056772]
- RDMA/ib_srp: Add more documentation (Kamal Heib) [2056772]
- IB/cma: Allow XRC INI QPs to set their local ACK timeout (Kamal Heib) [2056772]
- RDMA/hfi: Replace cpumask_weight with cpumask_empty where appropriate (Kamal Heib) [2056772]
- RDMA/irdma: Refactor DCB bits in prep for DSCP support (Kamal Heib) [2056772]
- RDMA/opa: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/iser: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/ipoib: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/usnic: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/hfi1: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Set MR type in ib_reg_user_mr (Kamal Heib) [2056772]
- RDMA/pvrdma: Remove useless DMA-32 fallback configuration (Kamal Heib) [2056772]
- redhat: disable CONFIG_USB_CHIPIDEA (Patrick Talbert)

* Sat May 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-91.el9]
- redhat/configs: Enable CONFIG_AMD_HSMP for x86_64 (John Allen) [2072235]
- platform/x86: Add AMD system management interface (John Allen) [2072235]
- scsi: core: Fix sbitmap depth in scsi_realloc_sdev_budget_map() (Ewan D. Milne) [2071832]
- lib/sbitmap: allocate sb->map via kvzalloc_node (Ewan D. Milne) [2071832]
- scsi: core: sd: Add silence_suspend flag to suppress some PM messages (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Fix FPIN Link Integrity statistics counters (Ewan D. Milne) [2071832]
- scsi: core: Put LLD module refcnt after SCSI device is released (Ewan D. Milne) [2071832]
- sd: delay calling free_opal_dev (Ewan D. Milne) [2071832]
- sd: call sd_zbc_release_disk before releasing the scsi_device reference (Ewan D. Milne) [2071832]
- sd: rename the scsi_disk.dev field (Ewan D. Milne) [2071832]
- scsi: don't use disk->private_data to find the scsi_driver (Ewan D. Milne) [2071832]
- scsi: core: Reallocate device's budget map on queue depth change (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() interface (Ewan D. Milne) [2071832]
- scsi: sr: Don't use GFP_DMA (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_device_max_queue_depth() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix buffer size of REPORT ZONES command (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Clean up sd_zbc_parse_report() setting of wp (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Simplify zone full condition check (Ewan D. Milne) [2071832]
- scsi: core: Show SCMD_LAST in text form (Ewan D. Milne) [2071832]
- scsi: core: Declare 'scsi_scan_type' static (Ewan D. Milne) [2071832]
- scsi: core: Suppress a kernel-doc warning (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Zero clear zones at reset write pointer (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix setting device state to SDEV_RUNNING (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Sanity check block descriptor length in resp_mode_select() (Ewan D. Milne) [2071832]
- scsi: core: Use eh_timeout for START STOP UNIT (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix type in min_t to avoid stack OOB (Ewan D. Milne) [2071832]
- scsi: core: Simplify control flow in scmd_eh_abort_handler() (Ewan D. Milne) [2071832]
- scsi: core: Avoid leaving shost->last_reset with stale value if EH does not run (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix hang when device state is set via sysfs (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Don't call kcalloc() if size arg is zero (Ewan D. Milne) [2071832]
- scsi: core: Remove command size deduction from scsi_setup_scsi_cmnd() (Ewan D. Milne) [2071832]
- scsi: scsi_ioctl: Validate command size (Ewan D. Milne) [2071832]
- scsi: sr: Remove duplicate assignment (Ewan D. Milne) [2071832]
- scsi: sd: add concurrent positioning ranges support (Ewan D. Milne) [2071832]
- scsi: scsi_transport_sas: Add 22.5 Gbps link rate definitions (Ewan D. Milne) [2071832]
- scsi: sr: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: sd: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_report_tgtpgs() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_readcap16() (Ewan D. Milne) [2071832]
- scsi: sd: Print write through due to no caching mode page as warning (Ewan D. Milne) [2071832]
- scsi: sd: Fix crashes in sd_resume_runtime() (Ewan D. Milne) [2071832]
- scsi: core: pm: Only runtime resume if necessary (Ewan D. Milne) [2071832]
- scsi: sd: Rename sd_resume() into sd_resume_system() (Ewan D. Milne) [2071832]
- scsi: core: pm: Rely on the device driver core for async power management (Ewan D. Milne) [2071832]
- scsi: core: Fix spelling in a source code comment (Ewan D. Milne) [2071832]
- scsi: sd: Fix sd_do_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Delete scsi_{get,free}_host_dev() (Ewan D. Milne) [2071832]
- scsi: core: Remove 'current_tag' (Ewan D. Milne) [2071832]
- scsi: acornscsi: Remove tagged queuing vestiges (Ewan D. Milne) [2071832]
- scsi: fas216: Kill scmd->tag (Ewan D. Milne) [2071832]
- scsi: core: Remove include <scsi/scsi_host.h> from scsi_cmnd.h (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Support disks with more than 2**32 logical blocks (Ewan D. Milne) [2071832]
- scsi: sd: Make sd_spinup_disk() less noisy (Ewan D. Milne) [2071832]
- scsi: sr: Fix spelling mistake "does'nt" -> "doesn't" (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE (Ewan D. Milne) [2071832]
- scsi: sd: Free scsi_disk device via put_device() (Ewan D. Milne) [2071832]
- scsi: sd: Do not exit sd_spinup_disk() quietly (Ewan D. Milne) [2071832]
- scsi: core: Remove scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: ibmvfc: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Stop setting scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: wd719: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: core: Add helper to return number of logical blocks in a request (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_spi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sd: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Introduce the scsi_cmd_to_rq() function (Ewan D. Milne) [2071832]
- scsi: core: Add BLIST_IGN_MEDIA_CHANGE for Ultra HS-SD/MMC USB card readers (Ewan D. Milne) [2071832]
- scsi: sd: REQUEST SENSE for BLIST_IGN_MEDIA_CHANGE devices in runtime_resume() (Ewan D. Milne) [2071832]
- scsi: core: Add new flag BLIST_IGN_MEDIA_CHANGE (Ewan D. Milne) [2071832]
- scsi: core: Make scsi_get_lba() return the LBA (Ewan D. Milne) [2071832]
- scsi: core: Introduce scsi_get_sector() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Improve RDPROTECT/WRPROTECT handling (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Remove dump_sector() (Ewan D. Milne) [2071832]
- scsi: core: Add scsi_prot_ref_tag() helper (Ewan D. Milne) [2071832]
- genirq/affinity: Consider that CPUs on nodes can be unbalanced (Ming Lei) [2074315]
- Revert "ata: ahci: mvebu: Make SATA PHY optional for Armada 3720" (Tomas Henzl) [2042790]
- ata: pata_pxa: Use platform_get_irq() to get the interrupt (Tomas Henzl) [2042790]
- ata: Drop commas after OF match table sentinels (Tomas Henzl) [2042790]
- ata: ahci: Rename board_ahci_mobile (Tomas Henzl) [2042790]
- ata: pata_hpt37x: merge transfer mode setting methods (Tomas Henzl) [2042790]
- ata: libata-sff: use *switch* statement in ata_sff_dev_classify() (Tomas Henzl) [2042790]
- ata: add/use ata_taskfile::{error|status} fields (Tomas Henzl) [2042790]
- ata: Kconfig: fix sata gemini compile test condition (Tomas Henzl) [2042790]
- ata: libata-scsi: use *switch* statements to check SCSI command codes (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_altstatus() (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_set_devctl() (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_resources_present() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt366: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_mpc52xx: use GFP_KERNEL (Tomas Henzl) [2042790]
- ata: sata_rcar: drop unused #define's (Tomas Henzl) [2042790]
- ata: pata_hpt366: check channel enable bits (Tomas Henzl) [2042790]
- ata: sata_rcar: make sata_rcar_ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: make pata_s3c_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused 'struct hpt_chip' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused HPT_PCI_FAST (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in atp8xx_fixup() (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in artop_init_one() (Tomas Henzl) [2042790]
- pata_hpt3x2n: fix writing to wrong register in hpt3x2n_bmdma_stop() (Tomas Henzl) [2042790]
- pata_hpt3x2n: check channel enable bits (Tomas Henzl) [2042790]
- ata: libata: make ata_host_suspend() *void* (Tomas Henzl) [2042790]
- ata: libata: ata_{sff|std}_prereset() always return 0 (Tomas Henzl) [2042790]
- ata: ahci: Skip 200 ms debounce delay for Marvell 88SE9235 (Tomas Henzl) [2042790]
- ata: libata-acpi: kill ata_acpi_on_suspend() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify scsi_XX_lba_len() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify ata_scsi_mode_select_xlat() (Tomas Henzl) [2042790]
- ata: libata-scsi: Cleanup ata_get_xlat_func() (Tomas Henzl) [2042790]
- ata: pata_pdc202xx_old: make static read-only array pio_timing const (Tomas Henzl) [2042790]
- ata: pata_atiixp: make static read-only arrays const (Tomas Henzl) [2042790]
- ata: pata_platform: Make use of platform_get_mem_or_io() (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable primary channel on HPT371 (Tomas Henzl) [2042790]
- ata: pata_hpt37x: fix PCI clock detection (Tomas Henzl) [2042790]
- ata: libata-core: Disable TRIM on M88V29 (Tomas Henzl) [2042790]
- ata: sata_fsl: fix sscanf() and sysfs_emit() format strings (Tomas Henzl) [2042790]
- ata: libata-core: Fix ata_dev_config_cpr() (Tomas Henzl) [2042790]
- ata: libata-core: Introduce ATA_HORKAGE_NO_LOG_DIR horkage (Tomas Henzl) [2042790]
- ata: pata_platform: Fix a NULL pointer dereference in __pata_platform_probe() (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: fix call to trace_ata_bmdma_stop() (Tomas Henzl) [2042790]
- ata: pata_ali: remove redundant return statement (Tomas Henzl) [2042790]
- ata: ahci: Add support for AMD A85 FCH (Hudson D4) (Tomas Henzl) [2042790]
- ata: libata: Rename link flag ATA_LFLAG_NO_DB_DELAY (Tomas Henzl) [2042790]
- ata: libata-scsi: simplify __ata_scsi_queuecmd() (Tomas Henzl) [2042790]
- ata: pata_of_platform: Use platform_get_irq_optional() to get the interrupt (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: add compile test support (Tomas Henzl) [2042790]
- ata: pata_pxa: add compile test support (Tomas Henzl) [2042790]
- ata: pata_imx: add compile test support (Tomas Henzl) [2042790]
- ata: pata_ftide010: add compile test support (Tomas Henzl) [2042790]
- ata: pata_cs5535: add compile test support (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove redundant val variable (Tomas Henzl) [2042790]
- ata: fix read_id() ata port operation interface (Tomas Henzl) [2042790]
- ata: ahci_xgene: use correct type for port mmio address (Tomas Henzl) [2042790]
- ata: sata_fsl: fix cmdhdr_tbl_entry and prde struct definitions (Tomas Henzl) [2042790]
- ata: sata_fsl: fix scsi host initialization (Tomas Henzl) [2042790]
- ata: pata_bk3710: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_seattle: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_xgene: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_tegra: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_sunxi: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mvebu: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mtk: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_dm816: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_da850: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_brcm: add compile test support (Tomas Henzl) [2042790]
- ata: sata_fsl: add compile test support (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove debug compile options (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: remove 'check_status' argument (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: drop DEBUG_NCQ (Tomas Henzl) [2042790]
- ata: libata-scsi: rework ata_dump_status to avoid using pr_cont() (Tomas Henzl) [2042790]
- ata: pata_hpt366: convert pr_warn() calls (Tomas Henzl) [2042790]
- ata: sata_gemini: convert pr_err() calls (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Replace pr_XXX() calls with structured logging (Tomas Henzl) [2042790]
- ata: pata_hpt37x: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: sata_mv: convert remaining printk() to structured logging (Tomas Henzl) [2042790]
- ata: sata_sx4: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_sil680: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_serverworks: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_rz1000: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_marvell: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_it821x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cypress: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5536: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5520: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd64x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd640: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_atp867x: convert printk() calls (Tomas Henzl) [2042790]
- ata: libata: remove debug compilation switches (Tomas Henzl) [2042790]
- ata: libata: remove 'new' ata message handling (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_drv() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_info() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_probe() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_warn() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_malloc() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_ctl() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_error() and ata_msg_intr() (Tomas Henzl) [2042790]
- ata: sata_sx4: add module parameter 'dimm_test' (Tomas Henzl) [2042790]
- ata: sata_sx4: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: sata_sil: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_fsl: convert VPRINTK() calls to ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_nv: drop pointless VPRINTK() calls and convert remaining ones (Tomas Henzl) [2042790]
- ata: sata_mv: Drop pointless VPRINTK() call and convert the remaining one (Tomas Henzl) [2042790]
- ata: sata_inic162x: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_rcar: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_qstor: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_promise: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: pata_via: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Drop pointless VPRINTK() calls and convert the remaining one (Tomas Henzl) [2042790]
- ata: pdc_adma: Drop pointless VPRINTK() calls and remove disabled NCQ debugging (Tomas Henzl) [2042790]
- ata: ahci: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: libata: remove pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_pdc2027x: Replace PDPRINTK() with standard ata logging (Tomas Henzl) [2042790]
- ata: sata_qstor: replace DPRINTK() with dev_dbg() (Tomas Henzl) [2042790]
- ata: sata_rcar: replace DPRINTK() with ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_fsl: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: pdc_adma: Remove DPRINTK call (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove DPRINTK() macro in interrupt context (Tomas Henzl) [2042790]
- ata: sata_mv: replace DPRINTK with dynamic debugging (Tomas Henzl) [2042790]
- ata: sata_mv: kill 'port' argument in mv_dump_all_regs() (Tomas Henzl) [2042790]
- ata: libata: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: libata: revamp ata_get_cmd_descript() (Tomas Henzl) [2042790]
- ata: libata: move ata_{port,link,dev}_dbg to standard pr_XXX() macros (Tomas Henzl) [2042790]
- ata: libata: add tracepoints for ATA error handling (Tomas Henzl) [2042790]
- ata: libata-scsi: drop DPRINTK calls for cdb translation (Tomas Henzl) [2042790]
- ata: libata-sff: tracepoints for HSM state machine (Tomas Henzl) [2042790]
- ata: libata: tracepoints for bus-master DMA (Tomas Henzl) [2042790]
- ata: libata: add qc_prep tracepoint (Tomas Henzl) [2042790]
- ata: libata: add reset tracepoints (Tomas Henzl) [2042790]
- ata: libata: sanitize ATA_HORKAGE_DUMP_ID (Tomas Henzl) [2042790]
- ata: libata: move ata_dump_id() to dynamic debugging (Tomas Henzl) [2042790]
- ata: libata: Add ata_port_classify() helper (Tomas Henzl) [2042790]
- ata: libata: whitespace cleanup (Tomas Henzl) [2042790]
- ata: libata: remove pointless debugging messages (Tomas Henzl) [2042790]
- ata: libata: use min() to make code cleaner (Tomas Henzl) [2042790]
- ata: libahci_platform: Get rid of dup message when IRQ can't be retrieved (Tomas Henzl) [2042790]
- ata: libahci_platform: Remove bogus 32-bit DMA mask attempt (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove unused forward declaration (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use temporary variable for struct device (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use devm_platform_*ioremap_resource() APIs (Tomas Henzl) [2042790]
- ata: sata_fsl: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: ahci: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-scsi: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-sata: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: sata_fsl: Use struct_group() for memcpy() region (Tomas Henzl) [2042790]
- ata: pata_ali: no need to initialise statics to 0 (Tomas Henzl) [2042790]
- libata: if T_LENGTH is zero, dma direction should be DMA_NONE (Tomas Henzl) [2042790]
- libata: add horkage for ASMedia 1092 (Tomas Henzl) [2042790]
- ata: ahci_ceva: Fix id array access in ceva_ahci_read_id() (Tomas Henzl) [2042790]
- ata: replace snprintf in show functions with sysfs_emit (Tomas Henzl) [2042790]
- sata_fsl: fix warning in remove_proc_entry when rmmod sata_fsl (Tomas Henzl) [2042790]
- sata_fsl: fix UAF in sata_fsl_port_stop when rmmod sata_fsl (Tomas Henzl) [2042790]
- pata_falcon: Avoid type warnings from sparse (Tomas Henzl) [2042790]
- ata: libahci: Adjust behavior when StorageD3Enable _DSD is set (Tomas Henzl) [2042790]
- ata: ahci: Add Green Sardine vendor ID as board_ahci_mobile (Tomas Henzl) [2042790]
- ata: libata: add missing ata_identify_page_supported() calls (Tomas Henzl) [2042790]
- ata: libata: improve ata_read_log_page() error message (Tomas Henzl) [2042790]
- libata: add horkage for missing Identify Device log (Tomas Henzl) [2042790]
- ata: sata_highbank: Remove unnecessary print function dev_err() (Tomas Henzl) [2042790]
- libata: fix read log timeout value (Tomas Henzl) [2042790]
- pata_radisys: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_optidma: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_amd: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_ali: fix checking of DMA state (Tomas Henzl) [2042790]
- libata-scsi: fix checking of DMA state (Tomas Henzl) [2042790]
- libata: fix checking of DMA state (Tomas Henzl) [2042790]
- Add AHCI support for ASM1062+JBM575 cards (Tomas Henzl) [2042790]
- ahci: remove duplicated PCI device IDs (Tomas Henzl) [2042790]
- libata: support concurrent positioning ranges log (Tomas Henzl) [2042790]
- ata: sata_mv: Fix the error handling of mv_chip_id() (Tomas Henzl) [2042790]
- ata: ahci_platform: fix null-ptr-deref in ahci_platform_enable_regulators() (Tomas Henzl) [2042790]
- pata_legacy: fix a couple uninitialized variable bugs (Tomas Henzl) [2042790]
- libata: Add ATA_HORKAGE_NO_NCQ_ON_ATI for Samsung 860 and 870 SSD. (Tomas Henzl) [2042790]
- libata: add ATA_HORKAGE_NO_NCQ_TRIM for Samsung 860 and 870 SSDs (Tomas Henzl) [2042790]
- pata: ixp4xx: Rewrite to use device tree (Tomas Henzl) [2042790]
- pata: ixp4xx: Refer to cmd and ctl rather than csN (Tomas Henzl) [2042790]
- pata: ixp4xx: Use IS_ENABLED() to determine endianness (Tomas Henzl) [2042790]
- pata: ixp4xx: Use local dev variable (Tomas Henzl) [2042790]
- include:libata: fix boolreturn.cocci warnings (Tomas Henzl) [2042790]
- libata: Introduce ncq_prio_supported sysfs sttribute (Tomas Henzl) [2042790]
- libata: print feature list on device scan (Tomas Henzl) [2042790]
- libata: fix ata_read_log_page() warning (Tomas Henzl) [2042790]
- libata: cleanup NCQ priority handling (Tomas Henzl) [2042790]
- libata: cleanup ata_dev_configure() (Tomas Henzl) [2042790]
- libata: cleanup device sleep capability detection (Tomas Henzl) [2042790]
- libata: simplify ata_scsi_rbuf_fill() (Tomas Henzl) [2042790]
- libata: fix ata_host_start() (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: No need to call phy_exit() befre phy_init() (Tomas Henzl) [2042790]
- redhat/configs: aarch64: Enable NXP i.MX8M SoCs (Mark Salter) [2069626]
- scsi: qedf: Stop using the SCSI pointer (Nilesh Javali) [2046632]
- scsi: qedf: Change context reset messages to ratelimited (Nilesh Javali) [2046632]
- scsi: qedf: Fix refcount issue when LOGO is received during TMF (Nilesh Javali) [2046632]
- scsi: qedf: Add stag_work to all the vports (Nilesh Javali) [2046632]
- scsi: qedf: Fix potential dereference of NULL pointer (Nilesh Javali) [2046632]
- scsi: qedf: Fix error codes in qedf_alloc_global_queues() (Nilesh Javali) [2046632]

* Fri May 13 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-90.el9]
- platform/x86/intel: Fix 'rmmod pmt_telemetry' panic (David Arcari) [2080320]
- net: mpls: Fix notifications when deleting a device (Guillaume Nault) [2081758]
- nvme-pci: disable namespace identifiers for Qemu controllers (Gopal Tiwari) [2079310]
- nvme-pci: disable namespace identifiers for the MAXIO MAP1002/1202 (Gopal Tiwari) [2079310]
- nvme: add a quirk to disable namespace identifiers (Gopal Tiwari) [2079310]
- nvme-multipath: fix hang when disk goes live over reconnect (Gopal Tiwari) [2079310]
- nvme-pci: add quirks for Samsung X5 SSDs (Gopal Tiwari) [2079310]
- nvme-pci: expose use_threaded_interrupts read-only in sysfs (Gopal Tiwari) [2079310]
- selftest: net: Test IPv4 PMTU exceptions with DSCP and ECN (Guillaume Nault) [2081383]
- ipv4: Fix route lookups when handling ICMP redirects and PMTU updates (Guillaume Nault) [2081383]
- ipv4: fix data races in fib_alias_hw_flags_set (Guillaume Nault) [2081383]
- ipv4: remove sparse error in ip_neigh_gw4() (Guillaume Nault) [2081383]
- ipv4: tcp: send zero IPID in SYNACK messages (Guillaume Nault) [2081383]
- ipv4: raw: lock the socket in raw_bind() (Guillaume Nault) [2081383]
- ipv4: update fib_info_cnt under spinlock protection (Guillaume Nault) [2081383]
- inet: frags: annotate races around fqdir->dead and fqdir->high_thresh (Guillaume Nault) [2081383]
- net: nexthop: fix null pointer dereference when IPv6 is not enabled (Guillaume Nault) [2081383]
- net: dcb: disable softirqs in dcbnl_flush_dev() (Xin Long) [2080477]
- doc/ip-sysctl: add bc_forwarding (Xin Long) [2080477]
- l3mdev: l3mdev_master_upper_ifindex_by_index_rcu should be using netdev_master_upper_dev_get_rcu (Xin Long) [2080477]
- net/packet: fix packet_sock xmit return value checking (Xin Long) [2080477]
- net: handle ARPHRD_PIMREG in dev_is_mac_header_xmit() (Xin Long) [2080477]
- net/packet: fix slab-out-of-bounds access in packet_recvmsg() (Xin Long) [2080477]
- net: dcb: flush lingering app table entries for unregistered devices (Xin Long) [2080477]
- veth: fix races around rq->rx_notify_masked (Xin Long) [2080477]
- net: fix a memleak when uncloning an skb dst and its metadata (Xin Long) [2080477]
- net: do not keep the dst cache when uncloning an skb dst and its metadata (Xin Long) [2080477]
- af_packet: fix data-race in packet_setsockopt / packet_setsockopt (Xin Long) [2080477]
- ipv4: remove sparse error in ip_neigh_gw4() (Xin Long) [2080477]
- af_unix: annote lockless accesses to unix_tot_inflight & gc_in_progress (Xin Long) [2080477]
- veth: Do not record rx queue hint in veth_xmit (Xin Long) [2080477]
- veth: ensure skb entering GRO are not cloned. (Xin Long) [2080477]
- ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md mode (Guillaume Nault) [2081047]
- ip6_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip6_gre: Fix skb_under_panic in __gre6_xmit() (Guillaume Nault) [2081047]
- ip6_gre: Avoid updating tunnel->tun_hlen in __gre6_xmit() (Guillaume Nault) [2081047]
- ipv6_tunnel: Rate limit warning messages (Guillaume Nault) [2081047]
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled (Guillaume Nault) [2080891]
- tipc: fix the timer expires after interval 100ms (Xin Long) [2080364]
- tipc: fix incorrect order of state message data sanity check (Xin Long) [2080364]
- tipc: fix kernel panic when enabling bearer (Xin Long) [2080364]
- tipc: Fix end of loop tests for list_for_each_entry() (Xin Long) [2080364]
- tipc: fix wrong notification node addresses (Xin Long) [2080364]
- tipc: fix wrong publisher node address in link publications (Xin Long) [2080364]
- tipc: fix a bit overflow in tipc_crypto_key_rcv() (Xin Long) [2080364]
- tipc: rate limit warning for received illegal binding update (Xin Long) [2080364]
- net: tipc: remove unused static inlines (Xin Long) [2080364]
- sctp: Initialize daddr on peeled off socket (Xin Long) [2079979]
- sctp: count singleton chunks in assoc user stats (Xin Long) [2079979]
- sctp: fix kernel-infoleak for SCTP sockets (Xin Long) [2079979]
- scsi: target: Allow changing dbroot if there are no registered devices (Maurizio Lombardi) [2075759]
- xfs: check sb_meta_uuid for dabuf buffer recovery (Dave Chinner) [2069776]

* Thu May 12 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-89.el9]
- nixge: fix mac address error handling again (Ivan Vecera) [2081256]
- ethernet: fix up ps3_gelic_net.c for "ethernet: use  eth_hw_addr_set()" (Ivan Vecera) [2081256]
- ethernet: ehea: add missing cast (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() - casts (Ivan Vecera) [2081256]
- fddi: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: s2io: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: chelsio: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- arch: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: cipso: fix warnings in netlbl_cipsov4_add_std (Guillaume Nault) [2079246]
- wireguard: device: check for metadata_dst with skb_valid_dst() (Hangbin Liu) [2076974]
- wireguard: socket: ignore v6 endpoints when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: socket: free skb in send6 when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: queueing: use CFI-safe ptr_ring cleanup function (Hangbin Liu) [2076974]
- wireguard: main: rename 'mod_init' & 'mod_exit' functions to be module-specific (Hangbin Liu) [2076974]
- fork: Use IS_ENABLED() in account_kernel_stack() (Phil Auld) [2076594]
- fork: Only cache the VMAP stack in finish_task_switch() (Phil Auld) [2076594]
- fork: Move task stack accounting to do_exit() (Phil Auld) [2076594]
- fork: Move memcg_charge_kernel_stack() into CONFIG_VMAP_STACK (Phil Auld) [2076594]
- fork: Don't assign the stack pointer in dup_task_struct() (Phil Auld) [2076594]
- fork, IA64: Provide alloc_thread_stack_node() for IA64 (Phil Auld) [2076594]
- fork: Duplicate task_struct before stack allocation (Phil Auld) [2076594]
- fork: Redo ifdefs around task stack handling (Phil Auld) [2076594]
- sched/tracing: Report TASK_RTLOCK_WAIT tasks as TASK_UNINTERRUPTIBLE (Phil Auld) [2076594]
- locking/rt: Take RCU nesting into account for __might_resched() (Phil Auld) [2076594]
- sched: Make cond_resched_lock() variants RT aware (Phil Auld) [2076594]
- sched: Make RCU nest depth distinct in __might_resched() (Phil Auld) [2076594]
- sched: Make might_sleep() output less confusing (Phil Auld) [2076594]
- sched: Cleanup might_sleep() printks (Phil Auld) [2076594]
- sched: Remove preempt_offset argument from __might_sleep() (Phil Auld) [2076594]
- sched: Make cond_resched_*lock() variants consistent vs. might_sleep() (Phil Auld) [2076594]
- sched: Clean up the might_sleep() underscore zoo (Phil Auld) [2076594]
- sched/deadline,rt: Remove unused parameter from pick_next_[rt|dl]_entity() (Phil Auld) [2065219]
- sched/deadline,rt: Remove unused functions for !CONFIG_SMP (Phil Auld) [2065219]
- sched/deadline: Use __node_2_[pdl|dle]() and rb_first_cached() consistently (Phil Auld) [2065219]
- sched/deadline: Merge dl_task_can_attach() and dl_cpu_busy() (Phil Auld) [2065219]
- sched/deadline: Move bandwidth mgmt and reclaim functions into sched class source file (Phil Auld) [2065219]
- sched/deadline: Remove unused def_dl_bandwidth (Phil Auld) [2065219]
- sched/headers: ARM needs asm/paravirt_api_clock.h too (Phil Auld) [2069275]
- sched/headers: Only include <linux/entry-common.h> when CONFIG_GENERIC_ENTRY=y (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/sched.h dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_utility.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_policy.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/fair.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/core.c dependencies (Phil Auld) [2069275]
- sched/headers: Standardize kernel/sched/sched.h header dependencies (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_policy.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_utility.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Make the <linux/sched/deadline.h> header build standalone (Phil Auld) [2069275]
- sched/headers: Fix comment typo in kernel/sched/cpudeadline.c (Phil Auld) [2069275]
- sched/headers: Add initial new headers as identity mappings (Phil Auld) [2069275]
- sched/headers: sched/clock: Mark all functions 'notrace', remove CC_FLAGS_FTRACE build asymmetry (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/stats.h and kernel/sched/autogroup.h (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/sched.h (Phil Auld) [2069275]
- sched/headers: Fix header to build standalone: <linux/sched_clock.h> (Phil Auld) [2069275]

* Wed May 11 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-88.el9]
- vrf: fix packet sniffing for traffic originating from ip tunnels (Antoine Tenart) [2082589]
- vrf: don't run conntrack on vrf with !dflt qdisc (Antoine Tenart) [2082589]
- vrf: run conntrack only in context of lower/physdev for locally generated packets (Antoine Tenart) [2082589]
- netfilter: conntrack: skip confirmation and nat hooks in postrouting for vrf (Antoine Tenart) [2082589]
- vrf: Revert "Reset skb conntrack connection..." (Antoine Tenart) [2082589]
- selftests: netfilter: add a vrf+conntrack testcase (Antoine Tenart) [2082589]
- ABI: configfs-usb-gadget-uac2: fix a broken table (Torez Smith) [2061784]
- usb: gadget: Fix use-after-free bug by not setting udc->dev.driver (Torez Smith) [2061784]
- usb: usbtmc: Fix bug in pipe direction for control transfers (Torez Smith) [2061784]
- partially Revert "usb: musb: Set the DT node on the child device" (Torez Smith) [2061784]
- usb: gadget: rndis: prevent integer overflow in rndis_set_response() (Torez Smith) [2061784]
- xen/usb: don't use gnttab_end_foreign_access() in xenhcd_gnttab_done() (Torez Smith) [2061784]
- usb: gadget: rndis: add spinlock for rndis response list (Torez Smith) [2061784]
- usb: dwc3: gadget: Let the interrupt handler disable bottom halves. (Torez Smith) [2061784]
- USB: gadget: validate endpoint index for xilinx udc (Torez Smith) [2061784]
- dt-bindings: update Roger Quadros email (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910R1 compositions (Torez Smith) [2061784]
- USB: serial: option: add support for DW5829e (Torez Smith) [2061784]
- Revert "USB: serial: ch341: add new Product ID for CH341A" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (Torez Smith) [2061784]
- tps6598x: clear int mask on probe failure (Torez Smith) [2061784]
- xhci: Prevent futile URB re-submissions due to incorrect return value. (Torez Smith) [2061784]
- xhci: re-initialize the HC during resume if HCE was set (Torez Smith) [2061784]
- usb: dwc3: pci: Add "snps,dis_u2_susphy_quirk" for Intel Bay Trail (Torez Smith) [2061784]
- usb: dwc3: pci: add support for the Intel Raptor Lake-S (Torez Smith) [2061784]
- Revert "usb: dwc2: drd: fix soft connect when gadget is unconfigured" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: gadget: rndis: check size of RNDIS_MSG_SET command (Torez Smith) [2061784]
- USB: gadget: validate interface OS descriptor requests (Torez Smith) [2061784]
- usb: core: Unregister device on component_add() failure (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: add compatible "intel,socfpga-agilex-hsotg" (Torez Smith) [2061784]
- usb: dwc3: gadget: Prevent core from processing stale TRBs (Torez Smith) [2061784]
- USB: serial: cp210x: add CPI Bulk Coin Recycler id (Torez Smith) [2061784]
- USB: serial: cp210x: add NCR Retail IO box id (Torez Smith) [2061784]
- USB: serial: ftdi_sio: add support for Brainboxes US-159/235/320 (Torez Smith) [2061784]
- usb: gadget: f_uac2: Define specific wTerminalType (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix host to USB_ROLE_NONE transition (Torez Smith) [2061784]
- usb: usb251xb: add boost-up property support (Torez Smith) [2061784]
- usb: raw-gadget: fix handling of dual-direction-capable endpoints (Torez Smith) [2061784]
- usb: ulpi: Call of_node_put correctly (Torez Smith) [2061784]
- usb: ulpi: Move of_node_put to ulpi_dev_release (Torez Smith) [2061784]
- USB: serial: option: add ZTE MF286D modem (Torez Smith) [2061784]
- USB: serial: ch341: add support for GW Instek USB2.0-Serial devices (Torez Smith) [2061784]
- usb: f_fs: Fix use-after-free for epfile (Torez Smith) [2061784]
- usb: dwc3: xilinx: fix uninitialized return value (Torez Smith) [2061784]
- usb: cdnsp: Fix segmentation fault in cdns_lost_power function (Torez Smith) [2061784]
- usb: dwc2: gadget: don't try to disable ep0 in dwc2_hsotg_suspend (Torez Smith) [2061784]
- usb: gadget: at91_udc: fix incorrect print type (Torez Smith) [2061784]
- usb: dwc3: xilinx: Fix error handling when getting USB3 PHY (Torez Smith) [2061784]
- usb: dwc3: xilinx: Skip resets and USB3 register settings for USB2.0 mode (Torez Smith) [2061784]
- usb: xhci-plat: fix crash when suspend if remote wake enable (Torez Smith) [2061784]
- usb: common: ulpi: Fix crash in ulpi_match() (Torez Smith) [2061784]
- usb: gadget: f_sourcesink: Fix isoc transfer for USB_SPEED_SUPER_PLUS (Torez Smith) [2061784]
- ucsi_ccg: Check DEV_INT bit only when starting CCG4 (Torez Smith) [2061784]
- USB: core: Fix hang in usb_kill_urb by adding memory barriers (Torez Smith) [2061784]
- usb-storage: Add unusual-devs entry for VL817 USB-SATA bridge (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect when receiving VSAFE0V (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect while receiving VBUS off (Torez Smith) [2061784]
- usb: typec: Don't try to register component master without components (Torez Smith) [2061784]
- usb: typec: Only attempt to link USB ports if there is fwnode (Torez Smith) [2061784]
- usb: typec: tcpci: don't touch CC line if it's Vconn source (Torez Smith) [2061784]
- usb: roles: fix include/linux/usb/role.h compile issue (Torez Smith) [2061784]
- usb: gadget: u_audio: Subdevice 0 for capture ctls (Torez Smith) [2061784]
- usb: gadget: u_audio: fix calculations for small bInterval (Torez Smith) [2061784]
- usb: dwc2: gadget: initialize max_speed from params (Torez Smith) [2061784]
- usb: dwc2: do not gate off the hardware if it does not support clock gating (Torez Smith) [2061784]
- usb: dwc3: qcom: Fix NULL vs IS_ERR checking in dwc3_qcom_probe (Torez Smith) [2061784]
- headers/deps: USB: Optimize <linux/usb/ch9.h> dependencies, remove <linux/device.h> (Torez Smith) [2061784]
- USB: common: debug: add needed kernel.h include (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/host/ohci-tmio.c (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/cdns3/core.h (Torez Smith) [2061784]
- headers/prep: usb: gadget: Fix namespace collision (Torez Smith) [2061784]
- USB: core: Fix bug in resuming hub's handling of wakeup requests (Torez Smith) [2061784]
- USB: Fix "slab-out-of-bounds Write" bug in usb_hcd_poll_rh_status (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Add missing platform_device_put() in dwc3_qcom_acpi_register_core (Torez Smith) [2061784]
- usb: gadget: clear related members when goto fail (Torez Smith) [2061784]
- usb: gadget: don't release an existing dev->buf (Torez Smith) [2061784]
- usb: dwc2: Simplify a bitmap declaration (Torez Smith) [2061784]
- usb: Remove usb_for_each_port() (Torez Smith) [2061784]
- usb: typec: port-mapper: Convert to the component framework (Torez Smith) [2061784]
- usb: Link the ports to the connectors they are attached to (Torez Smith) [2061784]
- acpi: Store CRC-32 hash of the _PLD in struct acpi_device (Torez Smith) [2061784]
- docs: ABI: fixed req_number desc in UAC1 (Torez Smith) [2061784]
- usb-storage: Remove redundant assignments (Torez Smith) [2061784]
- thunderbolt: Add module parameter for CLx disabling (Torez Smith) [2061784]
- thunderbolt: Enable CL0s for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Rename Intel TB_VSE_CAP_IECS capability (Torez Smith) [2061784]
- thunderbolt: Implement TMU time disruption for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Move usb4_switch_wait_for_bit() to switch.c (Torez Smith) [2061784]
- thunderbolt: Add CL0s support for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Add TMU uni-directional mode (Torez Smith) [2061784]
- usb: typec: ucsi: Only check the contract if there is a connection (Torez Smith) [2061784]
- xhci: Fresco FL1100 controller should not have BROKEN_MSI quirk set. (Torez Smith) [2061784]
- tty: tty_io: Switch to vmalloc() fallback in case of TTY_NO_WRITE_SPLIT (Torez Smith) [2061784]
- usb: mtu3: set interval of FS intr and isoc endpoint (Torez Smith) [2061784]
- usb: mtu3: fix list_head check warning (Torez Smith) [2061784]
- usb: mtu3: add memory barrier before set GPD's HWO (Torez Smith) [2061784]
- usb: mtu3: fix interval value for intr and isoc (Torez Smith) [2061784]
- usb: gadget: f_fs: Clear ffs_eventfd in ffs_data_clear. (Torez Smith) [2061784]
- usb: musb: dsps: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: cdns3: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: isp1760: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: dwc3: Drop unneeded calls to platform_get_resource_byname() (Torez Smith) [2061784]
- usb: renesas_usbhs: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: host: fotg210: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- xhci: use max() to make code cleaner (Torez Smith) [2061784]
- Revert "usb: host: ehci-sh: propagate errors from platform_get_irq()" (Torez Smith) [2061784]
- usb: misc: ehset: Rework test mode entry (Torez Smith) [2061784]
- usb: core: Export usb_device_match_id (Torez Smith) [2061784]
- usb: musb: Set the DT node on the child device (Torez Smith) [2061784]
- usb: musb: Drop unneeded resource copying (Torez Smith) [2061784]
- usb: host: ohci-omap: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: host: ehci-sh: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: pxa25x: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: bcm63xx: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: ftdi-elan: fix memory leak on device disconnect (Torez Smith) [2061784]
- usb: hub: Add delay for SuperSpeed hub resume to let links transit to U0 (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: Add SM6350 compatible (Torez Smith) [2061784]
- usb: dwc2: drd: restore role and overrides upon resume (Torez Smith) [2061784]
- usb: dwc2: drd: add role-switch-default-node support (Torez Smith) [2061784]
- dt-bindings: usb: document role-switch-default-mode property in dwc2 (Torez Smith) [2061784]
- usb: chipidea: Set the DT node on the child device (Torez Smith) [2061784]
- usb: uhci: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-s3c2410: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-spear: Remove direct access to platform_device resource list (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for SM8450 (Torez Smith) [2061784]
- Revert "usb: early: convert to readl_poll_timeout_atomic()" (Torez Smith) [2061784]
- dt-bindings: usb: Convert BDC to YAML (Torez Smith) [2061784]
- usb: hub: make wait_for_connected() take an int instead of a pointer to int (Torez Smith) [2061784]
- usb: chipidea: tegra: Add runtime PM and OPP support (Torez Smith) [2061784]
- usb: hub: avoid warm port reset during USB3 disconnect (Torez Smith) [2061784]
- usb: host: xen-hcd: add missing unlock in error path (Torez Smith) [2061784]
- dt-bindings: usb: dwc3-xilinx: Convert USB DWC3 bindings (Torez Smith) [2061784]
- usb: dwc2: platform: adopt dev_err_probe() to silent probe defer (Torez Smith) [2061784]
- usb: typec: tcpm: fix tcpm unregister port but leave a pending timer (Torez Smith) [2061784]
- usb: cdnsp: Fix lack of spin_lock_irqsave/spin_lock_restore (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04) (Torez Smith) [2061784]
- usb: dwc2: fix STM ID/VBUS detection startup delay in dwc2_driver_probe (Torez Smith) [2061784]
- USB: gadget: bRequestType is a bitfield, not a enum (Torez Smith) [2061784]
- thunderbolt: Check return value of kmemdup() in icm_handle_event() (Torez Smith) [2061784]
- dt-bindings: usb: Add missing properties used in examples (Torez Smith) [2061784]
- media: drivers:usb:remove unneeded variable (Torez Smith) [2061784]
- media: b2c2-flexcop-usb: fix some whitespace coding style (Torez Smith) [2061784]
- media: Revert "media: uvcvideo: Set unique vdev name based in type" (Torez Smith) [2061784]
- media: dw2102: Fix use after free (Torez Smith) [2061784]
- USB: serial: option: add Telit FN990 compositions (Torez Smith) [2061784]
- USB: serial: cp210x: fix CP2105 GPIO registration (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect status for control request (Torez Smith) [2061784]
- usb: cdnsp: Fix issue in cdnsp_log_ep trace event (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect calling of cdnsp_died function (Torez Smith) [2061784]
- usb: xhci-mtk: fix list_del warning when enable list debug (Torez Smith) [2061784]
- usb: gadget: u_ether: fix race in setting MAC address in setup phase (Torez Smith) [2061784]
- dt-bindings: usb: tegra-xudc: Document interconnects and iommus properties (Torez Smith) [2061784]
- usb: core: hcd: change sizeof(vaddr) to sizeof(unsigned long) (Torez Smith) [2061784]
- usb: aspeed-vhub: support test mode feature (Torez Smith) [2061784]
- usb: aspeed-vhub: fix ep0 OUT ack received wrong length issue (Torez Smith) [2061784]
- usb: aspeed-vhub: add qualifier descriptor (Torez Smith) [2061784]
- Add CONFIG_USB_XEN_HCD to configs (Torez Smith) [2061784]
- usb: Introduce Xen pvUSB frontend (xen hcd) (Torez Smith) [2061784]
- usb: dwc3: gadget: Support Multi-Stream Transfer (Torez Smith) [2061784]
- usb: core: config: using bit mask instead of individual bits (Torez Smith) [2061784]
- usb: core: config: fix validation of wMaxPacketValue entries (Torez Smith) [2061784]
- USB: gadget: zero allocate endpoint 0 buffers (Torez Smith) [2061784]
- USB: gadget: detect too-big endpoint 0 requests (Torez Smith) [2061784]
- xhci: avoid race between disable slot command and host runtime suspend (Torez Smith) [2061784]
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from runtime suspending (Torez Smith) [2061784]
- Revert "usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default" (Torez Smith) [2061784]
- thunderbolt: Do not dereference fwnode in struct device (Torez Smith) [2061784]
- thunderbolt: Add debug logging of DisplayPort resource allocation (Torez Smith) [2061784]
- thunderbolt: Do not program path HopIDs for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Do not allow subtracting more NFC credits than configured (Torez Smith) [2061784]
- thunderbolt: Runtime resume USB4 port when retimers are scanned (Torez Smith) [2061784]
- thunderbolt: Tear down existing tunnels when resuming from hibernate (Torez Smith) [2061784]
- thunderbolt: Runtime PM activate both ends of the device link (Torez Smith) [2061784]
- thunderbolt: xdomain: Avoid potential stack OOB read (Torez Smith) [2061784]
- media: m920x: don't use stack on USB reads (Torez Smith) [2061784]
- media: siano: remove duplicate USB device IDs (Torez Smith) [2061784]
- media: replace setting of bytesused with vb2_set_plane_payload (Torez Smith) [2061784]
- media: uvcvideo: Avoid returning invalid controls (Torez Smith) [2061784]
- media: uvcvideo: Avoid invalid memory access (Torez Smith) [2061784]
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds. (Torez Smith) [2061784]
- media: uvcvideo: Set the colorspace as sRGB if undefined (Torez Smith) [2061784]
- media: uvcvideo: fix division by zero at stream start (Torez Smith) [2061784]
- media: uvcvideo: Fix memory leak of object map on error exit path (Torez Smith) [2061784]
- usb: core: Fix file path that does not exist (Torez Smith) [2061784]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Torez Smith) [2061784]
- usb: cdnsp: Fix a NULL pointer dereference in cdnsp_endpoint_init() (Torez Smith) [2061784]
- usb: cdns3: gadget: fix new urb never complete if ep cancel previous requests (Torez Smith) [2061784]
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (Torez Smith) [2061784]
- xhci: Fix commad ring abort, write all 64 bits to CRCR register. (Torez Smith) [2061784]
- usb: bdc: fix error handling code in bdc_resume (Torez Smith) [2061784]
- usb: uhci: add aspeed ast2600 uhci support (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip reading GEVNTSIZn (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore Update Transfer cmd params (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip checking Update Transfer status (Torez Smith) [2061784]
- media: pvrusb2: fix inconsistent indenting (Torez Smith) [2061784]
- media: au0828-i2c: drop a duplicated function (Torez Smith) [2061784]
- media: lmedm04: don't ignore errors when setting a filter (Torez Smith) [2061784]
- USB: serial: option: add Fibocom FM101-GL variants (Torez Smith) [2061784]
- usb: dwc2: gadget: use existing helper (Torez Smith) [2061784]
- usb: gadget: configfs: use to_usb_function_instance() in cfg (un)link func (Torez Smith) [2061784]
- usb: gadget: configfs: use to_config_usb_cfg() in os_desc_link() (Torez Smith) [2061784]
- usb: gadget: configfs: remove os_desc_attr_release() (Torez Smith) [2061784]
- usb: gadget: configfs: simplify os_desc_item_to_gadget_info() helper (Torez Smith) [2061784]
- usb: xilinx: Add suspend resume support (Torez Smith) [2061784]
- usb: typec: tipd: Fix initialization sequence for cd321x (Torez Smith) [2061784]
- usb: typec: tipd: Fix typo in cd321x_switch_power_state (Torez Smith) [2061784]
- usb: hub: Fix locking issues with address0_mutex (Torez Smith) [2061784]
- USB: serial: pl2303: fix GC type detection (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910S1 0x9200 composition (Torez Smith) [2061784]
- media: dib0700: Only touch one bit when start/stop an adapter (Torez Smith) [2061784]
- media: dib0700: cleanup start/stop streaming logic (Torez Smith) [2061784]
- media: dib0700: fix undefined behavior in tuner shutdown (Torez Smith) [2061784]
- media: stk1160: fix control-message timeouts (Torez Smith) [2061784]
- media: s2255: fix control-message timeouts (Torez Smith) [2061784]
- media: pvrusb2: fix control-message timeouts (Torez Smith) [2061784]
- media: em28xx: fix control-message timeouts (Torez Smith) [2061784]
- media: cpia2: fix control-message timeouts (Torez Smith) [2061784]
- media: flexcop-usb: fix control-message timeouts (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: fix potential error pointer dereference in probe (Torez Smith) [2061784]
- usb: hub: Fix usb enumeration issue due to address0 race (Torez Smith) [2061784]
- usb: typec: fusb302: Fix masking of comparator and bc_lvl interrupts (Torez Smith) [2061784]
- usb: dwc3: leave default DMA for PCI devices (Torez Smith) [2061784]
- usb: dwc2: hcd_queue: Fix use of floating point literal (Torez Smith) [2061784]
- usb: dwc3: gadget: Fix null pointer exception (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Fix an error handling path in 'xudc_probe()' (Torez Smith) [2061784]
- usb: xhci: tegra: Check padctrl interrupt presence in device tree (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for elapsed frames (Torez Smith) [2061784]
- usb: dwc3: gadget: Check for L1/L2/U3 for Start Transfer (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore NoStream after End Transfer (Torez Smith) [2061784]
- usb: dwc3: core: Revise GHWPARAMS9 offset (Torez Smith) [2061784]
- usb: typec: ucsi: Expose number of alternate modes in partner (Torez Smith) [2061784]
- usb: xhci-mtk: fix random remote wakeup (Torez Smith) [2061784]
- usb: xhci-mtk: remove unnecessary error check (Torez Smith) [2061784]
- Docs: usb: update writesize, copy_from_user, usb_fill_bulk_urb, usb_submit_urb (Torez Smith) [2061784]
- Docs: usb: update comment and code near increment usage count (Torez Smith) [2061784]
- Docs: usb: update err() to pr_err() and replace __FILE__ (Torez Smith) [2061784]
- usb: gadget: at91_udc: Convert to GPIO descriptors (Torez Smith) [2061784]
- usb: gadget: composite: Show warning if function driver's descriptors are incomplete. (Torez Smith) [2061784]
- usb: gadget: f_midi: allow resetting index option (Torez Smith) [2061784]
- usb: Remove redundant 'flush_workqueue()' calls (Torez Smith) [2061784]
- usb: gadget: f_fs: Use stream_open() for endpoint files (Torez Smith) [2061784]
- USB: ehci_brcm_hub_control: Improve port index sanitizing (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: fix shared reset control use (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ4019 and IPQ8064 (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: document the port when usb-role-switch is used (Torez Smith) [2061784]
- usb: cdnsp: Remove unneeded semicolon after `}' (Torez Smith) [2061784]
- media: em28xx: fix memory leak in em28xx_init_dev (Torez Smith) [2061784]
- media: gspca: Make use of the helper macro kthread_run() (Torez Smith) [2061784]
- dt-bindings: treewide: Update @st.com email address to @foss.st.com (Torez Smith) [2061784]
- xhci: Fix USB 3.1 enumeration issues by increasing roothub power-on-good delay (Torez Smith) [2061784]
- Revert "usb: core: hcd: Add support for deferring roothub registration" (Torez Smith) [2061784]
- Revert "xhci: Set HCD flag to defer primary roothub registration" (Torez Smith) [2061784]
- usb: gadget: Mark USB_FSL_QE broken on 64-bit (Torez Smith) [2061784]
- usb: gadget: f_mass_storage: Disable eps during disconnect (Torez Smith) [2061784]
- usb: gadget: udc: core: Revise comments for USB ep enable/disable (Torez Smith) [2061784]
- usb: mtu3: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- usb: xhci-mtk: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- USB: serial: keyspan: fix memleak on probe errors (Torez Smith) [2061784]
- USB: serial: cp210x: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: ch314: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: iowarrior: fix control-message timeouts (Torez Smith) [2061784]
- Documentation: USB: fix example bulk-message timeout (Torez Smith) [2061784]
- usb: remove res2 argument from gadget code completions (Torez Smith) [2061784]
- usb: dwc2: stm32mp15: set otg_rev (Torez Smith) [2061784]
- usb: dwc2: add otg_rev and otg_caps information for gadget driver (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: adopt otg properties defined in usb-drd.yaml (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: Add reference to usb-drd.yaml (Torez Smith) [2061784]
- usb: gadget: uvc: implement dwPresentationTime and scrSourceClock (Torez Smith) [2061784]
- usb: gadget: uvc: use on returned header len in video_encode_isoc_sg (Torez Smith) [2061784]
- usb:gadget: f_uac1: fixed sync playback (Torez Smith) [2061784]
- Docs: usb: remove :c:func: for usb_register and usb_deregister (Torez Smith) [2061784]
- Docs: usb: update struct usb_driver (Torez Smith) [2061784]
- usb: gadget: configfs: change config attributes file operation (Torez Smith) [2061784]
- usb: gadget: configfs: add cfg_to_gadget_info() helper (Torez Smith) [2061784]
- usb: dwc3: Align DWC3_EP_* flag macros (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip resizing EP's TX FIFO if already resized (Torez Smith) [2061784]
- USB: chipidea: fix interrupt deadlock (Torez Smith) [2061784]
- usb: musb: Balance list entry in musb_gadget_queue (Torez Smith) [2061784]
- usb: musb: sunxi: Don't print error on MUSB_ULPI_BUSCONTROL access (Torez Smith) [2061784]
- usb: gadget: uvc: ensure the vdev is unset (Torez Smith) [2061784]
- usb: gadget: uvc: only pump video data if necessary (Torez Smith) [2061784]
- usb: gadget: uvc: only schedule stream in streaming state (Torez Smith) [2061784]
- usb: gadget: uvc: test if ep->desc is valid on ep_queue (Torez Smith) [2061784]
- usb: gadget: uvc: rename function to be more consistent (Torez Smith) [2061784]
- usb: gadget: uvc: consistently use define for headerlen (Torez Smith) [2061784]
- usb: max-3421: Use driver data instead of maintaining a list of bound devices (Torez Smith) [2061784]
- usb: dwc2: drd: reset current session before setting the new one (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_drd_role_sw_set when clock could be disabled (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_force_mode call in dwc2_ovr_init (Torez Smith) [2061784]
- usb: ohci: disable start-of-frame interrupt in ohci_rh_suspend (Torez Smith) [2061784]
- usb: host: ehci: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: host: fotg210: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: dwc3: gadget: Change to dev_dbg() when queuing to inactive gadget/ep (Torez Smith) [2061784]
- usb: gadget: u_ether: use eth_hw_addr_set() (Torez Smith) [2061784]
- usb: typec: tipd: Enable event interrupts by default (Torez Smith) [2061784]
- media: gspca/gl860-mi1320/ov9655: avoid -Wstring-concatenation warning (Torez Smith) [2061784]
- usb: typec: STUSB160X should select REGMAP_I2C (Torez Smith) [2061784]
- usb-storage: Add compatibility quirk flags for iODD 2531/2541 (Torez Smith) [2061784]
- scsi: usb: Switch to attribute groups (Torez Smith) [2061784]
- net: remove single-byte netdev->dev_addr writes (Torez Smith) [2061784]
- usb: musb: dsps: Fix the probe error path (Torez Smith) [2061784]
- usb: gadget: avoid unusual inline assembly (Torez Smith) [2061784]
- usb: musb: select GENERIC_PHY instead of depending on it (Torez Smith) [2061784]
- usb: host: ohci-tmio: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: gadget: u_audio.c: Adding Playback Pitch ctl for sync playback (Torez Smith) [2061784]
- usb: gadget: hid: fix error code in do_config() (Torez Smith) [2061784]
- xhci: Enable trust tx length quirk for Fresco FL11 USB controller (Torez Smith) [2061784]
- xhci: Fix command ring pointer corruption while aborting a command (Torez Smith) [2061784]
- USB: xhci: dbc: fix tty registration race (Torez Smith) [2061784]
- xhci: add quirk for host controllers that don't update endpoint DCS (Torez Smith) [2061784]
- xhci: guard accesses to ep_state in xhci_endpoint_reset() (Torez Smith) [2061784]
- USB: gadget: udc: Remove some dead code (Torez Smith) [2061784]
- usb: gadget: storage: add support for media larger than 2T (Torez Smith) [2061784]
- usb: chipidea: udc: make controller hardware endpoint primed (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Add clocking node (Torez Smith) [2061784]
- media: usb: dvd-usb: fix uninit-value bug in dibusb_read_eeprom_byte() (Torez Smith) [2061784]
- USB: serial: qcserial: add EM9191 QDL support (Torez Smith) [2061784]
- Revert "usb: misc: ehset: Workaround for "special" hubs" (Torez Smith) [2061784]
- USB: serial: option: add Quectel EC200S-CN module support (Torez Smith) [2061784]
- USB: serial: option: add prod. id for Quectel EG91 (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910Cx composition 0x1204 (Torez Smith) [2061784]
- thunderbolt: build kunit tests without structleak plugin (Torez Smith) [2061784]
- usb: core: config: Change sizeof(struct ...) to sizeof(*...) (Torez Smith) [2061784]
- ARM: omap1: move omap15xx local bus handling to usb.c (Torez Smith) [2061784]
- USB: cdc-acm: fix break reporting (Torez Smith) [2061784]
- USB: cdc-acm: fix racy tty buffer accesses (Torez Smith) [2061784]
- usb: gadget: f_uac2: fixed EP-IN wMaxPacketSize (Torez Smith) [2061784]
- usb: cdc-wdm: Fix check for WWAN (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: Also search for 'phys' phandle (Torez Smith) [2061784]
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes (Torez Smith) [2061784]
- usb: typec: tcpci: don't handle vSafe0V event if it's not enabled (Torez Smith) [2061784]
- usb: typec: tipd: Remove dependency on "connector" child fwnode (Torez Smith) [2061784]
- Partially revert "usb: Kconfig: using select for USB_COMMON dependency" (Torez Smith) [2061784]
- usb: dwc3: gadget: Revert "set gadgets parent to the right controller" (Torez Smith) [2061784]
- usb: xhci: tegra: mark PM functions as __maybe_unused (Torez Smith) [2061784]
- usb: gadget: udc: core: Print error code in usb_gadget_probe_driver() (Torez Smith) [2061784]
- usb: gadget: udc: core: Use pr_fmt() to prefix messages (Torez Smith) [2061784]
- usb: gadget: uvc: fix multiple opens (Torez Smith) [2061784]
- usb: cdc-wdm: Constify static struct wwan_port_ops (Torez Smith) [2061784]
- usb: usb-skeleton: Update min() to min_t() (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Fix usb-phy check (Torez Smith) [2061784]
- dt-bindings: usb: Convert SMSC USB3503 binding to a schema (Torez Smith) [2061784]
- usb: exynos: describe driver in KConfig (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Add clock support (Torez Smith) [2061784]
- usb: xhci-mtk: use xhci_dbg() to print log (Torez Smith) [2061784]
- USB: EHCI: Improve port index sanitizing (Torez Smith) [2061784]
- USB: phy: tahvo:remove unnecessary debug log (Torez Smith) [2061784]
- usb: atm: Use struct_size() helper (Torez Smith) [2061784]
- usb: phy: tegra: Support OTG mode programming (Torez Smith) [2061784]
- usb: host: oxu210hp: Fix a function name in comments (Torez Smith) [2061784]
- usb: host: fotg210: Fix a function name in comments (Torez Smith) [2061784]
- usb: ehci: Fix a function name in comments (Torez Smith) [2061784]
- usb: typec: tipd: Remove FIXME about testing with I2C_FUNC_I2C (Torez Smith) [2061784]
- usb: typec: tipd: Switch CD321X power state to S0 (Torez Smith) [2061784]
- usb: typec: tipd: Add support for Apple CD321X (Torez Smith) [2061784]
- usb: typec: tipd: Add short-circuit for no irqs (Torez Smith) [2061784]
- usb: typec: tipd: Split interrupt handler (Torez Smith) [2061784]
- dt-bindings: usb: tps6598x: Add Apple CD321x compatible (Torez Smith) [2061784]
- usb: typec: ucsi: Better fix for missing unplug events issue (Torez Smith) [2061784]
- usb: typec: ucsi: Read the PDOs in separate work (Torez Smith) [2061784]
- usb: typec: ucsi: Check the partner alt modes always if there is PD contract (Torez Smith) [2061784]
- usb: typec: ucsi: acpi: Reduce the command completion timeout (Torez Smith) [2061784]
- usb: typec: ucsi: Add polling mechanism for partner tasks like alt mode checking (Torez Smith) [2061784]
- usb: typec: ucsi: Don't stop alt mode registration on busy condition (Torez Smith) [2061784]
- usb: typec: ucsi: Always cancel the command if PPM reports BUSY condition (Torez Smith) [2061784]
- usb: typec: tcpci: Fix spelling mistake "resolbed" -> "resolved" (Torez Smith) [2061784]
- usb: misc: ehset: Workaround for "special" hubs (Torez Smith) [2061784]
- media: em28xx: Don't use ops->suspend if it is NULL (Torez Smith) [2061784]
- scsi: target: usb: Replace enable attr with ops.enable (Torez Smith) [2061784]
- media: mxl111sf: change mutex_init() location (Torez Smith) [2061784]
- media: tm6000: Avoid card name truncation (Torez Smith) [2061784]
- media: usb: stkwebcam: Update the reference count of the usb device structure (Torez Smith) [2061784]
- media: gspca: Limit frame size to sizeimage. (Torez Smith) [2061784]
- media: usb: airspy: clean the freed pointer and counter (Torez Smith) [2061784]
- media: pvrusb2: Replaced simple_strtol() with kstrtoint() (Torez Smith) [2061784]
- media: uvcvideo: Don't spam the log in uvc_ctrl_restore_values() (Torez Smith) [2061784]
- media: uvcvideo: Set error_idx during ctrl_commit errors (Torez Smith) [2061784]
- media: uvcvideo: Check controls flags before accessing them (Torez Smith) [2061784]
- media: uvcvideo: Use control names from framework (Torez Smith) [2061784]
- media: uvcvideo: Increase the size of UVC_METADATA_BUF_SIZE (Torez Smith) [2061784]
- media: uvcvideo: Set unique vdev name based in type (Torez Smith) [2061784]
- media: uvcvideo: Use dev->name for querycap() (Torez Smith) [2061784]
- media: uvcvideo: Add support for V4L2_CTRL_TYPE_CTRL_CLASS (Torez Smith) [2061784]
- media: uvcvideo: refactor __uvc_ctrl_add_mapping (Torez Smith) [2061784]
- media: uvcvideo: Return -EIO for control errors (Torez Smith) [2061784]
- media: uvcvideo: Set capability in s_param (Torez Smith) [2061784]
- media: uvcvideo: Remove s_ctrl and g_ctrl (Torez Smith) [2061784]
- media: uvcvideo: Remove unused including <linux/version.h> (Torez Smith) [2061784]
- media: uvcvideo: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: pvrusb2: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: m5602_ov7660: remove the repeated declaration (Torez Smith) [2061784]
- media: dvb-usb: fix ununit-value in az6027_rc_query (Torez Smith) [2061784]
- media: ttusb-dec: avoid release of non-acquired mutex (Torez Smith) [2061784]
- media: gspca/sn9c20x: Add ability to control built-in webcam LEDs (Torez Smith) [2061784]
- media: em28xx: add missing em28xx_close_extension (Torez Smith) [2061784]
- thunderbolt: Fix -Wrestrict warning (Torez Smith) [2061784]
- USB: serial: option: add device id for Foxconn T99W265 (Torez Smith) [2061784]
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital Multimeter (Torez Smith) [2061784]
- USB: serial: cp210x: add part-number debug printk (Torez Smith) [2061784]
- USB: serial: cp210x: fix dropped characters with CP2102 (Torez Smith) [2061784]
- USB: serial: kl5kusb105: drop line-status helper (Torez Smith) [2061784]
- USB: serial: kl5kusb105: simplify line-status handling (Torez Smith) [2061784]
- USB: serial: kl5kusb105: clean up line-status handling (Torez Smith) [2061784]
- usb: musb: tusb6010: uninitialized data in tusb_fifo_write_unaligned() (Torez Smith) [2061784]
- usb-storage: Add quirk for ScanLogic SL11R-IDE older than 2.6c (Torez Smith) [2061784]
- Re-enable UAS for LaCie Rugged USB3-FW with fk quirk (Torez Smith) [2061784]
- usb: dwc3: gadget: Avoid starting DWC3 gadget during UDC unbind (Torez Smith) [2061784]
- usb: core: hcd: fix messages in usb_hcd_request_irqs() (Torez Smith) [2061784]
- usb: host: ehci-mv: drop duplicated MODULE_ALIAS (Torez Smith) [2061784]
- usb: typec: tipd: Remove WARN_ON in tps6598x_block_read (Torez Smith) [2061784]
- usb: typec: tipd: Add an additional overflow check (Torez Smith) [2061784]
- usb: typec: tipd: Don't read/write more bytes than required (Torez Smith) [2061784]
- usb: musb: tusb6010: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- USB: cdc-acm: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: kl5kusb105: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: keyspan_pda: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: ftdi_sio: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: f81232: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: allow hung up ports to be suspended (Torez Smith) [2061784]
- USB: serial: clean up core error labels (Torez Smith) [2061784]
- USB: serial: option: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: mos7840: remove duplicated 0xac24 device ID (Torez Smith) [2061784]
- USB: core: Make do_proc_control() and do_proc_bulk() killable (Torez Smith) [2061784]
- usb: musb: mediatek: Expose role-switch control to userspace (Torez Smith) [2061784]
- usb: gadget: f_uac2: Populate SS descriptors' wBytesPerInterval (Torez Smith) [2061784]
- usb: gadget: f_uac2: Add missing companion descriptor for feedback EP (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC transfer complete handling for DDMA (Torez Smith) [2061784]
- usb: core: hcd: Modularize HCD stop configuration in usb_stop_hcd() (Torez Smith) [2061784]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2061784]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for BDMA and Slave (Torez Smith) [2061784]
- usb: dwc3: core: balance phy init and exit (Torez Smith) [2061784]
- Revert "USB: bcma: Add a check for devm_gpiod_get" (Torez Smith) [2061784]
- usb: ehci: Simplify platform driver registration (Torez Smith) [2061784]
- USB: cdc-acm: fix minor-number release (Torez Smith) [2061784]
- usb: dwc2: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: cdns3: fix race condition before setting doorbell (Torez Smith) [2061784]
- usb: gadget: r8a66597: fix a loop in set_feature() (Torez Smith) [2061784]
- usb: gadget: u_audio: EP-OUT bInterval in fback frequency (Torez Smith) [2061784]
- usb: testusb: Fix for showing the connection speed (Torez Smith) [2061784]
- usb: gadget: fix for a typo that conveys logically-inverted information. (Torez Smith) [2061784]
- usb: gadget: goku_udc: Fix mask and set operation on variable master (Torez Smith) [2061784]
- USB: host: ehci-atmel: Add support for HSIC phy (Torez Smith) [2061784]
- dt-bindings: usb: atmel: add USB PHY type property (Torez Smith) [2061784]
- usb: ehci: handshake CMD_RUN instead of STS_HALT (Torez Smith) [2061784]
- usb: gadget: f_uac2: clean up some inconsistent indenting (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ6018 (Torez Smith) [2061784]
- usb: dwc3: reference clock period configuration (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: add reference clock period (Torez Smith) [2061784]
- usb: ohci: Prefer struct_size over open coded arithmetic (Torez Smith) [2061784]
- usb: typec: hd3ss3220: Use regmap_write_bits() (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Convert binding to YAML (Torez Smith) [2061784]
- USB: serial: option: add Telit LN920 compositions (Torez Smith) [2061784]
- thunderbolt: test: split up test cases in tb_test_credit_alloc_all (Torez Smith) [2061784]
- USB: serial: pl2303: fix GL type detection (Torez Smith) [2061784]
- usb: isp1760: otg control register access (Torez Smith) [2061784]
- usb: isp1760: use the right irq status bit (Torez Smith) [2061784]
- usb: isp1760: write to status and address register (Torez Smith) [2061784]
- usb: isp1760: fix qtd fill length (Torez Smith) [2061784]
- usb: isp1760: fix memory pool initialization (Torez Smith) [2061784]
- usb: typec: tcpm: Fix spelling mistake "atleast" -> "at least" (Torez Smith) [2061784]
- usb: dwc2: Fix spelling mistake "was't" -> "wasn't" (Torez Smith) [2061784]
- usb: renesas_usbhs: Fix spelling mistake "faile" -> "failed" (Torez Smith) [2061784]
- usb: host: xhci-rcar: Don't reload firmware after the completion (Torez Smith) [2061784]
- usb: xhci-mtk: allow bandwidth table rollover (Torez Smith) [2061784]
- usb: mtu3: fix random remote wakeup (Torez Smith) [2061784]
- usb: mtu3: return successful suspend status (Torez Smith) [2061784]
- usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint (Torez Smith) [2061784]
- usb: xhci-mtk: modify the SOF/ITP interval for mt8195 (Torez Smith) [2061784]
- usb: xhci-mtk: add a member of num_esit (Torez Smith) [2061784]
- usb: xhci-mtk: check boundary before check tt (Torez Smith) [2061784]
- usb: xhci-mtk: update fs bus bandwidth by bw_budget_table (Torez Smith) [2061784]
- usb: xhci-mtk: fix issue of out-of-bounds array access (Torez Smith) [2061784]
- usb: xhci-mtk: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: xhci-mtk: fix use-after-free of mtk->hcd (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add compatible for mt8195 (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add optional property to disable usb2 ports (Torez Smith) [2061784]
- usb: bdc: Fix a resource leak in the error handling path of 'bdc_probe()' (Torez Smith) [2061784]
- usb: bdc: Fix an error handling path in 'bdc_probe()' when no suitable DMA config is available (Torez Smith) [2061784]
- Revert "usb: xhci-mtk: relax TT periodic bandwidth allocation" (Torez Smith) [2061784]
- usb: isp1760: clean never read udc_enabled warning (Torez Smith) [2061784]
- usb: isp1760: do not shift in uninitialized slot (Torez Smith) [2061784]
- usb: isp1760: do not reset retval (Torez Smith) [2061784]
- usb: isp1760: check maxpacketsize before using it (Torez Smith) [2061784]
- usb: isp1760: ignore return value for bus change pattern (Torez Smith) [2061784]
- usb: gadget: Add description for module parameter (Torez Smith) [2061784]
- usbip:vhci_hcd USB port can get stuck in the disabled state (Torez Smith) [2061784]
- usbip: clean up code in vhci_device_unlink_cleanup (Torez Smith) [2061784]
- usbip: give back URBs for unsent unlink requests during cleanup (Torez Smith) [2061784]
- usb: gadget: aspeed: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: gadget: mass_storage: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: musb: musb_dsps: request_irq() after initializing musb (Torez Smith) [2061784]
- usb: dwc3: pci: add support for AMD's newer generation platform. (Torez Smith) [2061784]
- usb: dwc3: imx8mp: request irq after initializing dwc3 (Torez Smith) [2061784]
- usb: ehci-orion: Handle errors of clk_prepare_enable() in probe (Torez Smith) [2061784]
- xhci: Add bus number to some debug messages (Torez Smith) [2061784]
- xhci: Add additional dynamic debug to follow URBs in cancel and error cases. (Torez Smith) [2061784]
- Revert "USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST quirk set" (Torez Smith) [2061784]
- xhci: Fix failure to give back some cached cancelled URBs. (Torez Smith) [2061784]
- xhci: fix even more unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- xhci: fix unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- USB: serial: replace symbolic permissions by octal permissions (Torez Smith) [2061784]
- usb: gadget: f_hid: optional SETUP/SET_REPORT mode (Torez Smith) [2061784]
- usb: chipidea: host: fix port index underflow and UBSAN complains (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Notify drm subsys of hotplug events (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Make dp_altmode_notify() more generic (Torez Smith) [2061784]
- drm/connector: Add support for out-of-band hotplug notification (v3) (Torez Smith) [2061784]
- drm/connector: Add drm_connector_find_by_fwnode() function (v3) (Torez Smith) [2061784]
- drm/connector: Add a fwnode pointer to drm_connector and register with ACPI (v2) (Torez Smith) [2061784]
- drm/connector: Give connector sysfs devices there own device_type (Torez Smith) [2061784]
- USB: EHCI: Add alias for Broadcom INSNREG (Torez Smith) [2061784]
- USB: EHCI: Add register array bounds to HCS ports (Torez Smith) [2061784]
- usb: gadget: mv_u3d: request_irq() after initializing UDC (Torez Smith) [2061784]
- usb: gadget: f_uac1: fixing inconsistent indenting (Torez Smith) [2061784]
- usb: remove reference to deleted config STB03xxx (Torez Smith) [2061784]
- usb: host: remove line for obsolete config USB_HWA_HCD (Torez Smith) [2061784]
- usb: host: remove dead EHCI support for on-chip PMC MSP71xx USB controller (Torez Smith) [2061784]
- usb: dwc3: Decouple USB 2.0 L1 & L2 events (Torez Smith) [2061784]
- usb: phy: tahvo: add IRQ check (Torez Smith) [2061784]
- usb: host: ohci-tmio: add IRQ check (Torez Smith) [2061784]
- dt-bindings: usb: mtk-musb: add MT7623 compatible (Torez Smith) [2061784]
- usb: gadget: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: bdc: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix soc_device_match() abuse (Torez Smith) [2061784]
- usb: typec: tcpm: Support non-PD mode (Torez Smith) [2061784]
- usb: gadget: tegra-xudc: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: cdnsp: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: fix the wrong HS mult value (Torez Smith) [2061784]
- usb: mtu3: use @mult for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: restore HS function when set SS/SSP (Torez Smith) [2061784]
- usb: phy: twl6030: add IRQ checks (Torez Smith) [2061784]
- usb: phy: fsl-usb: add IRQ check (Torez Smith) [2061784]
- usb: misc: brcmstb-usb-pinmap: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: s3c2410: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: at91: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: qcom: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: add IRQ check (Torez Smith) [2061784]
- usb: dwc2: gadget: implement udc_set_speed() (Torez Smith) [2061784]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2061784]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2L bindings (Torez Smith) [2061784]
- docs: usb: fix malformed table (Torez Smith) [2061784]
- usb: gadget: f_uac2: remove redundant assignments to pointer i_feature (Torez Smith) [2061784]
- usb: misc: adutux: use swap() (Torez Smith) [2061784]
- usb: gadget: remove useless cast (Torez Smith) [2061784]
- usb: gadget: Fix inconsistent indent (Torez Smith) [2061784]
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect (Torez Smith) [2061784]
- thunderbolt: Add authorized value to the KOBJ_CHANGE uevent (Torez Smith) [2061784]
- USB: serial: cp210x: determine fw version for CP2105 and CP2108 (Torez Smith) [2061784]
- USB: serial: cp210x: clean up type detection (Torez Smith) [2061784]
- USB: serial: cp210x: clean up set-chars request (Torez Smith) [2061784]
- USB: serial: cp210x: clean up control-request timeout (Torez Smith) [2061784]
- USB: serial: cp210x: fix flow-control error handling (Torez Smith) [2061784]
- USB: serial: cp210x: fix control-characters error handling (Torez Smith) [2061784]
- USB: serial: io_edgeport: drop unused descriptor helper (Torez Smith) [2061784]
- usb: gadget: pxa25x_udc: Constify static struct pxa25x_ep_ops (Torez Smith) [2061784]
- drivers: usb: dwc3-qcom: Add sdm660 compatible (Torez Smith) [2061784]
- usb: isp1760: rework cache initialization error handling (Torez Smith) [2061784]
- usb: isp1760: do not sleep in field register poll (Torez Smith) [2061784]
- usb: isp1760: remove debug message as error (Torez Smith) [2061784]
- dt-bindings: usb: ohci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- dt-bindings: usb: ehci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- usb: gadget: uvc: decrease the interrupt load to a quarter (Torez Smith) [2061784]
- usb: gadget: uvc: add scatter gather support (Torez Smith) [2061784]
- usb: gadget: uvc: set v4l2_dev->dev in f_uvc (Torez Smith) [2061784]
- usb: gadget: uvc: make uvc_num_requests depend on gadget speed (Torez Smith) [2061784]
- usb: dwc3: gadget: set gadgets parent to the right controller (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for dual-role mode (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for device mode (Torez Smith) [2061784]
- usb: mtu3: add helper to power on/down device (Torez Smith) [2061784]
- usb: mtu3: support runtime PM for host mode (Torez Smith) [2061784]
- usb: mtu3: add new helpers for host suspend/resume (Torez Smith) [2061784]
- usb: mtu3: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: mtu3: support property role-switch-default-mode (Torez Smith) [2061784]
- usb: dwc3: drd: use helper to get role-switch-default-mode (Torez Smith) [2061784]
- usb: common: add helper to get role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add wakeup interrupt (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add support property role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add optional property to disable usb2 ports (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: remove support VBUS detection of extcon (Torez Smith) [2061784]
- media: stkwebcam: fix memory leak in stk_camera_probe (Torez Smith) [2061784]
- media: go7007: remove redundant initialization (Torez Smith) [2061784]
- media: go7007: fix memory leak in go7007_usb_probe (Torez Smith) [2061784]
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Fix typo in the dwc3 vbus override API (Torez Smith) [2061784]
- usb: gadget: f_uac1: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: f_uac2: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: u_audio: add bi-directional volume and mute support (Torez Smith) [2061784]
- usb: audio-v2: add ability to define feature unit descriptor (Torez Smith) [2061784]
- dt-bindings: usb: generic-ohci: Document dr_mode property (Torez Smith) [2061784]
- dt-bindings: usb: generic-ehci: Document dr_mode property (Torez Smith) [2061784]
- usb: dwc2: gadget: Add endpoint wedge support (Torez Smith) [2061784]
- usb: gadget: composite: Allow bMaxPower=0 if self-powered (Torez Smith) [2061784]
- usb: isp1301-omap: Fix the GPIO include (Torez Smith) [2061784]
- usb: renesas-xhci: Remove renesas_xhci_pci_exit() (Torez Smith) [2061784]
- usb: xhci-renesas: Minor coding style cleanup (Torez Smith) [2061784]
- usb: host: ohci-spear: simplify calling usb_add_hcd() (Torez Smith) [2061784]
- USB: EHCI: ehci-mv: improve error handling in mv_ehci_enable() (Torez Smith) [2061784]
- usb: gadget: u_ether: fix a potential null pointer dereference (Torez Smith) [2061784]
- usb: gadget: f_ncm: ncm_wrap_ntb - move var definitions into if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove check for NULL skb_tx_data in timer function (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious boolean timer_stopping (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove timer_force_tx field (Torez Smith) [2061784]
- usb: host: fotg210: fix the actual_length of an iso packet (Torez Smith) [2061784]
- usb: host: fotg210: fix the endpoint's transactional opportunities calculation (Torez Smith) [2061784]
- Revert "usb: host: fotg210: Use dma_pool_zalloc" (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: let subdrv autoselect enable si2168 and si2157 (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: report if i2c client isn't bound (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Update dwc3 TX fifo properties (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default (Torez Smith) [2061784]
- usb: dwc3: Resize TX FIFOs to meet EP bursting requirements (Torez Smith) [2061784]
- usb: gadget: configfs: Check USB configuration before adding (Torez Smith) [2061784]
- usb: gadget: udc: core: Introduce check_config to verify USB configuration (Torez Smith) [2061784]
- media: drivers/media/usb/gspca: fix typo Fliker -> Flicker (Torez Smith) [2061784]
- media: uvc: don't do DMA on stack (Torez Smith) [2061784]
- media: gspca: Drop default m (Torez Smith) [2061784]
- media: dvbsky: add support for MyGica T230C2_LITE and T230A (Torez Smith) [2061784]
- oom_kill.c: futex: delay the OOM reaper to allow time for proper futex cleanup (Nico Pache) [1951330]
- scsi: mpt3sas: Fix mpt3sas_check_same_4gb_region() kdoc comment (Tomas Henzl) [2068044]
- scsi: mpt3sas: Fix incorrect 4GB boundary check (Tomas Henzl) [2068044]
- scsi: mpt3sas: Remove scsi_dma_map() error messages (Tomas Henzl) [2068044]
- qed: fix ethtool register dump (Manish Chopra) [2040279]
- qede: confirm skb is allocated before using (Manish Chopra) [2040279]
- qed: remove unnecessary memset in qed_init_fw_funcs (Manish Chopra) [2040279]
- qed: return status of qed_iov_get_link (Manish Chopra) [2040279]
- net: qlogic: check the return value of dma_alloc_coherent() in qed_vf_hw_prepare() (Manish Chopra) [2040279]
- qed: validate and restrict untrusted VFs vlan promisc mode (Manish Chopra) [2040279]
- qed: display VF trust config (Manish Chopra) [2040279]
- qed: prevent a fw assert during device shutdown (Manish Chopra) [2040279]
- qed: use msleep() in qed_mcp_cmd() and add qed_mcp_cmd_nosleep() for udelay. (Manish Chopra) [2040279]
- qed: Use dma_set_mask_and_coherent() and simplify code (Manish Chopra) [2040279]
- qed*: esl priv flag support through ethtool (Manish Chopra) [2040279]
- qed*: enhance tx timeout debug info (Manish Chopra) [2040279]
- qede: validate non LSO skb length (Manish Chopra) [2040279]
- qed: Enhance rammod debug prints to provide pretty details (Manish Chopra) [2040279]
- net: qed: fix the array may be out of bound (Manish Chopra) [2040279]
- qed: Use the bitmap API to simplify some functions (Manish Chopra) [2040279]
- RDMA/qed: Use helper function to set GUIDs (Manish Chopra) [2040279]
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP (Manish Chopra) [2040279]
- net: qed_dev: fix check of true !rc expression (Manish Chopra) [2040279]
- net: qed_ptp: fix check of true !rc expression (Manish Chopra) [2040279]
- RDMA/qedr: Remove unsupported qedr_resize_cq callback (Manish Chopra) [2040279]
- qed: Change the TCP common variable - "iscsi_ooo" (Manish Chopra) [2040279]
- qed: Optimize the ll2 ooo flow (Manish Chopra) [2040279]
- net: qed_debug: fix check of false (grc_param < 0) expression (Manish Chopra) [2040279]
- qed: Fix missing error code in qed_slowpath_start() (Manish Chopra) [2040279]
- qed: Fix compilation for CONFIG_QED_SRIOV undefined scenario (Manish Chopra) [2040279]
- qed: Initialize debug string array (Manish Chopra) [2040279]
- qed: Fix spelling mistake "ctx_bsaed" -> "ctx_based" (Manish Chopra) [2040279]
- qed: fix ll2 establishment during load of RDMA driver (Manish Chopra) [2040279]
- qed: Update the TCP active termination 2 MSL timer ("TIME_WAIT") (Manish Chopra) [2040279]
- qed: Update TCP silly-window-syndrome timeout for iwarp, scsi (Manish Chopra) [2040279]
- qed: Update debug related changes (Manish Chopra) [2040279]
- qed: Add '_GTT' suffix to the IRO RAM macros (Manish Chopra) [2040279]
- qed: Update FW init functions to support FW 8.59.1.0 (Manish Chopra) [2040279]
- qed: Use enum as per FW 8.59.1.0 in qed_iro_hsi.h (Manish Chopra) [2040279]
- qed: Update qed_hsi.h for fw 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update qed_mfw_hsi.h for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update common_hsi for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Split huge qed_hsi.h header file (Manish Chopra) [2040279]
- qed: Remove e4_ and _e4 from FW HSI (Manish Chopra) [2040279]
- qed: Fix kernel-doc warnings (Manish Chopra) [2040279]
- qed: rdma - don't wait for resources under hw error recovery flow (Manish Chopra) [2040279]
- qed: Improve the stack space of filter_config() (Manish Chopra) [2040279]
- qed: Handle management FW error (Manish Chopra) [2040279]
- qed: Enable automatic recovery on error condition. (Manish Chopra) [2040279]
- RDMA/qedr: Move variables reset to qedr_set_common_qp_params() (Manish Chopra) [2040279]
- qed: Remove duplicated include of kernel.h (Manish Chopra) [2040279]
- qed: Remove redundant prints from the iWARP SYN handling (Manish Chopra) [2040279]
- qed: Skip DORQ attention handling during recovery (Manish Chopra) [2040279]
- qed: Avoid db_recovery during recovery (Manish Chopra) [2040279]
- RDMA/qedr: Improve error logs for rdma_alloc_tid error return (Manish Chopra) [2040279]
- RDMA/qed: Use accurate error num in qed_cxt_dynamic_ilt_alloc (Manish Chopra) [2040279]
- qede: Remove the qede module version (Manish Chopra) [2040279]
- qed: Remove the qed module version (Manish Chopra) [2040279]
- net: qed: remove unneeded return variables (Manish Chopra) [2040279]
- sched/isolation: Split housekeeping cpumask per isolation features (Phil Auld) [2065222]
- sched/isolation: Fix housekeeping_mask memory leak (Phil Auld) [2065222]
- sched/isolation: Consolidate error handling (Phil Auld) [2065222]
- sched/isolation: Consolidate check for housekeeping minimum service (Phil Auld) [2065222]
- sched/isolation: Use single feature type while referring to housekeeping cpumask (Phil Auld) [2065222]
- net: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- workqueue: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- pci: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- mailbox: pcc: Avoid using the uninitialized variable 'dev' (Mark Langsdorf) [1998271]
- mailbox: pcc: Handle all PCC subtypes correctly in pcc_mbox_irq (Mark Langsdorf) [1998271]
- i2c: xgene-slimpro: Fix wrong pointer passed to PTR_ERR() (Mark Langsdorf) [1998271]
- ACPI: Make acpi_node_get_parent() local (Mark Langsdorf) [1998271]
- ACPI: Get acpi_device's parent from the parent field (Mark Langsdorf) [1998271]
- ACPI: Drop ACPI_USE_BUILTIN_STDARG ifdef from acgcc.h (Mark Langsdorf) [1998271]
- ACPI: PM: Fix device wakeup power reference counting error (Mark Langsdorf) [1998271]
- ACPI: video: use platform backlight driver on Xiaomi Mi Pad 2 (Mark Langsdorf) [1998271]
- ACPI: video: Drop dmi_system_id.ident settings from video_detect_dmi_table[] (Mark Langsdorf) [1998271]
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses (Mark Langsdorf) [1998271]
- ACPI: EC: Remove initialization of static variables to false (Mark Langsdorf) [1998271]
- ACPI: EC: Use ec_no_wakeup on HP ZHAN 66 Pro (Mark Langsdorf) [1998271]
- ACPI: Add a convenience function to tell a device is in D0 state (Mark Langsdorf) [1998271]
- ACPI: scan: Obtain device's desired enumeration power state (Mark Langsdorf) [1998271]
- perf: qcom_l2_pmu: ACPI: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI/PCC: Add maintainer for PCC mailbox driver (Mark Langsdorf) [1998271]
- mailbox: pcc: Move bulk of PCCT parsing into pcc_mbox_probe (Mark Langsdorf) [1998271]
- mailbox: pcc: Add support for PCCT extended PCC subspaces(type 3/4) (Mark Langsdorf) [1998271]
- mailbox: pcc: Drop handling invalid bit-width in {read,write}_register (Mark Langsdorf) [1998271]
- mailbox: pcc: Avoid accessing PCCT table in pcc_send_data and pcc_mbox_irq (Mark Langsdorf) [1998271]
- mailbox: pcc: Add PCC register bundle and associated accessor functions (Mark Langsdorf) [1998271]
- mailbox: pcc: Rename doorbell ack to platform interrupt ack register (Mark Langsdorf) [1998271]
- mailbox: pcc: Use PCC mailbox channel pointer instead of standard (Mark Langsdorf) [1998271]
- mailbox: pcc: Add pcc_mbox_chan structure to hold shared memory region info (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace doorbell register parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace interrupt information parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Refactor all PCC channel information into a structure (Mark Langsdorf) [1998271]
- mailbox: pcc: Fix kernel doc warnings (Mark Langsdorf) [1998271]
- ACPI: APEI: mark apei_hest_parse() static (Mark Langsdorf) [1998271]
- ACPI: APEI: EINJ: Relax platform response timeout to 1 second (Mark Langsdorf) [1998271]
- ACPI: resources: Add one more Medion model in IRQ override quirk (Mark Langsdorf) [1998271]
- ACPI: AC: Quirk GK45 to skip reading _PSR (Mark Langsdorf) [1998271]
- ACPI: PM: sleep: Do not set suspend_ops unnecessarily (Mark Langsdorf) [1998271]
- ACPI: PRM: Handle memory allocation and memory remap failure (Mark Langsdorf) [1998271]
- ACPI: PRM: Remove unnecessary blank lines (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off wakeup power resources on _DSW/_PSW errors (Mark Langsdorf) [1998271]
- ACPI: PM: Fix sharing of wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off unused wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Check states of power resources during initialization (Mark Langsdorf) [1998271]
- hwmon: (acpi_power_meter) Use acpi_bus_get_acpi_device() (Mark Langsdorf) [1998271]
- ACPI: replace snprintf() in "show" functions with sysfs_emit() (Mark Langsdorf) [1998271]
- ACPI: LPSS: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI: battery: Accept charges over the design capacity as full (Mark Langsdorf) [1998271]
- ACPICA: Update version to 20210930 (Mark Langsdorf) [1998271]
- ACPICA: iASL table disassembler: Added disassembly support for the NHLT ACPI table (Mark Langsdorf) [1998271]
- ACPICA: ACPI 6.4 SRAT: add Generic Port Affinity type (Mark Langsdorf) [1998271]
- ACPICA: Add support for Windows 2020 _OSI string (Mark Langsdorf) [1998271]
- ACPICA: Avoid evaluating methods too early during system resume (Mark Langsdorf) [1998271]
- ACPI: glue: Look for ACPI bus type only if ACPI companion is not known (Mark Langsdorf) [1998271]
- ACPI: glue: Drop cleanup callback from struct acpi_bus_type (Mark Langsdorf) [1998271]
- ACPI: processor: idle: Avoid falling back to C3 type C-states (Mark Langsdorf) [1998271]
- ACPI: processor idle: Allow playing dead in C3 state (Mark Langsdorf) [1998271]
- ACPI: Kconfig: Fix a typo in Kconfig (Mark Langsdorf) [1998271]
- ACPI: PNP: remove duplicated BRI0A49 and BDP3336 entries (Mark Langsdorf) [1998271]
- ACPI: resources: Add DMI-based legacy IRQ override quirk (Mark Langsdorf) [1998271]
- ACPICA: Add support for MADT online enabled bit (Mark Langsdorf) [1998271]
- ACPI: PM: Do not turn off power resources in unknown state (Mark Langsdorf) [1998269]
- acpi/arm64: fix next_platform_timer() section mismatch error (Mark Langsdorf) [1998269]
- ACPI: PM: Include alternate AMDI0005 id in special behaviour (Mark Langsdorf) [1998269]
- ACPI: NFIT: Use fallback node id when numa info in NFIT table is incorrect (Mark Langsdorf) [1998269]
- ACPICA: Update the list of maintainers (Mark Langsdorf) [1998269]
- MAINTAINERS: Change Rafael's e-mail address (Mark Langsdorf) [1998269]
- ACPI: PRM: Find PRMT table before parsing it (Mark Langsdorf) [1998269]
- ACPI: scan: Remove unneeded header linux/nls.h (Mark Langsdorf) [1998269]
- ACPI: PM: s2idle: Run both AMD and Microsoft methods if both are supported (Mark Langsdorf) [1998269]
- ACPI: power: Drop name from struct acpi_power_resource (Mark Langsdorf) [1998269]
- ACPI: power: Use acpi_handle_debug() to print debug messages (Mark Langsdorf) [1998269]
- ACPI: button: Add DMI quirk for Lenovo Yoga 9 (14INTL5) (Mark Langsdorf) [1998269]
- ACPI: SPCR: Add support for the new 16550-compatible Serial Port Subtype (Mark Langsdorf) [1998269]
- ACPI: platform-profile: call sysfs_notify() from platform_profile_store() (Mark Langsdorf) [1998269]
- ACPICA: Update version to 20210730 (Mark Langsdorf) [1998269]
- ACPICA: Add method name "_DIS" For use with aslmethod.c (Mark Langsdorf) [1998269]
- ACPICA: iASL: Fix for WPBT table with no command-line arguments (Mark Langsdorf) [1998269]
- ACPICA: Headers: Add new DBG2 Serial Port Subtypes (Mark Langsdorf) [1998269]
- ACPICA: Macros should not use a trailing semicolon (Mark Langsdorf) [1998269]
- ACPICA: Fix an if statement (add parens) (Mark Langsdorf) [1998269]
- ACPICA: iASL: Add support for the AEST table (data compiler) (Mark Langsdorf) [1998269]
- clk: fractional-divider: Introduce POWER_OF_TWO_PS flag (Mark Langsdorf) [1998269]
- ACPI: DPTF: Add new PCH FIVR methods (Mark Langsdorf) [1998269]
- clk: x86: Rename clk-lpt to more specific clk-lpss-atom (Mark Langsdorf) [1998269]
- ACPI: configfs: Make get_header() to return error pointer (Mark Langsdorf) [1998269]
- ACPI: configfs: Use sysfs_emit() in "show" functions (Mark Langsdorf) [1998269]
- ACPI: Add LoongArch support for ACPI_PROCESSOR/ACPI_NUMA (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize MIPI PMIQ sequence I2C-bus accesses (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize I2C-bus accesses (Mark Langsdorf) [1998269]

* Mon May 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-87.el9]
- perf tools: Add external commands to list-cmds (Michael Petlan) [2065179]
- perf docs: Add perf-iostat link to manpages (Michael Petlan) [2065179]
- net: make use of helper netif_is_bridge_master() (Ivan Vecera) [2081260]
- xfrm: enforce validity of offload input flags (Sabrina Dubroca) [2080384]
- xfrm: Don't accidentally set RTO_ONLINK in decode_session4() (Sabrina Dubroca) [2080384]
- net/xfrm: IPsec tunnel mode fix inner_ipproto setting in sec_path (Sabrina Dubroca) [2080384]
- xfrm: fix a small bug in xfrm_sa_len() (Sabrina Dubroca) [2080384]
- xfrm: fix policy lookup for ipv6 gre packets (Sabrina Dubroca) [2080384]
- net/tls: fix slab-out-of-bounds bug in decrypt_internal (Sabrina Dubroca) [2080356]
- tls: cap the output scatter list to something reasonable (Sabrina Dubroca) [2080356]
- net/tls: Fix authentication failure in CCM mode (Sabrina Dubroca) [2080356]
- tls: fix replacing proto_ops (Sabrina Dubroca) [2080356]
- tls: splice_read: fix accessing pre-processed records (Sabrina Dubroca) [2080356]
- tls: splice_read: fix record type check (Sabrina Dubroca) [2080356]
- net: macsec: Verify that send_sci is on when setting Tx sci explicitly (Sabrina Dubroca) [2080352]
- net: macsec: Fix offload support for NETDEV_UNREGISTER event (Sabrina Dubroca) [2080352]
- sctp: check asoc strreset_chunk in sctp_generate_reconf_event (Xin Long) [2069957]
- udf: Restore i_lenAlloc when inode expansion fails (Carlos Maiolino) [2054658] {CVE-2022-0617}
- udf: Fix NULL ptr deref when converting from inline format (Carlos Maiolino) [2054658] {CVE-2022-0617}
- cifs: destage any unwritten data to the server before calling copychunk_write (Ronnie Sahlberg) [1997373]
- i40e: xsk: Move tmp desc array from driver to pool (Ivan Vecera) [2078894]
- printk: use atomic updates for klogd work (Prarit Bhargava) [2078897]
- genirq: Provide generic_handle_irq_safe() (Prarit Bhargava) [2078897]
- printk: Remove printk.h inclusion in percpu.h (Prarit Bhargava) [2078897]
- efi: Allow efi=runtime (Prarit Bhargava) [2078897]
- efi: Disable runtime services on RT (Prarit Bhargava) [2078897]
- x86/softirq: Disable softirq stacks on PREEMPT_RT (Prarit Bhargava) [2078897]
- genirq: Disable irqfixup/poll on PREEMPT_RT. (Prarit Bhargava) [2078897]
- genirq: Move prio assignment into the newly created thread (Prarit Bhargava) [2078897]
- cpufreq: intel_pstate: Use firmware default EPP (Steve Best) [2072886]
- cpufreq: intel_pstate: Update cpuinfo.max_freq on HWP_CAP changes (Steve Best) [2072886]
- cpufreq: intel_pstate: Update EPP for AlderLake mobile (Steve Best) [2072886]
- cpufreq: intel_pstate: Drop redundant intel_pstate_get_hwp_cap() call (Steve Best) [2072886]
- cpufreq: intel_pstate: ITMT support for overclocked system (Steve Best) [2072886]
- cpufreq: intel_pstate: Fix active mode offline/online EPP handling (Steve Best) [2072886]
- cpufreq: intel_pstate: Add Ice Lake server to out-of-band IDs (Steve Best) [2072886]
- drivers/base/memory: clarify adding and removing of memory blocks (David Hildenbrand) [2077436]
- drivers/base/memory: determine and store zone for single-zone memory blocks (David Hildenbrand) [2077436]
- drivers/base/node: rename link_mem_sections() to register_memory_block_under_node() (David Hildenbrand) [2077436]
- drivers/base/node: consolidate node device subsystem initialization in node_dev_init() (David Hildenbrand) [2077436]
- powerpc/kernel: Add __init attribute to eligible functions (David Hildenbrand) [2077436]
- drivers/base/memory: add memory block to memory group after registration succeeded (David Hildenbrand) [2077436]
- af_key: add __GFP_ZERO flag for compose_sadb_supported in function pfkey_register (Xin Long) [2075183]
- proc/vmcore: fix vmcore_alloc_buf() kernel-doc comment (Baoquan He) [2051908]
- proc/vmcore: fix possible deadlock on concurrent mmap and read (Baoquan He) [2051908]
- proc/vmcore: don't fake reading zeroes on surprise vmcore_cb unregistration (Baoquan He) [2051908]
- enable DAMON configs (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for schemes statistics (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/reclaim: document statistics parameters (Chris von Recklinghausen) [2004230]
- mm/damon: hide kernel pointer from tracepoint event (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: hide kernel pointer from damon_va_three_regions() failure log (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: use pr_debug() for damon_va_three_regions() failure logging (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary variable (Chris von Recklinghausen) [2004230]
- mm/damon: move the implementation of damon_insert_region to damon.h (Chris von Recklinghausen) [2004230]
- mm/damon: add access checking for hugetlb pages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support all DAMOS stats (Chris von Recklinghausen) [2004230]
- mm/damon/reclaim: provide reclamation statistics (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account how many times quota limit has exceeded (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account scheme actions that successfully applied (Chris von Recklinghausen) [2004230]
- mm/damon: remove a mistakenly added comment for a future feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for kdamond_pid and (mk|rm)_contexts (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: mention tracepoint at the beginning (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: remove redundant information (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for scheme quotas and watermarks (Chris von Recklinghausen) [2004230]
- mm/damon: convert macro functions to static inline functions (Chris von Recklinghausen) [2004230]
- mm/damon: modify damon_rand() macro to static inline function (Chris von Recklinghausen) [2004230]
- mm/damon: move damon_rand() definition into damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: add the validity judgment of thresholds (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove swap_ranges() and replace it with swap() (Chris von Recklinghausen) [2004230]
- mm/damon: remove some unneeded function definitions in damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/core: use abs() instead of diff_of() (Chris von Recklinghausen) [2004230]
- mm/damon: add 'age' of region tracepoint support (Chris von Recklinghausen) [2004230]
- mm/damon: unified access_check function naming rules (Chris von Recklinghausen) [2004230]
- docs/vm: add vmalloced-kernel-stacks document (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix 'struct pid' leaks in 'dbgfs_target_ids_write()' (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: protect targets destructions with kdamond_lock (Chris von Recklinghausen) [2004230]
- selftests/damon: test debugfs file reads/writes with huge count (Chris von Recklinghausen) [2004230]
- selftests/damon: test DAMON enabling with empty target_ids case (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr-test: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove an unnecessary warning message (Chris von Recklinghausen) [2004230]
- mm/damon/core: remove unnecessary error messages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary error message (Chris von Recklinghausen) [2004230]
- mm/damon/core: use better timer mechanisms selection threshold (Chris von Recklinghausen) [2004230]
- mm/damon/core: fix fake load reports due to uninterruptible sleeps (Chris von Recklinghausen) [2004230]
- timers: implement usleep_idle_range() (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix missed use of damon_dbgfs_lock (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: use '__GFP_NOWARN' for user-specified size buffer allocation (Chris von Recklinghausen) [2004230]
- mm/damon: remove return value from before_terminate callback (Chris von Recklinghausen) [2004230]
- mm/damon: fix a few spelling mistakes in comments and a pr_debug message (Chris von Recklinghausen) [2004230]
- mm/damon: simplify stop mechanism (Chris von Recklinghausen) [2004230]
- include/linux/delay.h: replace kernel.h with the necessary inclusions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/pagemap: wordsmith page flags descriptions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: simplify the content (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix a wrong link (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix wrong example commands (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: add adaptive_targets list check before enable monitor_on (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary variable initialization (Chris von Recklinghausen) [2004230]
- Documentation/admin-guide/mm/damon: add a document for DAMON_RECLAIM (Chris von Recklinghausen) [2004230]
- mm/damon: introduce DAMON-based Reclamation (DAMON_RECLAIM) (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support watermarks (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: activate schemes based on a watermarks mechanism (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support prioritization weights (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr,paddr: support pageout prioritization (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: prioritize regions within the quotas (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support quotas of schemes (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement time quota (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: skip already charged targets and regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement size quota for schemes application speed control (Chris von Recklinghausen) [2004230]
- mm/damon/paddr: support the pageout scheme (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: constify static mm_walk_ops (Chris von Recklinghausen) [2004230]
- Docs/DAMON: document physical memory monitoring support (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support physical memory monitoring (Chris von Recklinghausen) [2004230]
- mm/damon: implement primitives for physical address space monitoring (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: separate commonly usable functions (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs-test: add a unit test case for 'init_regions' (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document 'init_regions' feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- docs/vm/damon: remove broken reference (Chris von Recklinghausen) [2004230]
- Documentation/vm: move user guides to admin-guide/mm/ (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: allow users to set initial monitoring target regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement statistics feature (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/core: implement DAMON-based Operation Schemes (DAMOS) (Chris von Recklinghausen) [2004230]
- mm/damon/core: account age of target regions (Chris von Recklinghausen) [2004230]
- mm/damon/core: nullify pointer ctx->kdamond with a NULL (Chris von Recklinghausen) [2004230]
- mm/damon: needn't hold kdamond_lock to print pid of kdamond (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary do_exit() from kdamond (Chris von Recklinghausen) [2004230]
- mm/damon/core: print kdamond start log in debug mode only (Chris von Recklinghausen) [2004230]
- mm/damon: grammar s/works/work/ (Chris von Recklinghausen) [2004230]
- drm/msm: Fix missing include files in msm_gem_shrinker.c (Chris von Recklinghausen) [2004230]
- NFSv4.2: Fix missing removal of SLAB_ACCOUNT on kmem_cache allocation (Waiman Long) [2013413]
- slab: remove __alloc_size attribute from __kmalloc_track_caller (Waiman Long) [2013413]
- mm: memcontrol: rename memcg_cache_id to memcg_kmem_id (Waiman Long) [2013413]
- mm: list_lru: rename list_lru_per_memcg to list_lru_memcg (Waiman Long) [2013413]
- mm: memcontrol: fix cannot alloc the maximum memcg ID (Waiman Long) [2013413]
- mm: memcontrol: reuse memory cgroup ID for kmem ID (Waiman Long) [2013413]
- mm: list_lru: replace linear array with xarray (Waiman Long) [2013413]
- mm: list_lru: rename memcg_drain_all_list_lrus to memcg_reparent_list_lrus (Waiman Long) [2013413]
- mm: list_lru: allocate list_lru_one only when needed (Waiman Long) [2013413]
- mm: memcontrol: move memcg_online_kmem() to mem_cgroup_css_online() (Waiman Long) [2013413]
- xarray: use kmem_cache_alloc_lru to allocate xa_node (Waiman Long) [2013413]
- mm: dcache: use kmem_cache_alloc_lru() to allocate dentry (Waiman Long) [2013413]
- fs: allocate inode by using alloc_inode_sb() (Waiman Long) [2013413]
- fs: introduce alloc_inode_sb() to allocate filesystems specific inode (Waiman Long) [2013413]
- mm: introduce kmem_cache_alloc_lru (Waiman Long) [2013413]
- mm: list_lru: transpose the array of per-node per-memcg lru lists (Waiman Long) [2013413]
- memcg: add per-memcg total kernel memory stat (Waiman Long) [2013413]
- memcg: add per-memcg vmalloc stat (Waiman Long) [2013413]
- mm: list_lru: only add memcg-aware lrus to the global lru list (Waiman Long) [2013413]
- mm: list_lru: fix the return value of list_lru_count_one() (Waiman Long) [2013413]
- mm: list_lru: remove holding lru lock (Waiman Long) [2013413]
- memcg, kmem: further deprecate kmem.limit_in_bytes (Waiman Long) [2013413]
- mm/list_lru.c: prefer struct_size over open coded arithmetic (Waiman Long) [2013413]
- slab: add __alloc_size attributes for better bounds checking (Waiman Long) [2013413]
- slab: clean up function prototypes (Waiman Long) [2013413]
- Compiler Attributes: add __alloc_size() for better bounds checking (Waiman Long) [2013413]
- Redhat: enable Kfence on production servers (Nico Pache) [2072662]
- kfence, x86: only define helpers if !MODULE (Nico Pache) [2072662]
- kfence: default to dynamic branch instead of static keys mode (Nico Pache) [2072662]
- kfence: test: try to avoid test_gfpzero trigger rcu_stall (Nico Pache) [2072662]
- kunit: fix UAF when run kfence test case test_gfpzero (Nico Pache) [2072662]
- kfence: alloc kfence_pool after system startup (Nico Pache) [2072662]
- kfence: allow re-enabling KFENCE after system startup (Nico Pache) [2072662]
- mm/kfence: remove unnecessary CONFIG_KFENCE option (Nico Pache) [2072662]
- kfence: make test case compatible with run time set sample interval (Nico Pache) [2072662]
- kfence: always use static branches to guard kfence_alloc() (Nico Pache) [2072662]
- kfence: shorten critical sections of alloc/free (Nico Pache) [2072662]
- kfence: test: use kunit_skip() to skip tests (Nico Pache) [2072662]
- kfence: limit currently covered allocations when pool nearly full (Nico Pache) [2072662]
- kfence: move saving stack trace of allocations into __kfence_alloc() (Nico Pache) [2072662]
- kfence: count unexpectedly skipped allocations (Nico Pache) [2072662]
- kfence: add function to mask address bits (Nico Pache) [2072662]
- cifs: verify that tcon is valid before dereference in cifs_kill_sb (Ronnie Sahlberg) [2048823]
- cifs: release cached dentries only if mount is complete (Ronnie Sahlberg) [2048823]
- cifs: we do not need a spinlock around the tree access during umount (Ronnie Sahlberg) [2048823]
- cifs: fix handlecache and multiuser (Ronnie Sahlberg) [2048823]
- cifs: fix workstation_name for multiuser mounts (Ronnie Sahlberg) [2048823]
- cifs: free ntlmsspblob allocated in negotiate (Ronnie Sahlberg) [2048823]
- cifs: fix ntlmssp auth when there is no key exchange (Ronnie Sahlberg) [2048823]
- cifs: send workstation name during ntlmssp session setup (Ronnie Sahlberg) [2048823]
- cifs: Fix crash on unload of cifs_arc4.ko (Ronnie Sahlberg) [2048823]
- Documentation, arch: Remove leftovers from CIFS_WEAK_PW_HASH (Ronnie Sahlberg) [2048823]
- cifs: fix the cifs_reconnect path for DFS (Ronnie Sahlberg) [2048823]
- cifs: sanitize multiple delimiters in prepath (Ronnie Sahlberg) [2048823]
- cifs: ignore resource_id while getting fscache super cookie (Ronnie Sahlberg) [2048823]
- cifs: avoid use of dstaddr as key for fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: add server conn_id to fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: wait for tcon resource_id before getting fscache super (Ronnie Sahlberg) [2048823]
- cifs: fix missed refcounting of ipc tcon (Ronnie Sahlberg) [2048823]
- cifs: update internal version number (Ronnie Sahlberg) [2048823]
- smb2: clarify rc initialization in smb2_reconnect (Ronnie Sahlberg) [2048823]
- cifs: populate server_hostname for extra channels (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should be set on new server (Ronnie Sahlberg) [2048823]
- cifs: introduce cifs_ses_mark_for_reconnect() helper (Ronnie Sahlberg) [2048823]
- cifs: protect srv_count with cifs_tcp_ses_lock (Ronnie Sahlberg) [2048823]
- cifs: move debug print out of spinlock (Ronnie Sahlberg) [2048823]
- cifs: do not duplicate fscache cookie for secondary channels (Ronnie Sahlberg) [2048823]
- cifs: connect individual channel servers to primary channel server (Ronnie Sahlberg) [2048823]
- cifs: protect session channel fields with chan_lock (Ronnie Sahlberg) [2048823]
- cifs: do not negotiate session if session already exists (Ronnie Sahlberg) [2048823]
- smb3: do not setup the fscache_super_cookie until fsinfo initialized (Ronnie Sahlberg) [2048823]
- cifs: fix potential use-after-free bugs (Ronnie Sahlberg) [2048823]
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB311_posix_mkdir (Ronnie Sahlberg) [2048823]
- cifs: release lock earlier in dequeue_mid error case (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_tcon (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_open (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_ioctl (Ronnie Sahlberg) [2048823]
- smb3: remove trivial dfs compile warning (Ronnie Sahlberg) [2048823]
- cifs: support nested dfs links over reconnect (Ronnie Sahlberg) [2048823]
- smb3: do not error on fsync when readonly (Ronnie Sahlberg) [2048823]
- cifs: for compound requests, use open handle if possible (Ronnie Sahlberg) [2048823]
- cifs: set a minimum of 120s for next dns resolution (Ronnie Sahlberg) [2048823]
- cifs: split out dfs code from cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: convert list_for_each to entry variant (Ronnie Sahlberg) [2048823]
- cifs: introduce new helper for cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: fix print of hdr_flags in dfscache_proc_show() (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should not share socket with future sessions (Ronnie Sahlberg) [2048823]
- smb3: add dynamic trace points for socket connection (Ronnie Sahlberg) [2048823]
- cifs: Move SMB2_Create definitions to the shared area (Ronnie Sahlberg) [2048823]
- cifs: Move more definitions into the shared area (Ronnie Sahlberg) [2048823]
- cifs: move NEGOTIATE_PROTOCOL definitions out into the common area (Ronnie Sahlberg) [2048823]
- cifs: Create a new shared file holding smb2 pdu definitions (Ronnie Sahlberg) [2048823]
- cifs: add mount parameter tcpnodelay (Ronnie Sahlberg) [2048823]
- cifs: To match file servers, make sure the server hostname matches (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect check for null pointer in header_assemble (Ronnie Sahlberg) [2048823]
- smb3: correct server pointer dereferencing check to be more consistent (Ronnie Sahlberg) [2048823]
- smb3: correct smb3 ACL security descriptor (Ronnie Sahlberg) [2048823]
- cifs: Clear modified attribute bit from inode flags (Ronnie Sahlberg) [2048823]
- cifs: Deal with some warnings from W=1 (Ronnie Sahlberg) [2048823]
- cifs: fix a sign extension bug (Ronnie Sahlberg) [2048823]
- cifs: Not to defer close on file when lock is set (Ronnie Sahlberg) [2048823]
- cifs: Fix soft lockup during fsstress (Ronnie Sahlberg) [2048823]
- cifs: Deferred close performance improvements (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect kernel doc comments (Ronnie Sahlberg) [2048823]
- cifs: remove pathname for file from SPDX header (Ronnie Sahlberg) [2048823]
- cifs: properly invalidate cached root handle when closing it (Ronnie Sahlberg) [2048823]
- cifs: move SMB FSCTL definitions to common code (Ronnie Sahlberg) [2048823]
- cifs: rename cifs_common to smbfs_common (Ronnie Sahlberg) [2048823]
- cifs: cifs_md4 convert to SPDX identifier (Ronnie Sahlberg) [2048823]
- cifs: create a MD4 module and switch cifs.ko to use it (Ronnie Sahlberg) [2048823]
- cifs: fork arc4 and create a separate module for it for cifs and other users (Ronnie Sahlberg) [2048823]
- cifs: remove support for NTLM and weaker authentication algorithms (Ronnie Sahlberg) [2048823]
- cifs: update FSCTL definitions (Ronnie Sahlberg) [2048823]
- cifs: Do not leak EDEADLK to dgetents64 for STATUS_USER_SESSION_DELETED (Ronnie Sahlberg) [2048823]
- cifs: enable fscache usage even for files opened as rw (Ronnie Sahlberg) [2048823]
- smb3: fix posix extensions mount option (Ronnie Sahlberg) [2048823]
- cifs: fix wrong release in sess_alloc_buffer() failed path (Ronnie Sahlberg) [2048823]
- CIFS: Fix a potencially linear read overflow (Ronnie Sahlberg) [2048823]

* Fri May 06 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-86.el9]
- configs: enable LOGITECH_FF (Benjamin Tissoires) [2070018]
- veth: Ensure eth header is in skb's linear part (Guillaume Nault) [2040238]
- virtchnl: Add support for new VLAN capabilities (Ivan Vecera) [2078776]
- virtchnl: Use the BIT() macro for capability/offload flags (Ivan Vecera) [2078776]
- virtchnl: Remove unused VIRTCHNL_VF_OFFLOAD_RSVD define (Ivan Vecera) [2078776]
- skbuff: introduce skb_pull_data (Ivan Vecera) [2078759]
- redhat/configs: Add CONFIG_PERF_EVENTS_AMD_UNCORE (Michael Petlan) [2069070]
- perf callchain: Fix compilation on powerpc with gcc11+ (Michael Petlan) [2069070]
- perf script: Check session->header.env.arch before using it (Michael Petlan) [2069070]
- perf build: Suppress 'rm dlfilter' build message (Michael Petlan) [2069070]
- libperf tests: Fix test_stat_cpu (Michael Petlan) [2069070]
- libperf test evsel: Fix build error on !x86 architectures (Michael Petlan) [2069070]
- perf report: Output non-zero offset for decompressed records (Michael Petlan) [2069070]
- perf build: Fix plugin static linking with libopencsd on ARM and ARM64 (Michael Petlan) [2069070]
- perf build: Add missing -lstdc++ when linking with libopencsd (Michael Petlan) [2069070]
- perf jevents: Free the sys_event_tables list after processing entries (Michael Petlan) [2069070]
- perf iostat: Fix Segmentation fault from NULL 'struct perf_counts_values *' (Michael Petlan) [2069070]
- perf iostat: Use system-wide mode if the target cpu_list is unspecified (Michael Petlan) [2069070]
- perf config: Refine error message to eliminate confusion (Michael Petlan) [2069070]
- perf doc: Fix typos all over the place (Michael Petlan) [2069070]
- perf arm: Fix off-by-one directory paths. (Michael Petlan) [2069070]
- perf vendor events powerpc: Fix spelling mistake "icach" -> "icache" (Michael Petlan) [2069070]
- perf tests: Fix flaky test 'Object code reading' (Michael Petlan) [2069070]
- perf test: Fix DWARF unwind for optimized builds. (Michael Petlan) [2069070]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Michael Petlan) [2069070]
- libperf evsel: Make use of FD robust. (Michael Petlan) [2069070]
- perf machine: Initialize srcline string member in add_location struct (Michael Petlan) [2069070]
- perf script: Fix ip display when type != attr->type (Michael Petlan) [2069070]
- perf annotate: Fix fused instr logic for assembly functions (Michael Petlan) [2069070]
- perf tools: Add an option to build without libbfd (Michael Petlan) [2069070]
- perf tools: Allow build-id with trailing zeros (Michael Petlan) [2069070]
- perf tools: Fix hybrid config terms list corruption (Michael Petlan) [2069070]
- perf tools: Factor out copy_config_terms() and free_config_terms() (Michael Petlan) [2069070]
- perf tools: Fix perf_event_attr__fprintf() missing/dupl. fields (Michael Petlan) [2069070]
- perf tools: Ignore Documentation dependency file (Michael Petlan) [2069070]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Michael Petlan) [2069070]
- perf beauty: Cover more flags in the  move_mount syscall argument beautifier (Michael Petlan) [2069070]
- perf report: Add support to print a textual representation of IBS raw sample data (Michael Petlan) [2069070]
- perf report: Add tools/arch/x86/include/asm/amd-ibs.h (Michael Petlan) [2069070]
- perf env: Add perf_env__cpuid, perf_env__{nr_}pmu_mappings (Michael Petlan) [2069070]
- perf symbol: Look for ImageBase in PE file to compute .text offset (Michael Petlan) [2069070]
- perf scripts python: Fix passing arguments to stackcollapse report (Michael Petlan) [2069070]
- perf test: Fix bpf test sample mismatch reporting (Michael Petlan) [2069070]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069070]
- perf tests: Add test for PMU aliases (Michael Petlan) [2069070]
- perf pmu: Add PMU alias support (Michael Petlan) [2069070]
- perf session: Report collisions in AUX records (Michael Petlan) [2069070]
- perf script python: Allow reporting the [un]throttle PERF_RECORD_ meta event (Michael Petlan) [2069070]
- perf build: Report failure for testing feature libopencsd (Michael Petlan) [2069070]
- perf cs-etm: Show a warning for an unknown magic number (Michael Petlan) [2069070]
- perf cs-etm: Print the decoder name (Michael Petlan) [2069070]
- perf cs-etm: Create ETE decoder (Michael Petlan) [2069070]
- perf cs-etm: Update OpenCSD decoder for ETE (Michael Petlan) [2069070]
- perf cs-etm: Fix typo (Michael Petlan) [2069070]
- perf cs-etm: Save TRCDEVARCH register (Michael Petlan) [2069070]
- perf cs-etm: Refactor out ETMv4 header saving (Michael Petlan) [2069070]
- perf cs-etm: Initialise architecture based on TRCIDR1 (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of decoder params. (Michael Petlan) [2069070]
- tools build: Fix feature detect clean for out of source builds (Michael Petlan) [2069070]
- perf evlist: Add evlist__for_each_entry_from() macro (Michael Petlan) [2069070]
- perf evsel: Handle precise_ip fallback in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move bpf_counter__install_pe() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move test_attr__open() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move ignore_missing_thread() to fallback code (Michael Petlan) [2069070]
- perf evsel: Separate rlimit increase from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature detection from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Add evsel__prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature disabling from evsel__open_cpu (Michael Petlan) [2069070]
- perf evsel: Save open flags in evsel in prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate open preparation from open itself (Michael Petlan) [2069070]
- perf evsel: Remove retry_sample_id goto label (Michael Petlan) [2069070]
- perf mmap: Add missing bitops.h header (Michael Petlan) [2069070]
- libperf cpumap: Take into advantage it is sorted to optimize perf_cpu_map__max() (Michael Petlan) [2069070]
- libsubcmd: add OPT_UINTEGER_OPTARG option type (Michael Petlan) [2069070]
- perf tools: Fix LLVM download hint link (Michael Petlan) [2069070]
- perf tools: Fix LLVM test failure when running in verbose mode (Michael Petlan) [2069070]
- perf tools: Refactor LLVM test warning for missing binary (Michael Petlan) [2069070]
- perf auxtrace arm: Support compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf auxtrace: Add compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf bpf: Fix memory leaks relating to BTF. (Michael Petlan) [2069070]
- perf data: Correct -h output (Michael Petlan) [2069070]
- perf header: Fix spelling mistake "cant'" -> "can't" (Michael Petlan) [2069070]
- perf dlfilters: Fix build on environments with a --sysroot gcc arg (Michael Petlan) [2069070]
- perf record: Fix wrong comm in system-wide mode with delay (Michael Petlan) [2069070]
- perf stat: Do not allow --for-each-cgroup without cpu (Michael Petlan) [2069070]
- perf bench evlist-open-close: Use PRIu64 with u64 to fix build on 32-bit architectures (Michael Petlan) [2069070]
- perf tests: Fix *probe_vfs_getname.sh test failures (Michael Petlan) [2069070]
- perf bench inject-buildid: Handle writen() errors (Michael Petlan) [2069070]
- perf unwind: Do not overwrite FEATURE_CHECK_LDFLAGS-libunwind-{x86,aarch64} (Michael Petlan) [2069070]
- perf config: Fix caching and memory leak in perf_home_perfconfig() (Michael Petlan) [2069070]
- perf tools: Fixup get_current_dir_name() compilation (Michael Petlan) [2069070]
- libperf tests: Fix verbose printing (Michael Petlan) [2069070]
- perf tools: Add missing newline at the end of header file (Michael Petlan) [2069070]
- perf tests dlfilter: Free desc and long_desc in check_filter_desc (Michael Petlan) [2069070]
- tools: Add sparse context/locking annotations in compiler-types.h (Michael Petlan) [2069070]
- perf test: Do not compare overheads in the zstd comp test (Michael Petlan) [2069070]
- perf tools: Enable on a list of CPUs for hybrid (Michael Petlan) [2069070]
- perf tools: Create hybrid flag in target (Michael Petlan) [2069070]
- libperf: Add perf_cpu_map__default_new() (Michael Petlan) [2069070]
- perf test: Make --skip work on shell tests (Michael Petlan) [2069070]
- perf tests: Add dlfilter test (Michael Petlan) [2069070]
- perf build: Move perf_dlfilters.h in the source tree (Michael Petlan) [2069070]
- perf dlfilter: Amend documentation wrt library dependencies (Michael Petlan) [2069070]
- perf script: Fix --list-dlfilters documentation (Michael Petlan) [2069070]
- perf script: Fix unnecessary machine_resolve() (Michael Petlan) [2069070]
- perf script: Fix documented const'ness of perf_dlfilter_fns (Michael Petlan) [2069070]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events: Update metrics for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for CascadeLake Server (Michael Petlan) [2069070]
- perf test: Add pmu-events sys event support (Michael Petlan) [2069070]
- perf jevents: Print SoC name per system event table (Michael Petlan) [2069070]
- perf pmu: Make pmu_add_sys_aliases() public (Michael Petlan) [2069070]
- perf test: Add more pmu-events uncore aliases (Michael Petlan) [2069070]
- perf test: Re-add pmu-event uncore PMU alias test (Michael Petlan) [2069070]
- perf pmu: Check .is_uncore field in pmu_add_cpu_aliases_map() (Michael Petlan) [2069070]
- perf test: Test pmu-events core aliases separately (Michael Petlan) [2069070]
- perf test: Factor out pmu-events alias comparison (Michael Petlan) [2069070]
- perf test: Declare pmu-events test events separately (Michael Petlan) [2069070]
- perf jevents: Relocate test events to cpu folder (Michael Petlan) [2069070]
- perf test: Factor out pmu-events event comparison (Michael Petlan) [2069070]
- perf jevents: Make build dependency on test JSONs (Michael Petlan) [2069070]
- perf bench: Add benchmark for evlist open/close operations (Michael Petlan) [2069070]
- perf docs: Fix accidental em-dashes (Michael Petlan) [2069070]
- perf env: Track kernel 64-bit mode in environment (Michael Petlan) [2069070]
- tools: Remove feature-sync-compare-and-swap feature detection (Michael Petlan) [2069070]
- perf: Cleanup for HAVE_SYNC_COMPARE_AND_SWAP_SUPPORT (Michael Petlan) [2069070]
- perf auxtrace: Remove auxtrace_mmap__read_snapshot_head() (Michael Petlan) [2069070]
- perf auxtrace: Drop legacy __sync functions (Michael Petlan) [2069070]
- perf auxtrace: Use WRITE_ONCE() for updating aux_tail (Michael Petlan) [2069070]
- perf script python: Fix unintended underline (Michael Petlan) [2069070]
- perf cs-etm: Add warnings for missing DSOs (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Icelake Server (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --pi parameter (Michael Petlan) [2069070]
- perf bench futex, requeue: Robustify futex_wait() handling (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --broadcast option (Michael Petlan) [2069070]
- perf bench futex: Add --mlockall parameter (Michael Petlan) [2069070]
- perf bench futex: Remove bogus backslash from comment (Michael Petlan) [2069070]
- perf bench futex: Group test parameters cleanup (Michael Petlan) [2069070]
- perf cs-etm: Improve Coresight zero timestamp warning (Michael Petlan) [2069070]
- perf tools: Add flag for tracking warnings of missing DSOs (Michael Petlan) [2069070]
- perf annotate: Add disassembly warnings for annotate --stdio (Michael Petlan) [2069070]
- perf annotate: Re-add annotate_warned functionality (Michael Petlan) [2069070]
- perf tools: Add WARN_ONCE equivalent for UI warnings (Michael Petlan) [2069070]
- perf tools: Add pipe_test.sh to verify pipe operations (Michael Petlan) [2069070]
- perf inject: Fix output from a file to a pipe (Michael Petlan) [2069070]
- perf inject: Fix output from a pipe to a file (Michael Petlan) [2069070]
- perf tools: Pass a fd to perf_file_header__read_pipe() (Michael Petlan) [2069070]
- perf tools: Remove repipe argument from perf_session__new() (Michael Petlan) [2069070]
- perf vendor events intel: Add basic metrics for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Tigerlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Tigerlake (Michael Petlan) [2069070]
- perf annotate: Add error log in symbol__annotate() (Michael Petlan) [2069070]
- perf env: Normalize aarch64.* and arm64.* to arm64 in normalize_arch() (Michael Petlan) [2069070]
- perf beauty: Reuse the generic arch errno switch (Michael Petlan) [2069070]
- perf doc: Reorganize ARTICLES variables. (Michael Petlan) [2069070]
- perf doc: Remove howto-index.sh related references. (Michael Petlan) [2069070]
- perf doc: Remove cmd-list.perl references (Michael Petlan) [2069070]
- perf doc: Add info pages to all target. (Michael Petlan) [2069070]
- perf doc: Remove references to user-manual (Michael Petlan) [2069070]
- perf doc: Fix doc.dep (Michael Petlan) [2069070]
- perf doc: Fix perfman.info build (Michael Petlan) [2069070]
- perf cs-etm: Pass unformatted flag to decoder (Michael Petlan) [2069070]
- perf cs-etm: Use existing decoder instead of resetting it (Michael Petlan) [2069070]
- perf cs-etm: Suppress printing when resetting decoder (Michael Petlan) [2069070]
- perf cs-etm: Only setup queues when they are modified (Michael Petlan) [2069070]
- perf cs-etm: Split setup and timestamp search functions (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of kernel start address (Michael Petlan) [2069070]
- perf trace: Update cmd string table to decode sys_bpf first arg (Michael Petlan) [2069070]
- perf/x86/msr: Add Sapphire Rapids CPU support (Michael Petlan) [2069070]
- perf/core: fix userpage->time_enabled of inactive events (Michael Petlan) [2069070]
- perf/x86/intel: Update event constraints for ICX (Michael Petlan) [2069070]
- perf/x86: Reset destroy callback on event init failure (Michael Petlan) [2069070]
- events: Reuse value read using READ_ONCE instead of re-reading it (Michael Petlan) [2069070]
- perf/x86/amd/ibs: Add bitfield definitions in new <asm/amd-ibs.h> header (Michael Petlan) [2069070]
- perf/amd/uncore: Allow the driver to be built as a module (Michael Petlan) [2069070]
- perf/amd/uncore: Clean up header use, use <linux/ include paths instead of <asm/ (Michael Petlan) [2069070]
- perf/amd/uncore: Simplify code, use free_percpu()'s built-in check for NULL (Michael Petlan) [2069070]
- perf/x86: Remove unused assignment to pointer 'e' (Michael Petlan) [2069070]
- perf/x86/intel/uncore: Fix IIO cleanup mapping procedure for SNR/ICX (Michael Petlan) [2069070]
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- cifs: prevent bad output lengths in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- ping: remove pr_err from ping_lookup (Xin Long) [2054023]
- ping: fix the dif and sdif check in ping_lookup (Xin Long) [2054023]
- ping: fix the sk_bound_dev_if match in ping_lookup (Xin Long) [2054023]
- redhat: configs: add CONFIG_INTEL_IDXD_COMPAT (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: restore traffic class defaults after wq reset (Jerry Snitselaar) [2046470]
- dmaengine: idxd: deprecate token sysfs attributes for read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: change bandwidth token to read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: fix wq settings post wq disable (Jerry Snitselaar) [2040046]
- dmaengine: idxd: change MSIX allocation based on per wq activation (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix descriptor flushing locking (Jerry Snitselaar) [2040496]
- dmaengine: idxd: embed irq_entry in idxd_wq struct (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix missed completion on abort path (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix calling wq quiesce inside spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add knob for enqcmds retries (Jerry Snitselaar) [2040048]
- dmaengine: idxd: set defaults for wq configs (Jerry Snitselaar) [2040048]
- dmaengine: idxd: handle interrupt handle revoked event (Jerry Snitselaar) [2040052]
- dmaengine: idxd: handle invalid interrupt handle descriptors (Jerry Snitselaar) [2040052]
- dmaengine: idxd: create locked version of idxd_quiesce() call (Jerry Snitselaar) [2040052]
- dmaengine: idxd: add helper for per interrupt handle drain (Jerry Snitselaar) [2040052]
- dmaengine: idxd: move interrupt handle assignment (Jerry Snitselaar) [2040052]
- dmaengine: idxd: int handle management refactoring (Jerry Snitselaar) [2040052]
- dmaengine: idxd: rework descriptor free path on failure (Jerry Snitselaar) [2040052]
- dmaengine: idxd: fix resource leak on dmaengine driver disable (Jerry Snitselaar) [2040041]
- dmaengine: idxd: cleanup completion record allocation (Jerry Snitselaar) [2040041]
- dmaengine: idxd: reconfig device after device reset command (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add halt interrupt support (Jerry Snitselaar) [2040048]
- dmaengine: idxd: Use list_move_tail instead of list_del/list_add_tail (Jerry Snitselaar) [2072168]
- dmanegine: idxd: fix resource free ordering on driver removal (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove kernel wq type set when load configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: remove gen cap field per spec 1.2 update (Jerry Snitselaar) [2040041]
- dmaengine: idxd: check GENCAP config support for gencfg register (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move out percpu_ref_exit() to ensure it's outside submission (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for dev_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for cmd_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix setting up priv mode for dwq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: set descriptor allocation size to threshold for swq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make submit failure path consistent on desc freeing (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt flag for completion list spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make I/O interrupt handler one shot (Jerry Snitselaar) [2040041]
- dmaengine: idxd: clear block on fault flag when clear wq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add capability check for 'block on fault' attribute (Jerry Snitselaar) [2040041]
- dmaengine: idxd: Remove unused status variable in irq_process_work_list() (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Fix a possible NULL pointer dereference (Jerry Snitselaar) [2072168]
- dmaengine: idxd: fix abort status check (Jerry Snitselaar) [2040041]
- dmanegine: idxd: add software command status (Jerry Snitselaar) [2040048]
- dmaengine: idxd: rotate portal address for better performance (Jerry Snitselaar) [2040048]
- dmaengine: idxd: fix wq slot allocation index check (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix uninit var for alt_drv (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Set defaults for GRPCFG traffic class (Jerry Snitselaar) [2040048]
- dmaengine: idxd: remove fault processing code (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move dsa_drv support to compatible mode (Jerry Snitselaar) [1971962]
- dmaengine: dsa: move dsa_bus_type out of idxd driver to standalone (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create user driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create dmaengine driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create idxd_device sub-driver (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add type to driver in order to allow device matching (Jerry Snitselaar) [1971962]
- dmanegine: idxd: open code the dsa_drv registration (Jerry Snitselaar) [1971962]
- dmaengine: idxd: idxd: move remove() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move probe() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: fix bus_probe() and bus_remove() for dsa_bus (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove iax_bus_type prototype (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove bus shutdown (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_disable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_enable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove IDXD_DEV_CONF_READY (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add 'struct idxd_dev' as wrapper for conf_dev (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver name (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver register helper (Jerry Snitselaar) [1971962]
- dmaengine: idxd: assign MSIX vectors to each WQ rather than roundrobin (Jerry Snitselaar) [2072168]
- dmaengine: idxd: add missing percpu ref put on failure (Jerry Snitselaar) [2072168]
- dmaengine: idxd: have command status always set (Jerry Snitselaar) [1973884]
- dmanegine: idxd: cleanup all device related bits after disabling device (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Simplify code and axe the use of a deprecated API (Jerry Snitselaar) [2072168]
- x86/fpu/xstate: Consolidate size calculations (Jerry Snitselaar) [2004573]
- x86/fpu/xstate: Handle supervisor states in XSTATE permissions (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Handle compacted offsets correctly with supervisor states (Jerry Snitselaar) [2004573]
- x86/fpu: Cache xfeature flags from CPUID (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Initialize offset/size cache early (Jerry Snitselaar) [2004573]
- x86/fpu: Remove unused supervisor only offsets (Jerry Snitselaar) [2004573]
- Documentation/x86: Update documentation for SVA (Shared Virtual Addressing) (Jerry Snitselaar) [2004573]
- tools/objtool: Check for use of the ENQCMD instruction in the kernel (Jerry Snitselaar) [2004573]
- x86/cpufeatures: Re-enable ENQCMD (Jerry Snitselaar) [2004573]
- x86/traps: Demand-populate PASID MSR via #GP (Jerry Snitselaar) [2004573]
- sched: Define and initialize a flag to identify valid PASID in the task (Jerry Snitselaar) [2004573]
- x86/fpu: Clear PASID when copying fpstate (Jerry Snitselaar) [2004573]
- iommu/sva: Assign a PASID to mm on PASID allocation and free it on mm exit (Jerry Snitselaar) [2004573]
- kernel/fork: Initialize mm's PASID (Jerry Snitselaar) [2004573]
- iommu/ioasid: Introduce a helper to check for valid PASIDs (Jerry Snitselaar) [2004573]
- mm: Change CONFIG option for mm->pasid field (Jerry Snitselaar) [2004573]
- iommu/sva: Rename CONFIG_IOMMU_SVA_LIB to CONFIG_IOMMU_SVA (Jerry Snitselaar) [2004573]
- stddef: Introduce DECLARE_FLEX_ARRAY() helper (Josef Oskera) [2069567]
- iommu/vt-d: Use correctly sized arguments for bit field (Jerry Snitselaar) [2068207]
- redhat: configs: Enable CONFIG_INTEL_IOMMU_DEBUGFS (Jerry Snitselaar) [2068207]

* Wed May 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-85.el9]
- net: mana: Remove unnecessary check of cqe_type in mana_process_rx_cqe() (Mohammed Gamal) [2064198]
- net: mana: Add handling of CQE_RX_TRUNCATED (Mohammed Gamal) [2064198]
- ipv6: make ip6_rt_gc_expire an atomic_t (Hangbin Liu) [2077372]
- ipv6: fix panic when forwarding a pkt with no in6 dev (Hangbin Liu) [2077372]
- ipv6: Fix stats accounting in ip6_pkt_drop (Hangbin Liu) [2077372]
- net: ipv6: ensure we call ipv6_mc_down() at most once (Hangbin Liu) [2077372]
- ipv6: fix data-race in fib6_info_hw_flags_set / fib6_purge_rt (Hangbin Liu) [2077372]
- ipv6: per-netns exclusive flowlabel checks (Hangbin Liu) [2077372]
- ipv6: mcast: use rcu-safe version of ipv6_get_lladdr() (Hangbin Liu) [2077372]
- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table() on failure path (Hangbin Liu) [2077372]
- ipv6: annotate accesses to fn->fn_sernum (Hangbin Liu) [2077372]
- redhat/configs: enable CONFIG_RANDOMIZE_KSTACK_OFFSET_DEFAULT (Joel Savitz) [2026319]
- net: annotate accesses to dev->gso_max_segs (Ivan Vecera) [2073465]
- net: annotate accesses to dev->gso_max_size (Ivan Vecera) [2073465]
- PCI/VGA: Move vgaarb to drivers/pci (Karol Herbst) [2072020]
- vgaarb: don't pass a cookie to vga_client_register (Karol Herbst) [2072020]
- vgaarb: remove the unused irq_set_state argument to vga_client_register (Karol Herbst) [2072020]
- vgaarb: provide a vga_client_unregister wrapper (Karol Herbst) [2072020]
- vgaarb: cleanup vgaarb.h (Karol Herbst) [2072020]
- vgaarb: move the kerneldoc for vga_set_legacy_decoding to vgaarb.c (Karol Herbst) [2072020]
- vgaarb: remove vga_conflicts (Karol Herbst) [2072020]
- vgaarb: remove VGA_DEFAULT_DEVICE (Karol Herbst) [2072020]
- agp/intel-gtt: reduce intel-gtt dependencies more (Karol Herbst) [2072020]
- agp/intel-gtt: Replace kernel.h with the necessary inclusions (Karol Herbst) [2072020]
- component: Add common helper for compare/release functions (Karol Herbst) [2072020]
- lib/string_helpers: Consolidate string helpers implementation (Karol Herbst) [2072020]
- include/linux/string_helpers.h: add linux/string.h for strlen() (Karol Herbst) [2072020]
- linux/container_of.h: switch to static_assert (Karol Herbst) [2072020]
- kernel.h: split out container_of() and typeof_member() macros (Karol Herbst) [2072020]
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs > 64 (Karol Herbst) [2072020]
- x86/kvm: Don't waste memory if kvmclock is disabled (Karol Herbst) [2072020]
- treewide: Replace the use of mem_encrypt_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_es_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sme: Replace occurrences of sme_active() with cc_platform_has() (Karol Herbst) [2072020]
- powerpc/pseries/svm: Add a powerpc version of cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Add an x86 version of cc_platform_has() (Karol Herbst) [2072020]
- arch/cc: Introduce a function to check for confidential computing features (Karol Herbst) [2072020]
- x86/ioremap: Selectively build arch override encryption functions (Karol Herbst) [2072020]
- lib: devres: Add managed arch_io_reserve_memtype_wc() (Karol Herbst) [2072020]
- lib: devres: Add managed arch_phys_wc_add() (Karol Herbst) [2072020]
- mm/vmscan: add sync_shrinkers function v3 (Karol Herbst) [2072020]
- kernel/locking: Use a pointer in ww_mutex_trylock(). (Karol Herbst) [2072020]
- locking/ww-mutex: Fix uninitialized use of ret in test_aa() (Karol Herbst) [2072020]
- kernel/locking: Add context to ww_mutex_trylock() (Karol Herbst) [2072020]
- samples/bpf: Fix build error due to -isystem removal (Karol Herbst) [2072020]
- isystem: delete global -isystem compile option (Karol Herbst) [2072020]
- uapi/linux/stddef.h: Add include guards (Karol Herbst) [2072020]
- stddef: Introduce struct_group() helper macro (Karol Herbst) [2072020]
- isystem: trim/fixup stdarg.h and other headers (Karol Herbst) [2072020]
- ACPI: tools: fix compilation error (Karol Herbst) [2072020]
- isystem: ship and use stdarg.h (Karol Herbst) [2072020]
- locking/lockdep: Provide lockdep_assert{,_once}() helpers (Karol Herbst) [2072020]

* Tue May 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-84.el9]
- sctp: use the correct skb for security_sctp_assoc_request (Ondrej Mosnacek) [2078856]
- security: implement sctp_assoc_established hook in selinux (Ondrej Mosnacek) [2078856]
- security: add sctp_assoc_established hook (Ondrej Mosnacek) [2078856]
- security: call security_sctp_assoc_request in sctp_sf_do_5_1D_ce (Ondrej Mosnacek) [2078856]
- security: pass asoc to sctp_assoc_request and sctp_sk_clone (Ondrej Mosnacek) [2078856]
- string.h: Introduce memset_startat() for wiping trailing members and padding (Íñigo Huguet) [2077839]
- string.h: Introduce memset_after() for wiping trailing members/padding (Íñigo Huguet) [2077839]
- net_tstamp: define new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- net_tstamp: add new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- bnx2x: truncate value to original sizing (Manish Chopra) [2040283]
- bnx2x: use correct format characters (Manish Chopra) [2040283]
- bnx2x: fix built-in kernel driver load failure (Manish Chopra) [2040283]
- bnx2x: fix driver load from initrd (Manish Chopra) [2040283]
- bnx2x: Replace one-element array with flexible-array member (Manish Chopra) [2040283]
- bnx2x: Remove useless DMA-32 fallback configuration (Manish Chopra) [2040283]
- bnx2x: Invalidate fastpath HSI version for VFs (Manish Chopra) [2040283]
- bnx2x: Utilize firmware 7.13.21.0 (Manish Chopra) [2040283]
- bnx2x: constify static inline stub for dev_addr (Manish Chopra) [2040283]
- net: bnx2x: fix variable dereferenced before check (Manish Chopra) [2040283]
- ethernet: bnx2x: use eth_hw_addr_set() (Manish Chopra) [2040283]
- cacheflush.h: Add forward declaration for struct folio (Aristeu Rozanski) [2019485]
- mm/swap: fix confusing comment in folio_mark_accessed (Aristeu Rozanski) [2019485]
- mm: page->mapping folio->mapping should have the same offset (Aristeu Rozanski) [2019485]
- mm: delete unsafe BUG from page_cache_add_speculative() (Aristeu Rozanski) [2019485]
- mm: Add functions to zero portions of a folio (Aristeu Rozanski) [2019485]
- fs: Rename AS_THP_SUPPORT and mapping_thp_support (Aristeu Rozanski) [2019485]
- fs: Remove FS_THP_SUPPORT (Aristeu Rozanski) [2019485]
- mm: Remove folio_test_single (Aristeu Rozanski) [2019485]
- mm: Rename folio_test_multi to folio_test_large (Aristeu Rozanski) [2019485]
- Add linux/cacheflush.h (Aristeu Rozanski) [2019485]
- folio: Add a function to get the host inode for a folio (Aristeu Rozanski) [2019485]
- folio: Add a function to change the private data attached to a folio (Aristeu Rozanski) [2019485]
- mm: fix mismerge of folio page flag manipulators (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_write_one (Aristeu Rozanski) [2019485]
- mm/filemap: Add FGP_STABLE (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_get_folio (Aristeu Rozanski) [2019485]
- mm/filemap: Convert mapping_get_entry to return a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_add_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_alloc_folio (Aristeu Rozanski) [2019485]
- mm/page_alloc: Add folio allocation functions (Aristeu Rozanski) [2019485]
- mm/lru: Add folio_add_lru() (Aristeu Rozanski) [2019485]
- mm/lru: Convert __pagevec_lru_add_fn to take a folio (Aristeu Rozanski) [2019485]
- mm: Add folio_evictable() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_refault() to take a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add readahead_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_mkwrite_check_truncate() (Aristeu Rozanski) [2019485]
- mm/filemap: Add i_blocks_per_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_redirty_for_writepage() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_redirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_clear_dirty_for_io() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_cancel_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_cleaned() (Aristeu Rozanski) [2019485]
- mm/writeback: Add filemap_dirty_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Convert tracing writeback_page_template to folios (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_start_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Change __wb_writeout_inc() to __wb_writeout_add() (Aristeu Rozanski) [2019485]
- flex_proportions: Allow N events instead of 1 (Aristeu Rozanski) [2019485]
- mm/writeback: Rename __add_wb_stat() to wb_stat_mod() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_copy() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_flags() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_mapping() (Aristeu Rozanski) [2019485]
- mm/rmap: Add folio_mkclean() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_mark_accessed() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_activate() (Aristeu Rozanski) [2019485]
- mm: Add folio_young and folio_idle (Aristeu Rozanski) [2019485]
- mm: Add arch_make_folio_accessible() (Aristeu Rozanski) [2019485]
- mm: Add kmap_local_folio() (Aristeu Rozanski) [2019485]
- mm: Add flush_dcache_folio() (Aristeu Rozanski) [2019485]
- mm: Add folio_raw_mapping() (Aristeu Rozanski) [2019485]
- mm: Add folio_pfn() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_activation to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_relock_irq() and folio_lruvec_relock_irqsave() (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_lock() and similar functions (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_move_account() to use a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg_lock() and folio_memcg_unlock() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_track_foreign_dirty_slowpath() to folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_migrate() to take folios (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_uncharge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert uncharge_page() to uncharge_folio() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert commit_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg() and related functions (Aristeu Rozanski) [2019485]
- mm/memcg: Convert memcg_check_events to take a node ID (Aristeu Rozanski) [2019485]
- mm/memcg: Remove soft_limit_tree_node() (Aristeu Rozanski) [2019485]
- mm/memcg: Use the node id in mem_cgroup_update_tree() (Aristeu Rozanski) [2019485]
- mm/memcg: Remove 'page' parameter to mem_cgroup_charge_statistics() (Aristeu Rozanski) [2019485]
- mm: Add folio_nid() (Aristeu Rozanski) [2019485]
- mm: Add folio_mapped() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio private_2 functions (Aristeu Rozanski) [2019485]
- mm/filemap: Convert page wait queues to be folios (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wake_bit() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_bit() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_stable() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_writeback() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_rotate_reclaimable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_or_retry() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_locked() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_async() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock_killable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_unlock() (Aristeu Rozanski) [2019485]
- mm/util: Add folio_mapping() and folio_file_mapping() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_pos() and folio_file_pos() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_next_index() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_index(), folio_file_page() and folio_contains() (Aristeu Rozanski) [2019485]
- mm: Handle per-folio private data (Aristeu Rozanski) [2019485]
- mm/lru: Add folio LRU functions (Aristeu Rozanski) [2019485]
- mm: Add folio flag manipulation functions (Aristeu Rozanski) [2019485]
- mm: Add folio_try_get_rcu() (Aristeu Rozanski) [2019485]
- mm: Add folio_get() (Aristeu Rozanski) [2019485]
- mm: Add folio_put() (Aristeu Rozanski) [2019485]
- mm: Add folio reference count functions (Aristeu Rozanski) [2019485]
- mm/debug: Add VM_BUG_ON_FOLIO() and VM_WARN_ON_ONCE_FOLIO() (Aristeu Rozanski) [2019485]
- mm/vmstat: Add functions to account folio statistics (Aristeu Rozanski) [2019485]
- mm: Add folio_pgdat(), folio_zone() and folio_zonenum() (Aristeu Rozanski) [2019485]
- mm: Introduce struct folio (Aristeu Rozanski) [2019485]
- mm: Convert get_page_unless_zero() to return bool (Aristeu Rozanski) [2019485]
- scripts: check_extable: fix typo in user error message (Aristeu Rozanski) [2019485]
- PCI: vmd: Prevent recursive locking on interrupt allocation (Myron Stowe) [2066898]
- PCI: Mark all AMD Navi10 and Navi14 GPU ATS as broken (Myron Stowe) [2066898]
- PCI: mvebu: Fix device enumeration regression (Myron Stowe) [2066898]
- PCI: kirin: Add dev struct for of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: j721e: Initialize pcie->cdns_pcie before using it (Myron Stowe) [2066898]
- PCI/sysfs: Find shadow ROM before static attribute initialization (Myron Stowe) [2066898]
- x86/gpu: Reserve stolen memory for first integrated Intel GPU (Myron Stowe) [2066898]
- PCI: spear13xx: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: hisi: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: xilinx-cpm: Rename xilinx_cpm_pcie_port to xilinx_cpm_pcie (Myron Stowe) [2066898]
- PCI: xilinx: Rename xilinx_pcie_port to xilinx_pcie (Myron Stowe) [2066898]
- PCI: xgene: Rename xgene_pcie_port to xgene_pcie (Myron Stowe) [2066898]
- PCI: uniphier: Rename uniphier_pcie_priv to uniphier_pcie (Myron Stowe) [2066898]
- PCI: tegra194: Rename tegra_pcie_dw to tegra194_pcie (Myron Stowe) [2066898]
- PCI: rcar-gen2: Rename rcar_pci_priv to rcar_pci (Myron Stowe) [2066898]
- PCI: microchip: Rename mc_port to mc_pcie (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Rename mtk_pcie_port to mtk_gen3_pcie (Myron Stowe) [2066898]
- PCI: ls-gen4: Rename ls_pcie_g4 to ls_g4_pcie (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_pltfm_ to iproc_pltfm_pcie_ (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_bcma_ to iproc_bcma_pcie_ (Myron Stowe) [2066898]
- PCI: intel-gw: Rename intel_pcie_port to intel_pcie (Myron Stowe) [2066898]
- PCI: j721e: Drop redundant struct device * (Myron Stowe) [2066898]
- PCI: j721e: Drop pointless of_device_get_match_data() cast (Myron Stowe) [2066898]
- PCI: kirin: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: keystone: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: dra7xx: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: designware-plat: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: cadence: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: artpec6: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: altera: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: xgene: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: hv: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: keystone: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: cpqphp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/PME: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/DPC: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: pciehp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: vmd: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/ERR: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: rockchip-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: rcar-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: altera: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mvebu: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: aardvark: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: kirin: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: histb: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: exynos: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mediatek: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: iproc: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: thunder: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Use PCI_SET_ERROR_RESPONSE() for disconnected devices (Myron Stowe) [2066898]
- PCI: Set error response data when config read fails (Myron Stowe) [2066898]
- PCI: Add PCI_ERROR_RESPONSE and related definitions (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Terminate statement with semicolon (Myron Stowe) [2066898]
- PCI: Correct misspelled words (Myron Stowe) [2066898]
- PCI: Change capability register offsets to hex (Myron Stowe) [2066898]
- PCI: Sort Intel Device IDs by value (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Set PCI_STATUS_CAP_LIST for PCIe device (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Correctly set PCIe capabilities (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Fix definitions of reserved bits (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Properly mark reserved PCIe bits in PCI config space (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Make expansion ROM Base Address register read-only (Myron Stowe) [2066898]
- PCI: xilinx-nwl: Simplify code and fix a memory leak (Myron Stowe) [2066898]
- PCI: xgene: Fix IB window setup (Myron Stowe) [2066898]
- PCI: xgene-msi: Use bitmap_zalloc() when applicable (Myron Stowe) [2066898]
- PCI: vmd: Add DID 8086:A77F for all Intel Raptor Lake SKU's (Myron Stowe) [2066898]
- PCI: vmd: Honor ACPI _OSC on PCIe features (Myron Stowe) [2066898]
- PCI: vmd: Clean up domain before enumeration (Myron Stowe) [2066898]
- PCI: qcom-ep: Constify static dw_pcie_ep_ops (Myron Stowe) [2066898]
- PCI: qcom: Use __be16 type to store return value from cpu_to_be16() (Myron Stowe) [2066898]
- PCI: mvebu: Add support for compiling driver as module (Myron Stowe) [2066898]
- bus: mvebu-mbus: Export symbols for public API window functions (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for DEVCAP2, DEVCTL2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_RTSTA on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_DEVCTL on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix configuring secondary bus of PCIe Root Port via emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2066898]
- PCI: mvebu: Setup PCIe controller to Root Complex mode (Myron Stowe) [2066898]
- PCI: mvebu: Propagate errors when updating PCI_IO_BASE and PCI_MEM_BASE registers (Myron Stowe) [2066898]
- PCI: mvebu: Do not modify PCI IO type bits in conf_write (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Disallow mapping interrupts on emulated bridges (Myron Stowe) [2066898]
- PCI: mvebu: Handle invalid size of read config request (Myron Stowe) [2066898]
- PCI: mvebu: Check that PCI bridge specified in DT has function number zero (Myron Stowe) [2066898]
- PCI: mvebu: Check for errors from pci_bridge_emul_init() call (Myron Stowe) [2066898]
- PCI: mvebu: Check for valid ports (Myron Stowe) [2066898]
- arm: ioremap: Remove unused ARM-specific function pci_ioremap_io() (Myron Stowe) [2066898]
- arm: ioremap: Replace pci_ioremap_io() usage by pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mvebu: Remove custom mvebu_pci_host_probe() function (Myron Stowe) [2066898]
- PCI: mvebu: Replace pci_ioremap_io() usage by devm_pci_remap_iospace() (Myron Stowe) [2066898]
- arm: ioremap: Implement standard PCI function pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mt7621: Allow COMPILE_TEST for all arches (Myron Stowe) [2066898]
- PCI: Let pcibios_root_bridge_prepare() access bridge->windows (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Disable DVFSRC voltage request (Myron Stowe) [2066898]
- PCI: mediatek: Assert PERST# for 100ms for power and clock to stabilize (Myron Stowe) [2066898]
-     PCI: keystone: Use phandle argument from "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" (Myron Stowe) [2066898]
- dt-bindings: PCI: ti,am65: Fix "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" to take argument (Myron Stowe) [2066898]
- PCI: endpoint: Return -EINVAL when interrupts num is smaller than 1 (Myron Stowe) [2066898]
- PCI: layerscape: Change to use the DWC common link-up check function (Myron Stowe) [2066898]
- PCI: imx: Add the imx8mm pcie support (Myron Stowe) [2066898]
- PCI: qcom-ep: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2066898]
- PCI: dwc: Do not remap invalid res (Myron Stowe) [2066898]
- PCI: brcmstb: Do not turn off WOL regulators on suspend (Myron Stowe) [2066898]
- PCI: brcmstb: Add control of subdevice voltage regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Add mechanism to turn on subdev regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Split brcm_pcie_setup() into two funcs (Myron Stowe) [2066898]
- dt-bindings: PCI: Add bindings for Brcmstb EP voltage regulators (Myron Stowe) [2066898]
- dt-bindings: PCI: Correct brcmstb interrupts, interrupt-map. (Myron Stowe) [2066898]
- PCI: brcmstb: Fix function return value handling (Myron Stowe) [2066898]
- PCI: brcmstb: Do not use __GENMASK (Myron Stowe) [2066898]
- PCI: brcmstb: Declare 'used' as bitmap, not unsigned long (Myron Stowe) [2066898]
- PCI: aardvark: Disable common PHY when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable link training when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Assert PERST# when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Fix memory leak in driver unbind (Myron Stowe) [2066898]
- PCI: aardvark: Mask all interrupts when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable bus mastering when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Comment actions in driver remove method (Myron Stowe) [2066898]
- PCI: aardvark: Clear all MSIs at setup (Myron Stowe) [2066898]
- PCI: aardvark: Add support for DEVCAP2, DEVCTL2, LNKCAP2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add definitions for missing capabilities registers (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add description for class_revision field (Myron Stowe) [2066898]
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9125 SATA controller (Myron Stowe) [2066898]
- PCI/switchtec: Declare local state_names[] as static (Myron Stowe) [2066898]
- PCI/switchtec: Add Gen4 automotive device IDs (Myron Stowe) [2066898]
- PCI: Work around Intel I210 ROM BAR overlap defect (Myron Stowe) [2066898]
- PCI/P2PDMA: Use percpu_ref_tryget_live_rcu() inside RCU critical section (Myron Stowe) [2066898]
- MAINTAINERS: Add Logan Gunthorpe as P2PDMA maintainer (Myron Stowe) [2066898]
- via-agp: convert to generic power management (Myron Stowe) [2066898]
- sis-agp: convert to generic power management (Myron Stowe) [2066898]
- amd64-agp: convert to generic power management (Myron Stowe) [2066898]
- PCI: pciehp: Use down_read/write_nested(reset_lock) to fix lockdep errors (Myron Stowe) [2066898]
- PCI: ibmphp: Remove commented-out functions (Myron Stowe) [2066898]
- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault (Myron Stowe) [2066898]
- x86/PCI: Remove initialization of static variables to false (Myron Stowe) [2066898]
- PCI: Use DWORD accesses for LTR, L1 SS to avoid erratum (Myron Stowe) [2066898]
- PCI/sysfs: Use default_groups in kobj_type for slot attrs (Myron Stowe) [2066898]
- PCI: Convert pci_dev_present() stub to static inline (Myron Stowe) [2066898]
- PCI: Use pci_find_vsec_capability() when looking for TBT devices (Myron Stowe) [2066898]
- PCI/ASPM: Remove struct aspm_latency (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching device L0s, L1 acceptable exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching link L0s, L1 exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Move pci_function_0() upward (Myron Stowe) [2066898]
- PCI: Add MSI masking quirk for Nvidia ION AHCI (Myron Stowe) [2066898]
- PCI/MSI: Destroy sysfs before freeing entries (Myron Stowe) [2066898]
- PCI/MSI: Deal with devices lying about their MSI mask capability (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Ensure relationship between miscdev and PCI (Myron Stowe) [2066898]
- redhat/configs: Enable CONFIG_NFT_SYNPROXY (Phil Sutter) [2069735]
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065351] {CVE-2022-1015}
- netfilter: nf_tables: initialize registers in nft_do_chain() (Phil Sutter) [2067964] {CVE-2022-1016}
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Phil Sutter) [2069114]
- ipmi: initialize len variable (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Remove old bindings support (Tony Camuso) [2067267]
- ipmi:ipmb: Add the ability to have a separate slave and master device (Tony Camuso) [2067267]
- ipmi:ipmi_ipmb: Unregister the SMI on remove (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Add AST2600 compatible string (Tony Camuso) [2067267]
- ipmi: ssif: replace strlcpy with strscpy (Tony Camuso) [2067267]
- ipmi/watchdog: Constify ident (Tony Camuso) [2067267]
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module (Tony Camuso) [2067267]
- ipmi: fix initialization when workqueue allocation fails (Tony Camuso) [2067267]
- ipmi: bail out if init_srcu_struct fails (Tony Camuso) [2067267]
- ipmi: ssif: initialize ssif_info->client early (Tony Camuso) [2067267]
- ipmi:ipmb: Fix unknown command response (Tony Camuso) [2067267]
- ipmi: fix IPMI_SMI_MSG_TYPE_IPMB_DIRECT response length checking (Tony Camuso) [2067267]
- ipmi: fix oob access due to uninit smi_msg type (Tony Camuso) [2067267]
- ipmi: msghandler: Make symbol 'remove_work_wq' static (Tony Camuso) [2067267]
- ipmi: Move remove_work to dedicated workqueue (Tony Camuso) [2067267]
- ipmi: kcs_bmc: Fix a memory leak in the error handling path of 'kcs_bmc_serio_add_device()' (Tony Camuso) [2067267]
- char: ipmi: replace snprintf in show functions with sysfs_emit (Tony Camuso) [2067267]
- ipmi: ipmb: fix dependencies to eliminate build error (Tony Camuso) [2067267]
- ipmi:ipmb: Add OF support (Tony Camuso) [2067267]
- ipmi: bt: Add ast2600 compatible string (Tony Camuso) [2067267]
- ipmi: bt-bmc: Use registers directly (Tony Camuso) [2067267]
- ipmi: ipmb: Fix off-by-one size check on rcvlen (Tony Camuso) [2067267]
- ipmi:ssif: Use depends on, not select, for I2C (Tony Camuso) [2067267]
- ipmi:ipmb: Add initial support for IPMI over IPMB (Tony Camuso) [2067267]
- ipmi: Add support for IPMB direct messages (Tony Camuso) [2067267]
- config: add CONFIG_IPMI_IPMB (Tony Camuso) [2067267]
- ipmi: Export ipmb_checksum() (Tony Camuso) [2067267]
- ipmi: Check error code before processing BMC response (Tony Camuso) [2067267]
- ipmi:devintf: Return a proper error when recv buffer too small (Tony Camuso) [2067267]
- ipmi: Disable some operations during a panic (Tony Camuso) [2067267]
- ipmi:watchdog: Set panic count to proper value on a panic (Tony Camuso) [2067267]
- parisc: Make struct parisc_driver::remove() return void (Tony Camuso) [2067267]
- char: ipmi: use DEVICE_ATTR helper macro (Tony Camuso) [2067267]
- ipmi: rate limit ipmi smi_event failure message (Tony Camuso) [2067267]

* Fri Apr 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-83.el9]
- redhat/configs: aarch64: enable CPU_FREQ_GOV_SCHEDUTIL (Mark Salter) [2077664]
- x86/platform/uv: Log gap hole end size (Frank Ramsay) [2074097]
- x86/platform/uv: Update TSC sync state for UV5 (Frank Ramsay) [2074097]
- x86/platform/uv: Update NMI Handler for UV5 (Frank Ramsay) [2074097]
- tun: annotate access to queue->trans_start (Ivan Vecera) [2073453]
- stmmac: fix build due to brainos in trans_start changes (Ivan Vecera) [2073453]
- net: no longer stop all TX queues in dev_watchdog() (Ivan Vecera) [2073453]
- net: do not inline netif_tx_lock()/netif_tx_unlock() (Ivan Vecera) [2073453]
- net: annotate accesses to queue->trans_start (Ivan Vecera) [2073453]
- net: use an atomic_long_t for queue->trans_timeout (Ivan Vecera) [2073453]
- virtio_net: introduce TX timeout watchdog (Ivan Vecera) [2073453]
- net: remove the unnecessary check in cipso_v4_doi_free (Guillaume Nault) [2074605]
- net: fix NULL pointer reference in cipso_v4_doi_free (Guillaume Nault) [2074605]
- selftest/powerpc: Add PAPR sysfs attributes sniff test (Steve Best) [1869665]
- powerpc/pseries: Interface to represent PAPR firmware attributes (Steve Best) [1869665]
- x86: intel_epb: Allow model specific normal EPB value (David Arcari) [2068330]
- redhat: configs: Disable CONFIG_MPLS for s390x/zfcpdump (Guillaume Nault) [2039239]
- ACPI: CPPC: Amend documentation in the comments (David Arcari) [1961725]
- ACPI: CPPC: Drop redundant local variable from cpc_read() (David Arcari) [1961725]
- ACPI: CPPC: Fix up I/O port access in cpc_read() (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix Kconfig dependencies for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix struct amd_cpudata kernel-doc comment (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State performance attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State frequencies attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add boost mode support for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Add trace for AMD P-State module (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce the support for the processors with shared memory solution (David Arcari) [1961725]
- cpufreq: amd-pstate: Add fast switch function for AMD P-State (David Arcari) [1961725]
- redhat/configs: enable CONFIG_X86_AMD_PSTATE (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce a new AMD P-State driver to support future processors (David Arcari) [1961725]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [1961725]
- x86/msr: Add AMD CPPC MSR definitions (David Arcari) [1961725]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [1961725]
- x86/cpufeatures: Add AMD Collaborative Processor Performance Control feature flag (David Arcari) [1961725]
- ACPI: CPPC: Add CPPC enable register function (David Arcari) [1961725]
- ACPI: CPPC: Check present CPUs for determining _CPC is valid (David Arcari) [1961725]
- ACPI: CPPC: Implement support for SystemIO registers (David Arcari) [1961725]

* Thu Apr 28 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-82.el9]
- mt76: mt7921e: fix possible probe failure after reboot (Íñigo Huguet) [2065633]
- mm: lru_cache_disable: replace work queue synchronization with synchronize_rcu (Marcelo Tosatti) [2033500]
- powerpc/lib/sstep: Don't use __{get/put}_user() on kernel addresses (Michael Petlan) [2049226]
- bpf, test_offload.py: Skip base maps without names (Felix Maurer) [2076961]
- perf header: Fix spelling mistake "could't" -> "couldn't" (Michael Petlan) [2075504]
- perf build-id: Fix spelling mistake "Cant" -> "Can't" (Michael Petlan) [2075504]
- e1000e: Add support for the next LOM generation (David Arcari) [2076668]
- vsprintf: Update %%pGp documentation about that it prints hex value (Waiman Long) [2073625]
- mm/page_owner.c: record tgid (Waiman Long) [2073625]
- mm/page_owner: record task command name (Waiman Long) [2073625]
- mm/page_owner: print memcg information (Waiman Long) [2073625]
- mm/page_owner: use scnprintf() to avoid excessive buffer overrun check (Waiman Long) [2073625]
- lib/vsprintf: avoid redundant work with 0 size (Waiman Long) [2073625]
- mm: make some vars and functions static or __init (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries into buffer (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries (Waiman Long) [2073625]
- lib, stackdepot: check stackdepot handle before accessing slabs (Waiman Long) [2073625]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Waiman Long) [2073625]
- vsprintf: Make %%pGp print the hex value (Waiman Long) [2073625]
- test_printf: Append strings more efficiently (Waiman Long) [2073625]
- test_printf: Remove custom appending of '|' (Waiman Long) [2073625]
- test_printf: Remove separate page_flags variable (Waiman Long) [2073625]
- test_printf: Make pft array const (Waiman Long) [2073625]
- proc: remove PDE_DATA() completely (Ivan Vecera) [2073492]
- fs: proc: store PDE()->data into inode->i_private (Ivan Vecera) [2073492]
- seq_file: fix passing wrong private data (Ivan Vecera) [2073492]
- tcp: seq_file: Refactor net and family matching (Ivan Vecera) [2073492]
- entry: Fix compile error in dynamic_irqentry_exit_cond_resched() (Phil Auld) [2065226]
- sched/preempt: Tell about PREEMPT_DYNAMIC on kernel headers (Phil Auld) [2065226]
- arm64: Support PREEMPT_DYNAMIC (Phil Auld) [2065226]
- arm64: entry: Centralize preemption decision (Phil Auld) [2065226]
- sched/preempt: Add PREEMPT_DYNAMIC using static keys (Phil Auld) [2065226]
- sched/preempt: Decouple HAVE_PREEMPT_DYNAMIC from GENERIC_ENTRY (Phil Auld) [2065226]
- sched/preempt: Simplify irqentry_exit_cond_resched() callers (Phil Auld) [2065226]
- sched/preempt: Refactor sched_dynamic_update() (Phil Auld) [2065226]
- sched/preempt: Move PREEMPT_DYNAMIC logic later (Phil Auld) [2065226]
- sched/debug: Remove mpol_get/put and task_lock/unlock from sched_show_numa (Phil Auld) [2062831]
- sched/numa: initialize numa statistics when forking new task (Phil Auld) [2062831]
- sched/uclamp: Fix iowait boost escaping uclamp restriction (Phil Auld) [2062831]
- sched/sugov: Ignore 'busy' filter when rq is capped by uclamp_max (Phil Auld) [2062831]
- sched/numa: Fix boot crash on arm64 systems (Phil Auld) [2062831]
- cgroup: Fix suspicious rcu_dereference_check() usage warning (Phil Auld) [2062831]
- sched/cpuacct: Remove redundant RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Optimize away RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Fix charge percpu cpuusage (Phil Auld) [2062831]
- sched/numa: Avoid migrating task to CPU-less node (Phil Auld) [2062831]
- sched/numa: Fix NUMA topology for systems with CPU-less nodes (Phil Auld) [2062831]
- sched: replace cpumask_weight with cpumask_empty where appropriate (Phil Auld) [2062831]
- sched/rt: Plug rt_mutex_setprio() vs push_rt_task() race (Phil Auld) [2062831]
- psi: fix possible trigger missing in the window (Phil Auld) [2062831]
- sched/tracing: Don't re-read p->state when emitting sched_switch event (Phil Auld) [2062831]
- sched/core: Export pelt_thermal_tp (Phil Auld) [2062831]
- sched/membarrier: Fix membarrier-rseq fence command missing from query bitmask (Phil Auld) [2062831]
- sched/core: Accounting forceidle time for all tasks except idle task (Phil Auld) [2062831]
- sched: Avoid double preemption in __cond_resched_*lock*() (Phil Auld) [2062831]
- fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA (Phil Auld) [2062831]
- sched/fair: Fix all kernel-doc warnings (Phil Auld) [2062831]
- sched/fair: Cleanup task_util and capacity type (Phil Auld) [2062831]
- sched/rt: Try to restart rt period timer when rt runtime exceeded (Phil Auld) [2062831]
- sched/fair: Fix per-CPU kthread and wakee stacking for asym CPU capacity (Phil Auld) [2062831]
- locking: Remove rt_rwlock_is_contended(). (Phil Auld) [2062831]
- sched: Trigger warning if ->migration_disabled counter underflows. (Phil Auld) [2062831]
- sched/fair: Fix detection of per-CPU kthreads waking a task (Phil Auld) [2062831]
- sched/fair: Replace CFS internal cpu_util() with cpu_util_cfs() (Phil Auld) [2062831]
- sched/cpuacct: Make user/system times in cpuacct.stat more precise (Phil Auld) [2062831]
- sched/cpuacct: Fix user/system in shown cpuacct.usage* (Phil Auld) [2062831]
- cpuacct: Convert BUG_ON() to WARN_ON_ONCE() (Phil Auld) [2062831]
- cputime, cpuacct: Include guest time in user time in cpuacct.stat (Phil Auld) [2062831]
- sched/core: Forced idle accounting (Phil Auld) [2062831]
- sched/fair: Document the slow path and fast path in select_task_rq_fair (Phil Auld) [2062831]
- pci: fix multiple definition error when CONFIG_RHEL_DIFFERENCES is not set (Joel Savitz) [2053991]
- selftests/bpf: Make test_lwt_ip_encap more stable and faster (Felix Maurer) [2019496]
- ucounts: Fix systemd LimitNPROC with private users regression (Alexey Gladkov) [2061724]
- ucounts: Enforce RLIMIT_NPROC not RLIMIT_NPROC+1 (Alexey Gladkov) [2061724]
- ucounts: Base set_cred_ucounts changes on the real user (Alexey Gladkov) [2061724]
- ucounts: Move RLIMIT_NPROC handling after set_user (Alexey Gladkov) [2061724]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2061724]
- redhat/configs: enable CONFIG_AMD_PTDMA for x86_64 (John W. Linville) [2027972]
- dmaengine: ptdma: handle the cases based on DMA is complete (John W. Linville) [2027972]
- dmaengine: ptdma: fix concurrency issue with multiple dma transfer (John W. Linville) [2027972]
- dmaengine: ptdma: Fix the error handling path in pt_core_init() (John W. Linville) [2027972]
- dmaengine: remove debugfs #ifdef (John W. Linville) [2027972]
- MAINTAINERS: Fix AMD PTDMA DRIVER entry (John W. Linville) [2027972]
- dmaengine: ptdma: remove PT_OFFSET to avoid redefnition (John W. Linville) [2027972]
- dmaengine: ptdma: Add debugfs entries for PTDMA (John W. Linville) [2027972]
- dmaengine: ptdma: register PTDMA controller as a DMA resource (John W. Linville) [2027972]
- dmaengine: ptdma: Initial driver for the AMD PTDMA (John W. Linville) [2027972]

* Tue Apr 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-81.el9]
- powerpc/pseries/vas: Add VAS migration handler (Steve Best) [2028677]
- powerpc/pseries/vas: Modify reconfig open/close functions for migration (Steve Best) [2028677]
- powerpc/pseries/vas: Define global hv_cop_caps struct (Steve Best) [2028677]
- powerpc/pseries/vas: Add 'update_total_credits' entry for QoS capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: sysfs interface to export capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: Reopen windows with DLPAR core add (Steve Best) [2028677]
- powerpc/pseries/vas: Close windows with DLPAR core removal (Steve Best) [2028677]
- powerpc/vas: Map paste address only if window is active (Steve Best) [2028677]
- powerpc/vas: Return paste instruction failure if no active window (Steve Best) [2028677]
- powerpc/vas: Add paste address mmap fault handler (Steve Best) [2028677]
- powerpc/pseries/vas: Save PID in pseries_vas_window struct (Steve Best) [2028677]
- powerpc/pseries/vas: Use common names in VAS capability structure (Steve Best) [2028677]
- s390/kexec: fix return code handling (Lichen Liu) [2017023]
- s390/kexec: fix memory leak of ipl report buffer (Lichen Liu) [2017023]
- Build intel_sdsi with %%{tools_make} (David Arcari) [1971952]
- redhat/kernel.spec.template: Add intel_sdsi utility (David Arcari) [1971952]
- redhat/configs: enable CONFIG_INTEL_SDSI (David Arcari) [1971952]
- selftests: sdsi: test sysfs setup (David Arcari) [1971952]
- tools arch x86: Add Intel SDSi provisiong tool (David Arcari) [1971952]
- platform/x86: Add Intel Software Defined Silicon driver (David Arcari) [1971952]
- spi: pxa2xx: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040032]
- redhat/configs: change intel-lpss to be a loadable module (David Arcari) [2040032]
- mfd: intel-lpss: Provide an SSP type to the driver (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Raptor Lake PCH-S PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Fix I2C4 not being available on the Microsoft Surface Go & Go 2 (David Arcari) [2040032]
- mfd: intel-lpss-pci: Fix clock speed for 38a8 UART (David Arcari) [2040032]
- mfd: intel-lpss: Fix too early PM enablement in the ACPI ->probe() (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Lakefield PCH PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Add support for MacBookPro16,2 ICL-N UART (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Cannon Lake ACPI IDs (David Arcari) [2040032]
- pinctrl: alderlake: Add Raptor Lake-S ACPI ID (David Arcari) [2040034]
- pinctrl: tigerlake: Revert "Add Alder Lake-M ACPI ID" (David Arcari) [2040034]
- pinctrl: intel: fix unexpected interrupt (David Arcari) [2040034]
- pinctrl: intel: Fix a glitch when updating IRQ flags on a preconfigured line (David Arcari) [2040034]
- pinctrl: intel: Kconfig: Add configuration menu to Intel pin control (David Arcari) [2040034]
- i2c: i801: Drop two outdated comments (David Arcari) [2040028]
- i2c: i801: Add support for the Process Call command (David Arcari) [2040028]
- i2c: i801: Drop useless masking in i801_access (David Arcari) [2040028]
- i2c: i801: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040028]
- eeprom: ee1004: limit i2c reads to I2C_SMBUS_BLOCK_MAX (David Arcari) [2040028]
- i2c: i801: Don't clear status flags twice in interrupt mode (David Arcari) [2040028]
- i2c: i801: Don't read back cleared status in i801_check_pre() (David Arcari) [2040028]
- i2c: i801: Improve handling platform data for tco device (David Arcari) [2040028]
- i2c: i801: Improve handling of chip-specific feature definitions (David Arcari) [2040028]
- i2c: i801: Remove i801_set_block_buffer_mode (David Arcari) [2040028]
- i2c: i801: Don't silently correct invalid transfer size (David Arcari) [2040028]
- i2c: i801: Fix interrupt storm from SMB_ALERT signal (David Arcari) [2040028]
- i2c: i801: Restore INTREN on unload (David Arcari) [2040028]
- i2c: i801: Add support for Intel Ice Lake PCH-N (David Arcari) [2040028]
- i2c: i801: Fix incorrect and needless software PEC disabling (David Arcari) [2040028]
- i2c: i801: Stop using pm_runtime_set_autosuspend_delay(-1) (David Arcari) [2040028]
- i2c: i801: Use PCI bus rescan mutex to protect P2SB access (David Arcari) [2040028]
- i2c: i801: Improve i801_add_mux (David Arcari) [2040028]
- i2c: i801: Improve i801_acpi_probe/remove functions (David Arcari) [2040028]
- i2c: i801: Remove not needed check for PCI_COMMAND_INTX_DISABLE (David Arcari) [2040028]
- i2c: i801: Improve is_dell_system_with_lis3lv02d (David Arcari) [2040028]
- i2c: i801: Remove not needed debug message (David Arcari) [2040028]
- i2c: i801: make p2sb_spinlock a mutex (David Arcari) [2040028]
- i2c: i801: Improve disabling runtime pm (David Arcari) [2040028]
- i2c: i801: Fix handling SMBHSTCNT_PEC_EN (David Arcari) [2040028]
- kABI: Pad the address_space struct (Nico Pache) [2048328]
- kABI: Pad the readahead_control struct (Nico Pache) [2048328]
- kABI: Pad the vm_fault struct (Nico Pache) [2048328]
- kABI: Pad vm_operations_struct (Nico Pache) [2048328]
- kABI: Pad the mempolicy struct (Nico Pache) [2048328]
- kABI: Pad mempool_s (Nico Pache) [2048328]
- kABI: Pad dev_pagemap and dev_pagemap_ops (Nico Pache) [2048328]
- kABI: Pad struct swap_info_struct (Nico Pache) [2048328]
- kABI: Pad vmem_altmap (Nico Pache) [2048328]
- kABI: Pad the vm_area_struct (Nico Pache) [2048328]
- kABI: Pad the mm_struct (Nico Pache) [2048328]
- kABI: exclude reclaim_state struct (Nico Pache) [2048328]
- kABI: Pad the shrinker struct (Nico Pache) [2048328]
- kABI: Exclude memcg pointer from shrinker (Nico Pache) [2048328]
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init (Steve Best) [2067770]
- scsi: smartpqi: Update version to 2.1.14-035 (Don Brace) [2012229]
- scsi: smartpqi: Fix lsscsi -t SAS addresses (Don Brace) [2012229]
- scsi: smartpqi: Fix hibernate and suspend (Don Brace) [2012229]
- scsi: smartpqi: Fix BUILD_BUG_ON() statements (Don Brace) [2012229]
- scsi: smartpqi: Fix NUMA node not updated during init (Don Brace) [2012229]
- scsi: smartpqi: Expose SAS address for SATA drives (Don Brace) [2012229]
- scsi: smartpqi: Speed up RAID 10 sequential reads (Don Brace) [2012229]
- scsi: smartpqi: Fix kdump issue when controller is locked up (Don Brace) [2012229]
- scsi: smartpqi: Update volume size after expansion (Don Brace) [2012229]
- scsi: smartpqi: Avoid drive spin-down during suspend (Don Brace) [2012229]
- scsi: smartpqi: Resolve delay issue with PQI_HZ value (Don Brace) [2012229]
- scsi: smartpqi: Fix a typo in func pqi_aio_submit_io() (Don Brace) [2012229]
- scsi: smartpqi: Fix a name typo and cleanup code (Don Brace) [2012229]
- scsi: smartpqi: Quickly propagate path failures to SCSI midlayer (Don Brace) [2012229]
- scsi: smartpqi: Eliminate drive spin down on warm boot (Don Brace) [2012229]
- scsi: smartpqi: Enable SATA NCQ priority in sysfs (Don Brace) [2012229]
- scsi: smartpqi: Add PCI IDs (Don Brace) [2012229]
- scsi: smartpqi: Fix rmmod stack trace (Don Brace) [2012229]
- selftests: xsk: Generate packet directly in umem (Felix Maurer) [2006330]
- selftests: xsk: Decrease sending speed (Felix Maurer) [2006330]
- selftests: xsk: Simplify packet validation in xsk tests (Felix Maurer) [2006330]
- selftests: xsk: Rename worker_* functions that are not thread entry points (Felix Maurer) [2006330]
- selftests: xsk: Remove end-of-test packet (Felix Maurer) [2006330]
- RDMA/qedr: Fix reporting max_{send/recv}_wr attrs (Kamal Heib) [2051532]

* Thu Apr 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-80.el9]
- redhat: disable uncommon media device infrastructure (Jarod Wilson) [2074598]
- netfilter: nf_tables: unregister flowtable hooks on netns exit (Florian Westphal) [2056869]
- netfilter: nf_tables_offload: incorrect flow offload action array size (Florian Westphal) [2056869] {CVE-2022-25636}
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065350] {CVE-2022-1015}
- scsi: qedi: Fix failed disconnect handling (Chris Leech) [2071524]
- scsi: iscsi: Fix unbound endpoint error handling (Chris Leech) [2071524]
- scsi: iscsi: Fix conn cleanup and stop race during iscsid restart (Chris Leech) [2071524]
- scsi: iscsi: Fix endpoint reuse regression (Chris Leech) [2071524]
- scsi: iscsi: Release endpoint ID when its freed (Chris Leech) [2071524]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2071524]
- Revert "scsi: iscsi: Fix offload conn cleanup when iscsid restarts" (Chris Leech) [2071524]
- scsi: iscsi: Speed up session unblocking and removal (Chris Leech) [2071524]
- scsi: iscsi: Fix recovery and unblocking race (Chris Leech) [2071524]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Chris Leech) [2071524]
- scsi: iscsi: Unblock session then wake up error handler (Chris Leech) [2071524]
- scsi: iscsi: Fix set_param() handling (Chris Leech) [2071524]
- scsi: iscsi: Fix iscsi_task use after free (Chris Leech) [2071524]
- scsi: iscsi: Adjust iface sysfs attr detection (Chris Leech) [2071524]
- scsi: qedi: Add support for fastpath doorbell recovery (Chris Leech) [2071524]
- redhat: Enable KASAN on all ELN debug kernels (Nico Pache) [1995251]
- sched/topology: Remove redundant variable and fix incorrect type in build_sched_domains (Phil Auld) [2065198]
- sched/fair: Adjust the allowed NUMA imbalance when SD_NUMA spans multiple LLCs (Phil Auld) [2065198]
- sched/fair: Improve consistency of allowed NUMA balance calculations (Phil Auld) [2065198]
- redhat/configs: Enable CONFIG_RCU_SCALE_TEST & CONFIG_RCU_REF_SCALE_TEST (Waiman Long) [2070740]
- thermal: int340x: Fix VCoRefLow MMIO bit offset for TGL (David Arcari) [2039995]
- thermal: int340x: Use struct_group() for memcpy() region (David Arcari) [2039995]
- thermal: int340x: Limit Kconfig to 64-bit (David Arcari) [2039995]
- thermal: int340x: fix build on 32-bit targets (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: processor_thermal: Suppot 64 bit RFIM responses (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: Improve the tcc offset saving for suspend/resume (David Arcari) [2039995]
- thermal: int340x: delete bogus length check (David Arcari) [2039995]
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume (David Arcari) [2039995]
- thermal/drivers/int340x: Use IMOK independently (David Arcari) [2039995]
- stddef: Introduce struct_group() helper macro (David Arcari) [2039995]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2031240]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2031240]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2031240]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2031240]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2031240]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2031240]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2031240]

* Tue Apr 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-79.el9]
- redhat/configs: Enable WDT devices used by qemu VMs (Prarit Bhargava) [2074160]
- redhat/configs: disable CONFIG_CAN_SOFTING (Brian Masney) [2073521]
- myri10ge: mark as unmaintained (Michal Schmidt) [2054208]
- benet: mark device 0xe220 (Lancer) as unmaintained (Michal Schmidt) [2054208]
- bnx2: mark as unmaintained (Michal Schmidt) [2054208]
- ice: Fix race condition during interface enslave (Petr Oros) [1988953]
- ice: Fix error with handling of bonding MTU (Petr Oros) [1988953]
- ice: Avoid RTNL lock when re-creating auxiliary device (Petr Oros) [1988953]
- ice: Fix KASAN error in LAG NETDEV_UNREGISTER handler (Petr Oros) [1988953]
- userfaultfd/selftests: fix calculation of expected ioctls (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: fix feature support detection (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: don't rely on GNU extensions for random numbers (Desnes A. Nunes do Rosario) [2036152]
- CI: Drop baseline runs (Veronika Kabatova)
- PCI: hv: Propagate coherence from VMbus device to PCI device (Vitaly Kuznetsov) [2068432]
- Drivers: hv: vmbus: Propagate VMbus coherence to each VMbus device (Vitaly Kuznetsov) [2068432]
- ibmvnic: fix race between xmit and reset (Gustavo Walbon) [2061556]
- mlxsw: spectrum_router: Increase parsing depth for multipath hash (Ivan Vecera) [2020113]
- mlxsw: Remove old parsing depth infrastructure (Ivan Vecera) [2020113]
- mlxsw: Convert existing consumers to use new API for parsing configuration (Ivan Vecera) [2020113]
- mlxsw: spectrum: Add infrastructure for parsing configuration (Ivan Vecera) [2020113]
- ipv6: separate ndisc_ns_create() from ndisc_send_ns() (Ivan Vecera) [2073506]
- powerpc/mce: Modify the real address error logging messages (Desnes A. Nunes do Rosario) [2068688]
- selftests/powerpc: Add test for real address error handling (Desnes A. Nunes do Rosario) [2068688]
- powerpc/pseries: Parse control memory access error (Desnes A. Nunes do Rosario) [2068688]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix power_pmu_disable to call clear_pmi_irq_pending only if PMI is pending (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Only define power_pmu_wants_prompt_pmi() for CONFIG_PPC64 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add data source encodings for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add encodings to represent data based on newer composite PERF_MEM_LVLNUM* fields (Desnes A. Nunes do Rosario) [2048779]
- perf: Add new macros for mem_hops field (Desnes A. Nunes do Rosario) [2048779]
- tools headers UAPI: Add new macros for mem_hops field to perf_event.h (Desnes A. Nunes do Rosario) [2048779]
- bpf: Remove config check to enable bpf support for branch records (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Update global/local variants for p_stage_cyc (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Include global and local variants for p_stage_cyc sort key (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'p_stage_cyc' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'ins_lat' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'weight' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf vendor events power10: Add metric events JSON file for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Add support to expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Refactor the code definition of perf reg extended mask in tools side header file (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL in power10 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Refactor the code definition of perf reg extended mask (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix data source encodings for L2.1 and L3.1 accesses (Desnes A. Nunes do Rosario) [2048779]
- tools/perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add comment about current state of PERF_MEM_LVL_* namespace and remove an extra line (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix the check for SIAR value (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Drop the case of returning 0 as instruction pointer (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Use stack siar instead of mfspr (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf/hv-gpci: Fix counter value parsing (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix PMU callbacks to clear pending PMI before resetting an overflown PMC (Desnes A. Nunes do Rosario) [2048779]
- EVM: fix the evm= __setup handler return value (Bruno Meneguele) [2063906]
- ima: Do not print policy rule with inactive LSM labels (Bruno Meneguele) [2063906]
- ima: Allow template selection with ima_template[_fmt]= after ima_hash= (Bruno Meneguele) [2063906]
- ima: Remove ima_policy file before directory (Bruno Meneguele) [2063906]
- integrity: check the return value of audit_log_start() (Bruno Meneguele) [2063906]
- ima: fix reference leak in asymmetric_verify() (Bruno Meneguele) [2063906]
- ipv4: avoid using shared IP generator for connected sockets (Paolo Abeni) [2062428] {CVE-2020-36516}
- bpf/selftests: Fix namespace mount setup in tc_redirect (Yauheni Kaliuta) [2063067]
- memcg: do not tweak node in alloc_mem_cgroup_per_node_info (Nico Pache) [2024054]
- mm: make free_area_init_node aware of memory less nodes (Nico Pache) [2024054]
- mm, memory_hotplug: reorganize new pgdat initialization (Nico Pache) [2024054]
- mm, memory_hotplug: drop arch_free_nodedata (Nico Pache) [2024054]
- mm: handle uninitialized numa nodes gracefully (Nico Pache) [2024054]
- mm, memory_hotplug: make arch_alloc_nodedata independent on CONFIG_MEMORY_HOTPLUG (Nico Pache) [2024054]
- block: restore the old set_task_ioprio() behaviour wrt PF_EXITING (Ming Lei) [2066297]
- scsi: core: scsi_logging: Fix a BUG (Ming Lei) [2066297]
- scsi: sr: Fix typo in CDROM(CLOSETRAY|EJECT) handling (Ming Lei) [2066297]
- block: add __must_check for *add_disk*() callers (Ming Lei) [2066297]
- scsi: bsg: Fix errno when scsi_bsg_register_queue() fails (Ming Lei) [2066297]
- scsi: st: Add missing break in switch statement in st_ioctl() (Ming Lei) [2066297]
- scsi: core: scsi_ioctl: Fix error code propagation in SG_IO (Ming Lei) [2066297]
- scsi: bsg: Fix device unregistration (Ming Lei) [2066297]
- scsi: bsg-lib: Fix commands without data transfer in bsg_transport_sg_io_fn() (Ming Lei) [2066297]
- scsi: bsg: Fix commands without data transfer in scsi_bsg_sg_io_fn() (Ming Lei) [2066297]
- block: limit request dispatch loop duration (Ming Lei) [2066297]
- block: fix rq-qos breakage from skipping rq_qos_done_bio() (Ming Lei) [2066297]
- block: flush plug based on hardware and software queue order (Ming Lei) [2066297]
- block: ensure plug merging checks the correct queue at least once (Ming Lei) [2066297]
- block: update io_ticks when io hang (Ming Lei) [2066297]
- block: release rq qos structures for queue without disk (Ming Lei) [2066297]
- block: fix blk_mq_attempt_bio_merge and rq_qos_throttle protection (Ming Lei) [2066297]
- blktrace: fix use after free for struct blk_trace (Ming Lei) [2066297]
- block: clear iocb->private in blkdev_bio_end_io_async() (Ming Lei) [2066297]
- block/wbt: fix negative inflight counter when remove scsi device (Ming Lei) [2066297]
- block-map: add __GFP_ZERO flag for alloc_page in function bio_copy_kern (Ming Lei) [2066297]
- block: loop:use kstatfs.f_bsize of backing file to set discard granularity (Ming Lei) [2066297]
- block: Add handling for zone append command in blk_complete_request (Ming Lei) [2066297]
- loop: revert "make autoclear operation asynchronous" (Ming Lei) [2066297]
- block: fix DIO handling regressions in blkdev_read_iter() (Ming Lei) [2066297]
- blk-mq: fix missing blk_account_io_done() in error path (Ming Lei) [2066297]
- block: cleanup q->srcu (Ming Lei) [2066297]
- block: Remove unnecessary variable assignment (Ming Lei) [2066297]
- brd: remove brd_devices_mutex mutex (Ming Lei) [2066297]
- aoe: remove redundant assignment on variable n (Ming Lei) [2066297]
- loop: remove redundant initialization of pointer node (Ming Lei) [2066297]
- block/rnbd-clt-sysfs: use default_groups in kobj_type (Ming Lei) [2066297]
- pktcdvd: convert to use attribute groups (Ming Lei) [2066297]
- rsxx: Drop PCI legacy power management (Ming Lei) [2066297]
- mtip32xx: convert to generic power management (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata lookups (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata checking (Ming Lei) [2066297]
- drbd: Use struct_group() to zero algs (Ming Lei) [2066297]
- loop: make autoclear operation asynchronous (Ming Lei) [2066297]
- null_blk: cast command status to integer (Ming Lei) [2066297]
- pktdvd: stop using bdi congestion framework. (Ming Lei) [2066297]
- block: null_blk: batched complete poll requests (Ming Lei) [2066297]
- floppy: Add max size check for user space request (Ming Lei) [2066297]
- floppy: Fix hang in watchdog when disk is ejected (Ming Lei) [2066297]
- loop: don't hold lo_mutex during __loop_clr_fd() (Ming Lei) [2066297]
- MAINTAINERS: add entries for block layer documentation (Ming Lei) [2066297]
- docs: sysfs-block: add contact for nomerges (Ming Lei) [2066297]
- docs: sysfs-block: sort alphabetically (Ming Lei) [2066297]
- docs: sysfs-block: move to stable directory (Ming Lei) [2066297]
- block: fix old-style declaration (Ming Lei) [2066297]
- nvme-pci: fix queue_rqs list splitting (Ming Lei) [2066297]
- block: introduce rq_list_move (Ming Lei) [2066297]
- block: drop needless assignment in set_task_ioprio() (Ming Lei) [2066297]
- bio.h: fix kernel-doc warnings (Ming Lei) [2066297]
- block: check minor range in device_add_disk() (Ming Lei) [2066297]
- block: use "unsigned long" for blk_validate_block_size(). (Ming Lei) [2066297]
- block: fix error unwinding in device_add_disk (Ming Lei) [2066297]
- block: call blk_exit_queue() before freeing q->stats (Ming Lei) [2066297]
- block: fix error in handling dead task for ioprio setting (Ming Lei) [2066297]
- blk-mq: blk-mq: check quiesce state before queue_rqs (Ming Lei) [2066297]
- block: only build the icq tracking code when needed (Ming Lei) [2066297]
- block: fold create_task_io_context into ioc_find_get_icq (Ming Lei) [2066297]
- block: open code create_task_io_context in set_task_ioprio (Ming Lei) [2066297]
- block: fold get_task_io_context into set_task_ioprio (Ming Lei) [2066297]
- block: move set_task_ioprio to blk-ioc.c (Ming Lei) [2066297]
- block: cleanup ioc_clear_queue (Ming Lei) [2066297]
- block: refactor put_io_context (Ming Lei) [2066297]
- block: remove the NULL ioc check in put_io_context (Ming Lei) [2066297]
- block: refactor put_iocontext_active (Ming Lei) [2066297]
- block: simplify struct io_context refcounting (Ming Lei) [2066297]
- block: remove the nr_task field from struct io_context (Ming Lei) [2066297]
- nvme: add support for mq_ops->queue_rqs() (Ming Lei) [2066297]
- block: add mq_ops->queue_rqs hook (Ming Lei) [2066297]
- block: use singly linked list for bio cache (Ming Lei) [2066297]
- block: add completion handler for fast path (Ming Lei) [2066297]
- block: make queue stat accounting a reference (Ming Lei) [2066297]
- bdev: Improve lookup_bdev documentation (Ming Lei) [2066297]
- mtd_blkdevs: don't scan partitions for plain mtdblock (Ming Lei) [2066297]
- blk-mq: Optimise blk_mq_queue_tag_busy_iter() for shared tags (Ming Lei) [2066297]
- blk-mq: Delete busy_iter_fn (Ming Lei) [2066297]
- blk-mq: Drop busy_iter_fn blk_mq_hw_ctx argument (Ming Lei) [2066297]
- blk-mq: don't use plug->mq_list->q directly in blk_mq_run_dispatch_ops() (Ming Lei) [2066297]
- blk-mq: don't run might_sleep() if the operation needn't blocking (Ming Lei) [2066297]
- blk-mq: run dispatch lock once in case of issuing from list (Ming Lei) [2066297]
- blk-mq: pass request queue to blk_mq_run_dispatch_ops (Ming Lei) [2066297]
- blk-mq: move srcu from blk_mq_hw_ctx to request_queue (Ming Lei) [2066297]
- blk-mq: remove hctx_lock and hctx_unlock (Ming Lei) [2066297]
- block: switch to atomic_t for request references (Ming Lei) [2066297]
- block: move direct_IO into our own read_iter handler (Ming Lei) [2066297]
- mm: move filemap_range_needs_writeback() into header (Ming Lei) [2066297]
- mm: move more expensive part of XA setup out of mapping check (Ming Lei) [2066297]
- block: get rid of useless goto and label in blk_mq_get_new_requests() (Ming Lei) [2066297]
- blk-mq: check q->poll_stat in queue_poll_stat_show (Ming Lei) [2066297]
- scsi: remove the gendisk argument to scsi_ioctl (Ming Lei) [2066297]
- block: remove the gendisk argument to blk_execute_rq (Ming Lei) [2066297]
- block: remove the ->rq_disk field in struct request (Ming Lei) [2066297]
- block: don't check ->rq_disk in merges (Ming Lei) [2066297]
- mtd_blkdevs: remove the sector out of range check in do_blktrans_request (Ming Lei) [2066297]
- block: Remove redundant initialization of variable ret (Ming Lei) [2066297]
- block: simplify ioc_lookup_icq (Ming Lei) [2066297]
- block: simplify ioc_create_icq (Ming Lei) [2066297]
- block: return the io_context from create_task_io_context (Ming Lei) [2066297]
- block: use alloc_io_context in __copy_io (Ming Lei) [2066297]
- block: factor out a alloc_io_context helper (Ming Lei) [2066297]
- block: remove get_io_context_active (Ming Lei) [2066297]
- block: move the remaining elv.icq handling to the I/O scheduler (Ming Lei) [2066297]
- block: move blk_mq_sched_assign_ioc to blk-ioc.c (Ming Lei) [2066297]
- block: mark put_io_context_active static (Ming Lei) [2066297]
- Revert "block: Provide blk_mq_sched_get_icq()" (Ming Lei) [2066297]
- bfq: use bfq_bic_lookup in bfq_limit_depth (Ming Lei) [2066297]
- bfq: simplify bfq_bic_lookup (Ming Lei) [2066297]
- fork: move copy_io to block/blk-ioc.c (Ming Lei) [2066297]
- bfq: Do not let waker requests skip proper accounting (Ming Lei) [2066297]
- bfq: Log waker detections (Ming Lei) [2066297]
- bfq: Provide helper to generate bfqq name (Ming Lei) [2066297]
- bfq: Limit waker detection in time (Ming Lei) [2066297]
- bfq: Limit number of requests consumed by each cgroup (Ming Lei) [2066297]
- bfq: Store full bitmap depth in bfq_data (Ming Lei) [2066297]
- bfq: Track number of allocated requests in bfq_entity (Ming Lei) [2066297]
- block: Provide blk_mq_sched_get_icq() (Ming Lei) [2066297]
- mmc: core: Use blk_mq_complete_request_direct(). (Ming Lei) [2066297]
- blk-mq: Add blk_mq_complete_request_direct() (Ming Lei) [2066297]
- blk-crypto: remove blk_crypto_unregister() (Ming Lei) [2066297]
- block: don't include <linux/part_stat.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/idr.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/blk-mq.h> in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq.h in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq-sched.h in blk.h (Ming Lei) [2066297]
- block: remove the e argument to elevator_exit (Ming Lei) [2066297]
- block: remove elevator_exit (Ming Lei) [2066297]
- block: move blk_get_flush_queue to blk-flush.c (Ming Lei) [2066297]
- blk_mq: remove repeated includes (Ming Lei) [2066297]
- block: move io_context creation into where it's needed (Ming Lei) [2066297]
- block: only allocate poll_stats if there's a user of them (Ming Lei) [2066297]
- blk-ioprio: don't set bio priority if not needed (Ming Lei) [2066297]
- blk-mq: move more plug handling from blk_mq_submit_bio into blk_add_rq_to_plug (Ming Lei) [2066297]
- sr: set GENHD_FL_REMOVABLE earlier (Ming Lei) [2066297]
- block: cleanup the GENHD_FL_* definitions (Ming Lei) [2066297]
- block: don't set GENHD_FL_NO_PART for hidden gendisks (Ming Lei) [2066297]
- block: remove GENHD_FL_EXT_DEVT (Ming Lei) [2066297]
- block: remove GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- mmc: don't set GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- null_blk: don't suppress partitioning information (Ming Lei) [2066297]
- block: remove the GENHD_FL_HIDDEN check in blkdev_get_no_open (Ming Lei) [2066297]
- block: rename GENHD_FL_NO_PART_SCAN to GENHD_FL_NO_PART (Ming Lei) [2066297]
- block: merge disk_scan_partitions and blkdev_reread_part (Ming Lei) [2066297]
- block: remove a dead check in show_partition (Ming Lei) [2066297]
- block: remove GENHD_FL_CD (Ming Lei) [2066297]
- block: move GENHD_FL_BLOCK_EVENTS_ON_EXCL_WRITE to disk->event_flags (Ming Lei) [2066297]
- block: move GENHD_FL_NATIVE_CAPACITY to disk->state (Ming Lei) [2066297]
- block: don't include blk-mq headers in blk-core.c (Ming Lei) [2066297]
- block: move blk_print_req_error to blk-mq.c (Ming Lei) [2066297]
- block: move blk_dump_rq_flags to blk-mq.c (Ming Lei) [2066297]
- block: move blk_account_io_{start,done} to blk-mq.c (Ming Lei) [2066297]
- block: move blk_steal_bios to blk-mq.c (Ming Lei) [2066297]
- block: move blk_rq_init to blk-mq.c (Ming Lei) [2066297]
- block: move request based cloning helpers to blk-mq.c (Ming Lei) [2066297]
- blk-mq: move blk_mq_flush_plug_list (Ming Lei) [2066297]
- block: remove blk-exec.c (Ming Lei) [2066297]
- block: remove rq_flush_dcache_pages (Ming Lei) [2066297]
- block: move blk_rq_err_bytes to scsi (Ming Lei) [2066297]
- block: remove blk_{get,put}_request (Ming Lei) [2066297]
- block: remove QUEUE_FLAG_SCSI_PASSTHROUGH (Ming Lei) [2066297]
- block: remove the initialize_rq_fn blk_mq_ops method (Ming Lei) [2066297]
- scsi: add a scsi_alloc_request helper (Ming Lei) [2066297]
- bsg-lib: initialize the bsg_job in bsg_transport_sg_io_fn (Ming Lei) [2066297]
- nfsd/blocklayout: use ->get_unique_id instead of sending SCSI commands (Ming Lei) [2066297]
- sd: implement ->get_unique_id (Ming Lei) [2066297]
- block: add a ->get_unique_id method (Ming Lei) [2066297]
- scsi: bsg: Move the whole request execution into the SCSI/transport handlers (Ming Lei) [2066297]
- scsi: block: Remove the remaining SG_IO-related fields from struct request_queue (Ming Lei) [2066297]
- scsi: block: Remove BLK_SCSI_MAX_CMDS (Ming Lei) [2066297]
- scsi: bsg: Simplify device registration (Ming Lei) [2066297]
- scsi: sr: cdrom: Move cdrom_read_cdda_bpc() into the sr driver (Ming Lei) [2066297]
- scsi: scsi_ioctl: Unexport sg_scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SG_IO handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SCSI_IOCTL_GET_IDLUN handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Consolidate the START STOP UNIT handling (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove a very misleading comment (Ming Lei) [2066297]
- scsi: core: Rename CONFIG_BLK_SCSI_REQUEST to CONFIG_SCSI_COMMON (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move the "block layer" SCSI ioctl handling to drivers/scsi (Ming Lei) [2066297]
- scsi: scsi_ioctl: Simplify SCSI passthrough permission checking (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move scsi_command_size_tbl to scsi_common.c (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_req_init() (Ming Lei) [2066297]
- scsi: bsg: Move bsg_scsi_ops to drivers/scsi/ (Ming Lei) [2066297]
- scsi: bsg: Decouple from scsi_cmd_ioctl() (Ming Lei) [2066297]
- scsi: block: Add a queue_max_bytes() helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Call scsi_cmd_ioctl() from scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_verify_blk_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_cmd_blk_ioctl() (Ming Lei) [2066297]
- scsi: cdrom: Remove the call to scsi_cmd_blk_ioctl() from cdrom_ioctl() (Ming Lei) [2066297]
- scsi: st: Simplify ioctl handling (Ming Lei) [2066297]
- scsi: core: Remove scsi_compat_ioctl() (Ming Lei) [2066297]
- scsi: sg: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: ch: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sd: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sr: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: bsg: Remove support for SCSI_IOCTL_SEND_COMMAND (Ming Lei) [2066297]
- block: fix argument type of bio_trim() (Ming Lei) [2066297]
- powerpc/xive: Export XIVE IPI information for online-only processors. (Steve Best) [2038242]
- RDMA/cma: Do not change route.addr.src_addr outside state checks (Kamal Heib) [2056771]
- RDMA/ib_srp: Fix a deadlock (Kamal Heib) [2056771]
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic. (Kamal Heib) [2056771]
- IB/cm: Release previously acquired reference counter in the cm_id_priv (Kamal Heib) [2056771]
- RDMA/siw: Fix refcounting leak in siw_create_qp() (Kamal Heib) [2056771]
- RDMA/ucma: Protect mc during concurrent multicast leaves (Kamal Heib) [2056771]
- RDMA/cma: Use correct address when leaving multicast group (Kamal Heib) [2056771]
- IB/hfi1: Fix tstats alloc and dealloc (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix AIP early init panic (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix alloc failure with larger txqueuelen (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix panic with larger ipoib send_queue_size (Kamal Heib) [2049164 2056771]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Kamal Heib) [2056771]
- RDMA/irdma: Remove the redundant return (Kamal Heib) [2037988 2056771]
- RDMA/irdma: Make the source udp port vary (Kamal Heib) [2037988 2056771]
- RDMA/core: Calculate UDP source port based on flow label or lqpn/rqpn (Kamal Heib) [2056771]
- IB/iser: Align coding style across driver (Kamal Heib) [2056771]
- IB/iser: Remove un-needed casting to/from void pointer (Kamal Heib) [2056771]
- IB/iser: Don't suppress send completions (Kamal Heib) [2056771]
- IB/iser: Rename ib_ret local variable (Kamal Heib) [2056771]
- IB/iser: Fix RNR errors (Kamal Heib) [2056771]
- IB/iser: Remove deprecated pi_guard module param (Kamal Heib) [2056771]
- IB/mlx5: Expose NDR speed through MAD (Kamal Heib) [2056771]
- RDMA/mad: Delete duplicated init_query_mad functions (Kamal Heib) [2056771]
- RDMA: Use default_groups in kobj_type (Kamal Heib) [2056771]
- RDMA/irdma: Use auxiliary_device driver data helpers (Kamal Heib) [2037988 2056771]
- driver core: auxiliary bus: Add driver data helpers (Kamal Heib) [2056771]
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Let ib_find_gid() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Modify rdma_query_gid() to return accurate error codes (Kamal Heib) [2056771]
- RDMA/irdma: Fix the type used to declare a bitmap (Kamal Heib) [2037988 2056771]
- IB/core: Remove redundant pointer mm (Kamal Heib) [2056771]
- RDMA/uverbs: Remove the unnecessary assignment (Kamal Heib) [2056771]
- RDMA/siw: Use max() instead of doing it manually (Kamal Heib) [2056771]
- RDMA/pvrdma: Use non-atomic bitmap functions when possible (Kamal Heib) [2056771]
- RDMA/pvrdma: Use bitmap_zalloc() when applicable (Kamal Heib) [2056771]
- IB/hfi1: Use bitmap_zalloc() when applicable (Kamal Heib) [2049164 2056771]
- RDMA/siw: Use helper function to set sys_image_guid (Kamal Heib) [2056771]
- RDMA/cma: Remove open coding of overflow checking for private_data_len (Kamal Heib) [2056771]
- RDMA/usnic: Clean up usnic_ib_alloc_pd() (Kamal Heib) [2056771]
- RDMA/irdma: Use helper function to set GUIDs (Kamal Heib) [2037988 2056771]
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (Kamal Heib) [2049164 2056770]
- IB/hfi1: Fix early init panic (Kamal Heib) [2049164 2056770]
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled (Kamal Heib) [2049164 2056770]
- IB/hfi1: Correct guard on eager buffer deallocation (Kamal Heib) [2049164 2056770]
- RDMA/nldev: Check stat attribute before accessing it (Kamal Heib) [2056770]
- IB/hfi1: Properly allocate rdma counter desc memory (Kamal Heib) [2049164 2056770]
- RDMA/core: Set send and receive CQ before forwarding to the driver (Kamal Heib) [2056770]
- RDMA/netlink: Add __maybe_unused to static inline in C file (Kamal Heib) [2056770]
- RDMA/core: Require the driver to set the IOVA correctly during rereg_mr (Kamal Heib) [2056770]
- RDMA/irdma: optimize rx path by removing unnecessary copy (Kamal Heib) [2037988 2056770]
- IB/opa_vnic: Rebranding of OPA VNIC driver to Cornelis Networks (Kamal Heib) [2056770]
- IB/hfi1: Rebranding of hfi1 driver to Cornelis Networks (Kamal Heib) [2049164 2056770]
- RDMA/irdma: Remove the unused variable local_qp (Kamal Heib) [2037988 2056770]
- RDMA/core: Fix missed initialization of rdma_hw_stats::lock (Kamal Heib) [2056770]
- RDMA/efa: Add support for dmabuf memory regions (Kamal Heib) [2056770]
- RDMA/umem: Allow pinned dmabuf umem usage (Kamal Heib) [2056770]
- RDMA/irdma: Remove the unused spin lock in struct irdma_qp_uk (Kamal Heib) [2037988 2056770]
- RDMA: Constify netdev->dev_addr accesses (Kamal Heib) [2056770]
- RDMA/ipoib: Use dev_addr_mod() (Kamal Heib) [2056770]
- RDMA/core: Use kvzalloc when allocating the struct ib_port (Kamal Heib) [2056770]
- RDMA/irdma: Make irdma_uk_cq_init() return a void (Kamal Heib) [2037988 2056770]
- RDMA/core: Set sgtable nents when using ib_dma_virt_map_sg() (Kamal Heib) [2056770]
- RDMA/irdma: Remove irdma_cqp_up_map_cmd() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_get_hw_addr() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_sc_send_lsmm_nostag() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_uk_mw_bind() (Kamal Heib) [2037988 2056770]
- RDMA: Remove redundant 'flush_workqueue()' calls (Kamal Heib) [2056770]
- RDMA/iwpm: Remove redundant initialization of pointer err_str (Kamal Heib) [2056770]
- RDMA/nldev: Allow optional-counter status configuration through RDMA netlink (Kamal Heib) [2056770]
- RDMA/nldev: Split nldev_stat_set_mode_doit out of nldev_stat_set_doit (Kamal Heib) [2056770]
- RDMA/nldev: Add support to get status of all counters (Kamal Heib) [2056770]
- RDMA/counter: Add optional counter support (Kamal Heib) [2056770]
- RDMA/counter: Add an is_disabled field in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/core: Add a helper API rdma_free_hw_stats_struct (Kamal Heib) [2056770]
- RDMA/bnxt_re: Fix kernel panic when trying to access bnxt_re_stat_descs (Kamal Heib) [2056770]
- RDMA/counter: Add a descriptor in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/bnxt_re: Update statistics counter name (Kamal Heib) [2056770]
- RDMA/bnxt_re: Add extended statistics counters (Kamal Heib) [2056770]
- RDMA/efa: CQ notifications (Kamal Heib) [2056770]
- RDMA/irdma: Delete unused struct irdma_bth (Kamal Heib) [2037988 2056770]
- IB/hf1: Use string_upper() instead of an open coded variant (Kamal Heib) [2056770]
- RDMA/rw: switch to dma_map_sgtable() (Kamal Heib) [2056770]
- RDMA/cma: Split apart the multiple uses of the same list heads (Kamal Heib) [2056770]
- RDMA/hfi1: Use struct_size() and flex_array_size() helpers (Kamal Heib) [2049164 2056770]
- IB/hfi1: Add ring consumer and producers traces (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove atomic completion count (Kamal Heib) [2049164 2056770]
- IB/hfi1: Tune netdev xmit cachelines (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of tx priv backpointer (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of hot path divide (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove cache and embed txreq in ring (Kamal Heib) [2049164 2056770]
- RDMA/rdmavt: Fix error code in rvt_create_qp() (Kamal Heib) [2049164 2056769]
- IB/hfi1: Fix abba locking issue with sc_disable() (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Fix kernel pointer leak (Kamal Heib) [2049164 2056769]
- RDMA/usnic: Lock VF with mutex instead of spinlock (Kamal Heib) [2056769]
- IB/hfi1: make hist static (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- IB/rdmavt: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- RDMA/irdma: Remove the repeated declaration (Kamal Heib) [2037988 2056769]
- RDMA/core/sa_query: Retry SA queries (Kamal Heib) [2056769]
- RDMA: Use the sg_table directly and remove the opencoded version from umem (Kamal Heib) [2056769]
- RDMA: switch from 'pci_' to 'dma_' API (Kamal Heib) [2056769]
- RDMA/efa: Rename vector field in efa_irq struct to irqn (Kamal Heib) [2056769]
- RDMA/efa: Remove unused cpu field from irq struct (Kamal Heib) [2056769]
- RDMA/core/sa_query: Remove unused function (Kamal Heib) [2056769]
- RDMA/hfi1: Stop using seq_get_buf in _driver_stats_seq_show (Kamal Heib) [2049164 2056769]
- RDMA/core: Create clean QP creations interface for uverbs (Kamal Heib) [2056769]
- RDMA/core: Properly increment and decrement QP usecnts (Kamal Heib) [2056769]
- RDMA/core: Configure selinux QP during creation (Kamal Heib) [2056769]
- RDMA/core: Reorganize create QP low-level functions (Kamal Heib) [2056769]
- RDMA/core: Remove protection from wrong in-kernel API usage (Kamal Heib) [2056769]
- RDMA/core: Delete duplicated and unreachable code (Kamal Heib) [2056769]
- rdma/qedr: Fix crash due to redundant release of device's qp memory (Kamal Heib) [2056769]
- RDMA: Globally allocate and release QP memory (Kamal Heib) [2056769]
- RDMA/mlx5: Rework custom driver QP type creation (Kamal Heib) [2056769]
- RDMA/rdmavt: Decouple QP and SGE lists allocations (Kamal Heib) [2049164 2056769]
- RDMA/efa: Remove double QP type assignment (Kamal Heib) [2056769]
- RDMA/hfi1: Fix typo in comments (Kamal Heib) [2049164 2056769]
- RDMA/iwpm: Rely on the rdma_nl_[un]register() to ensure that requests are valid (Kamal Heib) [2056769]
- RDMA/iwpm: Remove not-needed reference counting (Kamal Heib) [2056769]
- RDMA/hfi1: Convert from atomic_t to refcount_t on hfi1_devdata->user_refcount (Kamal Heib) [2049164 2056769]
- IB/hfi1: Adjust pkey entry in index 0 (Kamal Heib) [2049164 2056769]
- IB/hfi1: Indicate DMA wait when txq is queued for wakeup (Kamal Heib) [2049164 2056769]
- IB/core: Read subnet_prefix in ib_query_port via cache. (Kamal Heib) [2056769]
- IB/core: Shifting initialization of device->cache_lock (Kamal Heib) [2056769]
- IB/core: Updating cache for subnet_prefix in config_non_roce_gid_cache() (Kamal Heib) [2056769]
- RDMA/efa: Split hardware stats to device and port stats (Kamal Heib) [2056769]
- RDMA/siw: Convert siw_tx_hdt() to kmap_local_page() (Kamal Heib) [2056769]
- RDMA/siw: Remove kmap() (Kamal Heib) [2056769]
- lib/scatterlist: Fix wrong update of orig_nents (Kamal Heib) [2056769]
- lib/scatterlist: Provide a dedicated function to support table append (Kamal Heib) [2056769]
- PCI: mt7621: Remove unused function pcie_rmw() (Myron Stowe) [2052155]
- PCI: mt7621: Drop of_match_ptr() to avoid unused variable (Myron Stowe) [2052155]
- PCI: qcom: Fix an error handling path in 'qcom_pcie_probe()' (Myron Stowe) [2052155]
- PCI: mt7621: Rename mt7621_pci_ to mt7621_pcie_ (Myron Stowe) [2052155]
- PCI: mt7621: Add missing MODULE_LICENSE() (Myron Stowe) [2052155]
- PCI: mt7621: Move MIPS setup to pcibios_root_bridge_prepare() (Myron Stowe) [2052155]
- PCI: mt7621: Declare mt7621_pci_ops static (Myron Stowe) [2052155]
- PCI: mt7621: Convert driver into 'bool' (Myron Stowe) [2052155]
- PCI: xgene: Use PCI_VENDOR_ID_AMCC macro (Myron Stowe) [2052155]
- PCI: rcar-host: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: rcar-ep: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: qcom: Add sc8180x compatible (Myron Stowe) [2052155]
- PCI: qcom: Switch pcie_1_pipe_clk_src after PHY init in SC7280 (Myron Stowe) [2052155]
- PCI: qcom: Replace ops with struct pcie_cfg in pcie match data (Myron Stowe) [2052155]
- MAINTAINERS: Add entry for Qualcomm PCIe Endpoint driver and binding (Myron Stowe) [2052155]
- PCI: qcom-ep: Add Qualcomm PCIe Endpoint controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add Qualcomm PCIe Endpoint controller (Myron Stowe) [2052155]
- MAINTAINERS: Add Sergio Paracuellos as MT7621 PCIe maintainer (Myron Stowe) [2052155]
- PCI: mt7621: Add MediaTek MT7621 PCIe host controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add MT7621 SoC PCIe host controller (Myron Stowe) [2052155]
- staging: mt7621-pci: fix hang when nothing is connected to pcie ports (Myron Stowe) [2052155]
- PCI: kirin: Allow removing the driver (Myron Stowe) [2052155]
- PCI: kirin: De-init the dwc driver (Myron Stowe) [2052155]
- PCI: kirin: Disable clkreq during poweroff sequence (Myron Stowe) [2052155]
- PCI: kirin: Move the power-off code to a common routine (Myron Stowe) [2052155]
- PCI: kirin: Add power_off support for Kirin 960 PHY (Myron Stowe) [2052155]
- PCI: kirin: Allow building it as a module (Myron Stowe) [2052155]
- PCI: kirin: Add MODULE_* macros (Myron Stowe) [2052155]
- PCI: kirin: Add Kirin 970 compatible (Myron Stowe) [2052155]
- PCI: kirin: Support PERST# GPIOs for HiKey970 external PEX 8606 bridge (Myron Stowe) [2052155]
- PCI: kirin: Use regmap for APB registers (Myron Stowe) [2052155]
- PCI: kirin: Add support for a PHY layer (Myron Stowe) [2052155]
- PCI: kirin: Reorganize the PHY logic inside the driver (Myron Stowe) [2052155]
- PCI: imx6: Remove unused assignment to variable ret (Myron Stowe) [2052155]
- PCI: endpoint: Use sysfs_emit() in "show" functions (Myron Stowe) [2052155]
- PCI: uniphier: Serialize INTx masking/unmasking and fix the bit operation (Myron Stowe) [2052155]
- PCI: dwc: Perform host_init() before registering msi (Myron Stowe) [2052155]
- PCI: visconti: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_EP) (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_HOST) (Myron Stowe) [2052155]
- PCI: dra7xx: Get an optional clock (Myron Stowe) [2052155]
- PCI: dra7xx: Remove unused include (Myron Stowe) [2052155]
- PCI: dra7xx: Make it a kernel module (Myron Stowe) [2052155]
- PCI: dwc: Export more symbols to allow modular drivers (Myron Stowe) [2052155]
- dt-bindings: rockchip: Add DesignWare based PCIe controller (Myron Stowe) [2052155]
- PCI: cadence: Add cdns_plat_pcie_probe() missing return (Myron Stowe) [2052155]
- PCI: j721e: Fix j721e_pcie_probe() error path (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Read all 16-bits from PCIE_MSI_PAYLOAD_REG (Myron Stowe) [2052155]
- PCI: aardvark: Fix return value of MSI domain .alloc() method (Myron Stowe) [2052155]
- PCI: pci-bridge-emul: Fix emulation of W1C bits (Myron Stowe) [2052155]
- PCI: aardvark: Fix reporting Data Link Layer Link Active (Myron Stowe) [2052155]
- PCI: aardvark: Fix checking for link up via LTSSM state (Myron Stowe) [2052155]
- PCI: aardvark: Fix link training (Myron Stowe) [2052155]
- PCI: aardvark: Simplify initialization of rootcap on virtual bridge (Myron Stowe) [2052155]
- PCI: aardvark: Do not unmask unused interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Do not clear status bits of masked interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Fix configuring Reference clock (Myron Stowe) [2052155]
- PCI: aardvark: Don't spam about PIO Response Status (Myron Stowe) [2052155]
- PCI: aardvark: Fix PCIe Max Payload Size setting (Myron Stowe) [2052155]
- PCI: Add PCI_EXP_DEVCTL_PAYLOAD_* macros (Myron Stowe) [2052155]
- PCI: vmd: Drop redundant includes of <asm/device.h>, <asm/msi.h> (Myron Stowe) [2052155]
- PCI: cpqphp: Use <linux/io.h> instead of <asm/io.h> (Myron Stowe) [2052155]
- MAINTAINERS: Update PCI subsystem information (Myron Stowe) [2052155]
- PCI: Prefer 'unsigned int' over bare 'unsigned' (Myron Stowe) [2052155]
- PCI: Remove redundant 'rc' initialization (Myron Stowe) [2052155]
- PCI: Remove unused pci_pool wrappers (Myron Stowe) [2052155]
- PCI: cpqphp: Format if-statement code block correctly (Myron Stowe) [2052155]
- PCI: Use unsigned to match sscanf("%%x") in pci_dev_str_match_path() (Myron Stowe) [2052155]
- PCI: Correct misspelled and remove duplicated words (Myron Stowe) [2052155]
- PCI: Tidy comments (Myron Stowe) [2052155]
- cxgb3: Remove seeprom_write and use VPD API (Myron Stowe) [2052155]
- cxgb3: Use VPD API in t3_seeprom_wp() (Myron Stowe) [2052155]
- cxgb3: Remove t3_seeprom_read and use VPD API (Myron Stowe) [2052155]
- PCI/VPD: Use pci_read_vpd_any() in pci_vpd_size() (Myron Stowe) [2052155]
- PCI/VPD: Add pci_read/write_vpd_any() (Myron Stowe) [2052155]
- PCI: Add ACS quirk for Pericom PI7C9X2G switches (Myron Stowe) [2052155]
- PCI: Mark Atheros QCA6174 to avoid bus reset (Myron Stowe) [2052155]
- PCI: Use kstrtobool() directly, sans strtobool() wrapper (Myron Stowe) [2052155]
- PCI/sysfs: Return -EINVAL consistently from "store" functions (Myron Stowe) [2052155]
- PCI/sysfs: Check CAP_SYS_ADMIN before parsing user input (Myron Stowe) [2052155]
- PCI/switchtec: Add check of event support (Myron Stowe) [2052155]
- PCI/switchtec: Replace ENOTSUPP with EOPNOTSUPP (Myron Stowe) [2052155]
- PCI/switchtec: Update the way of getting management VEP instance ID (Myron Stowe) [2052155]
- PCI/switchtec: Fix a MRPC error status handling issue (Myron Stowe) [2052155]
- PCI/switchtec: Error out MRPC execution when MMIO reads fail (Myron Stowe) [2052155]
- PCI: Coalesce host bridge contiguous apertures (Myron Stowe) [2052155]
- PCI/P2PDMA: Apply bus offset correctly in DMA address calculation (Myron Stowe) [2052155]
- PCI/sysfs: Explicitly show first MSI IRQ for 'irq' (Myron Stowe) [2052155]
- PCI: Document /sys/bus/pci/devices/.../irq (Myron Stowe) [2052155]
- PCI/ERR: Reduce compile time for CONFIG_PCIEAER=n (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused pcie_port_bus_{,un}register() declarations (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused resume err_handler (Myron Stowe) [2052155]
- PCI: pciehp: Ignore Link Down/Up caused by error-induced Hot Reset (Myron Stowe) [2052155]
- PCI/portdrv: Rename pm_iter() to pcie_port_device_iter() (Myron Stowe) [2052155]
- x86/pci/probe_roms: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- perf/x86/intel/uncore: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- powerpc/eeh: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- usb: xhci: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- xen/pcifront: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- xen/pcifront: Drop pcifront_common_process() tests of pcidev, pdrv (Myron Stowe) [2052155]
- nfp: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- mlxsw: pci: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: marvell: prestera: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: hns3: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- crypto: hisilicon - use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- powerpc/eeh: Use dev_driver_string() instead of struct pci_dev->driver->name (Myron Stowe) [2052155]
- ssb: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- bcma: simplify reference to driver name (Myron Stowe) [2052155]
- scsi: message: fusion: Remove unused mpt_pci driver .probe() 'id' parameter (Myron Stowe) [2052155]
- PCI/ERR: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- PCI: Drop pci_device_probe() test of !pci_dev->driver (Myron Stowe) [2052155]
- PCI: Drop pci_device_remove() test of pci_dev->driver (Myron Stowe) [2052155]
- PCI: Return NULL for to_pci_driver(NULL) (Myron Stowe) [2052155]
- PCI: Do not enable AtomicOps on VFs (Myron Stowe) [2052155]
- PCI: Rename pcibios_add_device() to pcibios_device_add() (Myron Stowe) [2052155]
- PCI: Re-enable Downstream Port LTR after reset or hotplug (Myron Stowe) [2052155]
- rcu-tasks: Fix computation of CPU-to-list shift counts (Waiman Long) [2065994]
- torture: Properly redirect kvm-remote.sh "echo" commands (Waiman Long) [2065994]
- torture: Fix incorrectly redirected "exit" in kvm-remote.sh (Waiman Long) [2065994]
- rcu/exp: Mark current CPU as exp-QS in IPI loop second pass (Waiman Long) [2065994]
- rcu-tasks: Use fewer callbacks queues if callback flood ends (Waiman Long) [2065994]
- rcu-tasks: Use separate ->percpu_dequeue_lim for callback dequeueing (Waiman Long) [2065994]
- rcutorture: Test RCU Tasks lock-contention detection (Waiman Long) [2065994]
- rcu-tasks: Use more callback queues if contention encountered (Waiman Long) [2065994]
- rcu-tasks: Avoid raw-spinlocked wakeups from call_rcu_tasks_generic() (Waiman Long) [2065994]
- rcutorture: Combine n_max_cbs from all kthreads in a callback flood (Waiman Long) [2065994]
- rcutorture: Add ability to limit callback-flood intensity (Waiman Long) [2065994]
- rcutorture: Cause TREE02 and TREE10 scenarios to do more callback flooding (Waiman Long) [2065994]
- rcutorture: Enable multiple concurrent callback-flood kthreads (Waiman Long) [2065994]
- rcu/nocb: Merge rcu_spawn_cpu_nocb_kthread() and rcu_spawn_one_nocb_kthread() (Waiman Long) [2065994]
- rcu/nocb: Allow empty "rcu_nocbs" kernel parameter (Waiman Long) [2065994]
- rcu/nocb: Create kthreads on all CPUs if "rcu_nocbs=" or "nohz_full=" are passed (Waiman Long) [2065994]
- rcu/nocb: Optimize kthreads and rdp initialization (Waiman Long) [2065994]
- rcu/nocb: Prepare nocb_cb_wait() to start with a non-offloaded rdp (Waiman Long) [2065994]
- rcu/nocb: Remove rcu_node structure from nocb list when de-offloaded (Waiman Long) [2065994]
- rcu-tasks: Count trylocks to estimate call_rcu_tasks() contention (Waiman Long) [2065994]
- torture: Retry download once before giving up (Waiman Long) [2065994]
- rcutorture: Add CONFIG_PREEMPT_DYNAMIC=n to tiny scenarios (Waiman Long) [2065994]
- rcu: Avoid alloc_pages() when recording stack (Waiman Long) [2065994]
- rcu: Avoid running boost kthreads on isolated CPUs (Waiman Long) [2065994]
- rcutorture: Test RCU-tasks multiqueue callback queueing (Waiman Long) [2065994]
- rcu-tasks: Add rcupdate.rcu_task_enqueue_lim to set initial queueing (Waiman Long) [2065994]
- rcu-tasks: Make rcu_barrier_tasks*() handle multiple callback queues (Waiman Long) [2065994]
- rcu-tasks: Use workqueues for multiple rcu_tasks_invoke_cbs() invocations (Waiman Long) [2065994]
- torture: Make kvm-find-errors.sh report link-time undefined symbols (Waiman Long) [2065994]
- rcutorture: Avoid soft lockup during cpu stall (Waiman Long) [2065994]
- rcu-tasks: Abstract invocations of callbacks (Waiman Long) [2065994]
- rcu-tasks: Abstract checking of callback lists (Waiman Long) [2065994]
- rcu-tasks: Add a ->percpu_enqueue_lim to the rcu_tasks structure (Waiman Long) [2065994]
- rcu-tasks: Inspect stalled task's trc state in locked state (Waiman Long) [2065994]
- rcu-tasks: Use spin_lock_rcu_node() and friends (Waiman Long) [2065994]
- rcu_tasks: Convert bespoke callback list to rcu_segcblist structure (Waiman Long) [2065994]
- rcu-tasks: Convert grace-period counter to grace-period sequence number (Waiman Long) [2065994]
- rcu-tasks: Introduce ->percpu_enqueue_shift for dynamic queue selection (Waiman Long) [2065994]
- rcu-tasks: Create per-CPU callback lists (Waiman Long) [2065994]
- locktorture,rcutorture,torture: Always log error message (Waiman Long) [2065994]
- scftorture: Always log error message (Waiman Long) [2065994]
- doc: RCU: Avoid 'Symbol' font-family in SVG figures (Waiman Long) [2065994]
- rcuscale: Always log error message (Waiman Long) [2065994]
- scftorture: Account for weight_resched when checking for all zeroes (Waiman Long) [2065994]
- scftorture: Remove unused SCFTORTOUT (Waiman Long) [2065994]
- scftorture: Add missing '\n' to flush message (Waiman Long) [2065994]
- refscale: Add missing '\n' to flush message (Waiman Long) [2065994]
- doc: Add refcount analogy to What is RCU (Waiman Long) [2065994]
- refscale: Always log the error message (Waiman Long) [2065994]
- refscale: Prevent buffer to pr_alert() being too long (Waiman Long) [2065994]
- refscale: Simplify the errexit checkpoint (Waiman Long) [2065994]
- rcu: Improve tree_plugin.h comments and add code cleanups (Waiman Long) [2065994]
- rcu/nocb: Don't invoke local rcu core on callback overload from nocb kthread (Waiman Long) [2065994]
- rcu: Apply callbacks processing time limit only on softirq (Waiman Long) [2065994]
- rcu: Fix callbacks processing time limit retaining cond_resched() (Waiman Long) [2065994]
- rcu/nocb: Limit number of softirq callbacks only on softirq (Waiman Long) [2065994]
- rcu/nocb: Use appropriate rcu_nocb_lock_irqsave() (Waiman Long) [2065994]
- rcu/nocb: Check a stable offloaded state to manipulate qlen_last_fqs_check (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration (de-)offloading safe (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration preempt-safe (Waiman Long) [2065994]
- rcu/nocb: Invoke rcu_core() at the start of deoffloading (Waiman Long) [2065994]
- rcu/nocb: Prepare state machine for a new step (Waiman Long) [2065994]
- rcu/nocb: Make local rcu_nocb_lock_irqsave() safe against concurrent deoffloading (Waiman Long) [2065994]
- rcu: Make idle entry report expedited quiescent states (Waiman Long) [2065994]
- rcu: Prevent expedited GP from enabling tick on offline CPU (Waiman Long) [2065994]
- rcu: Mark sync_sched_exp_online_cleanup() ->cpu_no_qs.b.exp load (Waiman Long) [2065994]
- rcu: Always inline rcu_dynticks_task*_{enter,exit}() (Waiman Long) [2065994]
- rcu: in_irq() cleanup (Waiman Long) [2065994]
- doc: Remove obsolete kernel-per-CPU-kthreads RCU_FAST_NO_HZ advice (Waiman Long) [2065994]
- rcutorture: Suppress pi-lock-across read-unlock testing for Tiny SRCU (Waiman Long) [2065994]
- srcu: Prevent redundant __srcu_read_unlock() wakeup (Waiman Long) [2065994]
- rcutorture: More thoroughly test nested readers (Waiman Long) [2065994]
- rcutorture: Sanitize RCUTORTURE_RDR_MASK (Waiman Long) [2065994]
- torture: Catch kvm.sh help text up with actual options (Waiman Long) [2065994]
- rcu-tasks: Don't remove tasks with pending IPIs from holdout list (Waiman Long) [2065994]
- rcu: Remove rcu_data.exp_deferred_qs and convert to rcu_data.cpu no_qs.b.exp (Waiman Long) [2065994]
- rcu: Move rcu_data.cpu_no_qs.b.exp reset to rcu_export_exp_rdp() (Waiman Long) [2065994]
- rcu: Ignore rdp.cpu_no_qs.b.exp on preemptible RCU's rcu_qs() (Waiman Long) [2065994]
- rcu-tasks: Update comments to cond_resched_tasks_rcu_qs() (Waiman Long) [2065994]
- rcu: Replace ________p1 and _________p1 with __UNIQUE_ID(rcu) (Waiman Long) [2065994]
- rcu-tasks: Fix IPI failure handling in trc_wait_for_one_reader (Waiman Long) [2065994]
- rcu-tasks: Fix read-side primitives comment for call_rcu_tasks_trace (Waiman Long) [2065994]
- rcutorture: Avoid problematic critical section nesting on PREEMPT_RT (Waiman Long) [2065994]
- rcu: Fix existing exp request check in sync_sched_exp_online_cleanup() (Waiman Long) [2065994]
- rcu-tasks: Clarify read side section info for rcu_tasks_rude GP primitives (Waiman Long) [2065994]
- rcu-tasks: Correct comparisons for CPU numbers in show_stalled_task_trace (Waiman Long) [2065994]
- rcu-tasks: Correct firstreport usage in check_all_holdout_tasks_trace (Waiman Long) [2065994]
- rcu-tasks: Fix s/rcu_add_holdout/trc_add_holdout/ typo in comment (Waiman Long) [2065994]
- rcu-tasks: Move RTGS_WAIT_CBS to beginning of rcu_tasks_kthread() loop (Waiman Long) [2065994]
- rcu: Make rcu update module parameters world-readable (Waiman Long) [2065994]
- rcu: Make rcu_normal_after_boot writable again (Waiman Long) [2065994]
- rcutorture: Don't cpuhp_remove_state() if cpuhp_setup_state() failed (Waiman Long) [2065994]
- rcuscale: Warn on individual rcu_scale_init() error conditions (Waiman Long) [2065994]
- locktorture: Warn on individual lock_torture_init() error conditions (Waiman Long) [2065994]
- rcutorture: Warn on individual rcu_torture_init() error conditions (Waiman Long) [2065994]
- rcu-tasks: Fix s/instruction/instructions/ typo in comment (Waiman Long) [2065994]
- rcutorture: Suppressing read-exit testing is not an error (Waiman Long) [2065994]
- rcu-tasks: Wait for trc_read_check_handler() IPIs (Waiman Long) [2065994]
- rcu: Make rcutree_dying_cpu() use its "cpu" parameter (Waiman Long) [2065994]
- rcu: Simplify rcu_report_dead() call to rcu_report_exp_rdp() (Waiman Long) [2065994]
- rcu: Move rcu_dynticks_eqs_online() to rcu_cpu_starting() (Waiman Long) [2065994]
- rcu-tasks: Remove second argument of rcu_read_unlock_trace_special() (Waiman Long) [2065994]
- rcu-tasks: Add trc_inspect_reader() checks for exiting critical section (Waiman Long) [2065994]
- rcu-tasks: Simplify trc_read_check_handler() atomic operations (Waiman Long) [2065994]
- rcu: Comment rcu_gp_init() code waiting for CPU-hotplug operations (Waiman Long) [2065994]
- rcu: Fix undefined Kconfig macros (Waiman Long) [2065994]
- doc: Add another stall-warning root cause in stallwarn.rst (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable ruqp (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable rnhqp (Waiman Long) [2065994]
- rcu-nocb: Fix a couple of tree_nocb code-style nits (Waiman Long) [2065994]
- torture: Make torture.sh print the number of files to be compressed (Waiman Long) [2065994]
- torture: Apply CONFIG_KCSAN_STRICT to kvm.sh --kcsan argument (Waiman Long) [2065994]
- x86/tsc: Disable clocksource watchdog for TSC on qualified platorms (David Arcari) [2057923]
- x86/tsc: Add a timer to make sure TSC_adjust is always checked (David Arcari) [2057923]
- Revert "xfs: actually bump warning counts when we send warnings" (Carlos Maiolino) [2060081]
- vfs: check dentry is still valid in get_link() (Ian Kent) [2048567]
- xfs: don't expose internal symlink metadata buffers to the vfs (Ian Kent) [2048567]
- audit: log AUDIT_TIME_* records only from rules (Richard Guy Briggs) [2035124]
- audit: don't deref the syscall args when checking the openat2 open_how::flags (Richard Guy Briggs) [2035124]
- audit: improve audit queue handling when "audit=1" on cmdline (Richard Guy Briggs) [2035124]
- audit: replace zero-length array with flexible-array member (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in audit_[send|make]_reply() (Richard Guy Briggs) [2035124]
- audit: ensure userspace is penalized the same as the kernel when under pressure (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in kmalloc() (Richard Guy Briggs) [2035124]
- audit: improve robustness of the audit queue handling (Richard Guy Briggs) [2035124]
- fsnotify: clarify contract for create event hooks (Richard Guy Briggs) [2035124]
- fsnotify: pass dentry instead of inode data (Richard Guy Briggs) [2035124]
- fsnotify: pass data_type to fsnotify_name() (Richard Guy Briggs) [2035124]
- fsnotify: fix sb_connectors leak (Richard Guy Briggs) [2035124]
- fsnotify: optimize the case of no marks of any type (Richard Guy Briggs) [2035124]
- fsnotify: count all objects with attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: count s_fsnotify_inode_refs for attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: replace igrab() with ihold() on attach connector (Richard Guy Briggs) [2035124]
- audit: return early if the filter rule has a lower priority (Richard Guy Briggs) [2035124]
- audit: add OPENAT2 record to list "how" info (Richard Guy Briggs) [2035124]
- audit: add support for the openat2 syscall (Richard Guy Briggs) [2035124]
- audit: replace magic audit syscall class numbers with macros (Richard Guy Briggs) [2035124]
- lsm_audit: avoid overloading the "key" audit field (Richard Guy Briggs) [2035124]
- audit: Convert to SPDX identifier (Richard Guy Briggs) [2035124]
- audit: rename struct node to struct audit_node to prevent future name collisions (Richard Guy Briggs) [2035124]
- audit: add filtering for io_uring records (Richard Guy Briggs) [2035124]
- audit,io_uring,io-wq: add some basic audit support to io_uring (Richard Guy Briggs) [2035124]
- audit: prepare audit_context for use in calling contexts beyond syscalls (Richard Guy Briggs) [2035124]
- audit: fix possible null-pointer dereference in audit_filter_rules (Richard Guy Briggs) [2035124]
- audit: add header protection to kernel/audit.h (Richard Guy Briggs) [2035124]

* Mon Apr 11 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-78.el9]
- CI: Remove deprecated option (Veronika Kabatova)
- scsi: iscsi: Fix nop handling during conn recovery (Chris Leech) [2069973]
- scsi: iscsi: Merge suspend fields (Chris Leech) [2069973]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2069973]
- scsi: iscsi: Move iscsi_ep_disconnect (Chris Leech) [2069973]
- NFS: Don't loop forever in nfs_do_recoalesce() (Steve Dickson) [2069274]
- perf/x86/intel/uncore: Make uncore_discovery clean for 64 bit addresses (Michael Petlan) [2069686]
- KVM: SVM: Allow AVIC support on system w/ physical APIC ID > 255 (Bandan Das) [2033070]
- iommu/amd: Fix I/O page table memory leak (Jerry Snitselaar) [2053219]
- iommu/amd: Recover from event log overflow (Jerry Snitselaar) [2053219]
- redhat/configs: drop some config options for rhel 9. (David Airlie) [2067027]
- arm64: proton-pack: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Use the clearbhb instruction in mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered and migrated (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Mitigate spectre style branch history side channels (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part of Spectre-v2 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add percpu vectors for EL1 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add macro for reading symbol addresses from the trampoline (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add vectors that have the bhb mitigation sequences (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow the trampoline text to occupy multiple pages (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the kpti trampoline's kpti sequence optional (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move trampoline macros out of ifdef'd section (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Don't assume tramp_vectors is the start of the vectors (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow tramp_alias to access symbols after the 4K boundary (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move the trampoline data page before the text page (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Free up another register on kpti's tramp_exit path (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the trampoline cleanup optional (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow indirect vectors to be used without SPECTRE_V3A (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: spectre: Rename spectre_v4_patch_fw_mitigation_conduit (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry.S: Add ventry overflow sanity checks (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-A510 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-X2 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_RPRES (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: add ID_AA64ISAR2_EL1 sys register (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_AFP (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Neoverse-N2, Cortex-A710 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add HWCAP for self-synchronising virtual counter (Waiman Long) [2062288] {CVE-2022-23960}
- iommu/vt-d: Fix double list_add when enabling VMD in scalable mode (Jerry Snitselaar) [2061621]
- redhat/configs: remove unnecessary GPIO options for aarch64 (Brian Masney) [2060951]
- redhat/configs: remove viperboard related Kconfig options (Brian Masney) [2060951]
- configs: enable CONFIG_RMI4_F3A (Benjamin Tissoires) [2067243]
- block: release rq qos structures for queue without disk (Ming Lei) [2065610]
- fuse: fix pipe buffer lifetime for direct_io (Miklos Szeredi) [2064862] {CVE-2022-1011}
- crypto: hmac - disallow keys < 112 bits in FIPS mode (Herbert Xu) [2033512]
- crypto: hmac - add fips_skip support (Herbert Xu) [2033512]
- crypto: des - disallow des3 in FIPS mode (Herbert Xu) [2033512]
- crypto: dh - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- crypto: rsa - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- watch_queue: Make comment about setting ->defunct more accurate (David Howells) [2063758]
- watch_queue: Fix lack of barrier/sync/lock between post and read (David Howells) [2063758]
- watch_queue: Free the alloc bitmap when the watch_queue is torn down (David Howells) [2063758]
- watch_queue: Fix the alloc bitmap size to reflect notes allocated (David Howells) [2063758]
- watch_queue: Use the bitmap API when applicable (David Howells) [2063758]
- watch_queue: Fix to always request a pow-of-2 pipe ring size (David Howells) [2063758]
- watch_queue: Fix to release page in ->release() (David Howells) [2063758]
- watch_queue, pipe: Free watchqueue state after clearing pipe ring (David Howells) [2063758]
- watch_queue: Fix filter limit check (David Howells) [2063758] {CVE-2022-0995}
- s390/mm: check 2KB-fragment page on release (Rafael Aquini) [2069978]
- s390/mm: better annotate 2KB pagetable fragments handling (Rafael Aquini) [2069978]
- s390/mm: fix 2KB pgtable release race (Rafael Aquini) [2069978]
- ima: fix deadlock when traversing "ima_default_rules". (Bruno Meneguele) [2063913]
- IMA: prevent SETXATTR_CHECK policy rules with unavailable algorithms (Bruno Meneguele) [2063913]
- IMA: introduce a new policy option func=SETXATTR_CHECK (Bruno Meneguele) [2063913]
- IMA: add a policy option to restrict xattr hash algorithms on appraisal (Bruno Meneguele) [2063913]
- IMA: add support to restrict the hash algorithms used for file appraisal (Bruno Meneguele) [2063913]
- IMA: block writes of the security.ima xattr with unsupported algorithms (Bruno Meneguele) [2063913]
- IMA: remove the dependency on CRYPTO_MD5 (Bruno Meneguele) [2063913]
- perf symbols: Fix symbol size calculation condition (Michael Petlan) [2049222]
- redhat/Makefile: Fix dist-dump-variables target (Prarit Bhargava)
- redhat/configs/process_configs.sh: Avoid race with find (Prarit Bhargava)
- redhat/configs/process_configs.sh: Remove CONTINUEONERROR (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix race with tools generation (Prarit Bhargava)
- redhat/Makefile: Silence dist-clean-configs output (Prarit Bhargava)
- Print arch with process_configs errors (Prarit Bhargava)
- Pass RHJOBS to process_configs for dist-configs-check as well (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix issue with old error files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/build_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/build_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Add local variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/process_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/process_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add processing config function (Prarit Bhargava)
- cifs: modefromsids must add an ACE for authenticated users (Ronnie Sahlberg) [1988278]

* Thu Apr 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-77.el9]
- NFSD: Fix offset type in I/O trace points (Benjamin Coddington) [2063045]
- NFSD: COMMIT operations must not return NFS?ERR_INVAL (Benjamin Coddington) [2063045]
- NFSD: Clamp WRITE offsets (Benjamin Coddington) [2063045]
- NFSD: Fix NFSv3 SETATTR/CREATE's handling of large file sizes (Benjamin Coddington) [2063045]
- NFSD: Fix ia_size underflow (Benjamin Coddington) [2063045]
- NFSD: Fix the behavior of READ near OFFSET_MAX (Benjamin Coddington) [2063045]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2054100]
- Revert "include/linux/ioport.h: Pad resource struct for KABI" (Prarit Bhargava) [2055736]
- powerpc/pseries: Fix use after free in remove_phb_dynamic() (Prarit Bhargava) [2055736]
- lib/sbitmap: kill 'depth' from sbitmap_word (Ming Lei) [2064695]
- KVM: use __vcalloc for very large allocations (David Hildenbrand) [2057367]
- mm: use vmalloc_array and vcalloc for array allocations (David Hildenbrand) [2057367]
- mm: vmalloc: introduce array allocation functions (David Hildenbrand) [2057367]
- tpm: fix potential NULL pointer access in tpm_del_char_device (Desnes A. Nunes do Rosario) [2032117]
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF + SMT (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Warn about Spectre v2 LFENCE mitigation (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Update link to AMD speculation whitepaper (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Use generic retpoline by default on AMD (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Add eIBRS + Retpoline options (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86: deduplicate the spectre_v2_user documentation (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- redhat/configs: aarch64: Enable ARM_SPE_PMU (Mark Salter) [2063234]
- drm/i915/audio: Use BIOS provided value for RKL HDA link (Mika Penttilä) [2046691]
- redhat: configs: Disable TPM 1.2 device drivers (Jerry Snitselaar) [2060516]
- redhat: configs: Change aarch64 default dma domain to lazy (Jerry Snitselaar) [2050415]
- powerpc/64s/hash: Make hash faults work in NMI context (Desnes A. Nunes do Rosario) [2062762]
- CI: Remove deprecated option (Veronika Kabatova)
- redhat/configs: make SHA512_arch algos and CRYPTO_USER built-ins (Vladis Dronov) [2070624]
- futex: Fix PREEMPT_RT build (Fernando Pacheco) [2070369]
- crypto: ccp - ccp_dmaengine_unregister release dma channels (Vladis Dronov) [2047836]
- crypto: ccp - remove redundant ret variable (Vladis Dronov) [2047836]
- crypto: ccp - Ensure psp_ret is always init'd in __sev_platform_init_locked() (Vladis Dronov) [2047836]
- crypto: ccp - remove unneeded semicolon (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT_EX support (Vladis Dronov) [2047836]
- crypto: ccp - Add psp_init_on_probe module parameter (Vladis Dronov) [2047836]
- crypto: ccp - Refactor out sev_fw_alloc() (Vladis Dronov) [2047836]
- crypto: ccp - Move SEV_INIT retry for corrupted data (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT rc error logging on init (Vladis Dronov) [2047836]
- crypto: ccp - no need to initialise statics to 0 (Vladis Dronov) [2047836]
- perf tests attr: Add missing topdown metrics events (Michael Petlan) [2062513]
- powerpc/papr_scm: Implement initial support for injecting smart errors (Steve Best) [1873827]
- redhat/koji/Makefile: Decouple koji Makefile from Makefile.common (Andrea Claudi) [2037486]
- redhat: fix make {distg-brew,distg-koji} (Andrea Claudi) [2037486]
- mm: memcg: synchronize objcg lists with a dedicated spinlock (Waiman Long) [2046537]
- mm: memcontrol: remove the kmem states (Waiman Long) [2046537]
- mm: memcontrol: remove kmemcg_id reparenting (Waiman Long) [2046537]
- mm/memcg: remove obsolete memcg_free_kmem() (Waiman Long) [2046537]
- PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled() (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for MEM resource type (Myron Stowe) [2045254]
- PCI/MSI: Move non-mask check back into low level accessors (Myron Stowe) [2045254]
- PCI: aardvark: Implement re-issuing config requests on CRS response (Myron Stowe) [2045254]
- PCI: aardvark: Deduplicate code in advk_pcie_rd_conf() (Myron Stowe) [2045254]
- PCI: aardvark: Fix preserving PCI_EXP_RTCTL_CRSSVE flag on emulated bridge (Myron Stowe) [2045254]
- PCI: ACPI: Drop acpi_pci_bus (Myron Stowe) [2045254]
- ACPI: glue: Eliminate acpi_platform_notify() (Myron Stowe) [2045254]
- ACPI: bus: Rename functions to avoid name collision (Myron Stowe) [2045254]
- ACPI: glue: Change return type of two functions to void (Myron Stowe) [2045254]
- ACPI: glue: Rearrange acpi_device_notify() (Myron Stowe) [2045254]
- PCI/MSI: Handle msi_populate_sysfs() errors correctly (Myron Stowe) [2045254]
- MAINTAINERS: Add Nirmal Patel as VMD maintainer (Myron Stowe) [2045254]
- PCI: Add AMD GPU multi-function power dependencies (Myron Stowe) [2045254]
- tools: PCI: Zero-initialize param (Myron Stowe) [2045254]
- PCI: controller: PCI_IXP4XX should depend on ARCH_IXP4XX (Myron Stowe) [2045254]
- Documentation: PCI: endpoint/pci-endpoint-cfs: Guide to use SR-IOV (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Populate sriov_configure ops to configure SR-IOV device (Myron Stowe) [2045254]
- PCI: cadence: Add support to configure virtual functions (Myron Stowe) [2045254]
- PCI: cadence: Simplify code to get register base address for configuring BAR (Myron Stowe) [2045254]
- PCI: endpoint: Add virtual function number in pci_epc ops (Myron Stowe) [2045254]
- PCI: endpoint: Add support to link a physical function to a virtual function (Myron Stowe) [2045254]
- PCI: endpoint: Add support to add virtual function in endpoint core (Myron Stowe) [2045254]
- dt-bindings: PCI: pci-ep: Add binding to specify virtual function (Myron Stowe) [2045254]
- PCI: xilinx-nwl: Enable the clock through CCF (Myron Stowe) [2045254]
- dt-bindings: pci: xilinx-nwl: Document optional clock property (Myron Stowe) [2045254]
- PCI: xgene-msi: Remove redundant dev_err() call in xgene_msi_probe() (Myron Stowe) [2045254]
- PCI: tegra194: Cleanup unused code (Myron Stowe) [2045254]
- PCI: tegra194: Don't allow suspend when Tegra PCIe is in EP mode (Myron Stowe) [2045254]
- PCI: tegra194: Disable interrupts before entering L2 (Myron Stowe) [2045254]
- PCI: tegra194: Fix MSI-X programming (Myron Stowe) [2045254]
- PCI: tegra194: Fix handling BME_CHGED event (Myron Stowe) [2045254]
- PCI: tegra: make const array err_msg static (Myron Stowe) [2045254]
- PCI: tegra: Use 'seq_puts' instead of 'seq_printf' (Myron Stowe) [2045254]
- PCI: tegra: Fix OF node reference leak (Myron Stowe) [2045254]
- PCI: tegra: Remove unused struct tegra_pcie_bus (Myron Stowe) [2045254]
- PCI: rcar: Add L1 link state fix into data abort hook (Myron Stowe) [2045254]
- PCI: rcar: Fix runtime PM imbalance in rcar_pcie_ep_probe() (Myron Stowe) [2045254]
- PCI: mediatek: Use PCI domain to handle ports detection (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get irq number (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get shared pcie-cfg base address (Myron Stowe) [2045254]
- dt-bindings: PCI: mediatek: Update the Device tree bindings (Myron Stowe) [2045254]
- PCI: keembay: Add support for Intel Keem Bay (Myron Stowe) [2045254]
- dt-bindings: PCI: Add Intel Keem Bay PCIe controller (Myron Stowe) [2045254]
- PCI: iproc: Fix BCMA probe resource handling (Myron Stowe) [2045254]
- PCI: of: Don't fail devm_pci_alloc_host_bridge() on missing 'ranges' (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Add deviceID for AM64 and J7200 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for AM64 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for J7200 (Myron Stowe) [2045254]
- PCI: cadence: Add quirk flag to set minimum delay in LTSSM Detect.Quiet state (Myron Stowe) [2045254]
- PCI: cadence: Use bitfield for *quirk_retrain_flag* instead of bool (Myron Stowe) [2045254]
- PCI: aardvark: Fix masking and unmasking legacy INTx interrupts (Myron Stowe) [2045254]
- PCI: aardvark: Configure PCIe resources from 'ranges' DT property (Myron Stowe) [2045254]
- PCI: aardvark: Fix reporting CRS value (Myron Stowe) [2045254]
- PCI: pci-bridge-emul: Add PCIe Root Capabilities Register (Myron Stowe) [2045254]
- PCI: aardvark: Increase polling delay to 1.5s while waiting for PIO response (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for PIO status (Myron Stowe) [2045254]
- MAINTAINERS: Add entries for Toshiba Visconti PCIe controller (Myron Stowe) [2045254]
- PCI: visconti: Add Toshiba Visconti PCIe host controller driver (Myron Stowe) [2045254]
- PCI: rockchip-dwc: Add Rockchip RK356X host controller driver (Myron Stowe) [2045254]
- PCI: dwc: Remove surplus break statement after return (Myron Stowe) [2045254]
- PCI: artpec6: Remove local code block from switch statement (Myron Stowe) [2045254]
- PCI: artpec6: Remove surplus break statement after return (Myron Stowe) [2045254]
- x86/PCI: sta2x11: switch from 'pci_' to 'dma_' API (Myron Stowe) [2045254]
- PCI: Sync __pci_register_driver() stub for CONFIG_PCI=n (Myron Stowe) [2045254]
- PCI: Add schedule point in proc_bus_pci_read() (Myron Stowe) [2045254]
- PCI: Correct the pci_iomap.h header guard #endif comment (Myron Stowe) [2045254]
- PCI/PTM: Remove error message at boot (Myron Stowe) [2045254]
- PCI: Fix pci_dev_str_match_path() alloc while atomic bug (Myron Stowe) [2045254]
- x86/PCI: Add pci_numachip_init() declaration (Myron Stowe) [2045254]
- PCI/ACS: Enforce pci=noats with Transaction Blocking (Myron Stowe) [2045254]
- PCI: Add ACS quirks for Cavium multi-function devices (Myron Stowe) [2045254]
- PCI: Add ACS quirks for NXP LX2xx0 and LX2xx2 platforms (Myron Stowe) [2045254]
- PCI: Optimize pci_resource_len() to reduce kernel size (Myron Stowe) [2045254]
- PCI: Refactor pci_ioremap_bar() and pci_ioremap_wc_bar() (Myron Stowe) [2045254]
- PCI/portdrv: Enable Bandwidth Notification only if port supports it (Myron Stowe) [2045254]
- PCI: Bulk conversion to generic_handle_domain_irq() (Myron Stowe) [2045254]
- PCI: Set dma-can-stall for HiSilicon chips (Myron Stowe) [2045254]
- PCI: ibmphp: Fix double unmap of io_mem (Myron Stowe) [2045254]
- PCI: Return int from pciconfig_read() syscall (Myron Stowe) [2045254]
- PCI: Return ~0 data on pciconfig_read() CAP_SYS_ADMIN failure (Myron Stowe) [2045254]
- PCI: Restrict ASMedia ASM1062 SATA Max Payload Size Supported (Myron Stowe) [2045254]
- PCI: Call Max Payload Size-related fixup quirks early (Myron Stowe) [2045254]
- platform-msi: Add ABI to show msi_irqs of platform devices (Myron Stowe) [2045254]
- genirq/msi: Move MSI sysfs handling from PCI to MSI core (Myron Stowe) [2045254]
- genirq/timings: Fix error return code in irq_timings_test_irqs() (Myron Stowe) [2045254]
- PCI/MSI: Use new mask/unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Provide a new set of mask and unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Cleanup msi_mask() (Myron Stowe) [2045254]
- PCI/MSI: Deobfuscate virtual MSI-X (Myron Stowe) [2045254]
- PCI/MSI: Consolidate error handling in msi_capability_init() (Myron Stowe) [2045254]
- PCI/MSI: Rename msi_desc::masked (Myron Stowe) [2045254]
- PCI/MSI: Simplify msi_verify_entries() (Myron Stowe) [2045254]
- s390/pci: Do not mask MSI[-X] entries on teardown (Myron Stowe) [2045254]
- genirq: Improve "hwirq" output in /proc and /sys/ (Myron Stowe) [2045254]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2066225]
- ibmvnic: Allow queueing resets during probe (Diego Domingos) [2058835]
- ibmvnic: clear fop when retrying probe (Diego Domingos) [2058835]
- ibmvnic: init init_done_rc earlier (Diego Domingos) [2058835]
- ibmvnic: register netdev after init of adapter (Diego Domingos) [2058835]
- ibmvnic: complete init_done on transport events (Diego Domingos) [2058835]
- ibmvnic: define flush_reset_queue helper (Diego Domingos) [2058835]
- ibmvnic: initialize rc before completing wait (Diego Domingos) [2058835]
- ibmvnic: free reset-work-item when flushing (Diego Domingos) [2058835]
- powerpc/smp: Update cpu_core_map on all PowerPc systems (Diego Domingos) [2063682]
- nvmet: revert "nvmet: make discovery NQN configurable" (Gopal Tiwari) [2066146]
- nvme-tcp: send H2CData PDUs based on MAXH2CDATA (Gopal Tiwari) [2066146]
- nvme: also mark passthrough-only namespaces ready in nvme_update_ns_info (Gopal Tiwari) [2066146]
- nvme: don't return an error from nvme_configure_metadata (Gopal Tiwari) [2066146]
- block: fix surprise removal for drivers calling blk_set_queue_dying (Gopal Tiwari) [2066146]
- nvme-tcp: fix bogus request completion when failing to send AER (Gopal Tiwari) [2066146]
- nvme: add nvme_complete_req tracepoint for batched completion (Gopal Tiwari) [2066146]
- nvme-fabrics: remove the unneeded ret variable in nvmf_dev_show (Gopal Tiwari) [2066146]
- nvme-pci: add the IGNORE_DEV_SUBNQN quirk for Intel P4500/P4600 SSDs (Gopal Tiwari) [2066146]
- block: introduce rq_list_for_each_safe macro (Gopal Tiwari) [2066146]
- block: move rq_list macros to blk-mq.h (Gopal Tiwari) [2066146]
- nvme: add 'iopolicy' module parameter (Gopal Tiwari) [2066146]
- nvme-fabrics: print out valid arguments when reading from /dev/nvme-fabrics (Gopal Tiwari) [2066146]
- nvme: separate command prep and issue (Gopal Tiwari) [2066146]
- nvme: split command copy into a helper (Gopal Tiwari) [2066146]
- nvmet-tcp: fix possible list corruption for unexpected command failure (Gopal Tiwari) [2066146]
- nvme: fix use after free when disconnecting a reconnecting ctrl (Gopal Tiwari) [2066146]
- nvme-multipath: set ana_log_size to 0 after free ana_log_buf (Gopal Tiwari) [2066146]
- nvme: disable namespace access for unsupported metadata (Gopal Tiwari) [2066146]
- nvme: report write pointer for a full zone as zone start + zone len (Gopal Tiwari) [2066146]
- nvme: show subsys nqn for duplicate cntlids (Gopal Tiwari) [2066146]
- nvme-pci: add NO APST quirk for Kioxia device (Gopal Tiwari) [2066146]
- nvme: fix write zeroes pi (Gopal Tiwari) [2066146]
- nvmet: use flex_array_size and struct_size (Gopal Tiwari) [2066146]
- nvmet: use struct_size over open coded arithmetic (Gopal Tiwari) [2066146]
- nvme-pci: clear shadow doorbell memory on resets (Gopal Tiwari) [2066146]
- nvmet: use macro definitions for setting cmic value (Gopal Tiwari) [2066146]
- nvme-multipath: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme-rdma: fix error code in nvme_rdma_setup_ctrl (Gopal Tiwari) [2066146]
- nvmet: use macro definition for setting nmic value (Gopal Tiwari) [2066146]
- nvmet-rdma: implement get_max_queue_size controller op (Gopal Tiwari) [2066146]
- nvmet: add get_max_queue_size op for controllers (Gopal Tiwari) [2066146]
- nvme-rdma: limit the maximal queue size for RDMA controllers (Gopal Tiwari) [2066146]
- nvme: generate uevent once a multipath namespace is operational again (Gopal Tiwari) [2066146]
- nvme-fc: add support for ->map_queues (Gopal Tiwari) [2066146]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Gopal Tiwari) [2066146]
- nvme: don't memset() the normal read/write command (Gopal Tiwari) [2066146]
- nvme: move command clear into the various setup helpers (Gopal Tiwari) [2066146]
- nvme: wire up completion batching for the IRQ path (Gopal Tiwari) [2066146]
- nvme: add support for batched completion of polled IO (Gopal Tiwari) [2066146]
- nvme-multipath: enable polled I/O (Gopal Tiwari) [2066146]
- nvme: remove the call to nvme_update_disk_info in nvme_ns_remove (Gopal Tiwari) [2066146]
- nvme-rdma: destroy cm id before destroy qp to avoid use after free (Gopal Tiwari) [2066146]
- nvme: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme: only call synchronize_srcu when clearing current path (Gopal Tiwari) [2066146]
- nvme-multipath: revalidate paths during rescan (Gopal Tiwari) [2066146]
- nvme-multipath: set QUEUE_FLAG_NOWAIT (Gopal Tiwari) [2066146]
- nvme: remove the unused NVME_NS_* enum (Gopal Tiwari) [2066146]
- nvme: remove nvm_ndev from ns (Gopal Tiwari) [2066146]
- nvme: Have NVME_FABRICS select NVME_CORE instead of transport drivers (Gopal Tiwari) [2066146]
- nvme-pci: disable hmb on idle suspend (Gopal Tiwari) [2066146]
- nvme: allow user toggling hmb usage (Gopal Tiwari) [2066146]
- nvme-fabrics: remove superfluous nvmf_host_put in nvmf_parse_options (Gopal Tiwari) [2066146]
- nvme: add set feature tracing support (Gopal Tiwari) [2066146]
- nvmet: add set feature tracing support (Gopal Tiwari) [2066146]
- nvme-pci: cmb sysfs: one file, one value (Gopal Tiwari) [2066146]
- nvme-pci: use attribute group for cmb sysfs (Gopal Tiwari) [2066146]
- remove the lightnvm subsystem (Gopal Tiwari) [2066146]
- compiler.h: Introduce absolute_pointer macro (Gopal Tiwari) [2066146]
- mm/usercopy: return 1 from hardened_usercopy __setup() handler (Rafael Aquini) [2064990]
- mm: madvise: return correct bytes advised with process_madvise (Rafael Aquini) [2064990]
- mm/thp: refix __split_huge_pmd_locked() for migration PMD (Rafael Aquini) [2064990]
- mm/mlock: fix potential imbalanced rlimit ucounts adjustment (Rafael Aquini) [2064990]
- mm/hwpoison: fix error page recovered but reported "not recovered" (Rafael Aquini) [2064990]
- mm/page_alloc: check high-order pages for corruption during PCP operations (Rafael Aquini) [2064990]
- mm/page_alloc: do not prefetch buddies during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: limit number of high-order pages on PCP during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: free pages in a single pass during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: drain the requested list first during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: simplify how many pages are selected per pcp list during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: track range of active PCP lists during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: fetch the correct pcp buddy during bulk free (Rafael Aquini) [2064990]
- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of a node (Rafael Aquini) [2064990]
- mm/page_alloc: mark pagesets as __maybe_unused (Rafael Aquini) [2064990]
- mm: Consider __GFP_NOWARN flag for oversized kvmalloc() calls (Rafael Aquini) [2064990]
- kasan: test: prevent cache merging in kmem_cache_double_destroy (Rafael Aquini) [2064990]
- mm: don't try to NUMA-migrate COW pages that have other uses (Rafael Aquini) [2064990]
- mm/debug_vm_pgtable: remove pte entry from the page table (Rafael Aquini) [2064990]
- Revert "mm/gup: small refactoring: simplify try_grab_page()" (Rafael Aquini) [2064990]
- kasan: fix quarantine conflicting with init_on_free (Rafael Aquini) [2064990]
- kasan: test: add test case for double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: add ability to detect double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: test: add globals left-out-of-bounds test (Rafael Aquini) [2064990]
- mm/slab_common: use WARN() if cache still has objects on destroy (Rafael Aquini) [2064990]
- mm: mempolicy: fix THP allocations escaping mempolicy restrictions (Rafael Aquini) [2064990]
- kfence: fix memory leak when cat kfence objects (Rafael Aquini) [2064990]
- mm/memcg: relocate mod_objcg_mlstate(), get_obj_stock() and put_obj_stock() (Rafael Aquini) [2064990]
- mm/slub: fix endianness bug for alloc/free_traces attributes (Rafael Aquini) [2064990]
- hugetlb, userfaultfd: fix reservation restore on userfaultfd error (Rafael Aquini) [2064990]
- mm/zsmalloc.c: close race window between zs_pool_dec_isolated() and zs_unregister_migration() (Rafael Aquini) [2064990]
- hugetlb: remove unnecessary set_page_count in prep_compound_gigantic_page (Rafael Aquini) [2064990]
- mm: move fold_vm_numa_events() to fix NUMA without SMP (Rafael Aquini) [2064990]
- mm/page_alloc.c: fix obsolete comment in free_pcppages_bulk() (Rafael Aquini) [2064990]
- mm/large system hash: avoid possible NULL deref in alloc_large_system_hash (Rafael Aquini) [2064990]
- lib/test_vmalloc.c: use swap() to make code cleaner (Rafael Aquini) [2064990]
- mm/vmalloc: be more explicit about supported gfp flags (Rafael Aquini) [2064990]
- vmalloc: choose a better start address in vm_area_register_early() (Rafael Aquini) [2064990]
- vmalloc: back off when the current task is OOM-killed (Rafael Aquini) [2064990]
- mm/vmalloc: check various alignments when debugging (Rafael Aquini) [2064990]
- mm/vmalloc: make sure to dump unpurged areas in /proc/vmallocinfo (Rafael Aquini) [2064990]
- mm/vmalloc: make show_numa_info() aware of hugepage mappings (Rafael Aquini) [2064990]
- mm/vmalloc: don't allow VM_NO_GUARD on vmap() (Rafael Aquini) [2064990]
- mm/vmalloc: repair warn_alloc()s in __vmalloc_area_node() (Rafael Aquini) [2064990]
- mm/mremap: don't account pages in vma_to_resize() (Rafael Aquini) [2064990]
- mm/filemap.c: remove bogus VM_BUG_ON (Rafael Aquini) [2064990]
- kasan: fix tag for large allocations when using CONFIG_SLAB (Rafael Aquini) [2064990]
- mm: don't include <linux/dax.h> in <linux/mempolicy.h> (Rafael Aquini) [2064990]
- mm: disable NUMA_BALANCING_DEFAULT_ENABLED and TRANSPARENT_HUGEPAGE on PREEMPT_RT (Rafael Aquini) [2064990]
- mm, slub: use prefetchw instead of prefetch (Rafael Aquini) [2064990]
- mm/slub: increase default cpu partial list sizes (Rafael Aquini) [2064990]
- mm, slub: change percpu partial accounting from objects to pages (Rafael Aquini) [2064990]
- slub: add back check for free nonslab objects (Rafael Aquini) [2064990]
- mm/slab.c: remove useless lines in enable_cpucache() (Rafael Aquini) [2064990]
- mm: move kvmalloc-related functions to slab.h (Rafael Aquini) [2064990]
- selftests: kvm: add amx_test to .gitignore (Paul Lai) [1924149]
- kvm: Move KVM_GET_XSAVE2 IOCTL definition at the end of kvm.h (Paul Lai) [1924149]
- kvm: selftests: sync uapi/linux/kvm.h with Linux header (Paul Lai) [1924149]
- kvm: selftests: conditionally build vm_xsave_req_perm() (Paul Lai) [1924149]
- KVM: x86/cpuid: Exclude unpermitted xfeatures sizes at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- KVM: x86/cpuid: Clear XFD for component i if the base feature is missing (Paul Lai) [1924149]
- selftest: kvm: Add amx selftest (Paul Lai) [1924149]
- selftest: kvm: Move struct kvm_x86_state to header (Paul Lai) [1924149]
- selftest: kvm: Reorder vcpu_load_state steps for AMX (Paul Lai) [1924149]
- kvm: x86: Disable interception for IA32_XFD on demand (Paul Lai) [1924149]
- x86/fpu: Provide fpu_sync_guest_vmexit_xfd_state() (Paul Lai) [1924149]
- kvm: selftests: Add support for KVM_CAP_XSAVE2 (Paul Lai) [1924149]
- kvm: x86: Add support for getting/setting expanded xstate buffer (Paul Lai) [1924149]
- x86/fpu: Add uabi_size to guest_fpu (Paul Lai) [1924149]
- kvm: x86: Add CPUID support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Add XCR0 support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Disable RDMSR interception of IA32_XFD_ERR (Paul Lai) [1924149]
- kvm: x86: Intercept #NM for saving IA32_XFD_ERR (Paul Lai) [1924149]
- x86/fpu: Make XFD initialization in __fpstate_reset() a function argument (Paul Lai) [1924149]
- kvm: x86: Exclude unpermitted xfeatures at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- kvm: x86: Fix xstate_required_size() to follow XSTATE alignment rule (Paul Lai) [1924149]
- kvm: selftests: move ucall declarations into ucall_common.h (Paul Lai) [1924149]
- kvm: selftests: move base kvm_util.h declarations to kvm_util_base.h (Paul Lai) [1924149]
- rename c9s pipeline from centos-stream-9 to c9s (Bruno Goncalves)
- genirq: Provide new interfaces for affinity hints (Phil Auld) [2055300]
- um: vector: adjust to coalesce API changes (Ivan Vecera) [2047636]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Ivan Vecera) [2047636]
- ethtool: Fix link extended state for big endian (Ivan Vecera) [2047636]
- ethtool: use phydev variable (Ivan Vecera) [2047636]
- ethtool: Remove redundant ret assignments (Ivan Vecera) [2047636]
- ethtool: do not perform operations on net devices being unregistered (Ivan Vecera) [2047636]
- ethtool: netlink: Slightly simplify 'ethnl_features_to_bitmap()' (Ivan Vecera) [2047636]
- ethtool: ioctl: fix potential NULL deref in ethtool_set_coalesce() (Ivan Vecera) [2047636]
- net: ethtool: set a default driver name (Ivan Vecera) [2047636]
- ethtool: extend ringparam setting/getting API with rx_buf_len (Ivan Vecera) [2047636]
- ethtool: add support to set/get rx buf len via ethtool (Ivan Vecera) [2047636]
- ethtool: add support to set/get tx copybreak buf size via ethtool (Ivan Vecera) [2047636]
- ethtool: fix ethtool msg len calculation for pause stats (Ivan Vecera) [2047636]
- ethtool: don't drop the rtnl_lock half way thru the ioctl (Ivan Vecera) [2047636]
- devlink: expose get/put functions (Ivan Vecera) [2047636]
- ethtool: handle info/flash data copying outside rtnl_lock (Ivan Vecera) [2047636]
- ethtool: push the rtnl_lock into dev_ethtool() (Ivan Vecera) [2047636]
- ethtool: Add transceiver module extended state (Ivan Vecera) [2047636]
- ethtool: Add ability to control transceiver modules' power mode (Ivan Vecera) [2047636]
- ethtool: ioctl: Use array_size() helper in copy_{from,to}_user() (Ivan Vecera) [2047636]
- ethtool: prevent endless loop if eeprom size is smaller than announced (Ivan Vecera) [2047636]
- ethtool: extend coalesce setting uAPI with CQE mode (Ivan Vecera) [2047636]
- ethtool: add two coalesce attributes for CQE mode (Ivan Vecera) [2047636]
- ethtool: add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- docs: ethtool: Add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- ethtool: return error from ethnl_ops_begin if dev is NULL (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent in ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move netif_device_present check from ethnl_parse_header_dev_get to ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move implementation of ethnl_ops_begin/complete to netlink.c (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent before ethtool ioctl ops (Ivan Vecera) [2047636]

* Wed Mar 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-76.el9]
- vdpa/mlx5: Fix tracking of current number of VQs (Cindy Lu) [2055451]
- vdpa/mlx5: Fix is_index_valid() to refer to features (Cindy Lu) [2055451]
- vdpa: Protect vdpa reset with cf_mutex (Cindy Lu) [2055451]
- vdpa: Avoid taking cf_mutex lock on get status (Cindy Lu) [2055451]
- vdpa/vdpa_sim_net: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Use BIT_ULL for bit operations (Cindy Lu) [2055451]
- vdpa/vdpa_sim: Configure max supported virtqueues (Cindy Lu) [2055451]
- vdpa/mlx5: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Support reporting max device capabilities (Cindy Lu) [2055451]
- vdpa/mlx5: Restore cur_num_vqs in case of failure in change_num_qps() (Cindy Lu) [2055451]
- vdpa: Add support for returning device configuration information (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuring max data virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: Fix config_attr_mask assignment (Cindy Lu) [2055451]
- vdpa: Allow to configure max data virtqueues (Cindy Lu) [2055451]
- vdpa: Read device configuration only if FEATURES_OK (Cindy Lu) [2055451]
- vdpa: Sync calls set/get config/status with cf_mutex (Cindy Lu) [2055451]
- vdpa/mlx5: Distribute RX virtqueues in RQT object (Cindy Lu) [2055451]
- vdpa: Provide interface to read driver features (Cindy Lu) [2055451]
- vdpa: clean up get_config_size ret value handling (Cindy Lu) [2055451]
- vdpa/mlx5: Fix wrong configuration of virtio_version_1_0 (Cindy Lu) [2055451]
- vdpa: Mark vdpa_config_ops.get_vq_notification as optional (Cindy Lu) [2055451]
- vdpa: Avoid duplicate call to vp_vdpa get_status (Cindy Lu) [2055451]
- net/mlx5_vdpa: Offer VIRTIO_NET_F_MTU when setting MTU (Cindy Lu) [2055451]
- vdpa: add driver_override support (Cindy Lu) [2055451]
- docs: document sysfs ABI for vDPA bus (Cindy Lu) [2055451]
- ifcvf/vDPA: fix misuse virtio-net device config size for blk dev (Cindy Lu) [2055451]
- vdpa: Consider device id larger than 31 (Cindy Lu) [2055451]
- virtio: always enter drivers/virtio/ (Cindy Lu) [2055451]
- vdpa: check that offsets are within bounds (Cindy Lu) [2055451]
- vdpa_sim: avoid putting an uninitialized iova_domain (Cindy Lu) [2055451]
- vhost-vdpa: clean irqs before reseting vdpa device (Cindy Lu) [2055451]
- vdpa/mlx5: Forward only packets with allowed MAC address (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuration of MAC (Cindy Lu) [2055451]
- vdpa/mlx5: Fix clearing of VIRTIO_NET_F_MAC feature bit (Cindy Lu) [2055451]
- vdpa_sim_net: Enable user to set mac address and mtu (Cindy Lu) [2055451]
- vdpa: Enable user to set mac and mtu of vdpa device (Cindy Lu) [2055451]
- vdpa: Use kernel coding style for structure comments (Cindy Lu) [2055451]
- vdpa: Introduce query of device config layout (Cindy Lu) [2055451]
- vdpa: Introduce and use vdpa device get, set config helpers (Cindy Lu) [2055451]
- vdpa/mlx5: Propagate link status from device to vdpa driver (Cindy Lu) [2055451]
- vdpa/mlx5: Rename control VQ workqueue to vdpa wq (Cindy Lu) [2055451]
- vdpa/mlx5: Remove mtu field from vdpa net device (Cindy Lu) [2055451]
- vdpa: add new attribute VDPA_ATTR_DEV_MIN_VQ_SIZE (Cindy Lu) [2055451]
- virtio_vdpa: setup correct vq size with callbacks get_vq_num_{max,min} (Cindy Lu) [2055451]
- vdpa: min vq num of vdpa device cannot be greater than max vq num (Cindy Lu) [2055451]
- vdpa: add new callback get_vq_num_min in vdpa_config_ops (Cindy Lu) [2055451]
- vp_vdpa: add vq irq offloading support (Cindy Lu) [2055451]
- vdpa: fix typo (Cindy Lu) [2055451]
- vhost-vdpa: Fix the wrong input in config_cb (Cindy Lu) [2055451]
- vhost_vdpa: unset vq irq before freeing irq (Cindy Lu) [2055451]
- vdpa: potential uninitialized return in vhost_vdpa_va_map() (Cindy Lu) [2055451]
- vdpa/mlx5: Avoid executing set_vq_ready() if device is reset (Cindy Lu) [2055451]
- vdpa/mlx5: Clear ready indication for control VQ (Cindy Lu) [2055451]
- vdpa: Support transferring virtual addressing during DMA mapping (Cindy Lu) [2055451]
- vdpa: factor out vhost_vdpa_pa_map() and vhost_vdpa_pa_unmap() (Cindy Lu) [2055451]
- vdpa: Add an opaque pointer for vdpa_config_ops.dma_map() (Cindy Lu) [2055451]
- vhost-iotlb: Add an opaque pointer for vhost IOTLB (Cindy Lu) [2055451]
- vhost-vdpa: Handle the failure of vdpa_reset() (Cindy Lu) [2055451]
- vdpa: Add reset callback in vdpa_config_ops (Cindy Lu) [2055451]
- vdpa: Fix some coding style issues (Cindy Lu) [2055451]
- vdpa: Make use of PFN_PHYS/PFN_UP/PFN_DOWN helper macro (Cindy Lu) [2055451]
- vdpa/mlx5: Add multiqueue support (Cindy Lu) [2055451]
- vdpa/mlx5: Add support for control VQ and MAC setting (Cindy Lu) [2055451]
- vdpa/mlx5: Ensure valid indices are provided (Cindy Lu) [2055451]
- vdpa/mlx5: Decouple virtqueue callback from struct mlx5_vdpa_virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: function prototype modifications in preparation to control VQ (Cindy Lu) [2055451]
- vdpa/mlx5: Remove redundant header file inclusion (Cindy Lu) [2055451]
- vDPA/ifcvf: enable multiqueue and control vq (Cindy Lu) [2055451]
- vDPA/ifcvf: detect and use the onboard number of queues directly (Cindy Lu) [2055451]
- vDPA/ifcvf: implement management netlink framework for ifcvf (Cindy Lu) [2055451]
- vDPA/ifcvf: introduce get_dev_type() which returns virtio dev id (Cindy Lu) [2055451]
- x86/hyperv: Output host build info as normal Windows version number (Vitaly Kuznetsov) [2060708]
- lib/irq_poll: Declare IRQ_POLL softirq vector as ksoftirqd-parking safe (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Stop allowing RCU_SOFTIRQ in idle (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Remove obsolete rcu_needs_cpu() parameters (Desnes A. Nunes do Rosario) [2059555]
- tick: Detect and fix jiffies update stall (Desnes A. Nunes do Rosario) [2059555]
- rcu: Move rcu_needs_cpu() to tree.c (Desnes A. Nunes do Rosario) [2059555]
- rcu: Remove the RCU_FAST_NO_HZ Kconfig option (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcu scenarios (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcuscale and refscale scenarios (Desnes A. Nunes do Rosario) [2059555]
- copy_process(): Move fd_install() out of sighand->siglock critical section (Waiman Long) [2051855]
- redhat/configs: enable CONFIG_INTEL_VSEC for x86 (David Arcari) [2058806]
- platform/x86/intel: Move intel_pmt from MFD to Auxiliary Bus (David Arcari) [2058806]
- platform/x86: intel_pmt_telemetry: Ignore zero sized entries (David Arcari) [2058806]
- platform/x86/intel: Move Intel PMT drivers to new subfolder (David Arcari) [2058806]
- driver core: auxiliary bus: Add driver data helpers (David Arcari) [2058806]
- PCI: Add #defines for accessing PCIe DVSEC fields (David Arcari) [2058806]
- tools headers UAPI: Sync powerpc syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync s390 syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex: Wireup futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync MIPS syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- parisc: Wire up futex_waitv (Joel Savitz) [2038794]
- s390: wire up sys_futex_waitv system call (Joel Savitz) [2038794]
- MIPS: syscalls: Wire up futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync files changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex2: Documentation: Document sys_futex_waitv() uAPI (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() wouldblock (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() timeout (Joel Savitz) [2038794]
- selftests: futex: Add sys_futex_waitv() test (Joel Savitz) [2038794]
- futex,arm: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex,x86: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Implement sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Simplify double_lock_hb() (Joel Savitz) [2038794]
- futex: Split out wait/wake (Joel Savitz) [2038794]
- futex: Split out requeue (Joel Savitz) [2038794]
- futex: Rename mark_wake_futex() (Joel Savitz) [2038794]
- futex: Rename: match_futex() (Joel Savitz) [2038794]
- futex: Rename: hb_waiter_{inc,dec,pending}() (Joel Savitz) [2038794]
- futex: Split out PI futex (Joel Savitz) [2038794]
- futex: Rename: {get,cmpxchg}_futex_value_locked() (Joel Savitz) [2038794]
- futex: Rename hash_futex() (Joel Savitz) [2038794]
- futex: Rename __unqueue_futex() (Joel Savitz) [2038794]
- futex: Rename: queue_{,un}lock() (Joel Savitz) [2038794]
- futex: Rename futex_wait_queue_me() (Joel Savitz) [2038794]
- futex: Rename {,__}{,un}queue_me() (Joel Savitz) [2038794]
- futex: Split out syscalls (Joel Savitz) [2038794]
- futex: Move to kernel/futex/ (Joel Savitz) [2038794]
- cifs: fix double free race when mount fails in cifs_get_root() (Ronnie Sahlberg) [1979175]

* Fri Mar 25 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-75.el9]
- ipv6: fix skb drops in igmp6_event_query() and igmp6_event_report() (Hangbin Liu) [2059308] {CVE-2022-0742}
- redhat/configs: aarch64: Fix PAC/BTI config settings (Mark Salter) [2063215]
- RHEL9.0: arch_hw Update CONFIG_MOUSE_VSXXXAA=m (Tony Camuso) [2062909]
- redhat/configs: Disable KVM on POWER (Laurent Vivier) [2052898]
- drm/ast: Create threshold values for AST2600 (Jocelyn Falempe) [2062560]
- mm: gup: make fault_in_safe_writeable() use fixup_user_fault() (Andreas Gruenbacher) [2062797]
- drm/vmwgfx: Fix stale file descriptors on failed usercopy (David Airlie) [2047613] {CVE-2022-22942}
- netfilter: nf_queue: handle socket prefetch (Florian Westphal) [2060092]
- netfilter: nf_queue: fix possible use-after-free (Florian Westphal) [2060092]
- selftests: netfilter: add nfqueue TCP_NEW_SYN_RECV socket race test (Florian Westphal) [2060092]
- netfilter: nf_queue: don't assume sk is full socket (Florian Westphal) [2060092]
- scsi: mpi3mr: Fix flushing !WQ_MEM_RECLAIM events warning (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix memory leaks (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix reporting of actual data transfer size (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix cmnd getting marked as in use forever (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix hibernation issue (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix printing of pending I/O count (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix deadlock while canceling the fw event (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fixes around reply request queues (Tomas Henzl) [2056626]
- scsi: mpi3mr: Enhanced Task Management Support Reply handling (Tomas Henzl) [2056626]
- scsi: mpi3mr: Use TM response codes from MPI3 headers (Tomas Henzl) [2056626]
- scsi: mpi3mr: Increase internal cmnds timeout to 60s (Tomas Henzl) [2056626]
- scsi: mpi3mr: Do access status validation before adding devices (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part2 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part1 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Don't reset IOC if cmnds flush with reset status (Tomas Henzl) [2056626]
- scsi: mpi3mr: Replace spin_lock() with spin_lock_irqsave() (Tomas Henzl) [2056626]
- scsi: mpi3mr: Add debug APIs based on logging_level bits (Tomas Henzl) [2056626]
- x86/kvm/fpu: Remove kvm_vcpu_arch.guest_supported_xcr0 (Leonardo Bras) [2043545]
- x86/kvm/fpu: Limit guest user_xfeatures to supported bits of XCR0 (Leonardo Bras) [2043545]
- KVM: x86: Move CPUID.(EAX=0x12,ECX=1) mangling to __kvm_update_cpuid_runtime() (Leonardo Bras) [2043545]
- KVM: x86: Do runtime CPUID update before updating vcpu->arch.cpuid_entries (Leonardo Bras) [2043545]
- x86/fpu: Fix inline prefix warnings (Leonardo Bras) [2043545]
- kvm: x86: Emulate IA32_XFD_ERR for guest (Leonardo Bras) [2043545]
- x86/fpu: Prepare xfd_err in struct fpu_guest (Leonardo Bras) [2043545]
- kvm: x86: Add emulation for IA32_XFD (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_update_guest_xfd() for IA32_XFD emulation (Leonardo Bras) [2043545]
- kvm: x86: Enable dynamic xfeatures at KVM_SET_CPUID2 (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_enable_guest_xfd_features() for KVM (Leonardo Bras) [2043545]
- x86/fpu: Add guest support to xfd_enable_feature() (Leonardo Bras) [2043545]
- x86/fpu: Prepare guest FPU for dynamically enabled FPU features (Leonardo Bras) [2043545]
- x86/fpu: Extend fpu_xstate_prctl() with guest permissions (Leonardo Bras) [2043545]
- cpuid: kvm_find_kvm_cpuid_features() should be declared 'static' (Leonardo Bras) [2043545]
- KVM: x86: Make sure KVM_CPUID_FEATURES really are KVM_CPUID_FEATURES (Leonardo Bras) [2043545]
- KVM: x86: Add helper to consolidate core logic of SET_CPUID{2} flows (Leonardo Bras) [2043545]
- redhat/configs: Disable watchdog components (Prarit Bhargava) [2060117]
- sched: Fix yet more sched_fork() races (Phil Auld) [2062836]
- sched/fair: Fix fault in reweight_entity (Phil Auld) [2062836]
- x86/cpu: Add Xeon Icelake-D to list of CPUs that support PPIN (David Arcari) [2043225]
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA window for persistent memory" (Steve Best) [2056057]
- drivers/char: permit access to the RTAS user buffer under lockdown (Desnes A. Nunes do Rosario) [2046472]

* Tue Mar 22 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-74.el9]
- redhat: rpminspect: disable 'patches' check for known empty patch files (Patrick Talbert)
- KVM: x86/mmu: Don't advance iterator after restart due to yielding (Nico Pache) [2055725]
- ibmvnic: don't release napi in __ibmvnic_open() (Diego Domingos) [2055981]

* Sun Mar 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-73.el9]
- CI: Use 9.0-rt branch for rhel-9 realtime_check (Juri Lelli)
- redhat: enable zstream release numbering for rhel 9.0 (Herton R. Krzesinski)
- redhat: change kabi tarballs to use the package release (Herton R. Krzesinski)
- redhat: generate distgit changelog in genspec.sh as well (Herton R. Krzesinski)
- redhat: make genspec prefer metadata from git notes (Herton R. Krzesinski)
- redhat: use tags from git notes for zstream to generate changelog (Herton R. Krzesinski)
- CI: Add disttag setting (Veronika Kabatova)
- CI: Drop c9s config (Veronika Kabatova)
- virtio-net: fix pages leaking when building skb in big mode (Laurent Vivier) [2042559]
- lib/iov_iter: initialize "flags" in new pipe_buffer (Carlos Maiolino) [2060869] {CVE-2022-0847}
- redhat/configs: Make CRYPTO_ECDH algos built-in (Simo Sorce) [2062199]
- crypto: api - Move cryptomgr soft dependency into algapi (Vladis Dronov) [2062199]
- crypto: api - Fix boot-up crash when crypto manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Do not create test larvals if manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Export crypto_boot_test_finished (Vladis Dronov) [2062199]
- crypto: api - Fix built-in testing dependency failures (Vladis Dronov) [2062199]
- redhat/configs: Add CRYPTO_AES_ARM64 config explicitly (Vladis Dronov) [2062199]
- crypto: arm64/aes-ce - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- crypto: arm64/aes-neonbs - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- redhat: change default dist suffix for RHEL 9.0 (Herton R. Krzesinski)
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2050813]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2050813]
- block: kabi: reserve space for block layer public structure (Ming Lei) [2057238]
- block: kabi: reserve space for blk-mq related structure (Ming Lei) [2057238]
- block: kabi: reserve space for bsg related structure (Ming Lei) [2057238]
- block: kabi: reserve space for integrity related structure (Ming Lei) [2057238]
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (Dick Kennedy) [2054866]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC/amd64: Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC: Add RDDR5 and LRDDR5 memory types (Aristeu Rozanski) [1898165 2047430 2047446]
- drm/amdgpu: Register MCE notifier for Aldebaran RAS (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD: Export smca_get_bank_type symbol (Aristeu Rozanski) [1898165 2047430 2047446]
- PCI/ACPI: Fix acpi_pci_osc_control_set() kernel-doc comment (Mark Langsdorf) [2049635]
- PCI/ACPI: Check for _OSC support in acpi_pci_osc_control_set() (Mark Langsdorf) [2049635]
- PCI/ACPI: Move _OSC query checks to separate function (Mark Langsdorf) [2049635]
- PCI/ACPI: Move supported and control calculations to separate functions (Mark Langsdorf) [2049635]
- PCI/ACPI: Remove OSC_PCI_SUPPORT_MASKS and OSC_PCI_CONTROL_MASKS (Mark Langsdorf) [2049635]
- nvmet-tcp: fix missing unmainted messages (Chris Leech) [2054441]
- dm stats: fix too short end duration_ns when using precise_timestamps (Benjamin Marzinski) [2051798]
- dm: fix double accounting of flush with data (Benjamin Marzinski) [2051798]
- dm: interlock pending dm_io and dm_wait_for_bios_completion (Benjamin Marzinski) [2051798]
- dm: properly fix redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- dm: revert partial fix for redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- block: add bio_start_io_acct_time() to control start_time (Benjamin Marzinski) [2051798]
- scsi: mpt3sas: Fix incorrect system timestamp (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix system going into read-only mode (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix kernel panic during drive powercycle test (Tomas Henzl) [2049631]
- redhat/configs: enable mellanox platform drivers to support LED, fan & watchdog devices (Ivan Vecera) [2057491]
- x86/cpu: Drop spurious underscore from RAPTOR_LAKE #define (David Arcari) [2040022]
- x86/cpu: Add Raptor Lake to Intel family (David Arcari) [2040022]
- powerpc/64: Move paca allocation later in boot (Desnes A. Nunes do Rosario) [2055566]
- powerpc: Set crashkernel offset to mid of RMA region (Desnes A. Nunes do Rosario) [2055566]
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2060814]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2060814]
- igb: refactor XDP registration (Corinna Vinschen) [2054379]
- igc: avoid kernel warning when changing RX ring parameters (Corinna Vinschen) [2054379]
- redhat/configs: Enable CONFIG_ACER_WIRELESS (Peter Georg) [2025985]

* Tue Mar 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-72.el9]
- spec: Fix separate tools build (Jiri Olsa) [2054579]
- redhat: use centos x509.genkey file if building under centos (Herton R. Krzesinski) [2029952]

* Tue Mar 08 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-71.el9]
- CI: Build coverage RPMs on c9s environment (Veronika Kabatova)
- md: use default_groups in kobj_type (Nigel Croxon) [2042797]
- md: Move alloc/free acct bioset in to personality (Nigel Croxon) [2042797]
- md: fix spelling of "its" (Nigel Croxon) [2042797]
- md: raid456 add nowait support (Nigel Croxon) [2042797]
- md: raid10 add nowait support (Nigel Croxon) [2042797]
- md: raid1 add nowait support (Nigel Croxon) [2042797]
- md: add support for REQ_NOWAIT (Nigel Croxon) [2042797]
- md: drop queue limitation for RAID1 and RAID10 (Nigel Croxon) [2042797]
- md/raid5: play nice with PREEMPT_RT (Nigel Croxon) [2042797]
- md/raid1: fix missing bitmap update w/o WriteMostly devices (Nigel Croxon) [2042797]
- md: fix double free of mddev->private in autorun_array() (Nigel Croxon) [2042797]
- md: fix update super 1.0 on rdev size change (Nigel Croxon) [2042797]
- raid5-ppl: use swap() to make code cleaner (Nigel Croxon) [2042797]
- md/bitmap: don't set max_write_behind if there is no write mostly device (Nigel Croxon) [2042797]
- md: update superblock after changing rdev flags in state_store (Nigel Croxon) [2042797]
- md: remove unused argument from md_new_event (Nigel Croxon) [2042797]
- md/raid5: call roundup_pow_of_two in raid5_run (Nigel Croxon) [2042797]
- md/raid1: use rdev in raid1_write_request directly (Nigel Croxon) [2042797]
- md/raid1: only allocate write behind bio fof WriteMostly device (Nigel Croxon) [2042797]
- md: properly unwind when failing to add the kobject in md_alloc (Nigel Croxon) [2042797]
- md: extend disks_mutex coverage (Nigel Croxon) [2042797]
- md: add the bitmap group to the default groups for the md kobject (Nigel Croxon) [2042797]
- md: add error handling support for add_disk() (Nigel Croxon) [2042797]
- redhat: Bump RHEL_MINOR for 9.1 (Patrick Talbert)

* Tue Mar 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-70.1.1.el9_0]
- Revert 8dffe2b6 "Merge: kabi: add lib ACKed symbols" (Čestmír Kalina) [2059972]
- include/linux/kernel.h: fix function name for mark_hardware_unmaintained() if !CONFIG_RHEL_DIFFERENCES (Ewan D. Milne) [2059687]
- scsi: sd: Mark ZBC host-managed SCSI disks as unmaintained (Ewan D. Milne) [2059687]
- spec: make linux-firmware weak(er) dependency (Jan Stancek) [2031113]
- redhat/configs: Enable CONFIG_INTEL_PCH_THERMAL for x86 (David Arcari) [2058186]
- redhat/configs: Disable CONFIG_SURFACE_PLATFORMS (David Arcari) [2056609]

* Thu Feb 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-70.el9]
- stmmac/intel: mark driver as tech preview (Mark Salter) [2045594]
- net: stmmac: Add GFP_DMA32 for rx buffers if no 64 capability (Mark Salter) [2045594]
- mm: fix invalid page pointer returned with FOLL_PIN gups (Peter Xu) [2037300]
- tipc: improve size validations for received domain records (Xin Long) [2048972] {CVE-2022-0435}
- cgroup-v1: Require capabilities to set release_agent (Waiman Long) [2052168] {CVE-2022-0492}
- bpf, arm64: Use emit_addr_mov_i64() for BPF_PSEUDO_FUNC (Yauheni Kaliuta) [2033596]
- bpf: Stop caching subprog index in the bpf_pseudo_func insn (Yauheni Kaliuta) [2033596]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2049040] {CVE-2022-24122}
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2049040]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2049040]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2049040]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2049040]

* Wed Feb 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-69.el9]
- config: mt76: set CONFIG_MT7921S to not set, like in ark (Íñigo Huguet) [2043454]
- config: rtw89: enable driver and device RTL8852AE (Íñigo Huguet) [2043454]
- rtw89: 8852a: correct bit definition of dfs_en (Íñigo Huguet) [2043454]
- rtw89: coex: Update COEX to 5.5.8 (Íñigo Huguet) [2043454]
- rtw89: coex: Cancel PS leaving while C2H comes (Íñigo Huguet) [2043454]
- rtw89: coex: Update BT counters while receiving report (Íñigo Huguet) [2043454]
- rtw89: coex: Define LPS state for BTC using (Íñigo Huguet) [2043454]
- rtw89: coex: Add MAC API to get BT polluted counter (Íñigo Huguet) [2043454]
- rtw89: coex: Not to send H2C when WL not ready and count H2C (Íñigo Huguet) [2043454]
- rtw89: coex: correct C2H header length (Íñigo Huguet) [2043454]
- rtw89: don't kick off TX DMA if failed to write skb (Íñigo Huguet) [2043454]
- rtw89: remove cch_by_bw which is not used (Íñigo Huguet) [2043454]
- rtw89: fix sending wrong rtwsta->mac_id to firmware to fill address CAM (Íñigo Huguet) [2043454]
- rtw89: fix incorrect channel info during scan (Íñigo Huguet) [2043454]
- rtw89: update scan_mac_addr during scanning period (Íñigo Huguet) [2043454]
- rtw89: use inline function instead macro to set H2C and CAM (Íñigo Huguet) [2043454]
- rtw89: add const in the cast of le32_get_bits() (Íñigo Huguet) [2043454]
- rtw89: add AXIDMA and TX FIFO dump in mac_mem_dump (Íñigo Huguet) [2043454]
- rtw89: fix potentially access out of range of RF register array (Íñigo Huguet) [2043454]
- rtw89: remove unneeded variable (Íñigo Huguet) [2043454]
- rtw89: remove unnecessary conditional operators (Íñigo Huguet) [2043454]
- rtw89: update rtw89_regulatory map to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: update tx power limit/limit_ru tables to R54 (Íñigo Huguet) [2043454]
- rtw89: update rtw89 regulation definition to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: fill regd field of limit/limit_ru tables by enum (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: add support for BNJ HW (Íñigo Huguet) [2043454]
- iwlwifi: Read the correct addresses when getting the crf id (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add jacket bit to device configuration parsing (Íñigo Huguet) [2043454]
- iwlwifi: add new ax1650 killer device (Íñigo Huguet) [2043454]
- iwlwifi: add new Qu-Hr device (Íñigo Huguet) [2043454]
- iwlwifi: add missing entries for Gf4 with So and SoF (Íñigo Huguet) [2043454]
- iwlwifi: remove unused iwlax210_2ax_cfg_so_hr_a0 structure (Íñigo Huguet) [2043454]
- iwlwifi: support 4-bits in MAC step value (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds (Íñigo Huguet) [2043454]
- wilc1000: fix double free error in probe() (Íñigo Huguet) [2043454]
- wilc1000: Fix spurious "FW not responding" error (Íñigo Huguet) [2043454]
- wilc1000: Fix missing newline in error message (Íñigo Huguet) [2043454]
- wilc1000: Fix copy-and-paste typo in wilc_set_mac_address (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use div_s64 instead of do_div in iwl_mvm_ftm_rtt_smoothing() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2043454]
- ath11k: Fix unexpected return buffer manager error for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Fix napi related hang (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fix issue with new DBGI_SRAM region read. (Íñigo Huguet) [2043454]
- iwlwifi: pcie: make sure prph_info is set when treating wakeup IRQ (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix AUX ROC removal (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set protected flag only for NDP ranging (Íñigo Huguet) [2043454]
- iwlwifi: mvm: perform 6GHz passive scan after suspend (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix calculation of frame length (Íñigo Huguet) [2043454]
- iwlwifi: mvm: test roc running status bits before removing the sta (Íñigo Huguet) [2043454]
- iwlwifi: don't pass actual WGDS revision number in table_revision (Íñigo Huguet) [2043454]
- iwlwifi: fix leaks/bad data after failed firmware load (Íñigo Huguet) [2043454]
- iwlwifi: fix debug TLV parsing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix 32-bit build in FTM (Íñigo Huguet) [2043454]
- iwlwifi: fix Bz NMI behaviour (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore() with interrupts enabled (Íñigo Huguet) [2043454]
- rtw88: 8822c: update rx settings to prevent potential hw deadlock (Íñigo Huguet) [2043454]
- rtw88: Disable PCIe ASPM while doing NAPI poll on 8821CE (Íñigo Huguet) [2043454]
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_tx_get_packet() (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_rxep() (Íñigo Huguet) [2043454]
- mac80211: fix FEC flag in radio tap header (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible resume failure (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt76_connac_mcu_set_hif_suspend to bus-related files (Íñigo Huguet) [2043454]
- mt76: mt7921: fix network buffer leak by txs missing (Íñigo Huguet) [2043454]
- mt76: mt7615: clear mcu error interrupt status on mt7663 (Íñigo Huguet) [2043454]
- mt76: connac: fix last_chan configuration in mt76_connac_mcu_rate_txpower_band (Íñigo Huguet) [2043454]
- mt76: mt7921: use correct iftype data on 6GHz cap init (Íñigo Huguet) [2043454]
- mt76: mt7921: fix boolreturn.cocci warning (Íñigo Huguet) [2043454]
- mt76: mt7615: fix unused tx antenna mask in testmode (Íñigo Huguet) [2043454]
- mt76: fix the wiphy's available antennas to the correct value (Íñigo Huguet) [2043454]
- mt76: connac: fix a theoretical NULL pointer dereference in mt76_connac_get_phy_mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible NULL pointer dereference in mt7921_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: fix possible OOB issue in mt76_calculate_default_rate (Íñigo Huguet) [2043454]
- mt76: debugfs: fix queue reporting for mt76-usb (Íñigo Huguet) [2043454]
- mt76: mt7915: fix SMPS operation fail (Íñigo Huguet) [2043454]
- mt76: mt7915: fix return condition in mt7915_tm_reg_backup_restore() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix MT7921E reset failure (Íñigo Huguet) [2043454]
- mt76: mt7615: fix possible deadlock while mt7615_register_ext_phy() (Íñigo Huguet) [2043454]
- mt76: mt7921: drop offload_flags overwritten (Íñigo Huguet) [2043454]
- mt76: mt7915: get rid of mt7915_mcu_set_fixed_rate routine (Íñigo Huguet) [2043454]
- bus: mhi: core: Use correctly sized arguments for bit field (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix race while handling SYS_ERR at power up (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix reading wake_capable channel configuration (Íñigo Huguet) [2043454]
- bus: mhi: core: Minor style and comment fixes (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Graceful shutdown on freeze (Íñigo Huguet) [2043454]
- ath11k: Fix a NULL pointer dereference in ath11k_mac_op_hw_scan() (Íñigo Huguet) [2043454]
- mt76: remove variable set but not used (Íñigo Huguet) [2043454]
- ath11k: Fix deleting uninitialized kernel timer during fragment cache flush (Íñigo Huguet) [2043454]
- ath11k: add spectral/CFR buffer validation support (Íñigo Huguet) [2043454]
- ath11k: Fix buffer overflow when scanning with extraie (Íñigo Huguet) [2043454]
- mwifiex: Fix possible ABBA deadlock (Íñigo Huguet) [2043454]
- ath10k: fix scan abort when duration is set for hw scan (Íñigo Huguet) [2043454]
- ath10k: Fix tx hanging (Íñigo Huguet) [2043454]
- iwlwifi: Fix FW name for gl (Íñigo Huguet) [2043454]
- iwlwifi: add support for Bz-Z HW (Íñigo Huguet) [2043454]
- iwlwifi: acpi: fix wgds rev 3 size (Íñigo Huguet) [2043454]
- iwlwifi: mvm: avoid clearing a just saved session protection id (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix wrong documentation for scan request command (Íñigo Huguet) [2043454]
- iwlwifi: mvm: synchronize with FW after multicast commands (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix delBA vs. NSSN queue sync race (Íñigo Huguet) [2043454]
- ath11k: Fix QMI file type enum value (Íñigo Huguet) [2043454]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2043454]
- ath10k: Fix the MTU size on QCA9377 SDIO (Íñigo Huguet) [2043454]
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma (Íñigo Huguet) [2043454]
- mwifiex: Ignore BTCOEX events from the 88W8897 firmware (Íñigo Huguet) [2043454]
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv() (Íñigo Huguet) [2043454]
- ath11k: Use host CE parameters for CE interrupts configuration (Íñigo Huguet) [2043454]
- ath11k: Fix mon status ring rx tlv processing (Íñigo Huguet) [2043454]
- ath11k: skip sending vdev down for channel switch (Íñigo Huguet) [2043454]
- ath11k: fix read fail for htt_stats and htt_peer_stats for single pdev (Íñigo Huguet) [2043454]
- ath11k: Set IRQ affinity to CPU0 in case of one MSI vector (Íñigo Huguet) [2043454]
- ath11k: do not restore ASPM in case of single MSI vector (Íñigo Huguet) [2043454]
- ath11k: add support one MSI vector (Íñigo Huguet) [2043454]
- ath11k: refactor multiple MSI vector implementation (Íñigo Huguet) [2043454]
- ath11k: use ATH11K_PCI_IRQ_DP_OFFSET for DP IRQ (Íñigo Huguet) [2043454]
- ath11k: add CE and ext IRQ flag to indicate irq_handler (Íñigo Huguet) [2043454]
- ath11k: get msi_data again after request_irq is called (Íñigo Huguet) [2043454]
- ath9k: fix intr_txqs setting (Íñigo Huguet) [2043454]
- ath11k: add hw_param for wakeup_mhi (Íñigo Huguet) [2043454]
- ath11k: reset RSN/WPA present state for open BSS (Íñigo Huguet) [2043454]
- ath11k: clear the keys properly via DISABLE_KEY (Íñigo Huguet) [2043454]
- ath11k: Fix crash caused by uninitialized TX ring (Íñigo Huguet) [2043454]
- ath11k: use cache line aligned buffers for dbring (Íñigo Huguet) [2043454]
- ath11k: Fix ETSI regd with weather radar overlap (Íñigo Huguet) [2043454]
- ath11k: fix FCS_ERR flag in radio tap header (Íñigo Huguet) [2043454]
- ath11k: fix the value of msecs_to_jiffies in ath11k_debugfs_fw_stats_request (Íñigo Huguet) [2043454]
- ath11k: fix firmware crash during channel switch (Íñigo Huguet) [2043454]
- ath11k: Fix 'unused-but-set-parameter' error (Íñigo Huguet) [2043454]
- ath11k: fix DMA memory free in CE pipe cleanup (Íñigo Huguet) [2043454]
- ath11k: fix error routine when fallback of add interface fails (Íñigo Huguet) [2043454]
- ath11k: fix fw crash due to peer get authorized before key install (Íñigo Huguet) [2043454]
- ath11k: Clear auth flag only for actual association in security mode (Íñigo Huguet) [2043454]
- ath11k: Send PPDU_STATS_CFG with proper pdev mask to firmware (Íñigo Huguet) [2043454]
- ath11k: set correct NL80211_FEATURE_DYNAMIC_SMPS for WCN6855 (Íñigo Huguet) [2043454]
- mac80211: mesh: embedd mesh_paths and mpp_paths into ieee80211_if_mesh (Íñigo Huguet) [2043454]
- mac80211: initialize variable have_higher_than_11mbit (Íñigo Huguet) [2043454]
- mac80211: fix locking in ieee80211_start_ap error path (Íñigo Huguet) [2043454]
- mac80211: do drv_reconfig_complete() before restarting all (Íñigo Huguet) [2043454]
- mac80211: mark TX-during-stop for TX in in_reconfig (Íñigo Huguet) [2043454]
- mac80211: update channel context before station state (Íñigo Huguet) [2043454]
- mac80211: Fix the size used for building probe request (Íñigo Huguet) [2043454]
- mac80211: fix lookup when adding AddBA extension element (Íñigo Huguet) [2043454]
- mac80211: validate extended element ID is present (Íñigo Huguet) [2043454]
- cfg80211: Acquire wiphy mutex on regulatory work (Íñigo Huguet) [2043454]
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock (Íñigo Huguet) [2043454]
- nl80211: remove reload flag from regulatory_request (Íñigo Huguet) [2043454]
- mac80211: send ADDBA requests using the tid/queue of the aggregation session (Íñigo Huguet) [2043454]
- bus: mhi: core: Add support for forced PM resume (Íñigo Huguet) [2043454]
- mt76: mt7921: fix build regression (Íñigo Huguet) [2043454]
- brcmsmac: rework LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: fix LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't crash on invalid rate w/o STA (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Fix device recovery failed issue (Íñigo Huguet) [2043454]
- mt76: fix key pointer overwrite in mt7921s_write_txwi/mt7663_usb_sdio_write_txwi (Íñigo Huguet) [2043454]
- rt2x00: do not mark device gone on EPROTO errors during start (Íñigo Huguet) [2043454]
- nl80211: reset regdom when reloading regdb (Íñigo Huguet) [2043454]
- mac80211: add docs for ssn in struct tid_ampdu_tx (Íñigo Huguet) [2043454]
- mac80211: fix a memory leak where sta_info is not freed (Íñigo Huguet) [2043454]
- mac80211: set up the fwd_skb->dev for mesh forwarding (Íñigo Huguet) [2043454]
- mac80211: fix regression in SSN handling of addba tx (Íñigo Huguet) [2043454]
- mac80211: fix rate control for retransmitted frames (Íñigo Huguet) [2043454]
- mac80211: track only QoS data frames for admission control (Íñigo Huguet) [2043454]
- mac80211: fix TCP performance on mesh interface (Íñigo Huguet) [2043454]
- mt76: fix possible pktid leak (Íñigo Huguet) [2043454]
- mt76: fix timestamp check in tx_status (Íñigo Huguet) [2043454]
- mt76: mt7915: fix NULL pointer dereference in mt7915_get_phy_mode (Íñigo Huguet) [2043454]
- rtw89: update partition size of firmware header on skb->data (Íñigo Huguet) [2043454]
- iwlwifi: Fix memory leaks in error handling path (Íñigo Huguet) [2043454]
- iwlwifi: fix warnings produced by kernel debug options (Íñigo Huguet) [2043454]
- iwlwifi: mvm: retry init flow if failed (Íñigo Huguet) [2043454]
- iwlwifi: Fix missing error code in iwl_pci_probe() (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix constant-conversion warning (Íñigo Huguet) [2043454]
- mac80211: fix throughput LED trigger (Íñigo Huguet) [2043454]
- mac80211: fix monitor_sdata RCU/locking assertions (Íñigo Huguet) [2043454]
- mac80211: drop check for DONT_REORDER in __ieee80211_select_queue (Íñigo Huguet) [2043454]
- mac80211: fix radiotap header generation (Íñigo Huguet) [2043454]
- mac80211: do not access the IV when it was stripped (Íñigo Huguet) [2043454]
- nl80211: fix radio statistics in survey dump (Íñigo Huguet) [2043454]
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type (Íñigo Huguet) [2043454]
- mwifiex: fix division by zero in fw download path (Íñigo Huguet) [2043454]
- iwlwifi: bump FW API to 67 for AX devices (Íñigo Huguet) [2043454]
- iwlwifi: mvm: extend session protection on association (Íñigo Huguet) [2043454]
- iwlwifi: rename CHANNEL_SWITCH_NOA_NOTIF to CHANNEL_SWITCH_START_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection on disassoc (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix WGDS table print in iwl_mvm_chub_update_mcc() (Íñigo Huguet) [2043454]
- iwlwifi: rename GEO_TX_POWER_LIMIT to PER_CHAIN_LIMIT_OFFSET_CMD (Íñigo Huguet) [2043454]
- iwlwifi: mvm: d3: use internal data representation (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update RFI TLV (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't get address of mvm->fwrt just to dereference as a pointer (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: support for ROM usniffer (Íñigo Huguet) [2043454]
- iwlwifi: fw: uefi: add missing include guards (Íñigo Huguet) [2043454]
- iwlwifi: dump host monitor data when NIC doesn't init (Íñigo Huguet) [2043454]
- iwlwifi: pcie: simplify iwl_pci_find_dev_info() (Íñigo Huguet) [2043454]
- iwlwifi: ACPI: support revision 3 WGDS tables (Íñigo Huguet) [2043454]
- iwlwifi: pcie: update sw error interrupt for BZ family (Íñigo Huguet) [2043454]
- iwlwifi: add new pci SoF with JF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use all Rx chains for roaming scan (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove two duplicate PNJ device entries (Íñigo Huguet) [2043454]
- iwlwifi: pcie: refactor dev_info lookup (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove duplicate entry (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix killer name matching for AX200 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix some kerneldoc issues (Íñigo Huguet) [2043454]
- ath10k: fix division by zero in send path (Íñigo Huguet) [2043454]
- ath10k: fix control-message timeout (Íñigo Huguet) [2043454]
- rtw89: Fix variable dereferenced before check 'sta' (Íñigo Huguet) [2043454]
- rtw89: fix return value in hfc_pub_cfg_chk (Íñigo Huguet) [2043454]
- rtw89: remove duplicate register definitions (Íñigo Huguet) [2043454]
- rtw89: fix error function parameter (Íñigo Huguet) [2043454]
- ath10k: fix module load regression with iram-recovery feature (Íñigo Huguet) [2043454]
- ath10k: fix invalid dma_addr_t token assignment (Íñigo Huguet) [2043454]
- ath11k: change return buffer manager for QCA6390 (Íñigo Huguet) [2043454]
- mt76: connac: fix unresolved symbols when CONFIG_PM is unset (Íñigo Huguet) [2043454]
- mt76: Make use of the helper macro kthread_run() (Íñigo Huguet) [2043454]
- mt76: Print error message when reading EEPROM from mtd failed (Íñigo Huguet) [2043454]
- mt76: mt7921: disable 4addr capability (Íñigo Huguet) [2043454]
- mt76: mt7915: add debugfs knobs for MCU utilization (Íñigo Huguet) [2043454]
- mt76: mt7915: add WA firmware log support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endiannes warning mt7915_mcu_beacon_check_caps (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs fixed-rate knob (Íñigo Huguet) [2043454]
- mt76: mt7915: rework .set_bitrate_mask() to support more options (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_mcu_add_he() (Íñigo Huguet) [2043454]
- mt76: mt7615: apply cached RF data for DBDC (Íñigo Huguet) [2043454]
- mt76: mt7615: mt7622: fix ibss and meshpoint (Íñigo Huguet) [2043454]
- mt76: mt7921: fix Wformat build warning (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mt7921s Kconfig (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: print out the version properly (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat non active regions as unsupported regions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Read acpi dsm to get channel activation bitmap (Íñigo Huguet) [2043454]
- iwlwifi: add new device id 7F70 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: improve log when processing CSA (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set BT-coex high priority for 802.1X/4-way-HS (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat dbgc allocation failure when tlv is missing (Íñigo Huguet) [2043454]
- iwlwifi: add new killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set inactivity timeouts also for PS-poll (Íñigo Huguet) [2043454]
- iwlwifi: pcie: try to grab NIC access early (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reduce WARN_ON() in TX status path (Íñigo Huguet) [2043454]
- iwlwifi: allow rate-limited error messages (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection after auth/assoc (Íñigo Huguet) [2043454]
- iwlwifi: remove redundant iwl_finish_nic_init() argument (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add RTS and CTS flags to iwl_tx_cmd_flags. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove csi from iwl_mvm_pass_packet_to_mac80211() (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new rate_n_flags for REPLY_RX_MPDU_CMD and RX_NO_DATA_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new TX_RSP and COMPRESSED_BA_RES versions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of BEACON_TEMPLATE_CMD. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add support for new rate_n_flags in tx_cmd. (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family SW reset support (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family BUS_MASTER_DISABLE_REQ code duplication (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fw debug config from context info and preset (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of ranging response notification (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support version 3 of tlc_update_notif. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: convert old rate & flags to the new format. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add definitions for new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update definitions due to new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: scrub key material in firmware dumps (Íñigo Huguet) [2043454]
- iwlwifi: parse debug exclude data from firmware file (Íñigo Huguet) [2043454]
- iwlwifi: fw dump: add infrastructure for dump scrubbing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: correct sta-state logic for TDLS (Íñigo Huguet) [2043454]
- iwlwifi: api: fix struct iwl_wowlan_status_v7 kernel-doc (Íñigo Huguet) [2043454]
- iwlwifi: fix fw/img.c license statement (Íñigo Huguet) [2043454]
- iwlwifi: remove contact information (Íñigo Huguet) [2043454]
- iwlwifi: remove MODULE_AUTHOR() statements (Íñigo Huguet) [2043454]
- iwlwifi: api: remove unused RX status bits (Íñigo Huguet) [2043454]
- iwlwifi: add some missing kernel-doc in struct iwl_fw (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Remove antenna c references (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add support for 160Mhz in ranging measurements (Íñigo Huguet) [2043454]
- iwlwifi: add vendor specific capabilities for some RFs (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add lmac/umac PC info in case of error (Íñigo Huguet) [2043454]
- iwlwifi: mvm: disable RX-diversity in powersave (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix ieee80211_get_he_iftype_cap() iftype (Íñigo Huguet) [2043454]
- iwlwifi: Start scratch debug register for Bz family (Íñigo Huguet) [2043454]
- iwlwifi: Add support for more BZ HWs (Íñigo Huguet) [2043454]
- iwlwifi: Add support for getting rf id with blank otp (Íñigo Huguet) [2043454]
- cfg80211: fix kernel-doc for MBSSID EMA (Íñigo Huguet) [2043454]
- mac80211: Prevent AP probing during suspend (Íñigo Huguet) [2043454]
- nl80211: Add LC placeholder band definition to nl80211_band (Íñigo Huguet) [2043454]
- mac80211: split beacon retrieval functions (Íñigo Huguet) [2043454]
- cfg80211: separate get channel number from ies (Íñigo Huguet) [2043454]
- mac80211: use ieee80211_bss_get_elem() in most places (Íñigo Huguet) [2043454]
- cfg80211: scan: use element finding functions in easy cases (Íñigo Huguet) [2043454]
- nl80211: use element finding functions (Íñigo Huguet) [2043454]
- mac80211: fils: use cfg80211_find_ext_elem() (Íñigo Huguet) [2043454]
- mac80211: fix memory leaks with element parsing (Íñigo Huguet) [2043454]
- cfg80211: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- mac80211: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wireless: mac80211_hwsim: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- mac80211: debugfs: calculate free buffer size correctly (Íñigo Huguet) [2043454]
- fq_codel: generalise ce_threshold marking for subset of traffic (Íñigo Huguet) [2043454]
- wl3501_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- ray_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wilc1000: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- brcmfmac: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() instead of ether_addr_copy() (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- iwlwifi: cfg: set low-latency-xtal for some integrated So devices (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: read EFI data only if long enough (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: don't kmemdup() more than we have (Íñigo Huguet) [2043454]
- iwlwifi: change all JnP to NO-160 configuration (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reset PM state on unsuccessful resume (Íñigo Huguet) [2043454]
- mwifiex: Deactive host sleep using HSCFG after it was activated manually (Íñigo Huguet) [2043454]
- mwifiex: Send DELBA requests according to spec (Íñigo Huguet) [2043454]
- mwifiex: Fix an incorrect comment (Íñigo Huguet) [2043454]
- mwifiex: Log an error on command failure during key-material upload (Íñigo Huguet) [2043454]
- mwifiex: Don't log error on suspend if wake-on-wlan is disabled (Íñigo Huguet) [2043454]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2043454]
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd() (Íñigo Huguet) [2043454]
- mt76: mt7915: change max rx len limit of hw modules (Íñigo Huguet) [2043454]
- mt76: mt7915: fix missing HE phy cap (Íñigo Huguet) [2043454]
- mt76: mt7915: rework mt7915_mcu_sta_muru_tlv() (Íñigo Huguet) [2043454]
- mt76: mt7915: enable HE UL MU-MIMO (Íñigo Huguet) [2043454]
- mt76: mt7921: add per-vif counters in ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: add sta stats accounting in mt7921_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce stats reporting through ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: add some more MIB counters (Íñigo Huguet) [2043454]
- mt76: do not reset MIB counters in get_stats callback (Íñigo Huguet) [2043454]
- mt76: mt7915: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: run mt7915_get_et_stats holding mt76 mutex (Íñigo Huguet) [2043454]
- mt76: move mt76_ethtool_worker_info in mt76 module (Íñigo Huguet) [2043454]
- mt76: move mt76_sta_stats in mt76.h (Íñigo Huguet) [2043454]
- mt76: mt76x0: correct VHT MCS 8/9 tx power eeprom offset (Íñigo Huguet) [2043454]
- mt76: mt7921s: add reset support (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921s support (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mt7921_mcu_send_message (Íñigo Huguet) [2043454]
- mt76: mt7921: rely on mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: connac: extend mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: sdio: extend sdio module to support CONNAC2 (Íñigo Huguet) [2043454]
- mt76: sdio: introduce parse_irq callback (Íñigo Huguet) [2043454]
- mt76: sdio: move common code in mt76_sdio module (Íñigo Huguet) [2043454]
- mt76: mt7921: use physical addr to unify register access (Íñigo Huguet) [2043454]
- mt76: mt7921: make all event parser reusable between mt7921s and mt7921e (Íñigo Huguet) [2043454]
- mt76: mt7663s: rely on mcu reg access utility (Íñigo Huguet) [2043454]
- mt76: connac: move mcu reg access utility routines in mt76_connac_lib module (Íñigo Huguet) [2043454]
- mt76: mt7921: add MT7921_COMMON module (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor init.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mcu.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor dma.c to be pcie specific (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mac.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: add MU EDCA cmd support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove dead code in debugfs code (Íñigo Huguet) [2043454]
- mt76: sdio: export mt76s_alloc_rx_queue and mt76s_alloc_tx routines (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability for xmit-queue handler (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt76 debugfs sub-dir for ext-phy (Íñigo Huguet) [2043454]
- mt76: rely on phy pointer in mt76_register_debugfs_fops routine signature (Íñigo Huguet) [2043454]
- mt76: mt7915: set muru platform type (Íñigo Huguet) [2043454]
- mt76: mt7915: set VTA bit in tx descriptor (Íñigo Huguet) [2043454]
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req() (Íñigo Huguet) [2043454]
- mt76: mt7915: rework starec TLV tags (Íñigo Huguet) [2043454]
- mt76: mt7915: fix sta_rec_wtbl tag len (Íñigo Huguet) [2043454]
- mt76: mt7915: improve starec readability of txbf (Íñigo Huguet) [2043454]
- mt76: mt7915: fix txbf starec TLV issues (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2043454]
- mt76: connac: fix possible NULL pointer dereference in mt76_connac_get_phy_mode_v2 (Íñigo Huguet) [2043454]
- mt76: do not access 802.11 header in ccmp check for 802.3 rx skbs (Íñigo Huguet) [2043454]
- mt76: use a separate CCMP PN receive counter for management frames (Íñigo Huguet) [2043454]
- mt76: mt7921: add delay config for sched scan (Íñigo Huguet) [2043454]
- mt76: mt7615: fix monitor mode tear down crash (Íñigo Huguet) [2043454]
- mt76: debugfs: improve queue node readability (Íñigo Huguet) [2043454]
- mt76: mt7915: add twt_stats knob in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: enable twt responder capability (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mac_add_twt_setup routine (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_twt_agrt_update mcu command (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce __mt7915_get_tsf routine (Íñigo Huguet) [2043454]
- mt76: drop MCU header size from buffer size in __mt76_mcu_send_firmware (Íñigo Huguet) [2043454]
- mt76: introduce __mt76_mcu_send_firmware routine (Íñigo Huguet) [2043454]
- mt76: support reading EEPROM data embedded in fdt (Íñigo Huguet) [2043454]
- mt76: schedule status timeout at dma completion (Íñigo Huguet) [2043454]
- mt76: substitute sk_buff_head status_list with spinlock_t status_lock (Íñigo Huguet) [2043454]
- mt76: remove mt76_wcid pointer from mt76_tx_status_check signature (Íñigo Huguet) [2043454]
- mt76: introduce packet_id idr (Íñigo Huguet) [2043454]
- mt76: mt7921: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: connac: enable hw amsdu @ 6GHz (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_uni_add_bss (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_sta_tlv (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in single-sku support (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_set_channel_domain (Íñigo Huguet) [2043454]
- mt76: connac: enable 6GHz band for hw scan (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in mt76_connac_get_phy_mode{,v2} (Íñigo Huguet) [2043454]
- mt76: mt7915: add mib counters to ethtool stats (Íñigo Huguet) [2043454]
- mt76: mt7915: add more MIB registers (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx mu/su counters to mib (Íñigo Huguet) [2043454]
- mt76: mt7915: add some per-station tx stats to ethtool (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx stats gathered from tx-status callbacks (Íñigo Huguet) [2043454]
- mt76: mt7915: add ethtool stats support (Íñigo Huguet) [2043454]
- mt76: mt7921: fix retrying release semaphore without end (Íñigo Huguet) [2043454]
- mt76: mt7921: robustify hardware initialization flow (Íñigo Huguet) [2043454]
- mt76: mt7915: fix possible infinite loop release semaphore (Íñigo Huguet) [2043454]
- mt76: mt7915: honor all possible error conditions in mt7915_mcu_init() (Íñigo Huguet) [2043454]
- mt76: move spin_lock_bh to spin_lock in tasklet (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mt7921_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mcu rate reporting code (Íñigo Huguet) [2043454]
- mt76: mt7921: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7921: add support for tx status reporting (Íñigo Huguet) [2043454]
- mt76: mt7921: start reworking tx rate reporting (Íñigo Huguet) [2043454]
- mt76: mt7615: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: enable configured beacon tx rate (Íñigo Huguet) [2043454]
- mt76: disable BH around napi_schedule() calls (Íñigo Huguet) [2043454]
- mt76: fill boottime_ns in Rx path (Íñigo Huguet) [2043454]
- mt76: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2043454]
- mt76: fix boolreturn.cocci warnings (Íñigo Huguet) [2043454]
- mt76: mt7921: update mib counters dumping phy stats (Íñigo Huguet) [2043454]
- mt76: mt7921: always wake device if necessary in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: rename debugfs tx-queues (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs queue info (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt7921_queue_rx_skb to mac.c (Íñigo Huguet) [2043454]
- mt76: mt7915: fix WMM index on DBDC cards (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability in mt7915_mcu_sta_bfer_ht (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce bss coloring support (Íñigo Huguet) [2043454]
- mt76: mt7915: add LED support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential NPE in TXS processing (Íñigo Huguet) [2043454]
- mt76: mt7915: fix he_mcs capabilities for 160mhz (Íñigo Huguet) [2043454]
- mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD (Íñigo Huguet) [2043454]
- mt76: mt7915: update mac timing settings (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warnings in mt7921_mac_decode_he_mu_radiotap (Íñigo Huguet) [2043454]
- mt76: mt7921: fix kernel warning from cfg80211_calculate_bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix firmware usage of RA info using legacy rates (Íñigo Huguet) [2043454]
- mt76: mt7915: add HE-LTF into fixed rate command (Íñigo Huguet) [2043454]
- mt76: mt7921: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt7615: move mt7615_mcu_set_p2p_oppps in mt76_connac module (Íñigo Huguet) [2043454]
- mt76: overwrite default reg_ops if necessary (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921_mcu_set_beacon_filter utility routine (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of mt7921_mac_set_beacon_filter (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of monitor_vif (Íñigo Huguet) [2043454]
- mt76: connac: add support for limiting to maximum regulatory Tx power (Íñigo Huguet) [2043454]
- mt76: connac: fix GTK rekey offload failure on WPA mixed mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix dma hang in rmmod (Íñigo Huguet) [2043454]
- mt76: add support for setting mcast rate (Íñigo Huguet) [2043454]
- mt76: mt7915: fix bit fields for HT rate idx (Íñigo Huguet) [2043454]
- mt76: mt7915: switch proper tx arbiter mode in testmode (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential overflow of eeprom page index (Íñigo Huguet) [2043454]
- mt76: mt7921: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: add control knobs for thermal throttling (Íñigo Huguet) [2043454]
- mt76: mt7921: Add mt7922 support (Íñigo Huguet) [2043454]
- mt76: mt7615: fix skb use-after-free on mac reset (Íñigo Huguet) [2043454]
- mt76: mt7921: Fix out of order process by invalid event pkt (Íñigo Huguet) [2043454]
- mt76: mt7915: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: add mt76_default_basic_rate more devices can rely on (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce testmode support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7915: cleanup -Wunused-but-set-variable (Íñigo Huguet) [2043454]
- mt76: mt7915: take RCU read lock when calling ieee80211_bss_get_elem() (Íñigo Huguet) [2043454]
- mt76: mt7915: fix an off-by-one bound check (Íñigo Huguet) [2043454]
- mt76: mt7921: add .set_sar_specs support (Íñigo Huguet) [2043454]
- mt76: mt7915: adapt new firmware to update BA winsize for Rx session (Íñigo Huguet) [2043454]
- mt76: mt7915: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c (Íñigo Huguet) [2043454]
- mt76: mt7921: fix survey-dump reporting (Íñigo Huguet) [2043454]
- mt76: fix build error implicit enumeration conversion (Íñigo Huguet) [2043454]
- mt76: mt7921: enable aspm by default (Íñigo Huguet) [2043454]
- mt76: connac: fix mt76_connac_gtk_rekey_tlv usage (Íñigo Huguet) [2043454]
- mt76: mt7915: fix calling mt76_wcid_alloc with incorrect parameter (Íñigo Huguet) [2043454]
- mt76: mt7915: fix info leak in mt7915_mcu_set_pre_cal() (Íñigo Huguet) [2043454]
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warning in mt7921_update_txs (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endianness warning in mt7915_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: avoid unnecessary spin_lock/spin_unlock in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- rtw89: Remove redundant check of ret after call to rtw89_mac_enable_bb_rf (Íñigo Huguet) [2043454]
- rtw89: Fix two spelling mistakes in debug messages (Íñigo Huguet) [2043454]
- mwifiex: Try waking the firmware until we get an interrupt (Íñigo Huguet) [2043454]
- mwifiex: Read a PCI register after writing the TX ring write pointer (Íñigo Huguet) [2043454]
- fq_codel: implement L4S style ce_threshold_ect1 marking (Íñigo Huguet) [2043454]
- net: add skb_get_dsfield() helper (Íñigo Huguet) [2043454]
- wireless: Remove redundant 'flush_workqueue()' calls (Íñigo Huguet) [2043454]
- mt7601u: Remove redundant initialization of variable ret (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192ee: Remove redundant initialization of variable version (Íñigo Huguet) [2043454]
- rtw89: add Realtek 802.11ax driver (Íñigo Huguet) [2043454]
- ath10k: fix max antenna gain unit (Íñigo Huguet) [2043454]
- ath9k: fix an IS_ERR() vs NULL check (Íñigo Huguet) [2043454]
- ath11k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2043454]
- ath9k: support DT ieee80211-freq-limit property to limit channels (Íñigo Huguet) [2043454]
- ath11k: Change number of TCL rings to one for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Handle MSI enablement during rmmod and SSR (Íñigo Huguet) [2043454]
- ath: dfs_pattern_detector: Fix possible null-pointer dereference in channel_detector_create() (Íñigo Huguet) [2043454]
- ath11k: Use kcalloc() instead of kzalloc() (Íñigo Huguet) [2043454]
- ath11k: Remove redundant assignment to variable fw_size (Íñigo Huguet) [2043454]
- ath11k: fix m68k and xtensa build failure in ath11k_peer_assoc_h_smps() (Íñigo Huguet) [2043454]
- ath11k: Fix spelling mistake "incompaitiblity" -> "incompatibility" (Íñigo Huguet) [2043454]
- ath11k: Remove unused variable in ath11k_dp_rx_mon_merg_msdus() (Íñigo Huguet) [2043454]
- ath9k: Fix potential interrupt storm on queue reset (Íñigo Huguet) [2043454]
- ath9k: add option to reset the wifi chip via debugfs (Íñigo Huguet) [2043454]
- ath10k: Don't always treat modem stop events as crashes (Íñigo Huguet) [2043454]
- rtl8xxxu: Use lower tx rates for the ack packet (Íñigo Huguet) [2043454]
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet (Íñigo Huguet) [2043454]
- rtw88: refine fw_crash debugfs to show non-zero while triggering (Íñigo Huguet) [2043454]
- rtw88: fix RX clock gate setting while fifo dump (Íñigo Huguet) [2043454]
- net: qrtr: combine nameservice into main module (Íñigo Huguet) [2043454]
- ath10k: sdio: Add missing BH locking around napi_schdule() (Íñigo Huguet) [2043454]
- ath10k: Fix missing frame timestamp for beacon/probe-resp (Íñigo Huguet) [2043454]
- ath10k: high latency fixes for beacon buffer (Íñigo Huguet) [2043454]
- ath11k: Change DMA_FROM_DEVICE to DMA_TO_DEVICE when map reinjected packets (Íñigo Huguet) [2043454]
- ath11k: support SMPS configuration for 6 GHz (Íñigo Huguet) [2043454]
- ath11k: add 6 GHz params in peer assoc command (Íñigo Huguet) [2043454]
- ieee80211: Add new A-MPDU factor macro for HE 6 GHz peer caps (Íñigo Huguet) [2043454]
- ath11k: indicate to mac80211 scan complete with aborted flag for ATH11K_SCAN_STARTING state (Íñigo Huguet) [2043454]
- ath11k: indicate scan complete for scan canceled when scan running (Íñigo Huguet) [2043454]
- ath11k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED (Íñigo Huguet) [2043454]
- ath11k: add HTT stats support for new stats (Íñigo Huguet) [2043454]
- ath11k: Change masking and shifting in htt stats (Íñigo Huguet) [2043454]
- ath11k: Remove htt stats fixed size array usage (Íñigo Huguet) [2043454]
- ath11k: Replace HTT_DBG_OUT with scnprintf (Íñigo Huguet) [2043454]
- ath11k: Rename macro ARRAY_TO_STRING to PRINT_ARRAY_TO_BUF (Íñigo Huguet) [2043454]
- ath11k: Fix memory leak in ath11k_qmi_driver_event_work (Íñigo Huguet) [2043454]
- ath11k: Fix inaccessible debug registers (Íñigo Huguet) [2043454]
- ath11k: Drop MSDU with length error in DP rx path (Íñigo Huguet) [2043454]
- ath11k: copy cap info of 6G band under WMI_HOST_WLAN_5G_CAP for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: enable 6G channels for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: re-enable ht_cap/vht_cap for 5G band for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: fix survey dump collection in 6 GHz (Íñigo Huguet) [2043454]
- ath11k: fix packet drops due to incorrect 6 GHz freq value in rx status (Íñigo Huguet) [2043454]
- ath11k: add channel 2 into 6 GHz channel list (Íñigo Huguet) [2043454]
- mac80211: MBSSID support in interface handling (Íñigo Huguet) [2043454]
- ath11k: Add wmi peer create conf event in wmi_tlv_event_id (Íñigo Huguet) [2043454]
- ath11k: Avoid "No VIF found" warning message (Íñigo Huguet) [2043454]
- ath11k: Fix crash during firmware recovery on reo cmd ring access (Íñigo Huguet) [2043454]
- ath11k: Assign free_vdev_map value before ieee80211_register_hw (Íñigo Huguet) [2043454]
- ath11k: Add vdev start flag to disable hardware encryption (Íñigo Huguet) [2043454]
- ath11k: Avoid race during regd updates (Íñigo Huguet) [2043454]
- ath11k: Avoid reg rules update during firmware recovery (Íñigo Huguet) [2043454]
- ath11k: Update pdev tx and rx firmware stats (Íñigo Huguet) [2043454]
- ath11k: Fix pktlog lite rx events (Íñigo Huguet) [2043454]
- ath11k: Add support for RX decapsulation offload (Íñigo Huguet) [2043454]
- ath11k: fix some sleeping in atomic bugs (Íñigo Huguet) [2043454]
- ath11k: qmi: avoid error messages when dma allocation fails (Íñigo Huguet) [2043454]
- ath11k: Replace one-element array with flexible-array member (Íñigo Huguet) [2043454]
- ath11k: add caldata download support from EEPROM (Íñigo Huguet) [2043454]
- ath11k: add caldata file for multiple radios (Íñigo Huguet) [2043454]
- ath11k: clean up BDF download functions (Íñigo Huguet) [2043454]
- ath11k: use hw_params to access board_size and cal_offset (Íñigo Huguet) [2043454]
- ath11k: Wstringop-overread warning (Íñigo Huguet) [2043454]
- ath11k: Add spectral scan support for QCN9074 (Íñigo Huguet) [2043454]
- ath11k: Fix the spectral minimum FFT bin count (Íñigo Huguet) [2043454]
- ath11k: Introduce spectral hw configurable param (Íñigo Huguet) [2043454]
- ath11k: Refactor spectral FFT bin size (Íñigo Huguet) [2043454]
- ath11k: add support for 80P80 and 160 MHz bandwidth (Íñigo Huguet) [2043454]
- ath11k: add support for setting fixed HE rate/gi/ltf (Íñigo Huguet) [2043454]
- nl80211: MBSSID and EMA support in AP mode (Íñigo Huguet) [2043454]
- nl80211: don't kfree() ERR_PTR() value (Íñigo Huguet) [2043454]
- cfg80211: always free wiphy specific regdomain (Íñigo Huguet) [2043454]
- mac80211: save transmit power envelope element and power constraint (Íñigo Huguet) [2043454]
- mac80211: add parse regulatory info in 6 GHz operation information (Íñigo Huguet) [2043454]
- ieee80211: add power type definition for 6 GHz (Íñigo Huguet) [2043454]
- mac80211: twt: don't use potentially unaligned pointer (Íñigo Huguet) [2043454]
- cfg80211: AP mode driver offload for FILS association crypto (Íñigo Huguet) [2043454]
- ath11k: monitor mode clean up to use separate APIs (Íñigo Huguet) [2043454]
- ath11k: add separate APIs for monitor mode (Íñigo Huguet) [2043454]
- ath11k: move static function ath11k_mac_vdev_setup_sync to top (Íñigo Huguet) [2043454]
- rtw88: 8821c: correct 2.4G tx power for type 2/4 NIC (Íñigo Huguet) [2043454]
- rtw88: 8821c: support RFE type4 wifi NIC (Íñigo Huguet) [2043454]
- brcmfmac: Replace zero-length array with flexible array member (Íñigo Huguet) [2043454]
- mac80211_hwsim: enable 6GHz channels (Íñigo Huguet) [2043454]
- mac80211: use ieee802_11_parse_elems() in ieee80211_prep_channel() (Íñigo Huguet) [2043454]
- nl80211: don't put struct cfg80211_ap_settings on stack (Íñigo Huguet) [2043454]
- mac80211: always allocate struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mlme: find auth challenge directly (Íñigo Huguet) [2043454]
- mac80211: move CRC into struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mesh: clean up rx_bcn_presp API (Íñigo Huguet) [2043454]
- mac80211: reduce stack usage in debugfs (Íñigo Huguet) [2043454]
- nl80211: prefer struct_size over open coded arithmetic (Íñigo Huguet) [2043454]
- mac80211: check hostapd configuration parsing twt requests (Íñigo Huguet) [2043454]
- cfg80211: honour V=1 in certificate code generation (Íñigo Huguet) [2043454]
- rt2x00: remove duplicate USB device ID (Íñigo Huguet) [2043454]
- wilc1000: increase config packets response wait timeout limit (Íñigo Huguet) [2043454]
- wilc1000: use correct write command sequence in wilc_spi_sync_ext() (Íñigo Huguet) [2043454]
- wilc1000: add 'initialized' flag check before adding an element to TX queue (Íñigo Huguet) [2043454]
- wilc1000: invoke chip reset register before firmware download (Íñigo Huguet) [2043454]
- wilc1000: ignore clockless registers status response for SPI (Íñigo Huguet) [2043454]
- wilc1000: handle read failure issue for clockless registers (Íñigo Huguet) [2043454]
- wilc1000: add reset/terminate/repeat command support for SPI bus (Íñigo Huguet) [2043454]
- wilc1000: configure registers to handle chip wakeup sequence (Íñigo Huguet) [2043454]
- wilc1000: add new WID to pass wake_enable information to firmware (Íñigo Huguet) [2043454]
- wilc1000: fix possible memory leak in cfg_scan_result() (Íñigo Huguet) [2043454]
- wilc1000: move 'deinit_lock' lock init/destroy inside module probe (Íñigo Huguet) [2043454]
- mwifiex: Fix copy-paste mistake when creating virtual interface (Íñigo Huguet) [2043454]
- mwifiex: Properly initialize private structure on interface type changes (Íñigo Huguet) [2043454]
- mwifiex: Handle interface type changes from AP to STATION (Íñigo Huguet) [2043454]
- mwifiex: Allow switching interface type from P2P_CLIENT to P2P_GO (Íñigo Huguet) [2043454]
- mwifiex: Update virtual interface counters right after setting bss_type (Íñigo Huguet) [2043454]
- mwifiex: Use helper function for counting interface types (Íñigo Huguet) [2043454]
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION vif-type (Íñigo Huguet) [2043454]
- mwifiex: Use function to check whether interface type change is allowed (Íñigo Huguet) [2043454]
- mwifiex: Small cleanup for handling virtual interface type changes (Íñigo Huguet) [2043454]
- rtw88: move adaptivity mechanism to firmware (Íñigo Huguet) [2043454]
- rtw88: support adaptivity for ETSI/JP DFS region (Íñigo Huguet) [2043454]
- rtw88: add regulatory strategy by chip type (Íñigo Huguet) [2043454]
- rtw88: upgrade rtw_regulatory mechanism and mapping (Íñigo Huguet) [2043454]
- brcmfmac: fix incorrect error prints (Íñigo Huguet) [2043454]
- ath11k: Align bss_chan_info structure with firmware (Íñigo Huguet) [2043454]
- ath11k: add support in survey dump with bss_chan_info (Íñigo Huguet) [2043454]
- ath11k: Rename atf_config to flag1 in target_resource_config (Íñigo Huguet) [2043454]
- ath11k: fix 4addr multicast packet tx (Íñigo Huguet) [2043454]
- ath11k: fix 4-addr tx failure for AP and STA modes (Íñigo Huguet) [2043454]
- ath9k: owl-loader: fetch pci init values through nvmem (Íñigo Huguet) [2043454]
- ath9k: fetch calibration data via nvmem subsystem (Íñigo Huguet) [2043454]

* Tue Feb 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-68.el9]
- net: ena: Extract recurring driver reset code into a function (Petr Oros) [2038150]
- net: ena: Change the name of bad_csum variable (Petr Oros) [2038150]
- net: ena: Add debug prints for invalid req_id resets (Petr Oros) [2038150]
- net: ena: Remove ena_calc_queue_size_ctx struct (Petr Oros) [2038150]
- net: ena: Move reset completion print to the reset function (Petr Oros) [2038150]
- net: ena: Remove redundant return code check (Petr Oros) [2038150]
- net: ena: Update LLQ header length in ena documentation (Petr Oros) [2038150]
- net: ena: Change ENI stats support check to use capabilities field (Petr Oros) [2038150]
- net: ena: Add capabilities field with support for ENI stats capability (Petr Oros) [2038150]
- net: ena: Change return value of ena_calc_io_queue_size() to void (Petr Oros) [2038150]
- net: ena: Fix error handling when calculating max IO queues number (Petr Oros) [2038150]
- net: ena: Fix wrong rx request id by resetting device (Petr Oros) [2038150]
- net: ena: Fix undefined state when tx request id is out of bounds (Petr Oros) [2038150]
- net/packet: rx_owner_map depends on pg_vec (Hangbin Liu) [2050329] {CVE-2021-22600}
- powerpc: security: Lock down the kernel if booted in secure boot mode (Desnes A. Nunes do Rosario) [2041984]
- drm/i915: Flush TLBs before releasing backing store (Dave Airlie) [2044335] {CVE-2022-0330}
- sfc: The RX page_ring is optional (Íñigo Huguet) [2042801]
- sfc: Check null pointer of rx_queue->page_ring (Íñigo Huguet) [2042801]
- sfc_ef100: potential dereference of null pointer (Íñigo Huguet) [2042801]
- sfc: Don't use netif_info before net_device setup (Íñigo Huguet) [2042801]
- sfc: Export fibre-specific supported link modes (Íñigo Huguet) [2042801]
- sfc: Fix reading non-legacy supported link modes (Íñigo Huguet) [2042801]
- ethernet: constify references to netdev->dev_addr in drivers (Íñigo Huguet) [2042801]
- sfc: last resort fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- sfc: fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- RDMA/cma: Do not change route.addr.src_addr.ss_family (Kamal Heib) [2032069] {CVE-2021-4028}
- kernel/sched/sched.h: Exclude cpuidle from KABI (Prarit Bhargava) [2033340]
- redhat/configs: Disable CONFIG_SENSORS_NCT6683 in RHEL for arm/aarch64 (Dean Nelson) [2041186]
- kernel.spec: Add glibc-static build requirement (Prarit Bhargava)
- libbpf: Fix memleak in libbpf_netlink_recv() (Toke Høiland-Jørgensen) [2052543]
- libbpf: Use dynamically allocated buffer when receiving netlink messages (Toke Høiland-Jørgensen) [2052543]
- redhat/configs: Disable arch_hw disabled CONFIGS (Prarit Bhargava) [2053029]
- netfilter: conntrack: re-init state for retransmitted syn-ack (Florian Westphal) [2051973]
- netfilter: conntrack: move synack init code to helper (Florian Westphal) [2051973]
- ext4: fix remount with 'abort' option (Lukas Czerner) [2049657]
- thunderbolt: Enable retry logic for intra-domain control packets (David Arcari) [1960445]
- thunderbolt: Handle ring interrupt by reading interrupt status register (David Arcari) [1960445]
- thunderbolt: Add vendor specific NHI quirk for auto-clearing interrupt status (David Arcari) [1960445]
- thunderbolt: Fix port linking by checking all adapters (David Arcari) [1960445]
- thunderbolt: Do not read control adapter config space (David Arcari) [1960445]

* Tue Feb 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-67.el9]
- kabi: Adding symbol strncpy_from_user (lib/strncpy_from_user.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtoull (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtol (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memparse (lib/cmdline.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strsep (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol kstrtoll (lib/kstrtox.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __bitmap_weight (lib/bitmap.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsnprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strstr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strrchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcat (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strnlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol snprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol dump_stack (lib/dump_stack.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sscanf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memset (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memmove (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __list_add_valid (lib/list_debug.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_to_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_from_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- block: bio-integrity: Advance seed correctly for larger interval sizes (Ming Lei) [2044184]
- blk-mq: Fix wrong wakeup batch configuration which will cause hang (Ming Lei) [2044184]
- block: fix memory leak in disk_register_independent_access_ranges (Ming Lei) [2044184]
- block: fix async_depth sysfs interface for mq-deadline (Ming Lei) [2044184]
- blk-mq: fix tag_get wait task can't be awakened (Ming Lei) [2044184]
- block: Fix wrong offset in bio_truncate() (Ming Lei) [2044184]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Ming Lei) [2044184]
- block: Fix fsync always failed if once failed (Ming Lei) [2044184]
- block: don't protect submit_bio_checks by q_usage_counter (Ming Lei) [2044184]
- blk-mq: use bio->bi_opf after bio is checked (Ming Lei) [2044184]
- block: fix double bio queue when merging in cached request path (Ming Lei) [2044184]
- blk-mq: cleanup request allocation (Ming Lei) [2044184]
- blk-mq: simplify the plug handling in blk_mq_submit_bio (Ming Lei) [2044184]
- block: null_blk: only set set->nr_maps as 3 if active poll_queues is > 0 (Ming Lei) [2044184]
- null_blk: allow zero poll queues (Ming Lei) [2044184]
- iocost: Fix divide-by-zero on donation from low hweight cgroup (Ming Lei) [2044184]
- block: fix ioprio_get(IOPRIO_WHO_PGRP) vs setuid(2) (Ming Lei) [2044184]
- block: fix single bio async DIO error handling (Ming Lei) [2044184]
- usb: xhci: Extend support for runtime power management for AMD's Yellow carp. (Renjith Pananchikkal) [2015776]
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp platform (Renjith Pananchikkal) [2015776]
- redhat: switch the vsyscall config to CONFIG_LEGACY_VSYSCALL_XONLY=y (Herton R. Krzesinski) [2023041]
- ice: Implement support for SMA and U.FL on E810-T (Jonathan Toppins) [1975008]
- ice: Add support for SMA control multiplexer (Jonathan Toppins) [1975008]
- ice: Implement functions for reading and setting GPIO pins (Jonathan Toppins) [1975008]
- ice: Refactor ice_aqc_link_topo_addr (Jonathan Toppins) [1975008]

* Mon Feb 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-66.el9]
- lockd: fix failure to cleanup client locks (Scott Mayhew) [2049200]
- lockd: fix server crash on reboot of client holding lock (Scott Mayhew) [2049200]
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie (Scott Mayhew) [2049200]
- tracing: Fix mismatched comment in __string_len (Scott Mayhew) [2049200]
- nfs: block notification on fs with its own ->lock (Scott Mayhew) [2049200]
- NFSD: Fix READDIR buffer overflow (Scott Mayhew) [2049200]
- nfsd: fix use-after-free due to delegation race (Scott Mayhew) [2049200]
- nfsd: Fix nsfd startup race (again) (Scott Mayhew) [2049200]
- SUNRPC: use different lock keys for INET6 and LOCAL (Scott Mayhew) [2049200]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Scott Mayhew) [2049200]
- NFSv42: Fix pagecache invalidation after COPY/CLONE (Scott Mayhew) [2049200]
- NFS: Add a tracepoint to show the results of nfs_set_cache_invalid() (Scott Mayhew) [2049200]
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed (Scott Mayhew) [2049200]
- NFSD: Fix exposure in nfsd4_decode_bitmap() (Scott Mayhew) [2049200]
- NFSv4: Sanity check the parameters in nfs41_update_target_slotid() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from decode_getattr_*() functions (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_setsecurity (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_fhget() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_add_or_obtain() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_instantiate() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_setattrres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_getattr_res (Scott Mayhew) [2049200]
- NFS: Remove the f_label from the nfs4_opendata and nfs_openres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_lookupp_res struct (Scott Mayhew) [2049200]
- NFS: Remove the label from the nfs4_lookup_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_link_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_create_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_entry struct (Scott Mayhew) [2049200]
- NFS: Create a new nfs_alloc_fattr_with_label() function (Scott Mayhew) [2049200]
- NFS: Always initialise fattr->label in nfs_fattr_alloc() (Scott Mayhew) [2049200]
- NFSv4.2: alloc_file_pseudo() takes an open flag, not an f_mode (Scott Mayhew) [2049200]
- NFS: Don't allocate nfs_fattr on the stack in __nfs42_ssc_open() (Scott Mayhew) [2049200]
- NFSv4: Remove unnecessary 'minor version' check (Scott Mayhew) [2049200]
- NFSv4: Fix potential Oops in decode_op_map() (Scott Mayhew) [2049200]
- NFSv4: Ensure decode_compound_hdr() sanity checks the tag (Scott Mayhew) [2049200]
- NFS: Don't trace an uninitialised value (Scott Mayhew) [2049200]
- SUNRPC: Prevent immediate close+reconnect (Scott Mayhew) [2049200]
- SUNRPC: Fix races when closing the socket (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to OFFLOAD_CANCEL (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY_NOTIFY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CB_OFFLOAD (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CLONE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoints to FALLOCATE and DEALLOCATE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to SEEK (Scott Mayhew) [2049200]
- SUNRPC: Check if the xprt is connected before handling sysfs reads (Scott Mayhew) [2049200]
- nfs4: take a reference on the nfs_client when running FREE_STATEID (Scott Mayhew) [2049200]
- NFS: Add offset to nfs_aop_readahead tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Fix a maybe-uninitialized compiler warning (Scott Mayhew) [2049200]
- NFS: Move NFS protocol display macros to global header (Scott Mayhew) [2049200]
- NFS: Move generic FS show macros to global header (Scott Mayhew) [2049200]
- nfsd4: remove obselete comment (Scott Mayhew) [2049200]
- SUNRPC: Clean up xs_tcp_setup_sock() (Scott Mayhew) [2049200]
- SUNRPC: Replace use of socket sk_callback_lock with sock_lock (Scott Mayhew) [2049200]
- NFSv4: Fix a regression in nfs_set_open_stateid_locked() (Scott Mayhew) [2049200]
- fsnotify: Protect fsnotify_handle_inode_event from no-inode events (Scott Mayhew) [2049200]
- NFS: Remove redundant call to __set_page_dirty_nobuffers (Scott Mayhew) [2049200]
- sunrpc: remove unnecessary test in rpc_task_set_client() (Scott Mayhew) [2049200]
- NFS: Unexport nfs_probe_fsinfo() (Scott Mayhew) [2049200]
- NFS: Call nfs_probe_server() during a fscontext-reconfigure event (Scott Mayhew) [2049200]
- NFS: Replace calls to nfs_probe_fsinfo() with nfs_probe_server() (Scott Mayhew) [2049200]
- NFS: Move nfs_probe_destination() into the generic client (Scott Mayhew) [2049200]
- NFS: Create an nfs4_server_set_init_caps() function (Scott Mayhew) [2049200]
- NFS: Remove --> and <-- dprintk call sites (Scott Mayhew) [2049200]
- SUNRPC: Trace calls to .rpc_call_done (Scott Mayhew) [2049200]
- NFS: Replace dprintk callsites in nfs_readpage(s) (Scott Mayhew) [2049200]
- SUNRPC: Use BIT() macro in rpc_show_xprt_state() (Scott Mayhew) [2049200]
- SUNRPC: Tracepoints should display tk_pid and cl_clid as a fixed-size field (Scott Mayhew) [2049200]
- xprtrdma: Remove rpcrdma_ep::re_implicit_roundup (Scott Mayhew) [2049200]
- xprtrdma: Provide a buffer to pad Write chunks of unaligned length (Scott Mayhew) [2049200]
- Fix user namespace leak (Scott Mayhew) [2049200]
- NFS: Save some space in the inode (Scott Mayhew) [2049200]
- NFS: Fix WARN_ON due to unionization of nfs_inode.nrequests (Scott Mayhew) [2049200]
- NFSv4: Fixes for nfs4_inode_return_delegation() (Scott Mayhew) [2049200]
- NFS: Fix an Oops in pnfs_mark_request_commit() (Scott Mayhew) [2049200]
- NFS: Fix up commit deadlocks (Scott Mayhew) [2049200]
- NFSD:fix boolreturn.cocci warning (Scott Mayhew) [2049200]
- nfsd: update create verifier comment (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_encode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_encode (Scott Mayhew) [2049200]
- NFSD: Save location of NFSv4 COMPOUND status (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: De-duplicate .pc_release() call sites (Scott Mayhew) [2049200]
- SUNRPC: Simplify the SVC dispatch code path (Scott Mayhew) [2049200]
- NFS: Fix deadlocks in nfs_scan_commit_list() (Scott Mayhew) [2049200]
- NFS: Instrument i_size_write() (Scott Mayhew) [2049200]
- SUNRPC: Per-rpc_clnt task PIDs (Scott Mayhew) [2049200]
- NFS: Remove unnecessary TRACE_DEFINE_ENUM()s (Scott Mayhew) [2049200]
- NFSD: Keep existing listeners on portlist error (Scott Mayhew) [2049200]
- nfs: Fix kerneldoc warning shown up by W=1 (Scott Mayhew) [2049200]
- SUNRPC: Capture value of xdr_buf::page_base (Scott Mayhew) [2049200]
- SUNRPC: Add trace event when alloc_pages_bulk() makes no progress (Scott Mayhew) [2049200]
- svcrdma: Split svcrmda_wc_{read,write} tracepoints (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_send() tracepoint (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_receive() tracepoint (Scott Mayhew) [2049200]
- pnfs/flexfiles: Fix misplaced barrier in nfs4_ff_layout_prepare_ds (Scott Mayhew) [2049200]
- NFS: Remove unnecessary page cache invalidations (Scott Mayhew) [2049200]
- NFS: Do not flush the readdir cache in nfs_dentry_iput() (Scott Mayhew) [2049200]
- NFS: Fix dentry verifier races (Scott Mayhew) [2049200]
- NFS: Further optimisations for 'ls -l' (Scott Mayhew) [2049200]
- NFS: Fix up nfs_readdir_inode_mapping_valid() (Scott Mayhew) [2049200]
- NFS: Ignore the directory size when marking for revalidation (Scott Mayhew) [2049200]
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA (Scott Mayhew) [2049200]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Scott Mayhew) [2049200]
- NFSv4: Retrieve ACCESS on open if we're not using NFS4_CREATE_EXCLUSIVE (Scott Mayhew) [2049200]
- NFS: Fix a few more clear_bit() instances that need release semantics (Scott Mayhew) [2049200]
- SUNRPC: xprt_clear_locked() only needs release memory semantics (Scott Mayhew) [2049200]
- SUNRPC: Remove unnecessary memory barriers (Scott Mayhew) [2049200]
- SUNRPC: Remove WQ_HIGHPRI from xprtiod (Scott Mayhew) [2049200]
- SUNRPC: Add cond_resched() at the appropriate point in __rpc_execute() (Scott Mayhew) [2049200]
- SUNRPC: Partial revert of commit 6f9f17287e78 (Scott Mayhew) [2049200]
- NFS: Fix up nfs_ctx_key_to_expire() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_rmdir() and nfs_unlink() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_link(), nfs_symlink() (Scott Mayhew) [2049200]
- NFSD: Have legacy NFSD WRITE decoders use xdr_stream_subsegment() (Scott Mayhew) [2049200]
- SUNRPC: xdr_stream_subsegment() must handle non-zero page_bases (Scott Mayhew) [2049200]
- NFSD: Initialize pointer ni with NULL and not plain integer 0 (Scott Mayhew) [2049200]
- NFSD: simplify struct nfsfh (Scott Mayhew) [2049200]
- NFSD: drop support for ancient filehandles (Scott Mayhew) [2049200]
- NFSD: move filehandle format declarations out of "uapi". (Scott Mayhew) [2049200]
- SUNRPC: fix sign error causing rpcsec_gss drops (Scott Mayhew) [2049200]
- nfsd: Fix a warning for nfsd_file_close_inode (Scott Mayhew) [2049200]
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero (Scott Mayhew) [2049200]
- nfsd: fix error handling of register_pernet_subsys() in init_nfsd() (Scott Mayhew) [2049200]
- UNRPC: Return specific error code on kmalloc failure (Scott Mayhew) [2049200]
- NFSD: Optimize DRC bucket pruning (Scott Mayhew) [2049200]
- nfsd: don't alloc under spinlock in rpc_parse_scope_id (Scott Mayhew) [2049200]
- nfsd: back channel stuck in SEQ4_STATUS_CB_PATH_DOWN (Scott Mayhew) [2049200]
- NLM: Fix svcxdr_encode_owner() (Scott Mayhew) [2049200]
- SUNRPC: improve error response to over-size gss credential (Scott Mayhew) [2049200]
- SUNRPC: don't pause on incomplete allocation (Scott Mayhew) [2049200]
- NFS: Always provide aligned buffers to the RPC read layers (Scott Mayhew) [2049200]
- NFSv4.1 add network transport when session trunking is detected (Scott Mayhew) [2049200]
- SUNRPC enforce creation of no more than max_connect xprts (Scott Mayhew) [2049200]
- NFSv4 introduce max_connect mount options (Scott Mayhew) [2049200]
- SUNRPC add xps_nunique_destaddr_xprts to xprt_switch_info in sysfs (Scott Mayhew) [2049200]
- SUNRPC keep track of number of transports to unique addresses (Scott Mayhew) [2049200]
- NFSv3: Delete duplicate judgement in nfs3_async_handle_jukebox (Scott Mayhew) [2049200]
- SUNRPC: Tweak TCP socket shutdown in the RPC client (Scott Mayhew) [2049200]
- SUNRPC: Simplify socket shutdown when not reusing TCP ports (Scott Mayhew) [2049200]
- nfsd: fix crash on LOCKT on reexported NFSv3 (Scott Mayhew) [2049200]
- nfs: don't allow reexport reclaims (Scott Mayhew) [2049200]
- lockd: don't attempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- nfs: don't atempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- Keep read and write fds with each nlm_file (Scott Mayhew) [2049200]
- lockd: update nlm_lookup_file reexport comment (Scott Mayhew) [2049200]
- nlm: minor refactoring (Scott Mayhew) [2049200]
- nlm: minor nlm_lookup_file argument change (Scott Mayhew) [2049200]
- lockd: lockd server-side shouldn't set fl_ops (Scott Mayhew) [2049200]
- SUNRPC: Server-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Move client-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Add a /sys/kernel/debug/fail_sunrpc/ directory (Scott Mayhew) [2049200]
- redhat/configs: Add CONFIG_FAIL_SUNRPC (Scott Mayhew) [2049200]
- svcrdma: xpt_bc_xprt is already clear in __svc_rdma_free() (Scott Mayhew) [2049200]
- nfsd4: Fix forced-expiry locking (Scott Mayhew) [2049200]
- rpc: fix gss_svc_init cleanup on failure (Scott Mayhew) [2049200]
- SUNRPC: Add RPC_AUTH_TLS protocol numbers (Scott Mayhew) [2049200]
- lockd: change the proc_handler for nsm_use_hostnames (Scott Mayhew) [2049200]
- sysctl: introduce new proc handler proc_dobool (Scott Mayhew) [2049200]
- SUNRPC: Fix a NULL pointer deref in trace_svc_stats_latency() (Scott Mayhew) [2049200]
- NFSD: remove vanity comments (Scott Mayhew) [2049200]
- svcrdma: Convert rdma->sc_rw_ctxts to llist (Scott Mayhew) [2049200]
- svcrdma: Relieve contention on sc_send_lock. (Scott Mayhew) [2049200]
- svcrdma: Fewer calls to wake_up() in Send completion handler (Scott Mayhew) [2049200]
- lockd: Fix invalid lockowner cast after vfs_test_lock (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for nfsd_clid_class (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for the nfs_dirent tracepoint (Scott Mayhew) [2049200]
- tracing: Add trace_event helper macros __string_len() and __assign_str_len() (Scott Mayhew) [2049200]
- NFSD: Batch release pages during splice read (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst_replace_page() API (Scott Mayhew) [2049200]
- NFSD: Clean up splice actor (Scott Mayhew) [2049200]
- NFSv4.2: remove restriction of copy size for inter-server copy. (Scott Mayhew) [2049200]
- NFS: Clean up the synopsis of callback process_op() (Scott Mayhew) [2049200]
- NFS: Extract the xdr_init_encode/decode() calls from decode_compound (Scott Mayhew) [2049200]
- NFS: Remove unused callback void decoder (Scott Mayhew) [2049200]
- NFS: Add a private local dispatcher for NFSv4 callback operations (Scott Mayhew) [2049200]
- SUNRPC: Eliminate the RQ_AUTHERR flag (Scott Mayhew) [2049200]
- SUNRPC: Set rq_auth_stat in the pg_authenticate() callout (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst::rq_auth_stat (Scott Mayhew) [2049200]
- SUNRPC: Add dst_port to the sysfs xprt info file (Scott Mayhew) [2049200]
- SUNRPC: Add srcaddr as a file in sysfs (Scott Mayhew) [2049200]
- sunrpc: Fix return value of get_srcport() (Scott Mayhew) [2049200]
- SUNRPC/xprtrdma: Fix reconnection locking (Scott Mayhew) [2049200]
- SUNRPC: Clean up scheduling of autoclose (Scott Mayhew) [2049200]
- SUNRPC: Fix potential memory corruption (Scott Mayhew) [2049200]
- NFSv4/pnfs: The layout barrier indicate a minimal value for the seqid (Scott Mayhew) [2049200]
- NFSv4/pNFS: Always allow update of a zero valued layout barrier (Scott Mayhew) [2049200]
- NFSv4/pNFS: Remove dead code (Scott Mayhew) [2049200]
- NFSv4/pNFS: Fix a layoutget livelock loop (Scott Mayhew) [2049200]
- SUNRPC: Convert rpc_client refcount to use refcount_t (Scott Mayhew) [2049200]
- xprtrdma: Eliminate rpcrdma_post_sends() (Scott Mayhew) [2049200]
- xprtrdma: Add an xprtrdma_post_send_err tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Add xprtrdma_post_recvs_err() tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Put rpcrdma_reps before waking the tear-down completion (Scott Mayhew) [2049200]
- xprtrdma: Disconnect after an ib_post_send() immediate error (Scott Mayhew) [2049200]
- SUNRPC: Record timeout value in xprt_retransmit tracepoint (Scott Mayhew) [2049200]
- SUNRPC: xprt_retransmit() displays the the NULL procedure incorrectly (Scott Mayhew) [2049200]
- SUNRPC: Update trace flags (Scott Mayhew) [2049200]
- SUNRPC: Remove unneeded TRACE_DEFINE_ENUMs (Scott Mayhew) [2049200]
- SUNRPC: Unset RPC_TASK_NO_RETRANS_TIMEOUT for NULL RPCs (Scott Mayhew) [2049200]
- SUNRPC: Refactor rpc_ping() (Scott Mayhew) [2049200]

* Sat Feb 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-65.el9]
- ALSA: memalloc: Unify x86 SG-buffer handling (take#3) (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add mapping for MSI MPG X570S Carbon Max Wifi. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop CONFIG_PM ifdefs (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Use int for dB map values (Jaroslav Kysela) [2017320]
- ALSA: hda/tegra: Fix Tegra194 HDA reset failure (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Use ALC285_FIXUP_HP_GPIO_LED on another HP laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Add new AlderLake-P variant PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: Add AlderLake-N PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: use swap() to make code cleaner (Jaroslav Kysela) [2017320]
- ALSA: Fix some typo (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Consider ELD is invalid when no SAD is present (Jaroslav Kysela) [2017320]
- ALSA: hda: Remove redundant runtime PM calls (Jaroslav Kysela) [2017320]
- ALSA: hda: Do disconnect jacks at codec unbind (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: More comprehensive PM runtime setup for controller driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: fix build issue related to CODEC_PROBE_ENTRIES (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Report initial jack state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Re-order quirk entries for Lenovo (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2020 (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add speaker fixup for some Yoga 15ITL5 devices (Jaroslav Kysela) [2017320]
- tools headers UAPI: Sync sound/asound.h with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- ASoC: SOF: handle paused streams during system suspend (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: setup sched widgets during pipeline complete step (Jaroslav Kysela) [2017320]
- ASoC: SOF: free widgets in sof_tear_down_pipelines() for static pipelines (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct default value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct pcmif BE dai control flow (Jaroslav Kysela) [2017320]
- ALSA: RHEL - update kernel configs for RHEL 9.0 (Jaroslav Kysela) [2017320]
- ALSA: core: Fix SSID quirk lookup for subvendor=0 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Fix Jack detection after resume (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Increase delay during jack detection (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Master after reboot from Windows (Jaroslav Kysela) [2017320]
- ASoC: Intel: catpt: Test dmaengine_submit() result before moving on (Jaroslav Kysela) [2017320]
- ASoC: amd: Fix dependency for SPI master (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio 1810c's ID (Jaroslav Kysela) [2017320]
- ALSA: oss: fix compile error when OSS_DEBUG is enabled (Jaroslav Kysela) [2017320]
- ALSA: hda: Make proper use of timecounter (Jaroslav Kysela) [2017320]
- ALSA: led: Use restricted type for iface assignment (Jaroslav Kysela) [2017320]
- ALSA: hda: Fix potential deadlock at codec unbinding (Jaroslav Kysela) [2017320]
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: fix jack detection on HP Spectre x360 convertible (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (Jaroslav Kysela) [2017320]
- ALSA: rawmidi - fix the uninitalized user_pversion (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: go through HDAS ACPI at max depth of 2 (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: harden detection of controller (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Disable silent stream on GLK (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Move AIU_I2S_MISC hold setting to aiu-fifo-i2s (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: fifo: Add missing dma_coerce_mask_and_coherent() (Jaroslav Kysela) [2017320]
- ASoC: tas2770: Fix setting of high sample rates (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix the wrong jack type detected (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add new alc285-hp-amp-init model (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6 (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore headphones jack name on Nyan Big (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add DAPM switches for headphones and mic jack (Jaroslav Kysela) [2017320]
- ALSA: jack: Check the return value of kstrdup() (Jaroslav Kysela) [2017320]
- ALSA: drivers: opl3: Fix incorrect use of vp->state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897 platform (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add new ADL-P variant (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add ADL-N support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Reorder snd_djm_devices[] entries (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ALSA: ctl: Fix copy of updated id with element read/write (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Handle missing errors in snd_pcm_oss_change_params*() (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Limit the period size to 16MB (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Fix negative period/buffer sizes (Jaroslav Kysela) [2017320]
- ASoC: codecs: wsa881x: fix return values from kcontrol put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return correct value from mixer put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: handle channel mappping list correctly (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Fix return value from msm_routing_put_audio_mixer (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: fix HDA codec entry table order for ADL-P (Jaroslav Kysela) [2017320]
- ALSA: hda: Add Intel DG2 PCI ID and HDMI codec vid (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Retry codec probing if it fails (Jaroslav Kysela) [2017320]
- ASoC: amd: fix uninitialized variable in snd_acp6x_probe() (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set PMSG_ON earlier inside cs8409 driver (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Balance runtime PM count (Jaroslav Kysela) [2017320]
- ASoC: SOF: hda: reset DAI widget before reconfiguring it (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Set the max SPI speed for the whole device (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for CML devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on CML (Jaroslav Kysela) [2017320]
- ASoC: rk817: Add module alias for rk817-codec (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: Set mach->id field on comp_ids matches (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for JSL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Don't start stream for capture at prepare (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Switch back to non-latency mode at a later point (Jaroslav Kysela) [2017320]
- ALSA: ctxfi: Fix out-of-range access (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AHUB (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in ADMAIF (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (Jaroslav Kysela) [2017320]
- ASoC: stm32: i2s: fix 32 bits channel length without mclk (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: fix HPHR setting CLSH mask (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return error code correctly from hw_params (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix volatile register range (Jaroslav Kysela) [2017320]
- ASoC: topology: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: validate port id before setting up route (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: improve error reporting (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix q6asm_dai_prepare error handling (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Conditionally reset FrontEnd Mixer (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: qdsp6: q6prm: handle clk disable correctly (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: wm_adsp_control_add() error: uninitialized symbol 'ret' (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Drop stale variable assignment (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: fixup DMAEngine API (Jaroslav Kysela) [2017320]
- ASoC: SOF: build compression interface into snd_sof.ko (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173: Fix debugfs registration for components (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Re-detect the combo jack after resuming (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Avoid the unexpected IRQ event during going to suspend (Jaroslav Kysela) [2017320]
- ASoC: rt1011: revert 'I2S Reference' to SOC_ENUM_EXT (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add the compatibility with rt9120s (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Fix clock auto sync issue when fs is the multiple of 48 (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Update internal ocp level to the correct value (Jaroslav Kysela) [2017320]
- ALSA: fireworks: add support for Loud Onyx 1200f quirk (Jaroslav Kysela) [2017320]
- ALSA: hda: fix general protection fault in azx_runtime_idle (Jaroslav Kysela) [2017320]
- ALSA: hda: Free card instance properly at probe errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Remove a stale comment (Jaroslav Kysela) [2017320]
- ALSA: synth: missing check for possible NULL after the call to kstrdup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Use proper SG helpers for noncontig allocations (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Fix unaligned buffer addresses (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Track 16 (Jaroslav Kysela) [2017320]
- ALSA: PCM: Fix NULL dereference at mmap checks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B12 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B29 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B29 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B13 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B13 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B11 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B00 and 0B01 products (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0AF3 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0AF3 product (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173-rt5650: Rename Speaker control to Ext Spk (Jaroslav Kysela) [2017320]
- mfd: arizona: Split of_match table into I2C and SPI versions (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Cover regression by kctl change notification fix (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: fix hotplug when only codec is suspended (Jaroslav Kysela) [2017320]
- ALSA: timer: Unconditionally unlink slave instances, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Catch call with NULL snd_dma_buffer pointer (Jaroslav Kysela) [2017320]
- Revert "ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type" (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Traveler mk3 (Jaroslav Kysela) [2017320]
- ASoC: SOF:control: Fix variable type in snd_sof_refresh_control() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ (Jaroslav Kysela) [2017320]
- ALSA: timer: Fix use-after-free problem (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for Audient iD14 (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Change monitor widgets to siggens (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: Fix an error handling path in 'rsnd_node_count()' (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic3x: Make aic3x_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: use const for all uses of snd_soc_acpi_codecs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-cht: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-byt: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: use comp_ids to enumerate rt5682s (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: detect codec variant in probe function (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: add comp_ids field for machine driver matching (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1011 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: Stop dummy from overriding hwparams (Jaroslav Kysela) [2017320]
- ASoC: topology: Change topology device to card device (Jaroslav Kysela) [2017320]
- ASoC: topology: Use correct device for prints (Jaroslav Kysela) [2017320]
- ASoC: topology: Check for dapm widget completeness (Jaroslav Kysela) [2017320]
- ASoC: topology: Add header payload_size verification (Jaroslav Kysela) [2017320]
- ASoC: core: Remove invalid snd_soc_component_set_jack call (Jaroslav Kysela) [2017320]
- ASoC: codecs: tfa989x: Add support for tfa9897 RCV bit (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: select CONFIG_SND_SOC_ACPI (Jaroslav Kysela) [2017320]
- ASoC: Intel: glk_rt5682_max98357a: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_RT1015P (Jaroslav Kysela) [2017320]
- ASoC: es8316: add support for ESSX8336 ACPI _HID (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct configuring of switch inversion from ts-inv (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: remove TODO for interaction with userspace about control message (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix functional regression for Mackie Onyx 1640i in v5.14 or later (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: Fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: export meter information to userspace as float value (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: refine parser for meter information in register DSP models (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix null pointer dereference when polling hwdep character device (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: fix Kconfig dependencies (Jaroslav Kysela) [2017320]
- ASoC: rt5682-i2c: Use devm_clk_get_optional for optional clock (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on JSL (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Fix return value check in acp_machine_select() (Jaroslav Kysela) [2017320]
- ASoC: max98520: add max98520 audio amplifier driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: fix return value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: rename shadowed array (Jaroslav Kysela) [2017320]
- ASoC: mediatek: remove unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: nau8821: clarify out-of-bounds check (Jaroslav Kysela) [2017320]
- ASoC: nau8821: fix kernel-doc (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: use 'static' qualifier (Jaroslav Kysela) [2017320]
- ASoC: topology: handle endianness warning (Jaroslav Kysela) [2017320]
- ALSA: ua101: fix division by zero at probe (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_ACP_COMMON should depend on X86 && PCI (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_{LEGACY_MACH,SOF_MACH} should depend on X86 && PCI && I2C (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Wrap AMD Audio ACP components in SND_SOC_AMD_ACP_COMMON (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: free_irq() before powering-down on probe() fail (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Reset and power-down on remove() and failed probe() (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add support for q6prm-clocks (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6prm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm lpass dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm-dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add topology support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add Kconfig and Makefile (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add module configuration command helpers (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add basic pkt alloc support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-clocks: move audio-clocks to common file (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: move lpass audio ports to common file (Jaroslav Kysela) [2017320]
- ASoC: codecs: Change bulk clock voting to optional voting in digital codecs (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Update tx default values (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Enable tx top soundwire mic clock (Jaroslav Kysela) [2017320]
- ASoC: qcom: Add compatible names in va,wsa,rx,tx codec drivers for sc7280 (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add clock management for power saving (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add set_jack coponment support (Jaroslav Kysela) [2017320]
- ALSA: line6: fix control and interrupt message timeouts (Jaroslav Kysela) [2017320]
- ALSA: 6fire: fix control and bulk message timeouts (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix null pointer dereference on pointer cs_desc (Jaroslav Kysela) [2017320]
- ALSA: gus: fix null pointer dereference on pointer block (Jaroslav Kysela) [2017320]
- ALSA: mixer: fix deadlock in snd_mixer_oss_set_volume (Jaroslav Kysela) [2017320]
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove() (Jaroslav Kysela) [2017320]
- ASoC: qcom: common: Respect status = "disabled" on DAI link nodes (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Prevent NULL pointer deref in interrupt handler (Jaroslav Kysela) [2017320]
- ASoC: wm8962: Convert to devm_clk_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB for SND_SOC_MAX98357A (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Make cs35l41_remove() return void (Jaroslav Kysela) [2017320]
- ASoc: wm8900: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: tegra: Set default card name for Trimslice (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore AC97 support (Jaroslav Kysela) [2017320]
- ASoc: wm8731: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: doc: update codec example code (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add acp_machine struct for renoir platform. (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Downsizing the DAC volume scale (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-tdm-interface: manage formatters in trigger (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-card: make links nonatomic (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Remove unused runtime_suspend/runtime_resume callbacks (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14 (Jaroslav Kysela) [2017320]
- ALSA: mixer: oss: Fix racy access to slots (Jaroslav Kysela) [2017320]
- ASoC: cirrus: i2s: Prepare clock before using it (Jaroslav Kysela) [2017320]
- soundwire: qcom: add debugfs entry for soundwire register dump (Jaroslav Kysela) [2017320]
- soundwire: bus: stop dereferencing invalid slave pointer (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for RT5682-VS codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for Maxim amplifier codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add callback for machine driver on ACP (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Use generic dmaengine code (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: Dup static DAI template (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: improve return value handling (Jaroslav Kysela) [2017320]
- ASoC: Intel: Move soc_intel_is_foo() helpers to a generic header (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix a typo in snd_dma_buffer_sync() description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Drop superfluous snd_dma_buffer_sync() declaration (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix microphone sound on Jieli webcam. (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: Add Jack support (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: add support for TX and RX Macro dais (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow Carp platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add YC machine driver using dmic (Jaroslav Kysela) [2017320]
- ASoC: amd: create platform device for acp6x machine driver (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow carp acp6x drivers build (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver dma ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x irq handler (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add platform devices for acp6x pdm driver and dmic driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP6x IP register header (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add SOF audio support on Chrome board (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add legacy sound card support for Chrome audio (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add generic machine driver support for ACP cards (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add I2S support on Renoir platform (Jaroslav Kysela) [2017320]
- ASoC: amd: Add common framework to support I2S on ACP SOC (Jaroslav Kysela) [2017320]
- ALSA: uapi: Fix a C++ style comment in asound.h (Jaroslav Kysela) [2017320]
- ALSA: firewire: Fix C++ style comments in uapi header (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix refcount test (Jaroslav Kysela) [2017320]
- ASoC: meson: implement driver_name for snd_soc_card in meson-card-utils (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Make aic32x4_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: soc-core: accept zero format at snd_soc_runtime_set_dai_fmt() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: tidyup empty function (Jaroslav Kysela) [2017320]
- ASoC: soc-component: add snd_soc_component_is_codec() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step2 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step1 (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-coherent page allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-contiguous page allocation (Jaroslav Kysela) [2017320]
- ALSA: ISA: not for M68K (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Strip out direct CRU use (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: notify event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: queue event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for line input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer source parameters in register-DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached hardware meter (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser for meter information in command DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser to gather meter information in register DSP model (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always enable TS_PLUG and TS_UNPLUG interrupts (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Fix WARN in remove() if running without an interrupt (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Mark OSC_SWITCH_STATUS register volatile (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Set correct SRC MCLK (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Allow time for HP/ADC to power-up after enable (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use PLL for SCLK > 12.288MHz (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't claim to support 192k (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't set defaults for volatile registers (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct some register default values (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always configure both ASP TX channels (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't reconfigure the PLL while it is running (Jaroslav Kysela) [2017320]
- ASoC: soc-component: improve error reporting for register access (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh machine driver (Jaroslav Kysela) [2017320]
- ASoc: amd: create platform device for VG machine driver (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Nulti) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Single) (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 Custom Sample (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Codec2Codec support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add DPCM support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Multi CPU/Codec support (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 driver (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add codec2codec support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add asoc_graph_is_ports0() (Jaroslav Kysela) [2017320]
- ASoC: test-component: add Test Component for Sound debug/test (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fixes HP Spectre x360 15-eb1xxx speakers (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset (Jaroslav Kysela) [2017320]
- ALSA: pcm: Unify snd_pcm_delay() and snd_pcm_hwsync() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Initialize every feature unit once at probe time (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous error message after disconnection (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Downgrade error message in get_ctl_value_v2() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add Schiit Hel device to quirk table (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix a little pop while playback (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control (Jaroslav Kysela) [2017320]
- ASoC: wm8960: Fix clock configuration on slave mode (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [2017320]
- ASoC: mediatek: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Drop rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for VF0770 (Jaroslav Kysela) [2017320]
- ALSA: hda: avoid write to STATESTS if controller is in reset (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Less restriction for low-latency playback mode (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS G551JW (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control caused error (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Ensure 0dB full scale volume is used for headsets (Jaroslav Kysela) [2017320]
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat ioctl (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: amd: Kconfig: Select fch clock support with machine driver (Jaroslav Kysela) [2017320]
- ASoC: soc-core: fix null-ptr-deref in snd_soc_del_component_unlocked() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo 13s Gen2 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add support for the Pioneer DJM 750MK2 Mixer/Soundcard (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix error handling on i2s_tdm_prepare_enable_mclk failure (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Remove call to rockchip_i2s_ch_to_io (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update audsys clock parent name (Jaroslav Kysela) [2017320]
- ASoC: SOF: prepare code to allocate IPC messages in fw_ready (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: restore mixer functionality (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix hp pop produced immediately after resuming (Jaroslav Kysela) [2017320]
- ASoC: rockchip: add support for i2s-tdm controller (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce fragment elapsed notification API (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Use newly introduced generic IPC stream ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Make Intel IPC stream ops generic (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce snd_sof_mailbox_read / snd_sof_mailbox_write callbacks (Jaroslav Kysela) [2017320]
- ASoC: SOF: pipelines: Harmonize all functions to use struct snd_sof_dev (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: do not power down primary core during topology removal (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Dump registers and stack when SOF_DBG_DUMP_REGS is set (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-loader: Drop SOF_DBG_DUMP_REGS flag from dbg_dump calls (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Drop SOF_DBG_DUMP_REGS flag when firmware start fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Clean up snd_sof_get_status() prints (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: Drop 'error' prefix from error dump functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce macro to set the firmware state (Jaroslav Kysela) [2017320]
- ASoC: SOF: ops: Force DSP panic dumps to be printed (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Re-enable dumps after successful IPC tx (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Print out the fw_state along with the DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop SOF_DBG_DUMP_FORCE_ERR_LEVEL and sof_dev_dbg_or_err (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda-loader: Use snd_sof_dsp_dbg_dump() for DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add SOF_DBG_DUMP_OPTIONAL flag for DSP dumping (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug/ops: Move the IPC and DSP dump functions out from the header (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: atom: No need to do a DSP dump in atom_run() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Print the DSP dump if boot fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: Print the dbg_dump and ipc_dump once to reduce kernel log noise (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc and dsp dump: Add markers for better visibility (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Swap the dsp_dump and ipc_dump sequence for fw_exception (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: debug: force all processing on primary core (Jaroslav Kysela) [2017320]
- ASoC: max98927: Handle reset gpio when probing i2c (Jaroslav Kysela) [2017320]
- ASoC: codec: wcd938x: Add irq config support (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Fix missing kctl change notifications (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Switch to use gpiod_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: Fix jack detection issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Pass JOINT_DUPLEX info flag for implicit fb streams (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add more disconnection checks at file ops (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: Allow repeatedly probing on codec configuration errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ASoC: SOF: OF: Add fw_path and tplg_path parameters (Jaroslav Kysela) [2017320]
- ASoC: amd: acp-rt5645: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: return error if sof_connect_dai_widget() fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: allow for dynamic pipelines override for debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: show clks_control value in dynamic debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: improve SSP DAI handling for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK/BCLK_ES bits (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: add new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: include new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: mirror group_id definition added in firmware (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add missing quirk for Dell SKU 0A45 (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add missing quirk for TGL SDCA single amp (Jaroslav Kysela) [2017320]
- ASoC: Intel: add machine driver for SOF+ES8336 (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for APL/GLK/TGL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: apl/glk/tgl: add entry for devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - ALC236 headset MIC recording issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Enable rate validation for Scarlett devices (Jaroslav Kysela) [2017320]
- ASoC: Intel: cht_bsw_nau8824: Set card.components string (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add a nau8824_components() helper (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix NAU8824_JACK_LOGIC define (Jaroslav Kysela) [2017320]
- ASoC: rt5651: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ASoC: es8316: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Complete partial device name to avoid ambiguity (Jaroslav Kysela) [2017320]
- ASoC: nau8821: new driver (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: implement bypass mode from in to out (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add kernel parameter for topology verification (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add support for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: make sure DAI widget is set up before IPC (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce widget use_count (Jaroslav Kysela) [2017320]
- ASoC: SOF: Don't set up widgets during topology parsing (Jaroslav Kysela) [2017320]
- ASoC: SOF: restore kcontrols for widget during set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add new fields to snd_sof_route (Jaroslav Kysela) [2017320]
- AsoC: dapm: export a couple of functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: add helpers for widgets, kcontrols and dai config set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add new token for dynamic pipeline (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: Add access field in struct snd_sof_control (Jaroslav Kysela) [2017320]
- ASoC: topology: change the complete op in snd_soc_tplg_ops to return int (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8096: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix HP noise caused by SAR mode switch when the system resumes (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Enable ASRC auto-disable to fix pop during jack plug-in while playback (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: move of_node_put to remove function (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Remove conditional definition of debugfs data members (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix packet size calculation regression (Jaroslav Kysela) [2017320]
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with ALC3254 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: disable implicit feedback sync for Behringer UFX1204 and UFX1604 (Jaroslav Kysela) [2017320]
- soundwire: debugfs: use controller id and link_id for debugfs (Jaroslav Kysela) [2017320]
- ASoC: rt5682: move clk related code to rt5682_i2c_probe (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Add rpmsg audio support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: remove a repeated including (Jaroslav Kysela) [2017320]
- ASoC: SOF: Change SND_SOC_SOF_TOPLEVEL from config to menuconfig (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Revise the macro RT5682S_PLLB_SRC_MASK (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Use dev_dbg instead of pr_debug (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Remove the volatile SW reset register from reg_default (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix headphone vs headset, button-press detection no longer working (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix a potential UAF by wrong private_free call order (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Avoid killing in-flight URBs during draining (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Improved lowlatency playback support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add spinlock to stop_urbs() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Check available frames for the next packet size (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency mode for implicit feedback sync (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency playback for free-wheel mode (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Rename early_playback_start flag with lowlatency_playback (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix possible race at sync of urb completions (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Restrict rates for the shared clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision 5560 laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Use position buffer for SKL+ again (Jaroslav Kysela) [2017320]
- ALSA: hda: Reduce udelay() at SKL+ position reporting (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix a missing error check in scarlett gen2 mixer (Jaroslav Kysela) [2017320]
- ALSA: virtio: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2017320]
- ASoC: ux500: mop500: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: ti: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: update platform device name for Maxim amplifier (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Make the error prints consistent in tx_wait_done() (Jaroslav Kysela) [2017320]
- ASoC: SOF: prefix some terse and cryptic dev_dbg() with __func__ (Jaroslav Kysela) [2017320]
- ASoC: SOF: add error handling to snd_sof_ipc_msg_data() (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add missing of_node_put in probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: add header file for ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pm: fix a stale comment (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: Print stream name on STREAM_SD_OFFSET timeout (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Make hrtimer forwarding more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: fix potential locking issue (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_ext_stream: fix potential locking issues (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_stream: fix potential locking issue in snd_hdac_stream_assign() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix comment reference in __uac_clock_find_source (Jaroslav Kysela) [2017320]
- ASoC: ak4458: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak5558: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: dmaengine: Introduce module option prealloc_buffer_size_kbytes (Jaroslav Kysela) [2017320]
- ASoC: dwc-i2s: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4671: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: alc5623: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: bcm: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cpcap: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: codecs: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: ad193x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_dai_ops structs (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use two thresholds and increased wait time for manual type detection (Jaroslav Kysela) [2017320]
- ASoC: adav80x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1977: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau17x1: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1701: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1373: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1372: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ad1836: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ep93xx: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: samsung: add missing "fallthrough;" (Jaroslav Kysela) [2017320]
- ASoC: ak4642: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Use correct version to initialize Class H (Jaroslav Kysela) [2017320]
- ASoC: alc5632: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4104: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4118: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: zl38060: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- firmware: cs_dsp: add driver to support firmware loading on Cirrus Logic DSPs (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate wm_adsp specifics in cs_dsp_client_ops (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split out struct cs_dsp from struct wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: move firmware loading to client (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Pass firmware names as parameters when starting DSP core (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check of dsp->running to better place (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate generic cs_dsp_coeff_ctl handling (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move sys_config_size to wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split DSP power operations into helper functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate some ASoC and generic functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Introduce cs_dsp logging macros (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Rename generic DSP support (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Cancel ongoing work when removing controls (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Switch to using wm_coeff_read_ctrl for compressed buffers (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check for control existence (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove use of snd_ctl_elem_type_t (Jaroslav Kysela) [2017320]
- ASoC: cs4341: Add SPI device ID table (Jaroslav Kysela) [2017320]
- ASoC: pcm179x: Add missing entries SPI to device ID table (Jaroslav Kysela) [2017320]
- ALSA: rawmidi: introduce SNDRV_RAWMIDI_IOCTL_USER_PVERSION (Jaroslav Kysela) [2017320]
- ASoC: pl1022_rdk: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: pl1022_ds: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: mpc8610_hpcd: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-sgtl5000: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-hdmi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-es8328: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_ssi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-mqs: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-esai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-asoc-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: eureka-tlv320: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cros_ec_codec: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix truncated bytes in message tracepoints (Jaroslav Kysela) [2017320]
- ALSA: usx2y: Prefer struct_size over open coded arithmetic (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: Fix spelling mistake "Fronend" -> "Frontend" (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: Add support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: fsl: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Fix channel swap issue with ARC (Jaroslav Kysela) [2017320]
- ASoC: pcm512x: Mend accesses to the I2S_1 and I2S_2 registers (Jaroslav Kysela) [2017320]
- ASoC: codecs: max98390: simplify getting the adapter of a client (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ab8500: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Remove struct sof_ops_table and sof_get_ops() macro (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: make rt5682s_aif2_dai_ops and rt5682s_soc_component_dev (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based Mixer driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based ADX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based AMX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based SFC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based MVC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add routes for few AHUB modules (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: Fixup CPU endpoint hw_params in a BE<->BE link (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Increase maximum DAI links limit to 512 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: Don't reconnect an already active BE (Jaroslav Kysela) [2017320]
- ASoC: compress/component: Use module_get_when_open/put_when_close for cstream (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Convert the mark_module to void* (Jaroslav Kysela) [2017320]
- ASoC: 88pm860x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Rename sof_arch_ops to dsp_arch_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove redundant error check from sof_ipc_tx_message_unlocked (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Print 0x prefix for errors in ipc_trace/stream_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Clarify the parameter name for ipc_trace_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: trace: Omit error print when waking up trace sleepers (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: remove wrong fixup assignment on HDMITX (Jaroslav Kysela) [2017320]
- ASoC: au1x: Convert to modern terminology for DAI clocking (Jaroslav Kysela) [2017320]
- ASoC: atmel: Convert to new style DAI format definitions (Jaroslav Kysela) [2017320]
- misc: cs35l41: Remove unused pdn variable (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx8m: add SAI1 info (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Minor fix all errors reported by checkpatch.pl script (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Move probe work related code under a single if () branch (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Implement Manual Type detection as fallback (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-probes: Correct the function names used for snd_soc_cdai_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Rename hda-compress.c to hda-probes.c (Jaroslav Kysela) [2017320]
- ASoC: SOF: probe: Merge and clean up the probe and compress files (Jaroslav Kysela) [2017320]
- ASoC: SOF: compress: move and export sof_probe_compr_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pcm: Remove non existent CONFIG_SND_SOC_SOF_COMPRESS reference (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Add probe message logging to ipc_log_header() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Re-phrase the missing firmware error to avoid duplication (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: release_firmware() on load failure to avoid batching (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Setup Dolphin Headset Mic as Phantom Jack (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: "fix" PCXHR_REG_TO_PORT definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: No need to export the snd_sof_debugfs_io_item() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Use the generic ops for region debugfs handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add generic API and ops for DSP regions (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Do not use 'bar' as parameter for block_read/write (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: No need to export snd_sof_fw_parse_ext_data() (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Do not initialize the snd_sof_dsp_ops.read64 (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove snd_sof_dsp_mailbox_init() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: bdw: Set the mailbox offset directly in bdw_probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix a bunch of trivial code formating/style issues (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fixup the error messages (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Don't overwrite returned error code (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Combine adjacent register writes (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Use regmap_read_poll_timeout to wait for OTP boot (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix use of an uninitialised variable (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: Fix unexpected error in bind/unbind flow (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: load_firmware callback is mandatory, treat it like that (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: make array adda_dai_list static const (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Add missing of_node_put() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Relocate inline definitions from hda.h to hda.c for sdw (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Remove boot_firmware skl and iccmax_icl declarations (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dsp: Declare locally used functions as static (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop resindex_dma_base, dma_engine, dma_size from sof_dev_desc (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: Do no initialize resindex_dma_base (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_mx98360a board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015 board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015p board (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: SOF: Fix DSP oops stack dump output contents (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Unify mixer resume and reset_resume procedure (Jaroslav Kysela) [2017320]
- Revert "ALSA: hda: Drop workaround for a hang at shutdown again" (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix transmission method for Loud models based on OXFW971 (Jaroslav Kysela) [2017320]
- ASoC: pcm5102a: increase rate from 192k to 384k (Jaroslav Kysela) [2017320]
- ASoC: rt1011: add i2s reference control for rt1011 (Jaroslav Kysela) [2017320]
- ASoC: SOF: Handle control change notification from firmware (Jaroslav Kysela) [2017320]
- ASoC: mt8195: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: fix a typo in put operations for kcontrol (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: add soc specific data structure (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Add driver for ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix unused initialization of pointer etdm_data (Jaroslav Kysela) [2017320]
- ASoC: ti: rename CONFIG_SND_SOC_DM365_VOICE_CODEC_MODULE (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: allow module parameter to override dma trace Kconfig (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Make use of the helper function devm_platform_ioremap_resource() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: Move template info print soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: declare and add prefix to 'bt_uart_enable' symbol (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Remove unsued irqs_lock. (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: CS35L41 Boosted Smart Amplifier (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for path map (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for rk3568 pdm (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Add support for rv1126 pdm (Jaroslav Kysela) [2017320]
- ASoC: mediatek: common: handle NULL case in suspend/resume function (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_micfil: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_esai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: mediatek: add required config dependency (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probe for ISA interwave card (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probes of snd_gus_create() (Jaroslav Kysela) [2017320]
- ALSA: vx222: fix null-ptr-deref (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix concurrency between tx/rx (Jaroslav Kysela) [2017320]
- ASoC: mt8195: correct the dts parsing logic about DPTX and HDMITX (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Fix CONFIG_SND_SOC_SDW_MOCKUP select (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800 (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix headset background noise when S3 state (Jaroslav Kysela) [2017320]
- ASoC: mediatek: SND_SOC_MT8195 should depend on ARCH_MEDIATEK (Jaroslav Kysela) [2017320]
- ASoC: samsung: s3c24xx_simtec: fix spelling mistake "devicec" -> "device" (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: respawn Platform Support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add MTK_PMIC_WRAP dependency (Jaroslav Kysela) [2017320]
- ASoC: Revert PCM trigger changes (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add lowlatency module option (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Initialize Codec only in init fixup. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Ensure Type Detection is only run on startup when necessary (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Work around for XRUN with low latency playback (Jaroslav Kysela) [2017320]
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: protect BE dailink state changes in trigger (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Disable irq on slave ports in the remove function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a memory leak in the error handling path of the probe function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a double irq free in the remove function (Jaroslav Kysela) [2017320]
- ALSA: hda: Disable runtime resume at shutdown (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for frame inversion (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add compatible for more SoCs (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Make playback/capture optional (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup config for DAIFMT_DSP_A/B (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix regmap_ops hang (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Improve dma data transfer efficiency (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup clk div error (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for set bclk ratio (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Add support for rk3568 spdif (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Fix some coding style (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Mark SPDIF_SMPDR as volatile (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix spelling mistake "bitwiedh" -> "bitwidth" (Jaroslav Kysela) [2017320]
- ASoC: dwc: Get IRQ optionally (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: change dev_err to dev_err_probe for -EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix the vol+ button detection issue (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Make rt5640_jack_gpio/rt5640_jack2_gpio static (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: remove duplicate include (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add HDMITX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add DPTX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1019 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support pcm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support adda in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support etdm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support audsys clock control (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update mediatek common driver (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Put debugfs_remove_recursive back in (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move set-interface-first workaround into common quirk (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC (Jaroslav Kysela) [2017320]
- ASoC: rt1015: remove possible unused variable `bclk_ms' (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Mark hp_elitepad_1000g2_jack?_check functions static (Jaroslav Kysela) [2017320]
- ASoC: ics43432: add CMM-4030D-261 support (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select first entry for singular pipe config arrays (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Properly configure modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support multiple format configs (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Simplify m_state for loadable modules (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix passing loadable flag for module (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module resource and format selection (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select proper format for NHLT blob (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs (Jaroslav Kysela) [2017320]
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for max98373 (Jaroslav Kysela) [2017320]
- soundwire: cadence: do not extend reset delay (Jaroslav Kysela) [2017320]
- soundwire: intel: conditionally exit clock stop mode on system suspend (Jaroslav Kysela) [2017320]
- soundwire: intel: skip suspend/resume/wake when link was not started (Jaroslav Kysela) [2017320]
- soundwire: intel: fix potential race condition during power down (Jaroslav Kysela) [2017320]
- ASoC: intel: atom: Revert PCM buffer address setup workaround again (Jaroslav Kysela) [2017320]
- ALSA: doc: Fix indentation warning (Jaroslav Kysela) [2017320]
- ALSA: hda: Update documentation for aliasing via the model option (Jaroslav Kysela) [2017320]
- ALSA: hda: Allow model option to specify PCI SSID alias (Jaroslav Kysela) [2017320]
- ALSA: hda: Code refactoring snd_hda_pick_fixup() (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU 896HD (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS ROG Strix G17 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: adg: clearly handle clock error / NULL case (Jaroslav Kysela) [2017320]
- ASoC: rsnd: core: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for HP Elite Pad 1000G2 jack-detect (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytct_rt5640: Add a separate "Headset Mic 2" DAPM pin for the mic on the 2nd jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add rt5640_set_ovcd_params() helper (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add optional hp_det_gpio parameter to rt5640_detect_headset() (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Delay requesting IRQ until the machine-drv calls set_jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Move rt5640_disable_jack_detect() up in the rt5640.c file (Jaroslav Kysela) [2017320]
- ASoC: uniphier: make arrays mul and div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_dma_request function (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Check -EPROBE_DEFER for getting clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/analog - Sink ad198x_shutup() and shuffle CONFIG_PM guards (Jaroslav Kysela) [2017320]
- ALSA: hda/sigmatel - Sink stac_shutup() into stac_suspend() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use cfg-lineout:2 in the components string (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix wrong operator used issue (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ALSA: hda: Drop workaround for a hang at shutdown again (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix dereference of noderef expression warning (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: soc-ac97: cleanup cppcheck warning (Jaroslav Kysela) [2017320]
- ASoC: soc-component: cleanup cppcheck warning at snd_soc_pcm_component_pm_runtime_get() (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning for CONFIG_GPIOLIB (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning at snd_soc_jack_report() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_pcm_dai_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_dai_link_set_capabilities() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_copy_user() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_hw_params() (Jaroslav Kysela) [2017320]
- ALSA: hda: Nuke unused reboot_notify callback (Jaroslav Kysela) [2017320]
- ALSA: hda: Suspend codec at shutdown (Jaroslav Kysela) [2017320]
- ALSA: hda: conexant: Turn off EAPD at suspend, too (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add SNDRV_PCM_INFO_EXPLICIT_SYNC flag (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Input source control - digidesign mbox (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: use software node API in Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: remove device_properties for Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: use software node API in SoundWire machines (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_rt711*: keep codec device reference until remove (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: pass card information to init/exit functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: handle errors with acpi_dev_get_first_match_dev() (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: harden codec property handling (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove() (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Add SSI DMAC support (Jaroslav Kysela) [2017320]
- ASoC: sh: Add RZ/G2L SSIF-2 driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: make DMI L1 selection more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: simplify logic for DMI_L1 handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: remove always true condition (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Kconfig: clarify DMI L1 option description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Count continuous pages in vmalloc buffer handler (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent pops and clicks during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda_audio_ext: fix kernel-doc (Jaroslav Kysela) [2017320]
- ALSA: core: control_led: use strscpy instead of strlcpy (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Unmute/Mute codec when stream starts/stops (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Follow correct CS42L42 power down sequence for suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Remove unnecessary delays (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use timeout rather than retries for I2C transaction waits (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set fixed sample rate of 48kHz for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Enable Full Scale Volume for Line Out Codec on Dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add support for dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add Support to disable jack type detection for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support multiple sub_codecs for Suspend/Resume/Unsol events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move codec properties to its own struct (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Separate CS8409, CS42L42 and project functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support i2c bulk read/write functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid re-setting the same page as the last access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid setting the same I2C address for every access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Dont disable I2C clock between consecutive accesses (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Generalize volume controls (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent I2C access during suspend time (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Simplify CS42L42 jack detect. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask CS42L42 wake events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited response for the first boot (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited responses during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unnecessary Ring Sense for Cyborg/Warlock/Bullseye (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Reduce HS pops/clicks for Cyborg (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask all CS42L42 interrupts on initialization (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use enums for register names and coefficients (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move arrays of configuration to a new file (Jaroslav Kysela) [2017320]
- ALSA: hda/cirrus: Move CS8409 HDA bridge to separate module (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Properly turn off regulators if wrong device ID (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Adjust headset volume button threshold again (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix platform ID matching (Jaroslav Kysela) [2017320]
- ASoC: rt1015p: add new acpi id and comapatible id (Jaroslav Kysela) [2017320]
- ASoC: max98390: Add support change dsm param name (Jaroslav Kysela) [2017320]
- ALSA: msnd: Use proper mmap method (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8016_sbc: Add SEC_MI2S support (Jaroslav Kysela) [2017320]
- ALSA: pci: cs46xx: Fix set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pcm: Check mmap capability of runtime dma buffer at first (Jaroslav Kysela) [2017320]
- ALSA: harmony: Drop superfluous address setup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix mmap of SG-buffer with WC pages (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Update module authors (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Assume 24-bit samples are in 32-bit slots (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Validate dai_set_sysclk() frequency (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Add PLL configuration for 44.1kHz/16-bit (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Silence warning message about missing interrupt (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: add Multi Button Headset Control support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Avoid over-allocating DLCs (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: simplify return value (Jaroslav Kysela) [2017320]
- ASoC: mt6359-accdet.c: remove useless assignments (Jaroslav Kysela) [2017320]
- ASoC: max98090: remove duplicate status reads and useless assignmment (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at soc_dapm_dai_stream_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_new_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_weak_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_add_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_del_route() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_run() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_check_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_pga() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_set_mixer_path_status() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_connect_mux() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_wcache_lookup() (Jaroslav Kysela) [2017320]
- ALSA: es1688: Avoid devres management for es1688 object creation (Jaroslav Kysela) [2017320]
- ALSA: pci/korg1212: completely remove 'set but not used' warnings (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Store snd_dma_buffer.addr for continuous pages, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix pgprot for WC mmap on x86 (Jaroslav Kysela) [2017320]
- ASoC: sprd: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: qdsp6: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: lpass: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: mpc5200: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_asrc_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-rpmsg: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-fiq: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: bcm: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: pxa2xx: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support WC allocation on all architectures (Jaroslav Kysela) [2017320]
- ALSA: pcm: Allow exact buffer preallocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Correctly name as WC (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Minor refactoring (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: convert to use module_platform_driver (Jaroslav Kysela) [2017320]
- ASoC: rt5514: make array div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: codecs: ad193x: add support for 96kHz and 192kHz playback rates (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_get_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_limit_volume() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_volsw_sx() (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_max98373: remove useless inits (Jaroslav Kysela) [2017320]
- ASoC: Intel: update sof_pcm512x quirks (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Use DMI string to search for adl_mx98373_rt5682 variant (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add quirk for Dell XPS 9710 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: make array static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: make array clocks static, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Fix HP ElitePad 1000 G2 quirk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headset mic input (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headphones output (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add a byt_rt5640_get_codec_dai() helper (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add line-out support (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to the maps for the matching in-/output (Jaroslav Kysela) [2017320]
- soundwire: intel: introduce shim and alh base (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add snd_sof_dsp_check_sdw_irq ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: move sof_intel_dsp_desc() forward (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: remove HDA_DSP_REG_SNDW_WAKE_STS definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add sdw_shim/alh_base to sof_intel_dsp_desc (Jaroslav Kysela) [2017320]
- soundwire: move intel sdw register definitions to sdw_intel.h (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at snd_soc_find_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_kcontrol_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dapm_widget_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dai_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_process_headers() (Jaroslav Kysela) [2017320]
- ASoC: rsnd: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ALSA: doc: Add the description of quirk_flags option for snd-usb-audio (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk_flags module option (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move generic DSD raw detection into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ignore_ctl_error check into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move autosuspend quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move rate validation quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move interface setup delay into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move control message delay quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ITF-USB DSD quirk handling into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move clock setup quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move playback_first flag into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move tx_length quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move txfr_quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move media-controller API quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Introduce quirk_flags field (Jaroslav Kysela) [2017320]
- soundwire: cadence: override PDI configurations to create loopback (Jaroslav Kysela) [2017320]
- soundwire: cadence: add debugfs interface for PDI loopbacks (Jaroslav Kysela) [2017320]
- soundwire: stream: don't program mockup device ports (Jaroslav Kysela) [2017320]
- soundwire: bus: squelch error returned by mockup devices (Jaroslav Kysela) [2017320]
- soundwire: add flag to ignore all command/control for mockup devices (Jaroslav Kysela) [2017320]
- soundwire: stream: don't abort bank switch on Command_Ignored/-ENODATA (Jaroslav Kysela) [2017320]
- soundwire: cadence: add paranoid check on self-clearing bits (Jaroslav Kysela) [2017320]
- ALSA: core: Fix double calls of snd_card_free() via devres (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: use __func__ to get funcion's name in an output message (Jaroslav Kysela) [2017320]
- ASoC: intel: skylake: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ASoC: amd: Drop superfluous mmap callbacks (Jaroslav Kysela) [2017320]
- ASoC: v253_init: eliminate pointer to string (Jaroslav Kysela) [2017320]
- ASoC: cx20442: tty_ldisc_ops::write_wakeup is optional (Jaroslav Kysela) [2017320]
- ASoC: samsung: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_routing() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_simple_widgets() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_add_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_unregister_component() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_daifmt_parse_format() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_get_dai_name() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_set_dmi_name() (Jaroslav Kysela) [2017320]
- ASoC: bcm: cygnus-pcm: Fix unused assignment about 'rc' (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix spelling contraction "cant" -> "can't" (Jaroslav Kysela) [2017320]
- ASoC: amd: fix an IS_ERR() vs NULL bug in probe (Jaroslav Kysela) [2017320]
- ASoC: rt5682: enable SAR ADC power saving mode during suspend (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_runtime_setup_be_chan() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_be_is_active() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_get_playback_capture() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_components_close() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_apply_msb() (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix comments of wrong client number for MIDI Passthrough (Jaroslav Kysela) [2017320]
- ASoC: rt1015: Remove unnecessary flush work on rt1015 driver (Jaroslav Kysela) [2017320]
- docs: sound: kernel-api: writing-an-alsa-driver.rst: replace some characters (Jaroslav Kysela) [2017320]
- ASoC: amd: Use dev_probe_err helper (Jaroslav Kysela) [2017320]
- ASoC: amd: Don't show messages about deferred probing by default (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- soundwire: bus: update Slave status in sdw_clear_slave_status (Jaroslav Kysela) [2017320]
- soundwire: cadence: Remove ret variable from sdw_cdns_irq() (Jaroslav Kysela) [2017320]
- soundwire: bus: filter out more -EDATA errors on clock stop (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add ull suffix for SoundWire _ADR values (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh acp5x driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dma driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dai driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s controller driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x pcm dma driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: irq handler changes for ACP5x PCM dma driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x PCM platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: create acp5x platform devices (Jaroslav Kysela) [2017320]
- ASoc: amd: add acp5x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP5x IP register header (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Use explicit cast for __iomem pointer (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Fix wrongly shuffled firmware loader code (Jaroslav Kysela) [2017320]
- ALSA: als300: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Assign vport directly on card's private_data (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Fix incorrect sizeof operator (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: fix missing { } around an if block (Jaroslav Kysela) [2017320]
- ALSA: nm256: Fix error return code in snd_nm256_create() (Jaroslav Kysela) [2017320]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- ASoC: ti: j721e-evm: Convert the audio domain IDs to enum (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: dummy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aloop: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mpu401: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: serial-u16550: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mtpav: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: virmidi: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: x86: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wavefront: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sscape: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opl3sa2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: msnd: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: gus: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: galaxy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es18xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1688: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs423x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8330: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt2320: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als100: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: adlib: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1848: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sb: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wss: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1816a: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ymfpci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx222: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx: Manage vx_core object with devres (Jaroslav Kysela) [2017320]
- ALSA: trident: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme9652: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdspm: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: riptide: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: oxygen: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: nm256: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lx6464es: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lola: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1712: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: echoaudio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5535audio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs46xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ca0106: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aw2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: au88x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: via82xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sonicvibes: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sis7019: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme96: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme32: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: maestro3: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: fm801: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1968: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1938: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ens137x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5530: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: bt87x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt3328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als4000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als300: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1889: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hda: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: atiixp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: doc: Add device-managed resource section (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed request_dma() (Jaroslav Kysela) [2017320]
- ALSA: core: Add managed card creation (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed page allocator helper (Jaroslav Kysela) [2017320]
- ALSA: aloop: Fix spelling mistake "synchronization" -> "synchronization" (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: remove unused port-map reference (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: clean up for-loop indentation in switch statement (Jaroslav Kysela) [2017320]
- ALSA: compress: Initialize mutex in snd_compress_new() (Jaroslav Kysela) [2017320]
- ALSA: compress: Drop unused functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: sof_sdw: add SoundWire mockup codecs for tests (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: tgl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: cnl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: codecs: add SoundWire mockup device support (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: update quirk for jack detection in ADL RVP (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: include rt711.h for RT711 JD mode (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: extends SOF_RT711_JDSRC to 4 bits (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: code refactor for max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: add support for jsl_cs4242_mx98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: maxim-common: support max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: support arbitrary DAI link sequence (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Skip ac97 clock measurement on VM (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Add option to enable all pins forcibly (Jaroslav Kysela) [2017320]
- ALSA: x86: simplify with sync_stop PCM ops (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Remove superfluous loop over model table (Jaroslav Kysela) [2017320]
- ALSA: hda/ca0132: remove redundant initialization of variable status (Jaroslav Kysela) [2017320]
- ASoC: amd: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 channel count (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Omit superfluous error message in fsl_xcvr_probe() (Jaroslav Kysela) [2017320]
- ASoC: sh: rcar: dma: : use proper DMAENGINE API for termination (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove pointless string comparison (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix returnvar.cocci warnings (Jaroslav Kysela) [2017320]
- ASoC: atmel: ATMEL drivers don't need HAS_DMA (Jaroslav Kysela) [2017320]
- ASoC: ti: delete some dead code in omap_abe_probe() (Jaroslav Kysela) [2017320]
- ASoC: atmel: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: use helper function to get bclk frequency (Jaroslav Kysela) [2017320]
- ASoC: SOF: add a helper to get topology configured bclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add support for SoundWire of TGL-H-RVP (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8183: Fix Unbalanced pm_runtime_enable in mt8183_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8192:Fix Unbalanced pm_runtime_enable in mt8192_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Add support for the OMAP4 version of McASP (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Fix DIT mode support (Jaroslav Kysela) [2017320]

* Thu Feb 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-64.el9]
- igc: Fix TX timestamp support for non-MSI-X platforms (Corinna Vinschen) [2040335]
- igc: Do not enable crosstimestamping for i225-V models (Corinna Vinschen) [2040335]
- igc: Fix typo in i225 LTR functions (Corinna Vinschen) [2040335]
- igc: enable XDP metadata in driver (Corinna Vinschen) [2040335]
- igc: AF_XDP zero-copy metadata adjust breaks SKBs on XDP_PASS (Corinna Vinschen) [2040335]
- igc: Change Device Reset to Port Reset (Corinna Vinschen) [2040335]
- igc: Add new device ID (Corinna Vinschen) [2040335]
- igc: Remove media type checking on the PHY initialization (Corinna Vinschen) [2040335]
- igc: Update I226_K device ID (Corinna Vinschen) [2040335]
- net: intel: igc_ptp: fix build for UML (Corinna Vinschen) [2040335]
- igc: fix tunnel offloading (Corinna Vinschen) [2040335]
- igc: Add support for CBS offloading (Corinna Vinschen) [2040335]
- igc: Simplify TSN flags handling (Corinna Vinschen) [2040335]
- igc: Use default cycle 'start' and 'end' values for queues (Corinna Vinschen) [2040335]
- igc: Add support for PTP getcrosststamp() (Corinna Vinschen) [2040335]
- igc: Enable PCIe PTM (Corinna Vinschen) [2040335]
- igc: Increase timeout value for Speed 100/1000/2500 (Corinna Vinschen) [2040335]
- igc: Set QBVCYCLET_S to 0 for TSN Basic Scheduling (Corinna Vinschen) [2040335]
- igc: Remove phy->type checking (Corinna Vinschen) [2040335]
- igc: Remove _I_PHY_ID checking (Corinna Vinschen) [2040335]
- igc: Check if num of q_vectors is smaller than max before array access (Corinna Vinschen) [2040335]
- Revert "igc: Export LEDs" (Corinna Vinschen) [2040335]
- igc: Export LEDs (Corinna Vinschen) [2040335]
- igc: Make flex filter more flexible (Corinna Vinschen) [2040335]
- igc: Allow for Flex Filters to be installed (Corinna Vinschen) [2040335]
- igc: Integrate flex filter into ethtool ops (Corinna Vinschen) [2040335]
- igc: Add possibility to add flex filter (Corinna Vinschen) [2040335]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1998360]
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts() (Gopal Tiwari) [2043756]
- scsi: reserve space in structures for KABI (Ewan D. Milne) [2044443]
- vt_kdsetmode: extend console locking (John W. Linville) [2003820]
- ice: Fix problems with DSCP QoS implementation (Jonathan Toppins) [2032582]
- ice: Fix race conditions between virtchnl handling and VF ndo ops (Jonathan Toppins) [2032582]
- ice: Fix not stopping Tx queues for VFs (Jonathan Toppins) [2032582]
- ice: Fix replacing VF hardware MAC to existing MAC filter (Jonathan Toppins) [2032582]
- ice: Remove toggling of antispoof for VF trusted promiscuous mode (Jonathan Toppins) [2032582]
- ice: Fix VF true promiscuous mode (Jonathan Toppins) [2032582]
- ice: Remove boolean vlan_promisc flag from function (Jonathan Toppins) [2032582]
- ice: check whether PTP is initialized in ice_ptp_release() (Jonathan Toppins) [2032582]
- ice: Respond to a NETDEV_UNREGISTER event for LAG (Jonathan Toppins) [2032582]
- ice: use devm_kcalloc() instead of devm_kzalloc() (Jonathan Toppins) [2032582]
- ice: Make use of the helper function devm_add_action_or_reset() (Jonathan Toppins) [2032582]
- ice: fix software generating extra interrupts (Jonathan Toppins) [2032582]
- ice: fix rate limit update after coalesce change (Jonathan Toppins) [2032582]
- ice: update dim usage and moderation (Jonathan Toppins) [2032582]
- ice: Add support for VF rate limiting (Jonathan Toppins) [2032582]
- ice: Add missing E810 device ids (Jonathan Toppins) [2032582]
- ice: make use of ice_for_each_* macros (Jonathan Toppins) [2032582]
- ice: split ice_ring onto Tx/Rx separate structs (Jonathan Toppins) [2032582]
- ice: move ice_container_type onto ice_ring_container (Jonathan Toppins) [2032582]
- ice: remove ring_active from ice_ring (Jonathan Toppins) [2032582]
- ice: Print the api_patch as part of the fw.mgmt.api (Jonathan Toppins) [2032582]
- ice: fix getting UDP tunnel entry (Jonathan Toppins) [1978828 2032582]
- ice: Avoid crash from unnecessary IDA free (Jonathan Toppins) [2032582]
- ice: Fix failure to re-add LAN/RDMA Tx queues (Jonathan Toppins) [2032582]
- ice: fix locking for Tx timestamp tracking flush (Jonathan Toppins) [2032582]
- ice: Prefer kcalloc over open coded arithmetic (Jonathan Toppins) [2032582]
- ice: Fix macro name for IPv4 fragment flag (Jonathan Toppins) [2032582]
- ice: refactor devlink getter/fallback functions to void (Jonathan Toppins) [2032582]
- ice: Fix link mode handling (Jonathan Toppins) [2032582]
- ice: Add feature bitmap, helpers and a check for DSCP (Jonathan Toppins) [2032582]
- ice: Add DSCP support (Jonathan Toppins) [2032582]
- ice: Correctly deal with PFs that do not support RDMA (Jonathan Toppins) [2032582]
- ice: add lock around Tx timestamp tracker flush (Jonathan Toppins) [2032582]
- ice: remove dead code for allocating pin_config (Jonathan Toppins) [2032582]

* Thu Feb 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-63.el9]
- wireguard: ratelimiter: use kvcalloc() instead of kvzalloc() (Hangbin Liu) [2041408]
- wireguard: receive: drop handshakes if queue lock is contended (Hangbin Liu) [2041408]
- wireguard: receive: use ring buffer for incoming handshakes (Hangbin Liu) [2041408]
- wireguard: allowedips: add missing __rcu annotation to satisfy sparse (Hangbin Liu) [2041408]
- ionic: Initialize the 'lif->dbid_inuse' bitmap (Jonathan Toppins) [2039988]
- ionic: tame the filter no space message (Jonathan Toppins) [2013549 2039988]
- ionic: allow adminq requests to override default error message (Jonathan Toppins) [2013549 2039988]
- ionic: handle vlan id overflow (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter delete (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter add (Jonathan Toppins) [2013549 2039988]
- ionic: add generic filter search (Jonathan Toppins) [2013549 2039988]
- ionic: remove mac overflow flags (Jonathan Toppins) [2013549 2039988]
- ionic: move lif mac address functions (Jonathan Toppins) [2013549 2039988]
- ionic: add filterlist to debugfs (Jonathan Toppins) [2013549 2039988]
- ionic: add lif param to ionic_qcq_disable (Jonathan Toppins) [2039988]
- ionic: have ionic_qcq_disable decide on sending to hardware (Jonathan Toppins) [2039988]
- ionic: add polling to adminq wait (Jonathan Toppins) [2039988]
- ionic: widen queue_lock use around lif init and deinit (Jonathan Toppins) [2039988]
- ionic: move lif mutex setup and delete (Jonathan Toppins) [2039988]
- ionic: check for binary values in FW ver string (Jonathan Toppins) [2039988]
- ionic: remove debug stats (Jonathan Toppins) [2039988]
- ionic: don't remove netdev->dev_addr when syncing uc list (Jonathan Toppins) [2039988]
- ionic: move filter sync_needed bit set (Jonathan Toppins) [2039988]
- ionic: fix gathering of debug stats (Jonathan Toppins) [2039988]
- ionic: fix a sleeping in atomic bug (Jonathan Toppins) [2039988]
- ionic: fix double use of queue-lock (Jonathan Toppins) [2039988]
- ionic: recreate hwstamp queues on ifup (Jonathan Toppins) [2039988]
- ionic: pull hwstamp queue_lock up a level (Jonathan Toppins) [2039988]
- ionic: add queue lock around open and stop (Jonathan Toppins) [2039988]
- ionic: fill mac addr earlier in add_addr (Jonathan Toppins) [2039988]
- ionic: squelch unnecessary fw halted message (Jonathan Toppins) [2039988]
- ionic: fire watchdog again after fw_down (Jonathan Toppins) [2039988]
- ionic: handle mac filter overflow (Jonathan Toppins) [2039988]
- ionic: refactor ionic_lif_addr to remove a layer (Jonathan Toppins) [2039988]
- ionic: sync the filters in the work task (Jonathan Toppins) [2039988]
- ionic: flatten calls to set-rx-mode (Jonathan Toppins) [2039988]
- ionic: remove old work task types (Jonathan Toppins) [2039988]
- ionic: add function tag to debug string (Jonathan Toppins) [2039988]
- ionic: enable rxhash only with multiple queues (Jonathan Toppins) [2039988]
- ionic: block some ethtool operations when fw in reset (Jonathan Toppins) [2039988]
- ionic: remove unneeded comp union fields (Jonathan Toppins) [2039988]
- ionic: increment num-vfs before configure (Jonathan Toppins) [2039988]
- ionic: use fewer inits on the buf_info struct (Jonathan Toppins) [2039988]
- ionic: init reconfig err to 0 (Jonathan Toppins) [2039988]
- ionic: print firmware version on identify (Jonathan Toppins) [2039988]
- ionic: monitor fw status generation (Jonathan Toppins) [2039988]
- ionic: minimize resources when under kdump (Jonathan Toppins) [2039988]
- ionic: drop useless check of PCI driver data validity (Jonathan Toppins) [2039988]

* Wed Feb 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-62.el9]
- ibmvnic: remove unused defines (Diego Domingos) [2047921]
- ibmvnic: Update driver return codes (Diego Domingos) [2047921]
- powerpc/fadump: opt out from freeing pages on cma activation failure (Diego Domingos) [2040289]
- mm/cma: provide option to opt out from exposing pages on activation failure (Diego Domingos) [2040289]
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented (Vitaly Kuznetsov) [2052908]
- rcu: Tighten rcu_advance_cbs_nowake() checks (Daniel Vacek) [2026991]
- redhat/configs: Disable CONFIG_MACINTOSH_DRIVERS (Prarit Bhargava) [2053028]
- ibmvnic: remove unused ->wait_capability (Diego Domingos) [2047928]
- ibmvnic: don't spin in tasklet (Diego Domingos) [2047928]
- ibmvnic: init ->running_cap_crqs early (Diego Domingos) [2047928]
- ibmvnic: Allow extra failures before disabling (Diego Domingos) [2047928]
- s390/pv: fix the forcing of the swiotlb (Thomas Huth) [2051581]
- scsi: vmw_pvscsi: Set residual data length conditionally (Cathy Avery) [2048178]
- selinux: fix double free of cond_list on error paths (Ondrej Mosnacek) [2052439]
- selinux: fix NULL-pointer dereference when hashtab allocation fails (Ondrej Mosnacek) [2052436]
- isdn: cpai: check ctr->cnr to avoid array index out of bound (Chris von Recklinghausen) [2016492] {CVE-2021-43389}
- mm/hwpoison: fix unpoison_memory() (Aristeu Rozanski) [1972220]
- mm/hwpoison: remove MF_MSG_BUDDY_2ND and MF_MSG_POISONED_HUGE (Aristeu Rozanski) [1972220]
- mm/hwpoison: mf_mutex for soft offline and unpoison (Aristeu Rozanski) [1972220]
- mm/hwpoison: clear MF_COUNT_INCREASED before retrying get_any_page() (Aristeu Rozanski) [1972220]
- mm, hwpoison: fix condition in free hugetlb page path (Aristeu Rozanski) [1972220]
- filemap: remove PageHWPoison check from next_uptodate_page() (Aristeu Rozanski) [1972220]
- mm: hwpoison: handle non-anonymous THP correctly (Aristeu Rozanski) [1972220]
- mm: hwpoison: refactor refcount check handling (Aristeu Rozanski) [1972220]
- mm: filemap: coding style cleanup for filemap_map_pmd() (Aristeu Rozanski) [1972220]
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (John Meneghini) [2031648]
- scsi: bnx2fc: Flush destroy_work queue before calling bnx2fc_interface_put() (John Meneghini) [2006606]
- redhat/configs: Enable CONFIG_TEST_BPF (Viktor Malik) [2035168]
- ext4: fix potential NULL pointer dereference in ext4_fill_super() (Lukas Czerner) [2051466]
- netfilter: ipset: Emit deprecation warning at set creation time (Phil Sutter) [2048194]
- redhat: move CONFIG_ARM64_MTE to aarch64 config directory (Herton R. Krzesinski)
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning (Waiman Long) [1996015]
- cpuset: Fix the bug that subpart_cpus updated wrongly in update_cpumask() (Waiman Long) [1996015]
- net ticp:fix a kernel-infoleak in __tipc_sendmsg() (Xin Long) [2050039]
- tipc: discard MSG_CRYPTO msgs when key_exchange_enabled is not set (Xin Long) [2050039]
- tipc: delete the unlikely branch in tipc_aead_encrypt (Xin Long) [2050039]
- blktrace: switch trace spinlock to a raw spinlock (Wander Lairson Costa) [2047971]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Steve Dickson) [2027447]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Corinna Vinschen) [2040312]
- igb: Fix removal of unicast MAC filters of VFs (Corinna Vinschen) [2040312]
- igb: fix netpoll exit with traffic (Corinna Vinschen) [2040312]
- igb: unbreak I2C bit-banging on i350 (Corinna Vinschen) [2040312]
- igb: Avoid memcpy() over-reading of ETH_SS_STATS (Corinna Vinschen) [2040312]
- igb: Add counter to i21x doublecheck (Corinna Vinschen) [2040312]
- net: create netdev->dev_addr assignment helpers (Josef Oskera) [2030720]

* Wed Feb 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-61.el9]
- Enable KUNIT tests for redhat kernel-modules-internal (Nico Pache) [2048326]
- kasan: test: fix compatibility with FORTIFY_SOURCE (Nico Pache) [2048326]
- kasan: test: silence intentional read overflow warnings (Nico Pache) [2048326]
- kasan: test: bypass __alloc_size checks (Nico Pache) [2048326]
- mm/damon/vaddr-test: split a test function having >1024 bytes frame size (Nico Pache) [2048326]
- lib: Introduce CONFIG_MEMCPY_KUNIT_TEST (Nico Pache) [2048326]
- nvme-rdma: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme-tcp: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme: fix a possible use-after-free in controller reset during load (Chris Leech) [1994618 2033414]
- redhat/configs: enable CONFIG_CMA on aarch64 as tech-preview (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_AREAS (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUG (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUGFS (David Hildenbrand) [2043141]
- bpf: Fix kernel address leakage in atomic fetch (Jiri Olsa) [2046636] {CVE-2021-4203}
- IB/rdmavt: Validate remote_addr during loopback atomic tests (Kamal Heib) [2032114]
- [s390] scsi: zfcp: Fix failed recovery on gone remote port with non-NPIV FCP devices (Mete Durlu) [2049016]
- [s390] s390/cpumf: Support for CPU Measurement Sampling Facility LS bit (Mete Durlu) [2048979]
- [s390] s390/cpumf: Support for CPU Measurement Facility CSVN 7 (Mete Durlu) [2048979]
- net: openvswitch: Fix ct_state nat flags for conns arriving from tc (Antoine Tenart) [2045048]
- net: openvswitch: Fix matching zone id for invalid conns arriving from tc (Antoine Tenart) [2045048]
- net/sched: flow_dissector: Fix matching on zone id for invalid conns (Antoine Tenart) [2045048]
- net/sched: Extend qdisc control block with tc control block (Antoine Tenart) [2045048]
- openvswitch: fix sparse warning incorrect type (Antoine Tenart) [2045048]
- openvswitch: fix alignment issues (Antoine Tenart) [2045048]
- openvswitch: update kdoc OVS_DP_ATTR_PER_CPU_PIDS (Antoine Tenart) [2045048]
- openvswitch: Introduce per-cpu upcall dispatch (Antoine Tenart) [2045048]
- netfilter: fix regression in looped (broad|multi)cast's MAC handling (Florian Westphal) [2044272]
- selftests: nft_concat_range: add test for reload with no element add/del (Florian Westphal) [2044272]
- selftests: netfilter: Add correctness test for mac,net set type (Florian Westphal) [2044272]
- netfilter: conntrack: don't increment invalid counter on NF_REPEAT (Florian Westphal) [2044272]
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone (Florian Westphal) [2044272]
- netfilter: nft_payload: do not update layer 4 checksum when mangling fragments (Florian Westphal) [2044272]
- netfilter: bridge: add support for pppoe filtering (Florian Westphal) [2044272]
- netfilter: nf_tables: fix use-after-free in nft_set_catchall_destroy() (Florian Westphal) [2044272]
- netfilter: conntrack: annotate data-races around ct->timeout (Florian Westphal) [2044272]
- netfilter: nft_exthdr: break evaluation if setting TCP option fails (Florian Westphal) [2044272]
- nft_set_pipapo: Fix bucket load in AVX2 lookup routine for six 8-bit groups (Florian Westphal) [2044272]
- tracing: Tag trace_percpu_buffer as a percpu pointer (Jerome Marchand) [2035164]
- tracing: Fix check for trace_percpu_buffer validity in get_trace_buf() (Jerome Marchand) [2035164]
- selftests: cgroup: Test open-time cgroup namespace usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Test open-time credential usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Make cg_create() use 0755 for permission instead of 0644 (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time cgroup namespace for process migration perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time credentials for process migraton perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- x86/sched: Decrease further the priorities of SMT siblings (Prarit Bhargava) [1971926]

* Tue Feb 15 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-60.el9]
- crypto: jitter - add oversampling of noise source (Herbert Xu) [2036816]
- Revert "ipv6: Honor all IPv6 PIO Valid Lifetime values" (Guillaume Nault) [2027560]
- Change "-auto" suffix to fix CI automotive pipeline issues (Julio Faracco)
- nvme: drop unused variable ctrl in nvme_setup_cmd (John Meneghini) [2044616]
- nvme: increment request genctr on completion (John Meneghini) [2044616]
- nvme-pci: Fix abort command id (John Meneghini) [2044616]
- nvme: add command id quirk for apple controllers (John Meneghini) [2044616]
- nvme: move nvme_multi_css into nvme.h (John Meneghini) [2044616]
- nvme: code command_id with a genctr for use-after-free validation (John Meneghini) [2044616]
- nvme-pci: limit maximum queue depth to 4095 (John Meneghini) [2044616]
- selftests: Calculate udpgso segment count without header adjustment (Xin Long) [2044129]
- udp: using datalen to cap ipv6 udp max gso segments (Xin Long) [2044129]
- inet_diag: fix kernel-infoleak for UDP sockets (Xin Long) [2044129]
- udp: using datalen to cap max gso segments (Xin Long) [2044129]
- sctp: hold endpoint before calling cb in sctp_transport_lookup_process (Xin Long) [2043823]
- sctp: use call_rcu to free endpoint (Xin Long) [2043823]
- sctp: move hlist_node and hashent out of sctp_ep_common (Xin Long) [2043823]
- sctp: make the raise timer more simple and accurate (Xin Long) [2043823]
- nfsd: fix use-after-free due to delegation race (Benjamin Coddington) [1991929]
- bonding: Fix extraction of ports from the packet headers (Jonathan Toppins) [2042548]
- bonding: fix ad_actor_system option setting to default (Jonathan Toppins) [2042548]
- bonding: make tx_rebalance_counter an atomic (Jonathan Toppins) [2042548]
- bonding: Fix a use-after-free problem when bond_sysfs_slave_add() failed (Jonathan Toppins) [2042548]
- bonding: 3ad: pass parameter bond_params by reference (Jonathan Toppins) [2042548]
- bonding: complain about missing route only once for A/B ARP probes (Jonathan Toppins) [2042548]
- bonding: improve nl error msg when device can't be enslaved because of IFF_MASTER (Jonathan Toppins) [2042548]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2042548]
- net, bonding: Refactor bond_xmit_hash for use with xdp_buff (Jonathan Toppins) [2042548]
- net: bonding: bond_alb: Remove the dependency on ipx network layer (Jonathan Toppins) [2042548]
- bonding: add new option lacp_active (Jonathan Toppins) [1951951 2042548]
- bonding: 3ad: fix the concurrency between __bond_release_one() and bond_3ad_state_machine_handler() (Jonathan Toppins) [2042548]
- fget: clarify and improve __fget_files() implementation (Miklos Szeredi) [2030418] {CVE-2021-4083}
- fget: check that the fd still exists after getting a ref to it (Miklos Szeredi) [2030418] {CVE-2021-4083}
- ipv6: Continue processing multipath route even if gateway attribute is invalid (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY when deleting multipath route (Hangbin Liu) [2041401]
- ipv6: Do cleanup if attribute validation fails in multipath route (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY in multipath route (Hangbin Liu) [2041401]
- ipv6: fix memory leak in fib6_rule_suppress (Hangbin Liu) [2041401]
- net: nexthop: reduce rcu synchronizations when replacing resilient groups (Hangbin Liu) [2041401]
- net: nexthop: release IPv6 per-cpu dsts when replacing a nexthop group (Hangbin Liu) [2041401]
- net: ipv6: add fib6_nh_release_dsts stub (Hangbin Liu) [2041401]
- ipv6: fix typos in __ip6_finish_output() (Hangbin Liu) [2041401]
- igbvf: Refactor trace (Corinna Vinschen) [2040322]
- igbvf: fix double free in `igbvf_probe` (Corinna Vinschen) [2040322]
- bnx2x: Fix enabling network interfaces without VFs (Manish Chopra) [1998304]
- tun: fix bonding active backup with arp monitoring (Jonathan Toppins) [2050837]

* Fri Feb 11 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-59.el9]
- gfs2: Fix gfs2_release for non-writers regression (Bob Peterson) [2030397]
- gfs2: gfs2_create_inode rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup cleanup (Andreas Gruenbacher) [2002803]
- gfs2: Fix remote demote of weak glock holders (Andreas Gruenbacher) [1958140]
- gfs2: Fix unused value warning in do_gfs2_set_flags() (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock_hash_walk bugs (Andreas Gruenbacher) [2008541]
- gfs2: Cancel remote delete work asynchronously (Bob Peterson) [2002803]
- gfs2: set glock object after nq (Bob Peterson) [1998303]
- gfs2: remove RDF_UPTODATE flag (Bob Peterson) [1998303]
- gfs2: Eliminate GIF_INVALID flag (Bob Peterson) [1998303]
- gfs2: Fix atomic bug in gfs2_instantiate (Andreas Gruenbacher) [1998303]
- gfs2: fix GL_SKIP node_scope problems (Bob Peterson) [1998303]
- gfs2: split glock instantiation off from do_promote (Bob Peterson) [1998303]
- gfs2: further simplify do_promote (Bob Peterson) [1998303]
- gfs2: re-factor function do_promote (Bob Peterson) [1998303]
- gfs2: Remove 'first' trace_gfs2_promote argument (Andreas Gruenbacher) [1998303]
- gfs2: change go_lock to go_instantiate (Bob Peterson) [1998303]
- gfs2: dump glocks from gfs2_consist_OBJ_i (Bob Peterson) [1998303]
- gfs2: dequeue iopen holder in gfs2_inode_lookup error (Bob Peterson) [2006870]
- gfs2: Save ip from gfs2_glock_nq_init (Bob Peterson) [1998303]
- gfs2: Allow append and immutable bits to coexist (Bob Peterson) [1998303]
- gfs2: Switch some BUG_ON to GLOCK_BUG_ON for debug (Bob Peterson) [1998303]
- gfs2: move GL_SKIP check from glops to do_promote (Bob Peterson) [1998303]
- gfs2: Add GL_SKIP holder flag to dump_holder (Bob Peterson) [1998303]
- gfs2: remove redundant check in gfs2_rgrp_go_lock (Bob Peterson) [1998303]
- gfs2: Fix mmap + page fault deadlocks for direct I/O (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce nofault flag to disable page faults (Andreas Gruenbacher) [1958140]
- gup: Introduce FOLL_NOFAULT flag to disable page faults (Andreas Gruenbacher) [1958140]
- iomap: Add done_before argument to iomap_dio_rw (Andreas Gruenbacher) [1958140]
- iomap: Support partial direct I/O on user copy failures (Andreas Gruenbacher) [1958140]
- iomap: Fix iomap_dio_rw return value for user copies (Andreas Gruenbacher) [1958140]
- iomap: support reading inline data from non-zero pos (Andreas Gruenbacher) [1958140]
- gfs2: Only dereference i->iov when iter_is_iovec(i) (Andreas Gruenbacher) [1958140]
- gfs2: Prevent endless loops in gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix mmap + page fault deadlocks for buffered I/O (Andreas Gruenbacher) [1958140]
- gfs2: Eliminate ip->i_gh (Andreas Gruenbacher) [1958140]
- gfs2: Move the inode glock locking to gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix "Introduce flag for glock holder auto-demotion" (Andreas Gruenbacher) [1958140]
- gfs2: Introduce flag for glock holder auto-demotion (Bob Peterson) [1958140]
- gfs2: Clean up function may_grant (Andreas Gruenbacher) [1958140]
- gfs2: Add wrapper for iomap_file_buffered_write (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce fault_in_iov_iter_writeable (Andreas Gruenbacher) [1958140]
- iov_iter: Turn iov_iter_fault_in_readable into fault_in_iov_iter_readable (Andreas Gruenbacher) [1958140]
- gup: Turn fault_in_pages_{readable,writeable} into fault_in_{readable,writeable} (Andreas Gruenbacher) [1958140]
- powerpc/kvm: Fix kvm_use_magic_page (Andreas Gruenbacher) [1958140]
- iov_iter: Fix iov_iter_get_pages{,_alloc} page fault return value (Andreas Gruenbacher) [1958140]
- gfs2: Fix length of holes reported at end-of-file (Andreas Gruenbacher) [2029955]
- gfs2: release iopen glock early in evict (Bob Peterson) [2009406]
- gfs2: Switch to may_setattr in gfs2_setattr (Bob Peterson) [2029947]
- fs: Move notify_change permission checks into may_setattr (Bob Peterson) [2029947]
- gfs2: Remove redundant check from gfs2_glock_dq (Bob Peterson) [2030090]
- gfs2: Delay withdraw from atomic context (Bob Peterson) [2030090]
- gfs2: nit: gfs2_drop_inode shouldn't return bool (Bob Peterson) [2030090]
- gfs2: Eliminate vestigial HIF_FIRST (Bob Peterson) [2030090]
- gfs2: Make recovery error more readable (Bob Peterson) [2030090]
- gfs2: Don't release and reacquire local statfs bh (Bob Peterson) [2030090]
- gfs2: init system threads before freeze lock (Bob Peterson) [2030090]
- gfs2: tiny cleanup in gfs2_log_reserve (Bob Peterson) [2030090]
- gfs2: trivial clean up of gfs2_ail_error (Bob Peterson) [2030090]
- gfs2: be more verbose replaying invalid rgrp blocks (Bob Peterson) [2030090]
- iomap: remove the iomap arguments to ->page_{prepare,done} (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock recursion in freeze_go_xmote_bh (Bob Peterson) [2030090]
- gfs2: Fix memory leak of object lsi on error return path (Andreas Gruenbacher) [2030090]
- x86/sgx: Fix minor documentation issues (Vladis Dronov) [1920028]
- selftests/sgx: Add test for multiple TCS entry (Vladis Dronov) [1920028]
- selftests/sgx: Enable multiple thread support (Vladis Dronov) [1920028]
- selftests/sgx: Add page permission and exception test (Vladis Dronov) [1920028]
- selftests/sgx: Rename test properties in preparation for more enclave tests (Vladis Dronov) [1920028]
- selftests/sgx: Provide per-op parameter structs for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Add a new kselftest: Unclobbered_vdso_oversubscribed (Vladis Dronov) [1920028]
- selftests/sgx: Move setup_test_encl() to each TEST_F() (Vladis Dronov) [1920028]
- selftests/sgx: Encpsulate the test enclave creation (Vladis Dronov) [1920028]
- selftests/sgx: Dump segments and /proc/self/maps only on failure (Vladis Dronov) [1920028]
- selftests/sgx: Create a heap for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Make data measurement for an enclave segment optional (Vladis Dronov) [1920028]
- selftests/sgx: Assign source for each segment (Vladis Dronov) [1920028]
- selftests/sgx: Fix a benign linker warning (Vladis Dronov) [1920028]
- x86/sgx: Fix free page accounting (Vladis Dronov) [1920028]
- x86/sgx: Add check for SGX pages to ghes_do_memory_failure() (Vladis Dronov) [1920028]
- x86/sgx: Add hook to error injection address validation (Vladis Dronov) [1920028]
- x86/sgx: Hook arch_memory_failure() into mainline code (Vladis Dronov) [1920028]
- x86/sgx: Add SGX infrastructure to recover from poison (Vladis Dronov) [1920028]
- x86/sgx: Initial poison handling for dirty and free pages (Vladis Dronov) [1920028]
- x86/sgx: Add infrastructure to identify SGX EPC pages (Vladis Dronov) [1920028]
- x86/sgx: Add new sgx_epc_page flag bit to mark free pages (Vladis Dronov) [1920028]

* Wed Feb 09 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-58.el9]
- KVM: nVMX: Allow VMREAD when Enlightened VMCS is in use (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Implement evmcs_field_offset() suitable for handle_vmread() (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Rename vmcs_to_field_offset{,_table} (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: eVMCS: Filter out VM_EXIT_SAVE_VMX_PREEMPTION_TIMER (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Also filter MSR_IA32_VMX_TRUE_PINBASED_CTLS when eVMCS (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Use INVALID_GPA for pointers used in nVMX. (Vitaly Kuznetsov) [2027639]
- x86/kvm: Always inline evmcs_write64() (Vitaly Kuznetsov) [2027639]
- [s390] s390/pci: move pseudo-MMIO to prevent MIO overlap (Mete Durlu) [2047755]
- CI: Update the RHEL9-private pipeline names to new schema (Veronika Kabatova)
- CI: Sync RHEL9-RT-baseline with c9s-RT-baseline (Veronika Kabatova)
- CI: Add kpet_tree_family to RT check config (Veronika Kabatova)
- selftests/bpf: Enlarge select() timeout for test_maps (Felix Maurer) [2032718]
- netfilter: nft_reject_bridge: Fix for missing reply from prerouting (Phil Sutter) [2044848]
- gre: Don't accidentally set RTO_ONLINK in gre_fill_metadata_dst() (Guillaume Nault) [2047202]
- net: fix use-after-free in tw_timer_handler (Guillaume Nault) [2047202]
- inet: use #ifdef CONFIG_SOCK_RX_QUEUE_MAPPING consistently (Guillaume Nault) [2047202]
- ipv4: convert fib_num_tclassid_users to atomic_t (Guillaume Nault) [2047202]
- vfs: fs_context: fix up param length parsing in legacy_parse_param (Carlos Maiolino) [2040587] {CVE-2022-0185}
- sched/pelt: Relax the sync of load_sum with load_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of runnable_sum with runnable_avg (Phil Auld) [2045052]
- sched/pelt: Continue to relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- pinctrl: amd: Fix wakeups when IRQ is shared with SCI (Renjith Pananchikkal) [2039350]
- platform/x86: amd-pmc: only use callbacks for suspend (David Arcari) [2016041]
- platform/x86: amd-pmc: Add support for AMD Smart Trace Buffer (David Arcari) [2016041]
- platform/x86: amd-pmc: Simplify error handling and store the pci_dev in amd_pmc_dev structure (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix s2idle failures on certain AMD laptops (David Arcari) [2016041]
- platform/x86: amd-pmc: Make CONFIG_AMD_PMC depend on RTC_CLASS (David Arcari) [2016041]
- platform/x86: amd-pmc: Drop check for valid alarm time (David Arcari) [2016041]
- platform/x86: amd-pmc: Downgrade dev_info message to dev_dbg (David Arcari) [2016041]
- platform/x86: amd-pmc: fix compilation without CONFIG_RTC_SYSTOHC_DEVICE (David Arcari) [2016041]
- platform/x86: amd-pmc: Add special handling for timer based S0i3 wakeup (David Arcari) [2016041]
- platform/x86: amd-pmc: adjust arguments for `amd_pmc_send_cmd` (David Arcari) [2016041]
- platform/x86: amd-pmc: Add alternative acpi id for PMC controller (David Arcari) [2016041]
- platform/x86: amd-pmc: Add a message to print resume time info (David Arcari) [2016041]
- platform/x86: amd-pmc: Send command to dump data after clearing OS_HINT (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix compilation when CONFIG_DEBUGFS is disabled (David Arcari) [2016041]
- platform/x86: amd-pmc: Export Idlemask values based on the APU (David Arcari) [2016041]
- platform/x86: amd-pmc: Check s0i3 cycle status (David Arcari) [2016041]
- platform/x86: amd-pmc: Increase the response register timeout (David Arcari) [2016041]
- mm/page_alloc.c: do not warn allocation failure on zone DMA if no managed pages (Baoquan He) [2024381]
- dma/pool: create dma atomic pool only if dma zone has managed pages (Baoquan He) [2024381]
- mm_zone: add function to check if managed dma zone exists (Baoquan He) [2024381]
- PCI: hv: Add arm64 Hyper-V vPCI support (Vitaly Kuznetsov) [2024852]
- PCI: hv: Make the code arch neutral by adding arch specific interfaces (Vitaly Kuznetsov) [2024852]
- PCI: hv: Remove unnecessary use of %%hx (Vitaly Kuznetsov) [2024852]

* Tue Feb 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-57.el9]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Benjamin Marzinski) [2026948]
- dm sysfs: use default_groups in kobj_type (Benjamin Marzinski) [2043224]
- dm space map common: add bounds check to sm_ll_lookup_bitmap() (Benjamin Marzinski) [2043224]
- dm btree: add a defensive bounds check to insert_at() (Benjamin Marzinski) [2043224]
- dm btree remove: change a bunch of BUG_ON() calls to proper errors (Benjamin Marzinski) [2043224]
- dm btree spine: eliminate duplicate le32_to_cpu() in node_check() (Benjamin Marzinski) [2043224]
- dm btree spine: remove extra node_check function declaration (Benjamin Marzinski) [2043224]
- redhat: drop the RELEASED_KERNEL switch (Herton R. Krzesinski) [2037084 2045327]
- redhat: switch the kernel package to use certs from system-sb-certs (Herton R. Krzesinski) [2037084 2045327]
- mptcp: disable by default (Davide Caratti) [2044392]
- sch_api: Don't skip qdisc attach on ingress (Davide Caratti) [2044560]
- flow_offload: return EOPNOTSUPP for the unsupported mpls action type (Davide Caratti) [2044560]
- sch_cake: do not call cake_destroy() from cake_init() (Davide Caratti) [2044560]
- net/sched: fq_pie: prevent dismantle issue (Davide Caratti) [2044560]
- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf dev xmit (Antoine Tenart) [2044252]
- qla2xxx: Add new messaging (Ewan D. Milne) [2039070]
- nvme-fc: remove freeze/unfreeze around update_nr_hw_queues (Ewan D. Milne) [2030051]
- nvme-fc: avoid race between time out and tear down (Ewan D. Milne) [2030051]
- nvme-fc: update hardware queues before using them (Ewan D. Milne) [2030051]
- lpfc: Add new messaging (Ewan D. Milne) [2039068]
- tee: handle lookup of shm with reference count 0 (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dma-buf: move dma-buf symbols into the DMA_BUF module namespace (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- tee: add sec_world_id to struct tee_shm (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/selftests: Do not use import_obj uninitialized (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{vmap,vunmap}() (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm: Define DRM_FORMAT_MAX_PLANES (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/gem: Correct the locking and pin pattern for dma-buf (v8) (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gm12u320: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gud: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/udl: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{begin,end}_cpu_access() helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dmaengine: idxd: Add wq occupancy information to sysfs attribute (Julia Denham) [1971888]
- arch/x86: KABI structs and array padding (Prarit Bhargava) [2033081]
- hpsa: add new messaging (Tomas Henzl) [2028575]
- aacraid: add new messaging (Tomas Henzl) [2028574]
- mptsas: add new messaging (Tomas Henzl) [2027741]
- megaraid_sas: add new messaging (Tomas Henzl) [2027741]
- mpt3sas: Add new messaging (Tomas Henzl) [2027741]
- scsi: mpi3mr: Use scnprintf() instead of snprintf() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Clean up mpi3mr_print_ioc_info() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Set up IRQs in resume path (Tomas Henzl) [1876005]
- scsi: mpi3mr: Use the proper SCSI midlayer interfaces for PI (Tomas Henzl) [1876005]

* Mon Feb 07 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-56.el9]
- KVM: VMX: switch blocked_vcpu_on_cpu_lock to raw spinlock (Marcelo Tosatti) [2034007]
- x86/hyperv: Properly deal with empty cpumasks in hyperv_flush_tlb_multi() (Vitaly Kuznetsov) [2035993]
- tcp: add missing htmldocs for skb->ll_node and sk->defer_list (Antoine Tenart) [2041382]
- net: move early demux fields close to sk_refcnt (Antoine Tenart) [2041382]
- tcp: defer skb freeing after socket lock is released (Antoine Tenart) [2041382]
- net: shrink struct sock by 8 bytes (Antoine Tenart) [2041382]
- ipv6: shrink struct ipcm6_cookie (Antoine Tenart) [2041382]
- net: remove sk_route_nocaps (Antoine Tenart) [2041382]
- net: remove sk_route_forced_caps (Antoine Tenart) [2041382]
- net: use sk_is_tcp() in more places (Antoine Tenart) [2041382]
- bpf, sockmap: Use stricter sk state checks in sk_lookup_assign (Antoine Tenart) [2041382]
- ipv6: move inet6_sk(sk)->rx_dst_cookie to sk->sk_rx_dst_cookie (Antoine Tenart) [2041382]
- tcp: move inet->rx_dst_ifindex to sk->sk_rx_dst_ifindex (Antoine Tenart) [2041382]
- [RHEL-9.0] IPMI Add RH_KABI_RESERVE to kABI sensitive structs (Tony Camuso) [2042031]
- configs: disable CONFIG_CRAMFS (Abhi Das) [2041184]
- ppp: ensure minimum packet size in ppp_write() (Guillaume Nault) [2042936]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [2039086]
- PCI: ACPI: Check parent pointer in acpi_pci_find_companion() (Myron Stowe) [2039086]
- PCI/ACPI: Don't reset a fwnode set by OF (Myron Stowe) [2039086]
- PCI: Make saved capability state private to core (Myron Stowe) [2039086]
- PCI: Change the type of probe argument in reset functions (Myron Stowe) [2039086]
- PCI: Add support for ACPI _RST reset method (Myron Stowe) [2039086]
- PCI: Setup ACPI fwnode early and at the same time with OF (Myron Stowe) [2039086]
- PCI: Use acpi_pci_power_manageable() (Myron Stowe) [2039086]
- PCI: Add pci_set_acpi_fwnode() to set ACPI_COMPANION (Myron Stowe) [2039086]
- PCI: Allow userspace to query and set device reset mechanism (Myron Stowe) [2039086]
- PCI: Remove reset_fn field from pci_dev (Myron Stowe) [2039086]
- PCI: Add array to track reset method ordering (Myron Stowe) [2039086]
- PCI: Add pcie_reset_flr() with 'probe' argument (Myron Stowe) [2039086]
- PCI: Cache PCIe Device Capabilities register (Myron Stowe) [2039086]
- PCI: Allow PASID on fake PCIe devices without TLP prefixes (Myron Stowe) [2039086]
- clocksource: Reduce the default clocksource_watchdog() retries to 2 (Waiman Long) [2027463]
- clocksource: Avoid accidental unstable marking of clocksources (Waiman Long) [2027463]
- Revert "clocksource: Increase WATCHDOG_MAX_SKEW" (Waiman Long) [2027463]
- PCI: Add pcie_ptm_enabled() (Petr Oros) [2037314]
- Revert "PCI: Make pci_enable_ptm() private" (Petr Oros) [2037314]
- iommu/vt-d: Fix unmap_pages support (Jerry Snitselaar) [2027762]

* Fri Feb 04 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-55.el9]
- selftests: netfilter: switch to socat for tests using -q option (Hangbin Liu) [2041409]
- selftests: net: udpgro_fwd.sh: explicitly checking the available ping feature (Hangbin Liu) [2041409]
- selftests: net: using ping6 for IPv6 in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests: net: Fix a typo in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests/net: udpgso_bench_tx: fix dst ip argument (Hangbin Liu) [2041409]
- selftest/net/forwarding: declare NETIFS p9 p10 (Hangbin Liu) [2041409]
- selftests: Fix IPv6 address bind tests (Hangbin Liu) [2041409]
- selftests: Fix raw socket bind tests with VRF (Hangbin Liu) [2041409]
- selftests: Add duplicate config only for MD5 VRF tests (Hangbin Liu) [2041409]
- selftests: icmp_redirect: pass xfail=0 to log_test() (Hangbin Liu) [2041409]
- selftests: net: Correct ping6 expected rc from 2 to 1 (Hangbin Liu) [2041409]
- selftests/fib_tests: Rework fib_rp_filter_test() (Hangbin Liu) [2041409]
- selftests: net: Correct case name (Hangbin Liu) [2041409]
- redhat/configs: Enable CONFIG_PCI_P2PDMA (Myron Stowe) [1923862]
- nvme: drop scan_lock and always kick requeue list when removing namespaces (Gopal Tiwari) [2038783]
- ACPI: CPPC: Add NULL pointer check to cppc_get_perf() (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP Status during HWP Interrupt enable (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix unchecked MSR 0x773 access (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP desired on suspend/shutdown and offline (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix cpu->pstate.turbo_freq initialization (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: intel_pstate: Override parameters if HWP forced by BIOS (David Arcari) [2025291]
- cpufreq: intel_pstate: hybrid: Rework HWP calibration (David Arcari) [2025291]
- Revert "cpufreq: intel_pstate: Process HWP Guaranteed change notification" (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: Replace deprecated CPU-hotplug functions (David Arcari) [2025291]
- ACPI: CPPC: Introduce cppc_get_nominal_perf() (David Arcari) [2025291]
- Change s390x CONFIG_NODES_SHIFT from 4 to 1 (Prarit Bhargava) [2018568]
- Build CONFIG_SPI_PXA2XX as a module on x86 (Prarit Bhargava) [2018568]
- Turn on CONFIG_CPU_FREQ_GOV_SCHEDUTIL for x86 (Prarit Bhargava) [2018568]
- Turn CONFIG_DEVMEM back off for aarch64 (Prarit Bhargava) [2018568]
- New configs in drivers/media (Prarit Bhargava) [2018568]
- Manually add pending items that need to be set due to mismatch (Prarit Bhargava) [2018568]
- Build CRYPTO_SHA3_*_S390 inline for s390 zfcpdump (Prarit Bhargava) [2018568]
- configs: Remove pending CONFIG_CHELSIO_IPSEC_INLINE file (Prarit Bhargava) [2018568]
- New configs in arch/powerpc (Prarit Bhargava) [2018568]
- New configs in lib/Kconfig.debug (Prarit Bhargava) [2018568]
- New configs in drivers/vhost (Prarit Bhargava) [2018568]
- New configs in drivers/pinctrl (Prarit Bhargava) [2018568]
- New configs in drivers/gpu (Prarit Bhargava) [2018568]
- New configs in drivers/gpio (Prarit Bhargava) [2018568]
- New configs in drivers/block (Prarit Bhargava) [2018568]
- New configs in crypto/Kconfig (Prarit Bhargava) [2018568]
- New configs in drivers/acpi (Prarit Bhargava) [2018568]
- New configs in arch/arm64 (Prarit Bhargava) [2018568]
- New configs in arch/Kconfig (Prarit Bhargava) [2018568]
- AUTOMATIC: New configs (Prarit Bhargava) [2018568]
- Clean up pending common (Prarit Bhargava) [2018568]

* Thu Feb 03 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-54.el9]
- iwlwifi: mvm: read 6E enablement flags from DSM and pass to FW (Íñigo Huguet) [2033354]
- ath11k: add string type to search board data in board-2.bin for WCN6855 (Íñigo Huguet) [2033354]
- mt76: enable new device MT7921E (Íñigo Huguet) [2033354]
- cfg80211: correct bridge/4addr mode check (Íñigo Huguet) [2033354]
- cfg80211: fix management registrations locking (Íñigo Huguet) [2033354]
- cfg80211: scan: fix RCU in cfg80211_add_nontrans_list() (Íñigo Huguet) [2033354]
- mac80211: mesh: fix HE operation element length check (Íñigo Huguet) [2033354]
- mwifiex: avoid null-pointer-subtraction warning (Íñigo Huguet) [2033354]
- Revert "brcmfmac: use ISO3166 country code and 0 rev as fallback" (Íñigo Huguet) [2033354]
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell XPS 15 (Íñigo Huguet) [2033354]
- mac80211: Fix Ptk0 rekey documentation (Íñigo Huguet) [2033354]
- mac80211: check return value of rhashtable_init (Íñigo Huguet) [2033354]
- mac80211: fix use-after-free in CCMP/GCMP RX (Íñigo Huguet) [2033354]
- drivers: net: mhi: fix error path in mhi_net_newlink (Íñigo Huguet) [2033354]
- mac80211-hwsim: fix late beacon hrtimer handling (Íñigo Huguet) [2033354]
- mac80211: mesh: fix potentially unaligned access (Íñigo Huguet) [2033354]
- mac80211: limit injected vht mcs/nss in ieee80211_parse_tx_radiotap (Íñigo Huguet) [2033354]
- mac80211: Drop frames from invalid MAC address in ad-hoc mode (Íñigo Huguet) [2033354]
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug (Íñigo Huguet) [2033354]
- Revert "mac80211: do not use low data rates for data frames with no ack flag" (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: missing unlock in iwl_mvm_wowlan_program_keys() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: Fix off by ones in iwl_mvm_wowlan_get_rsc_v5_data() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix possible NULL dereference (Íñigo Huguet) [2033354]
- iwl: fix debug printf format strings (Íñigo Huguet) [2033354]
- iwlwifi: pnvm: Fix a memory leak in 'iwl_pnvm_get_from_fs()' (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 66 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add rtnl_lock() in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2033354]
- net: qrtr: revert check in qrtr_endpoint_post() (Íñigo Huguet) [2033354]
- net: qrtr: make checks in qrtr_endpoint_post() stricter (Íñigo Huguet) [2033354]
- intel: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]
- mwifiex: pcie: add reset_d3cold quirk for Surface gen4+ devices (Íñigo Huguet) [2033354]
- mwifiex: pcie: add DMI-based quirk implementation for Surface devices (Íñigo Huguet) [2033354]
- brcmfmac: pcie: fix oops on failure to resume and reprobe (Íñigo Huguet) [2033354]
- wilc1000: Convert module-global "isinit" to device-specific variable (Íñigo Huguet) [2033354]
- brcmfmac: Add WPA3 Personal with FT to supported cipher suites (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Fix initialization of place in _rtl92c_phy_get_rightchnlplace() (Íñigo Huguet) [2033354]
- rtw88: add quirk to disable pci caps on HP Pavilion 14-ce0xxx (Íñigo Huguet) [2033354]
- ath9k: fix sleeping in atomic context (Íñigo Huguet) [2033354]
- ath9k: fix OOB read ar9300_eeprom_restore_internal (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't use FW key ID in beacon protection (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix scan channel flags settings (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support broadcast TWT alone (Íñigo Huguet) [2033354]
- iwlwifi: mvm: introduce iwl_stored_beacon_notif_v3 (Íñigo Huguet) [2033354]
- iwlwifi: move get pnvm file name to a separate function (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for responder config command version 9 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for range request command version 13 (Íñigo Huguet) [2033354]
- iwlwifi: allow debug init in RF-kill (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't schedule the roc_done_wk if it is already running (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: support for new DBGI_SRAM region (Íñigo Huguet) [2033354]
- iwlwifi: add 'Rx control frame to MBSSID' HE capability (Íñigo Huguet) [2033354]
- iwlwifi: fw: fix debug dump data declarations (Íñigo Huguet) [2033354]
- iwlwifi: api: remove datamember from struct (Íñigo Huguet) [2033354]
- iwlwifi: fix __percpu annotation (Íñigo Huguet) [2033354]
- iwlwifi: pcie: avoid dma unmap/remap in crash dump (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in SAR tables with defaults (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in WGDS table with defaults (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 65 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WGDS revision 2 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: load regdomain at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Read the PPAG and SAR tables at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: trigger WRT when no beacon heard (Íñigo Huguet) [2033354]
- iwlwifi: fw: correctly limit to monitor dump (Íñigo Huguet) [2033354]
- iwlwifi: skip first element in the WTAS ACPI table (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support version 11 of wowlan statuses notification (Íñigo Huguet) [2033354]
- iwlwifi: convert flat GEO profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: remove unused ACPI_WGDS_TABLE_SIZE definition (Íñigo Huguet) [2033354]
- iwlwifi: support reading and storing EWRD revisions 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WRDS revision 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: pass number of chains and sub-bands to iwl_sar_set_profile() (Íñigo Huguet) [2033354]
- iwlwifi: remove ACPI_SAR_NUM_TABLES definition (Íñigo Huguet) [2033354]
- iwlwifi: convert flat SAR profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: rename ACPI_SAR_NUM_CHAIN_LIMITS to ACPI_SAR_NUM_CHAINS (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix access to BSS elements (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Refactor setting of SSIDs for 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: mvm: silently drop encrypted frames for unknown station (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: implement RSC command version 5 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: make key reprogramming iteration optional (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: add separate key iteration for GTK type (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: refactor TSC/RSC configuration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: remove fixed cmd_flags argument (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: separate TKIP data from key iteration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: simplify __iwl_mvm_set_sta_key() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support new station key API (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix umac scan request probe parameters (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz reset flow (Íñigo Huguet) [2033354]
- iwlwifi: implement Bz NMI behaviour (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz device startup (Íñigo Huguet) [2033354]
- iwlwifi: read MAC address from correct place on Bz (Íñigo Huguet) [2033354]
- iwlwifi: give Bz devices their own name (Íñigo Huguet) [2033354]
- iwlwifi: split off Bz devices into their own family (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: cleanup internal buffer allocation in D3 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: treat MMPDUs in iwl_mvm_mac_tx() as bcast (Íñigo Huguet) [2033354]
- iwlwifi: mvm: clean up number of HW queues (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid static queue number aliasing (Íñigo Huguet) [2033354]
- iwlwifi: use DEFINE_MUTEX() for mutex lock (Íñigo Huguet) [2033354]
- iwlwifi: remove trailing semicolon in macro definition (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix a memory leak in iwl_mvm_mac_ctxt_beacon_changed (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix old-style static const declaration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove check for vif in iwl_mvm_vif_from_mac80211() (Íñigo Huguet) [2033354]
- iwlwifi: pcie: remove spaces from queue names (Íñigo Huguet) [2033354]
- iwlwifi: mvm: restrict FW SMPS request (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set replay counter on key install (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove trigger EAPOL time event (Íñigo Huguet) [2033354]
- iwlwifi: iwl-dbg-tlv: add info about loading external dbg bin (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Add support for hidden network scan on 6GHz band (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Do not use full SSIDs in 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: print PNVM complete notification status in hexadecimal (Íñigo Huguet) [2033354]
- iwlwifi: pcie: dump error on FW reset handshake failures (Íñigo Huguet) [2033354]
- iwlwifi: prepare for synchronous error dumps (Íñigo Huguet) [2033354]
- iwlwifi: pcie: free RBs during configure (Íñigo Huguet) [2033354]
- iwlwifi: pcie: optimise struct iwl_rx_mem_buffer layout (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid FW restart while shutting down (Íñigo Huguet) [2033354]
- iwlwifi: nvm: enable IEEE80211_HE_PHY_CAP10_HE_MU_M1RU_MAX_LTF (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set BROADCAST_TWT_SUPPORTED in MAC policy (Íñigo Huguet) [2033354]
- iwlwifi: iwl-nvm-parse: set STBC flags for HE phy capabilities (Íñigo Huguet) [2033354]
- cfg80211: use wiphy DFS domain if it is self-managed (Íñigo Huguet) [2033354]
- mac80211: parse transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition for transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition of regulatory info in 6 GHz operation information (Íñigo Huguet) [2033354]
- mac80211: introduce individual TWT support in AP mode (Íñigo Huguet) [2033354]
- ieee80211: add TWT element definitions (Íñigo Huguet) [2033354]
- brcmsmac: make array addr static const, makes object smaller (Íñigo Huguet) [2033354]
- rtw88: Remove unnecessary check code (Íñigo Huguet) [2033354]
- rtw88: wow: fix size access error of probe request (Íñigo Huguet) [2033354]
- rtw88: wow: report wow reason through mac80211 api (Íñigo Huguet) [2033354]
- rtw88: wow: build wow function only if CONFIG_PM is on (Íñigo Huguet) [2033354]
- rtw88: refine the setting of rsvd pages for different firmware (Íñigo Huguet) [2033354]
- rtw88: use read_poll_timeout instead of fixed sleep (Íñigo Huguet) [2033354]
- rtw88: 8822ce: set CLKREQ# signal to low during suspend (Íñigo Huguet) [2033354]
- rtw88: change beacon filter default mode (Íñigo Huguet) [2033354]
- rtw88: 8822c: add tx stbc support under HT mode (Íñigo Huguet) [2033354]
- rtw88: adjust the log level for failure of tx report (Íñigo Huguet) [2033354]
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation (Íñigo Huguet) [2033354]
- rtl8xxxu: disable interrupt_in transfer for 8188cu and 8192cu (Íñigo Huguet) [2033354]
- mwifiex: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- mwifiex: usb: Replace one-element array with flexible-array member (Íñigo Huguet) [2033354]
- mwifiex: drop redundant null-pointer check in mwifiex_dnld_cmd_to_fw() (Íñigo Huguet) [2033354]
- wilc1000: remove redundant code (Íñigo Huguet) [2033354]
- wilc1000: use devm_clk_get_optional() (Íñigo Huguet) [2033354]
- wilc1000: dispose irq on failure path (Íñigo Huguet) [2033354]
- wilc1000: use goto labels on error path (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Remove redundant variable initializations (Íñigo Huguet) [2033354]
- ray_cs: Split memcpy() to avoid bounds check warning (Íñigo Huguet) [2033354]
- ray_cs: use %%*ph to print small buffer (Íñigo Huguet) [2033354]
- brcmfmac: add 43752 SDIO ids and initialization (Íñigo Huguet) [2033354]
- brcmfmac: Set SDIO workqueue as WQ_HIGHPRI (Íñigo Huguet) [2033354]
- brcmfmac: use separate firmware for 43430 revision 2 (Íñigo Huguet) [2033354]
- brcmfmac: support chipsets with different core enumeration space (Íñigo Huguet) [2033354]
- brcmfmac: add xtlv support to firmware interface layer (Íñigo Huguet) [2033354]
- brcmfmac: increase core revision column aligning core list (Íñigo Huguet) [2033354]
- brcmfmac: use different error value for invalid ram base address (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Fix firmware loading (Íñigo Huguet) [2033354]
- cfg80211: fix BSS color notify trace enum confusion (Íñigo Huguet) [2033354]
- mac80211: Fix insufficient headroom issue for AMSDU (Íñigo Huguet) [2033354]
- mac80211: add support for BSS color change (Íñigo Huguet) [2033354]
- nl80211: add support for BSS coloring (Íñigo Huguet) [2033354]
- mac80211: Use flex-array for radiotap header bitmap (Íñigo Huguet) [2033354]
- mac80211: radiotap: Use BIT() instead of shifts (Íñigo Huguet) [2033354]
- mac80211: Remove unnecessary variable and label (Íñigo Huguet) [2033354]
- mac80211: include <linux/rbtree.h> (Íñigo Huguet) [2033354]
- mac80211: Fix monitor MTU limit so that A-MSDUs get through (Íñigo Huguet) [2033354]
- mac80211: remove unnecessary NULL check in ieee80211_register_hw() (Íñigo Huguet) [2033354]
- mac80211: Reject zero MAC address in sta_info_insert_check() (Íñigo Huguet) [2033354]
- bus: mhi: core: Improve debug messages for power up (Íñigo Huguet) [2033354]
- bus: mhi: core: Replace DMA allocation wrappers with original APIs (Íñigo Huguet) [2033354]
- bus: mhi: core: Add range checks for BHI and BHIe (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Set register access length for MHI driver (Íñigo Huguet) [2033354]
- ath11k: set register access length for MHI driver (Íñigo Huguet) [2033354]
- bus: mhi: Add MMIO region length to controller structure (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI and BHIe pointers to NULL in clean-up (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI/BHIe offsets on power up preparation (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Add Cinterion MV31-W PCIe to MHI (Íñigo Huguet) [2033354]
- net: mhi: Remove MBIM protocol (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Allow per-board firmware binaries (Íñigo Huguet) [2033354]
- net: mhi: Improve MBIM packet counting (Íñigo Huguet) [2033354]
- bus: mhi: pci-generic: configurable network interface MRU (Íñigo Huguet) [2033354]
- ath11k: Remove some duplicate code (Íñigo Huguet) [2033354]
- ath: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]

* Wed Feb 02 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-53.el9]
- quota: correct error number in free_dqentry() (Lukas Czerner) [2041793]
- quota: check block number when reading the block in quota file (Lukas Czerner) [2041793]
- ext4: don't use the orphan list when migrating an inode (Lukas Czerner) [2041486]
- ext4: use BUG_ON instead of if condition followed by BUG (Lukas Czerner) [2041486]
- ext4: fix a copy and paste typo (Lukas Czerner) [2041777]
- ext4: set csum seed in tmp inode while migrating to extents (Lukas Czerner) [2041486]
- ext4: remove unnecessary 'offset' assignment (Lukas Czerner) [2041486]
- ext4: remove redundant o_start statement (Lukas Czerner) [2041486]
- ext4: drop an always true check (Lukas Czerner) [2041486]
- ext4: remove unused assignments (Lukas Czerner) [2041486]
- ext4: remove redundant statement (Lukas Czerner) [2041486]
- ext4: remove useless resetting io_end_size in mpage_process_page() (Lukas Czerner) [2041486]
- ext4: allow to change s_last_trim_minblks via sysfs (Lukas Czerner) [2041486]
- ext4: change s_last_trim_minblks type to unsigned long (Lukas Czerner) [2041486]
- ext4: implement support for get/set fs label (Lukas Czerner) [2041486]
- ext4: only set EXT4_MOUNT_QUOTA when journalled quota file is specified (Lukas Czerner) [2041777]
- ext4: don't use kfree() on rcu protected pointer sbi->s_qf_names (Lukas Czerner) [2041486]
- ext4: avoid trim error on fs with small groups (Lukas Czerner) [2041486]
- ext4: fix an use-after-free issue about data=journal writeback mode (Lukas Czerner) [2041486]
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits' (Lukas Czerner) [2041486]
- ext4: initialize err_blk before calling __ext4_get_inode_loc (Lukas Czerner) [2041486]
- ext4: fix a possible ABBA deadlock due to busy PA (Lukas Czerner) [2041486]
- ext4: replace snprintf in show functions with sysfs_emit (Lukas Czerner) [2041486]
- ext4: make sure to reset inode lockdep class when quota enabling fails (Lukas Czerner) [2041486]
- ext4: make sure quota gets properly shutdown on error (Lukas Czerner) [2041486]
- ext4: Fix BUG_ON in ext4_bread when write quota data (Lukas Czerner) [2041486]
- ext4: destroy ext4_fc_dentry_cachep kmemcache on module removal (Lukas Czerner) [2041486]
- ext4: fast commit may miss tracking unwritten range during ftruncate (Lukas Czerner) [2041486]
- ext4: use ext4_ext_remove_space() for fast commit replay delete range (Lukas Czerner) [2041486]
- ext4: fix fast commit may miss tracking range for FALLOC_FL_ZERO_RANGE (Lukas Czerner) [2041486]
- ext4: update fast commit TODOs (Lukas Czerner) [2041486]
- ext4: simplify updating of fast commit stats (Lukas Czerner) [2041486]
- ext4: drop ineligible txn start stop APIs (Lukas Czerner) [2041486]
- ext4: use ext4_journal_start/stop for fast commit transactions (Lukas Czerner) [2041486]
- ext4: fix i_version handling on remount (Lukas Czerner) [2041777]
- ext4: remove lazytime/nolazytime mount options handled by MS_LAZYTIME (Lukas Czerner) [2041777]
- ext4: don't fail remount if journalling mode didn't change (Lukas Czerner) [2041777]
- ext4: Remove unused match_table_t tokens (Lukas Czerner) [2041777]
- ext4: switch to the new mount api (Lukas Czerner) [2041777]
- ext4: change token2str() to use ext4_param_specs (Lukas Czerner) [2041777]
- ext4: clean up return values in handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Completely separate options parsing and sb setup (Lukas Czerner) [2041777]
- ext4: get rid of super block and sbi from handle_mount_ops() (Lukas Czerner) [2041777]
- ext4: check ext2/3 compatibility outside handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: move quota configuration out of handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Allow sb to be NULL in ext4_msg() (Lukas Czerner) [2041777]
- ext4: Change handle_mount_opt() to use fs_parameter (Lukas Czerner) [2041777]
- ext4: move option validation to a separate function (Lukas Czerner) [2041777]
- ext4: Add fs parameter specifications for mount options (Lukas Czerner) [2041777]
- fs_parse: allow parameter value to be empty (Lukas Czerner) [2041777]
- ext4: fix error code saved on super block during file system abort (Lukas Czerner) [2041486]
- ext4: inline data inode fast commit replay fixes (Lukas Czerner) [2041486]
- ext4: commit inline data during fast commit (Lukas Czerner) [2041486]
- ext4: scope ret locally in ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove an unused variable warning with CONFIG_QUOTA=n (Lukas Czerner) [2041486]
- ext4: fix boolreturn.cocci warnings in fs/ext4/name.c (Lukas Czerner) [2041486]
- ext4: prevent getting empty inode buffer (Lukas Czerner) [2041486]
- ext4: move ext4_fill_raw_inode() related functions (Lukas Czerner) [2041486]
- ext4: factor out ext4_fill_raw_inode() (Lukas Czerner) [2041486]
- ext4: prevent partial update of the extent blocks (Lukas Czerner) [2035878]
- ext4: check for inconsistent extents between index and leaf block (Lukas Czerner) [2035878]
- ext4: check for out-of-order index extents in ext4_valid_extent_entries() (Lukas Czerner) [2035878]
- ext4: convert from atomic_t to refcount_t on ext4_io_end->count (Lukas Czerner) [2041486]
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem. (Lukas Czerner) [2041486]
- ext4: ensure enough credits in ext4_ext_shift_path_extents (Lukas Czerner) [2041486]
- ext4: correct the left/middle/right debug message for binsearch (Lukas Czerner) [2041486]
- ext4: fix lazy initialization next schedule time computation in more granular unit (Lukas Czerner) [2041486]
- ext4: recheck buffer uptodate bit under buffer lock (Lukas Czerner) [2041486]
- ext4: fix potential infinite loop in ext4_dx_readdir() (Lukas Czerner) [2041486]
- ext4: flush s_error_work before journal destroy in ext4_fill_super (Lukas Czerner) [2041486]
- ext4: fix loff_t overflow in ext4_max_bitmap_size() (Lukas Czerner) [2041486]
- ext4: fix reserved space counter leakage (Lukas Czerner) [2041486]
- ext4: limit the number of blocks in one ADD_RANGE TLV (Lukas Czerner) [2041486]
- ext4: remove extent cache entries when truncating inline data (Lukas Czerner) [2041486]
- ext4: drop unnecessary journal handle in delalloc write (Lukas Czerner) [2041486]
- ext4: factor out write end code of inline file (Lukas Czerner) [2041486]
- ext4: correct the error path of ext4_write_inline_data_end() (Lukas Czerner) [2041486]
- ext4: check and update i_disksize properly (Lukas Czerner) [2041486]
- ext4: add error checking to ext4_ext_replay_set_iblocks() (Lukas Czerner) [2041486]
- ext4: make the updating inode data procedure atomic (Lukas Czerner) [2041486]
- ext4: remove an unnecessary if statement in __ext4_get_inode_loc() (Lukas Czerner) [2041486]
- ext4: move inode eio simulation behind io completeion (Lukas Czerner) [2041486]
- ext4: Improve scalability of ext4 orphan file handling (Lukas Czerner) [2041486]
- ext4: Speedup ext4 orphan inode handling (Lukas Czerner) [2041486]
- ext4: Move orphan inode handling into a separate file (Lukas Czerner) [2041486]
- jbd2: add sparse annotations for add_transaction_credits() (Lukas Czerner) [2041486]
- ext4: Support for checksumming from journal triggers (Lukas Czerner) [2041486]
- ext4: fix sparse warnings (Lukas Czerner) [2041486]
- ext4: fix race writing to an inline_data file while its xattrs are changing (Lukas Czerner) [2003461]
- ext4: Make sure quota files are not grabbed accidentally (Lukas Czerner) [2041486]
- ext4: fix e2fsprogs checksum failure for mounted filesystem (Lukas Czerner) [2022859]
- ext4: if zeroout fails fall back to splitting the extent node (Lukas Czerner) [2041486]
- ext4: reduce arguments of ext4_fc_add_dentry_tlv (Lukas Czerner) [2041486]
- ext4: remove the repeated comment of ext4_trim_all_free (Lukas Czerner) [2041486]
- ext4: add new helper interface ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove the 'group' parameter of ext4_trim_extent (Lukas Czerner) [2041486]
- jbd2: clean up two gcc -Wall warnings in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix clang warning in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix portability problems caused by unaligned accesses (Lukas Czerner) [2041486]
- ext4: Convert to use mapping->invalidate_lock (Lukas Czerner) [2041486]

* Tue Feb 01 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-52.el9]
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and CPTR_EL2 to 1 (Andrew Jones) [2009341]
- KVM: arm64: Extract ESR_ELx.EC only (Andrew Jones) [2009341]
- KVM: selftests: Build the memslot tests for arm64 (Andrew Jones) [2009341]
- KVM: selftests: Make memslot_perf_test arch independent (Andrew Jones) [2009341]
- selftests: KVM: Fix kvm device helper ioctl assertions (Andrew Jones) [2009341]
- KVM: arm64: selftests: arch_timer: Support vCPU migration (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add arch_timer test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add host support for vGIC (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic GICv3 support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add light-weight spinlock support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add guest support to get the vcpuid (Andrew Jones) [2009341]
- KVM: arm64: selftests: Maintain consistency for vcpuid type (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support to disable and enable local IRQs (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support to generate delays (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support for arch_timers (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support for cpu_relax (Andrew Jones) [2009341]
- KVM: arm64: selftests: Introduce ARM64_SYS_KVM_REG (Andrew Jones) [2009341]
- tools: arm64: Import sysreg.h (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add MMIO readl/writel support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add init ITS device test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add test for legacy GICv3 REDIST base partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add tests for GIC redist/cpuif partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add some tests for GICv2 in vgic_init (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init/vm_gic_create version agnostic (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init gic version agnostic (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop vgic_check_ioaddr() (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check ITS region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v2: Check cpu interface region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check redist region is not above the VM IPA size (Andrew Jones) [2009341]
- kvm: arm64: vgic: Introduce vgic_check_iorange (Andrew Jones) [2009341]
- KVM: arm64: Release mmap_lock when using VM_SHARED with MTE (Andrew Jones) [2009341]
- KVM: arm64: Report corrupted refcount at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Fix host stage-2 PGD refcount (Andrew Jones) [2009341]
- KVM: arm64: Fix PMU probe ordering (Andrew Jones) [2009341]
- KVM: arm64: nvhe: Fix missing FORCE for hyp-reloc.S build rule (Andrew Jones) [2009341]
- arm64: Do not trap PMSNEVFR_EL1 (Andrew Jones) [2009341]
- KVM: arm64: Trim guest debug exception handling (Andrew Jones) [2009341]
- KVM: arm64: Minor optimization of range_is_memory (Andrew Jones) [2009341]
- KVM: arm64: Upgrade trace_kvm_arm_set_dreg32() to 64bit (Andrew Jones) [2009341]
- KVM: arm64: Add config register bit definitions (Andrew Jones) [2009341]
- KVM: arm64: Track value of cptr_el2 in struct kvm_vcpu_arch (Andrew Jones) [2009341]
- KVM: arm64: Keep mdcr_el2's value as set by __init_el2_debug (Andrew Jones) [2009341]
- KVM: arm64: Restore mdcr_el2 from vcpu (Andrew Jones) [2009341]
- KVM: arm64: Refactor sys_regs.h,c for nVHE reuse (Andrew Jones) [2009341]
- KVM: arm64: Fix names of config register fields (Andrew Jones) [2009341]
- KVM: arm64: MDCR_EL2 is a 64-bit register (Andrew Jones) [2009341]
- KVM: arm64: Remove trailing whitespace in comment (Andrew Jones) [2009341]
- KVM: arm64: placeholder to check if VM is protected (Andrew Jones) [2009341]
- KVM: arm64: Upgrade VMID accesses to {READ,WRITE}_ONCE (Andrew Jones) [2009341]
- KVM: arm64: Unify stage-2 programming behind __load_stage2() (Andrew Jones) [2009341]
- KVM: arm64: Move kern_hyp_va() usage in __load_guest_stage2() into the callers (Andrew Jones) [2009341]
- KVM: arm64: vgic: Resample HW pending state on deactivation (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop WARN from vgic_get_irq (Andrew Jones) [2009341]
- KVM: arm64: Use generic KVM xfer to guest work function (Andrew Jones) [2009341]
- entry: KVM: Allow use of generic KVM entry w/o full generic support (Andrew Jones) [2009341]
- KVM: arm64: Record number of signal exits as a vCPU stat (Andrew Jones) [2009341]
- selftests: KVM: Introduce psci_cpu_on_test (Andrew Jones) [2009341]
- KVM: arm64: Enforce reserved bits for PSCI target affinities (Andrew Jones) [2009341]
- KVM: arm64: Handle PSCI resets before userspace touches vCPU state (Andrew Jones) [2009341]
- KVM: arm64: Fix read-side race on updates to vcpu reset state (Andrew Jones) [2009341]
- KVM: arm64: Make hyp_panic() more robust when protected mode is enabled (Andrew Jones) [2009341]
- KVM: arm64: Drop unused REQUIRES_VIRT (Andrew Jones) [2009341]
- KVM: arm64: Drop check_kvm_target_cpu() based percpu probe (Andrew Jones) [2009341]
- KVM: arm64: Drop init_common_resources() (Andrew Jones) [2009341]
- KVM: arm64: Use ARM64_MIN_PARANGE_BITS as the minimum supported IPA (Andrew Jones) [2009341]
- arm64/mm: Add remaining ID_AA64MMFR0_PARANGE_ macros (Andrew Jones) [2009341]
- KVM: arm64: Return -EPERM from __pkvm_host_share_hyp() (Andrew Jones) [2009341]
- KVM: arm64: Restrict IPA size to maximum 48 bits on 4K and 16K page size (Andrew Jones) [2009341]
- arm64/mm: Define ID_AA64MMFR0_TGRAN_2_SHIFT (Andrew Jones) [2009341]
- KVM: arm64: perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Andrew Jones) [2009341]
- KVM: arm64: Make __pkvm_create_mappings static (Andrew Jones) [2009341]
- KVM: arm64: Restrict EL2 stage-1 changes in protected mode (Andrew Jones) [2009341]
- KVM: arm64: Refactor protected nVHE stage-1 locking (Andrew Jones) [2009341]
- KVM: arm64: Remove __pkvm_mark_hyp (Andrew Jones) [2009341]
- KVM: arm64: Mark host bss and rodata section as shared (Andrew Jones) [2009341]
- KVM: arm64: Enable retrieving protections attributes of PTEs (Andrew Jones) [2009341]
- KVM: arm64: Introduce addr_is_memory() (Andrew Jones) [2009341]
- KVM: arm64: Expose pkvm_hyp_id (Andrew Jones) [2009341]
- KVM: arm64: Expose host stage-2 manipulation helpers (Andrew Jones) [2009341]
- KVM: arm64: Add helpers to tag shared pages in SW bits (Andrew Jones) [2009341]
- KVM: arm64: Allow populating software bits (Andrew Jones) [2009341]
- KVM: arm64: Enable forcing page-level stage-2 mappings (Andrew Jones) [2009341]
- KVM: arm64: Tolerate re-creating hyp mappings to set software bits (Andrew Jones) [2009341]
- KVM: arm64: Don't overwrite software bits with owner id (Andrew Jones) [2009341]
- KVM: arm64: Rename KVM_PTE_LEAF_ATTR_S2_IGNORED (Andrew Jones) [2009341]
- KVM: arm64: Optimize host memory aborts (Andrew Jones) [2009341]
- KVM: arm64: Expose page-table helpers (Andrew Jones) [2009341]
- KVM: arm64: Provide the host_stage2_try() helper macro (Andrew Jones) [2009341]
- KVM: arm64: Introduce hyp_assert_lock_held() (Andrew Jones) [2009341]
- redhat: configs: Disable NVHE_EL2_DEBUG (Andrew Jones) [2009341]
- KVM: arm64: Add hyp_spin_is_locked() for basic locking assertions at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Unregister HYP sections from kmemleak in protected mode (Andrew Jones) [2009341]
- arm64: Move .hyp.rodata outside of the _sdata.._edata range (Andrew Jones) [2009341]
- KVM: arm64: Fix comments related to GICv2 PMR reporting (Andrew Jones) [2009341]
- KVM: arm64: Count VMID-wide TLB invalidations (Andrew Jones) [2009341]
- KVM: arm64: Remove PMSWINC_EL0 shadow register (Andrew Jones) [2009341]
- KVM: arm64: Disabling disabled PMU counters wastes a lot of time (Andrew Jones) [2009341]
- KVM: arm64: Drop unnecessary masking of PMU registers (Andrew Jones) [2009341]
- KVM: arm64: Narrow PMU sysreg reset values to architectural requirements (Andrew Jones) [2009341]
- KVM: arm64: Introduce helper to retrieve a PTE and its level (Andrew Jones) [2009341]
- KVM: Remove kvm_is_transparent_hugepage() and PageTransCompoundMap() (Andrew Jones) [2009341]
- KVM: arm64: Avoid mapping size adjustment on permission fault (Andrew Jones) [2009341]
- KVM: arm64: Walk userspace page tables to compute the THP mapping size (Andrew Jones) [2009341]

* Mon Jan 31 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-51.el9]
- selftests: bpf: Fix bind on used port (Felix Maurer) [2043528]
- Add packaged but empty /lib/modules/<kver>/systemtap (Herton R. Krzesinski) [2012908]
- powerpc/bpf: Update ldimm64 instructions during extra pass (Yauheni Kaliuta) [2040549]
- RDMA/irdma: Don't arm the CQ more than two times if no CE for this CQ (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC errors (Kamal Heib) [2039426]
- RDMA/irdma: Fix a potential memory allocation issue in 'irdma_prm_add_pble_mem()' (Kamal Heib) [2039426]
- RDMA/irdma: Fix a user-after-free in add_pble_prm (Kamal Heib) [2039426]
- RDMA/irdma: Do not hold qos mutex twice on QP resume (Kamal Heib) [2039426]
- RDMA/irdma: Set VLAN in UD work completion correctly (Kamal Heib) [2039426]
- RDMA/irdma: Process extended CQ entries correctly (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when there are MW bind errors (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when transport retry counter is exceeded (Kamal Heib) [2039426]
- RDMA/irdma: Validate number of CQ entries on create CQ (Kamal Heib) [2039426]
- RDMA/irdma: Skip CQP ring during a reset (Kamal Heib) [2039426]
- redhat/configs: Enable CONFIG_DM_MULTIPATH_HST (Benjamin Marzinski) [2000835]
- RDMA/core: Don't infoleak GRH fields (Kamal Heib) [2036599]
- RDMA/uverbs: Check for null return of kmalloc_array (Kamal Heib) [2036599]
- RDMA/sa_query: Use strscpy_pad instead of memcpy to copy a string (Kamal Heib) [2036599]
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing more requests (Kamal Heib) [2036599]
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure (Kamal Heib) [2036599]
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups (Kamal Heib) [2036599]
- IB/core: Remove deprecated current_seq comments (Kamal Heib) [2036599]
- RDMA/iwcm: Release resources if iw_cm module initialization fails (Kamal Heib) [2036599]
- sched: padding for user_struct for KABI (Phil Auld) [2033084]
- sched: padding for signal_struct in linux/sched/signal.h (Phil Auld) [2033084]
- sched: padding for struct rq and related (Phil Auld) [2033084]
- sched: Padding for sched_domain and root_domain (Phil Auld) [2033084]
- sched: Padding for task_struct and related in include/linux/sched.h (Phil Auld) [2033084]
- hwmon: (k10temp) Support up to 12 CCDs on AMD Family of processors (David Arcari) [2022526]
- hwmon: (k10temp) Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (David Arcari) [2022526]
- hwmon: (k10temp) Remove unused definitions (David Arcari) [2022526]
- x86/amd_nb: Add AMD Family 19h Models (10h-1Fh) and (A0h-AFh) PCI IDs (David Arcari) [2022526]
- hwmon: (k10temp) Remove residues of current and voltage (David Arcari) [2022526]
- tipc: check for null after calling kmemdup (Xin Long) [2024993]
- tipc: only accept encrypted MSG_CRYPTO msgs (Xin Long) [2024993]
- tipc: constify dev_addr passing (Xin Long) [2024993]
- tipc: increase timeout in tipc_sk_enqueue() (Xin Long) [2024993]
- tipc: clean up inconsistent indenting (Xin Long) [2024993]
- redhat: configs: add CONFIG_NTB and related items (John Linville) [1874186]

* Fri Jan 28 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-50.el9]
- net: fix possible NULL deref in sock_reserve_memory (Paolo Abeni) [2028420]
- mptcp: fix per socket endpoint accounting (Paolo Abeni) [2028420]
- mptcp: Check reclaim amount before reducing allocation (Paolo Abeni) [2028420]
- mptcp: fix a DSS option writing error (Paolo Abeni) [2028420]
- mptcp: fix opt size when sending DSS + MP_FAIL (Paolo Abeni) [2028420]
- mptcp: clean up harmless false expressions (Paolo Abeni) [2028420]
- selftests: mptcp: try to set mptcp ulp mode in different sk states (Paolo Abeni) [2028420]
- mptcp: enforce HoL-blocking estimation (Paolo Abeni) [2028420]
- mptcp: fix deadlock in __mptcp_push_pending() (Paolo Abeni) [2028420]
- mptcp: clear 'kern' flag from fallback sockets (Paolo Abeni) [2028420]
- mptcp: remove tcp ulp setsockopt support (Paolo Abeni) [2028420]
- mptcp: never allow the PM to close a listener subflow (Paolo Abeni) [2028420]
- selftests: mptcp: remove duplicate include in mptcp_inq.c (Paolo Abeni) [2028420]
- mptcp: support TCP_CORK and TCP_NODELAY (Paolo Abeni) [2028420]
- mptcp: expose mptcp_check_and_set_pending (Paolo Abeni) [2028420]
- tcp: expose __tcp_sock_set_cork and __tcp_sock_set_nodelay (Paolo Abeni) [2028420]
- selftests: mptcp: check IP_TOS in/out are the same (Paolo Abeni) [2028420]
- mptcp: getsockopt: add support for IP_TOS (Paolo Abeni) [2028420]
- mptcp: allow changing the "backup" bit by endpoint id (Paolo Abeni) [2028420]
- selftests: mptcp: add inq test case (Paolo Abeni) [2028420]
- mptcp: add SIOCINQ, OUTQ and OUTQNSD ioctls (Paolo Abeni) [2028420]
- selftests: mptcp: add TCP_INQ support (Paolo Abeni) [2028420]
- mptcp: add TCP_INQ cmsg support (Paolo Abeni) [2028420]
- mptcp: use delegate action to schedule 3rd ack retrans (Paolo Abeni) [2028420]
- mptcp: fix delack timer (Paolo Abeni) [2028420]
- selftests: mptcp: add tproxy test case (Paolo Abeni) [2028420]
- mptcp: sockopt: add SOL_IP freebind & transparent options (Paolo Abeni) [2028420]
- mptcp: Support for IP_TOS for MPTCP setsockopt() (Paolo Abeni) [2028420]
- ipv4: Exposing __ip_sock_set_tos() in ip.h (Paolo Abeni) [2028420]
- selftests: mptcp: more stable simult_flows tests (Paolo Abeni) [2028420]
- selftests: mptcp: fix proto type in link_failure tests (Paolo Abeni) [2028420]
- mptcp: fix corrupt receiver key in MPC + data + checksum (Paolo Abeni) [2028420]
- mptcp: drop unused sk in mptcp_push_release (Paolo Abeni) [2028420]
- mptcp: allocate fwd memory separately on the rx and tx path (Paolo Abeni) [2028420]
- net: introduce sk_forward_alloc_get() (Paolo Abeni) [2028420]
- tcp: define macros for a couple reclaim thresholds (Paolo Abeni) [2028420]
- net: add new socket option SO_RESERVE_MEM (Paolo Abeni) [2028420]
- mptcp: Make mptcp_pm_nl_mp_prio_send_ack() static (Paolo Abeni) [2028420]
- mptcp: increase default max additional subflows to 2 (Paolo Abeni) [2028420]
- mptcp: Avoid NULL dereference in mptcp_getsockopt_subflow_addrs() (Paolo Abeni) [2028420]
- mptcp: fix possible stall on recvmsg() (Paolo Abeni) [2028420]
- mptcp: use batch snmp operations in mptcp_seq_show() (Paolo Abeni) [2028420]
- net: snmp: inline snmp_get_cpu_field() (Paolo Abeni) [2028420]
- net: introduce and use lock_sock_fast_nested() (Paolo Abeni) [2028420]
- net: core: Correct the sock::sk_lock.owned lockdep annotations (Paolo Abeni) [2028420]
- mptcp: re-arm retransmit timer if data is pending (Paolo Abeni) [2028420]
- mptcp: remove tx_pending_data (Paolo Abeni) [2028420]
- mptcp: use lockdep_assert_held_once() instead of open-coding it (Paolo Abeni) [2028420]
- mptcp: use OPTIONS_MPTCP_MPC (Paolo Abeni) [2028420]
- mptcp: do not shrink snd_nxt when recovering (Paolo Abeni) [2028420]
- mptcp: allow changing the 'backup' bit when no sockets are open (Paolo Abeni) [2028420]
- mptcp: don't return sockets in foreign netns (Paolo Abeni) [2028420]
- tcp: remove sk_{tr}x_skb_cache (Paolo Abeni) [2028420]
- tcp: make tcp_build_frag() static (Paolo Abeni) [2028420]
- mptcp: stop relying on tcp_tx_skb_cache (Paolo Abeni) [2028420]
- tcp: expose the tcp_mark_push() and tcp_skb_entail() helpers (Paolo Abeni) [2028420]
- selftests: mptcp: add mptcp getsockopt test cases (Paolo Abeni) [2028420]
- mptcp: add MPTCP_SUBFLOW_ADDRS getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_TCPINFO getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_INFO getsockopt (Paolo Abeni) [2028420]
- mptcp: add new mptcp_fill_diag helper (Paolo Abeni) [2028420]
- mptcp: Only send extra TCP acks in eligible socket states (Paolo Abeni) [2028420]
- selftests: mptcp: clean tmp files in simult_flows (Paolo Abeni) [2028420]
- mptcp: ensure tx skbs always have the MPTCP ext (Paolo Abeni) [2028420]
- mptcp: fix possible divide by zero (Paolo Abeni) [2028420]
- mptcp: Fix duplicated argument in protocol.h (Paolo Abeni) [2028420]
- mptcp: make the locking tx schema more readable (Paolo Abeni) [2028420]
- mptcp: optimize the input options processing (Paolo Abeni) [2028420]
- mptcp: consolidate in_opt sub-options fields in a bitmask (Paolo Abeni) [2028420]
- mptcp: better binary layout for mptcp_options_received (Paolo Abeni) [2028420]
- mptcp: do not set unconditionally csum_reqd on incoming opt (Paolo Abeni) [2028420]
- selftests: mptcp: add MP_FAIL mibs check (Paolo Abeni) [2028420]
- mptcp: add the mibs for MP_FAIL (Paolo Abeni) [2028420]
- mptcp: send out MP_FAIL when data checksum fails (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption receiving (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption sending (Paolo Abeni) [2028420]
- mptcp: shrink mptcp_out_options struct (Paolo Abeni) [2028420]
- mptcp: optimize out option generation (Paolo Abeni) [2028420]
- selftests: mptcp: add_addr and echo race test (Paolo Abeni) [2028420]
- mptcp: remove MPTCP_ADD_ADDR_IPV6 and MPTCP_ADD_ADDR_PORT (Paolo Abeni) [2028420]
- mptcp: build ADD_ADDR/echo-ADD_ADDR option according pm.add_signal (Paolo Abeni) [2028420]
- mptcp: fix ADD_ADDR and RM_ADDR maybe flush addr_signal each other (Paolo Abeni) [2028420]
- mptcp: make MPTCP_ADD_ADDR_SIGNAL and MPTCP_ADD_ADDR_ECHO separate (Paolo Abeni) [2028420]
- mptcp: move drop_other_suboptions check under pm lock (Paolo Abeni) [2028420]
- selftests: mptcp: delete uncontinuous removing ids (Paolo Abeni) [2028420]
- selftests: mptcp: add fullmesh testcases (Paolo Abeni) [2028420]
- selftests: mptcp: set and print the fullmesh flag (Paolo Abeni) [2028420]
- mptcp: local addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: remote addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: drop flags and ifindex arguments (Paolo Abeni) [2028420]
- selftests: mptcp: add testcase for active-back (Paolo Abeni) [2028420]
- mptcp: backup flag from incoming MPJ ack option (Paolo Abeni) [2028420]
- mptcp: add mibs for stale subflows processing (Paolo Abeni) [2028420]
- mptcp: faster active backup recovery (Paolo Abeni) [2028420]
- mptcp: cleanup sysctl data and helpers (Paolo Abeni) [2028420]
- mptcp: handle pending data on closed subflow (Paolo Abeni) [2028420]
- mptcp: less aggressive retransmission strategy (Paolo Abeni) [2028420]
- mptcp: more accurate timeout (Paolo Abeni) [2028420]
- ionic: no devlink_unregister if not registered (Petr Oros) [2032260]
- devlink: fix netns refcount leak in devlink_nl_cmd_reload() (Petr Oros) [2032260]
- devlink: Don't throw an error if flash notification sent before devlink visible (Petr Oros) [2032260]
- devlink: make all symbols GPL-only (Petr Oros) [2032260]
- devlink: Simplify internal devlink params implementation (Petr Oros) [2032260]
- devlink: Clean not-executed param notifications (Petr Oros) [2032260]
- devlink: Delete obsolete parameters publish API (Petr Oros) [2032260]
- devlink: Remove extra device_lock assert checks (Petr Oros) [2032260]
- devlink: Delete reload enable/disable interface (Petr Oros) [2032260]
- net/mlx5: Set devlink reload feature bit for supported devices only (Petr Oros) [2032260]
- devlink: Allow control devlink ops behavior through feature mask (Petr Oros) [2032260]
- devlink: Annotate devlink API calls (Petr Oros) [2032260]
- devlink: Move netdev_to_devlink helpers to devlink.c (Petr Oros) [2032260]
- devlink: Reduce struct devlink exposure (Petr Oros) [2032260]
- devlink: report maximum number of snapshots with regions (Petr Oros) [2032260]
- devlink: Add missed notifications iterators (Petr Oros) [2032260]
- netdevsim: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- qed: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- ionic: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- nfp: Move delink_register to be last command (Petr Oros) [2032260]
- mlxsw: core: Register devlink instance last (Petr Oros) [2032260]
- net/mlx5: Accept devlink user input after driver initialization complete (Petr Oros) [2032260]
- net/mlx4: Move devlink_register to be the last initialization command (Petr Oros) [2032260]
- ice: Open devlink when device is ready (Petr Oros) [2032260]
- net: hinic: Open device for the user access when it is ready (Petr Oros) [2032260]
- bnxt_en: Register devlink instance at the end devlink configuration (Petr Oros) [2032260]
- devlink: Notify users when objects are accessible (Petr Oros) [2032260]
- net/mlx5: Fix rdma aux device on devlink reload (Petr Oros) [2032260]
- qed: Don't ignore devlink allocation failures (Petr Oros) [2032260]
- ice: Delete always true check of PF pointer (Petr Oros) [2032260]
- devlink: Remove single line function obfuscations (Petr Oros) [2032260]
- devlink: Delete not used port parameters APIs (Petr Oros) [2032260]
- bnxt_en: Properly remove port parameter support (Petr Oros) [2032260]
- bnxt_en: Check devlink allocation and registration status (Petr Oros) [2032260]
- devlink: Make devlink_register to be void (Petr Oros) [2032260]
- devlink: Delete not-used devlink APIs (Petr Oros) [2032260]
- devlink: Delete not-used single parameter notification APIs (Petr Oros) [2032260]
- net/mlx5: Publish and unpublish all devlink parameters at once (Petr Oros) [2032260]
- devlink: Use xarray to store devlink instances (Petr Oros) [2032260]
- devlink: Count struct devlink consumers (Petr Oros) [2032260]
- devlink: Remove check of always valid devlink pointer (Petr Oros) [2032260]
- devlink: Simplify devlink_pernet_pre_exit call (Petr Oros) [2032260]
- net/mlx5: Support enable_vnet devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_rdma devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_eth devlink dev param (Petr Oros) [2032260]
- net/mlx5: Fix unpublish devlink parameters (Petr Oros) [2032260]
- devlink: Add APIs to publish, unpublish individual parameter (Petr Oros) [2032260]
- devlink: Add API to register and unregister single parameter (Petr Oros) [2032260]
- devlink: Create a helper function for one parameter registration (Petr Oros) [2032260]
- devlink: Add new "enable_vnet" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_rdma" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_eth" generic device param (Petr Oros) [2032260]
- devlink: Fix port_type_set function pointer check (Petr Oros) [2032260]
- devlink: Set device as early as possible (Petr Oros) [2032260]
- devlink: Simplify devlink port API calls (Petr Oros) [2032260]
- devlink: Allocate devlink directly in requested net namespace (Petr Oros) [2032260]
- devlink: Remove duplicated registration check (Petr Oros) [2032260]
- netdevsim: Protect both reload_down and reload_up paths (Petr Oros) [2032260]
- netdevsim: Forbid devlink reload when adding or deleting ports (Petr Oros) [2032260]
- net/mlx5: Don't rely on always true registered field (Petr Oros) [2032260]
- ionic: cleanly release devlink instance (Petr Oros) [2032260]
- selftests: net: bridge: fix typo in vlan_filtering dependency test (Ivan Vecera) [2037335]
- selftests: net: bridge: add test for vlan_filtering dependency (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_router tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast query and query response interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_querier_interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_membership_interval test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_startup_query_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_last_member_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast igmp/mld version tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast querier test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast snooping control test (Ivan Vecera) [2037335]
- net: bridge: mcast: fix br_multicast_ctx_vlan_global_disabled helper (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce startup query interval minimum (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce query interval minimum (Ivan Vecera) [2037335]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2037335]
- net: bridge: Use array_size() helper in copy_to_user() (Ivan Vecera) [2037335]
- net: bridge: fix uninitialized variables when BRIDGE_CFM is disabled (Ivan Vecera) [2037335]
- net: bridge: mcast: use multicast_membership_interval for IGMPv3 (Ivan Vecera) [2037335]
- net: bridge: fix under estimation in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: use nla_total_size_64bit() in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: mcast: Associate the seqcount with its protecting lock. (Ivan Vecera) [2037335]
- net: bridge: mcast: fix vlan port router deadlock (Ivan Vecera) [2037335]
- net: bridge: use mld2r_ngrec instead of icmpv6_dataun (Ivan Vecera) [2037335]
- net: bridge: change return type of br_handle_ingress_vlan_tunnel (Ivan Vecera) [2037335]
- net: bridge: vlan: convert mcast router global option to per-vlan entry (Ivan Vecera) [2037335]
- net: bridge: mcast: br_multicast_set_port_router takes multicast context as argument (Ivan Vecera) [2037335]
- net: bridge: mcast: toggle also host vlan state in br_multicast_toggle_vlan (Ivan Vecera) [2037335]
- net: bridge: mcast: use the correct vlan group helper (Ivan Vecera) [2037335]
- net: bridge: vlan: account for router port lists when notifying (Ivan Vecera) [2037335]
- net: bridge: vlan: enable mcast snooping for existing master vlans (Ivan Vecera) [2037335]
- net: bridge: mcast: account for ipv6 size when dumping querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: drop sizeof for nest attribute's zero size (Ivan Vecera) [2037335]
- net: bridge: mcast: don't dump querier state if snooping is disabled (Ivan Vecera) [2037335]
- net: bridge: vlan: dump mcast ctx querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv6 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv4 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: consolidate querier selection for ipv4 and ipv6 (Ivan Vecera) [2037335]
- net: bridge: mcast: make sure querier port/address updates are consistent (Ivan Vecera) [2037335]
- net: bridge: mcast: record querier port device ifindex instead of pointer (Ivan Vecera) [2037335]
- net: bridge: vlan: use br_rports_fill_info() to export mcast router ports (Ivan Vecera) [2037335]
- net: bridge: mcast: use the proper multicast context when dumping router ports (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast router global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier global option (Ivan Vecera) [2037335]
- net: bridge: mcast: querier and query state affect only current context type (Ivan Vecera) [2037335]
- net: bridge: mcast: move querier state to the multicast context (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query response interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast membership interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast igmp/mld version global options (Ivan Vecera) [2037335]
- net: bridge: vlan: fix global vlan option range dumping (Ivan Vecera) [2037335]
- net: make switchdev_bridge_port_{,unoffload} loosely coupled with the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: fix incorrect use of FDB flags when picking the dst device (Ivan Vecera) [2037335]
- net: bridge: switchdev: treat local FDBs the same as entries towards the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: replay the entire FDB for each port (Ivan Vecera) [2037335]
- net: bridge: add a helper for retrieving port VLANs from the data path (Ivan Vecera) [2037335]
- net: bridge: update BROPT_VLAN_ENABLED before notifying switchdev in br_vlan_filter_toggle (Ivan Vecera) [2037335]
- net: bridge: fix build when setting skb->offload_fwd_mark with CONFIG_NET_SWITCHDEV=n (Ivan Vecera) [2037335]
- net: bridge: switchdev: allow the TX data plane forwarding to be offloaded (Ivan Vecera) [2037335]
- net: switchdev: fix FDB entries towards foreign ports not getting propagated to us (Ivan Vecera) [2037335]
- net: bridge: move the switchdev object replay helpers to "push" mode (Ivan Vecera) [2037335]
- net: bridge: guard the switchdev replay helpers against a NULL notifier block (Ivan Vecera) [2037335]
- net: bridge: switchdev: let drivers inform which bridge ports are offloaded (Ivan Vecera) [2037335]
- net: bridge: switchdev: recycle unused hwdoms (Ivan Vecera) [2037335]
- net: bridge: disambiguate offload_fwd_mark (Ivan Vecera) [2037335]
- net: bridge: multicast: add context support for host-joined groups (Ivan Vecera) [2037335]
- net: bridge: multicast: add mdb context support (Ivan Vecera) [2037335]
- net: bridge: multicast: fix igmp/mld port context null pointer dereferences (Ivan Vecera) [2037335]
- net: switchdev: recurse into __switchdev_handle_fdb_del_to_device (Ivan Vecera) [2037335]
- net: switchdev: remove stray semicolon in switchdev_handle_fdb_del_to_device shim (Ivan Vecera) [2037335]
- net: bridge: vlan: add mcast snooping control (Ivan Vecera) [2037335]
- net: bridge: vlan: notify when global options change (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for dumping global vlan options (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for global options (Ivan Vecera) [2037335]
- net: bridge: multicast: include router port vlan id in notifications (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan querier and query support (Ivan Vecera) [2037335]
- net: bridge: multicast: check if should use vlan mcast ctx (Ivan Vecera) [2037335]
- net: bridge: multicast: use the port group to port context helper (Ivan Vecera) [2037335]
- net: bridge: multicast: add helper to get port mcast context from port group (Ivan Vecera) [2037335]
- net: bridge: add vlan mcast snooping knob (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan state initialization and control (Ivan Vecera) [2037335]
- net: bridge: vlan: add global and per-port multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: use multicast contexts instead of bridge or port (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out bridge multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out port multicast context (Ivan Vecera) [2037335]
- net: switchdev: introduce a fanout helper for SWITCHDEV_FDB_{ADD,DEL}_TO_DEVICE (Ivan Vecera) [2037335]
- net: switchdev: introduce helper for checking dynamically learned FDB entries (Ivan Vecera) [2037335]
- kernel: Add redhat code (Prarit Bhargava) [2047259]
- nvme: Mark NVMe over FC Target support unmaintained (Prarit Bhargava) [2019379]
- hdlc_fr: Mark driver unmaintained (Prarit Bhargava) [2019379]
- sfc: Mark siena driver unmaintained (Prarit Bhargava) [2019379]
- qla3xxx: Mark driver unmaintained (Prarit Bhargava) [2019379]
- netxen: Mark nic driver unmaintained (Prarit Bhargava) [2019379]
- redhat/configs: Disable ethoc driver (Prarit Bhargava) [2019379]
- redhat/configs: Disable dnet driver (Prarit Bhargava) [2019379]
- drivers/pci/pci-driver.c: Fix if/ifdef typo (Prarit Bhargava) [2019379]
- kernel/rh_taint.c: Update to new messaging (Prarit Bhargava) [2019379]

* Wed Jan 26 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-49.el9]
- net: skb: use kfree_skb_reason() in __udp4_lib_rcv() (Antoine Tenart) [2041931]
- net: skb: use kfree_skb_reason() in tcp_v4_rcv() (Antoine Tenart) [2041931]
- net: skb: introduce kfree_skb_reason() (Antoine Tenart) [2041931]
- net: add kerneldoc comment for sk_peer_lock (Guillaume Nault) [2037783]
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses (Guillaume Nault) [2037783] {CVE-2021-4203}
- netfilter: nat: force port remap to prevent shadowing well-known ports (Florian Westphal) [2006169] {CVE-2021-3773}
- netfilter: conntrack: tag conntracks picked up in local out hook (Florian Westphal) [2006169]
- selftests: nft_nat: switch port shadow test cases to socat (Florian Westphal) [2006169]
- selftests: nft_nat: Simplify port shadow notrack test (Florian Westphal) [2006169]
- selftests: nft_nat: Improve port shadow test stability (Florian Westphal) [2006169]
- selftests: nft_nat: add udp hole punch test case (Florian Westphal) [2006169]
- net: Remove redundant if statements (Petr Oros) [2037315]
- netdevice: add the case if dev is NULL (Petr Oros) [2037315]
- redhat: fix the exclusion of rhdocs changes entries in the changelog (Herton R. Krzesinski)
- get_maintainer.conf: Update with new location of RHMAINTAINERS (Prarit Bhargava)
- redhat: make pathspec exclusion compatible with old git versions (Herton R. Krzesinski)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- tree: remove existing redhat/rhdocs subtree in 9.0 (Prarit Bhargava)
- CI: Use realtime_check_baseline template (Veronika Kabatova)
- powerpc/fadump: Fix inaccurate CPU state info in vmcore generated with panic (Gustavo Walbon) [2025518]
- powerpc: handle kdump appropriately with crash_kexec_post_notifiers option (Gustavo Walbon) [2025518]
- powerpc/pseries: use slab context cpumask allocation in CPU hotplug init (Waiman Long) [2019671]
- powerpc/pseries: Fix build error when NUMA=n (Waiman Long) [2019671]
- powerpc/smp: Use existing L2 cache_map cpumask to find L3 cache siblings (Diego Domingos) [2039639]
- powerpc/cacheinfo: Remove the redundant get_shared_cpu_map() (Diego Domingos) [2039639]
- powerpc/cacheinfo: Lookup cache by dt node and thread-group id (Diego Domingos) [2039639]
- powerpc: select CPUMASK_OFFSTACK if NR_CPUS >= 8192 (Diego Domingos) [2039163]
- powerpc: remove cpu_online_cores_map function (Diego Domingos) [2039163]
- adding support for c9s automotive coverage build (bgrech)
- CI: Use tagged containers (Veronika Kabatova)
- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like fallocate (Carlos Maiolino) [2034871] {CVE-2021-4155}
- selftests/powerpc: skip tests for unavailable mitigations. (Diego Domingos) [2021389]
- selftests/powerpc: Use date instead of EPOCHSECONDS in mitigation-patching.sh (Diego Domingos) [2021389]
- ip6_vti: initialize __ip6_tnl_parm struct in vti6_siocdevprivate (William Zhao) [2037810]
- KVM: x86: Wait for IPIs to be delivered when handling Hyper-V TLB flush hypercall (Vitaly Kuznetsov) [2036570]
- net: vlan: fix underflow for the real_dev refcnt (Balazs Nemeth) [2030036]
- net: vlan: fix a UAF in vlan_dev_real_dev() (Balazs Nemeth) [2030036]

* Mon Jan 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-48.el9]
- net: mana: Add RX fencing (Mohammed Gamal) [2030357]
- net: mana: Add XDP support (Mohammed Gamal) [2030357]
- net: mana: Fix memory leak in mana_hwc_create_wq (Mohammed Gamal) [2030357]
- net: mana: Fix spelling mistake "calledd" -> "called" (Mohammed Gamal) [2030357]
- ibmvnic: drop bad optimization in reuse_tx_pools() (Diego Domingos) [2014236]
- ibmvnic: drop bad optimization in reuse_rx_pools() (Diego Domingos) [2014236]
- ibmvnic: Reuse tx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse rx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse LTB when possible (Diego Domingos) [2014236]
- ibmvnic: init_tx_pools move loop-invariant code (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_tx_pools (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_rx_pools (Diego Domingos) [2014236]
- ibmvnic: Consolidate code in replenish_rx_pool() (Diego Domingos) [2014236]
- ibmvnic: Fix up some comments and messages (Diego Domingos) [2014236]
- ibmvnic: Use bitmap for LTB map_ids (Diego Domingos) [2014236]
- [s390] s390/qeth: fix deadlock during failing recovery (Mete Durlu) [1869669]
- [s390] s390/qeth: Fix deadlock in remove_discipline (Mete Durlu) [1869669]
- [s390] s390/qeth: fix NULL deref in qeth_clear_working_pool_list() (Mete Durlu) [1869669]
- [s390] s390/qeth: Update MACs of LEARNING_SYNC device (Mete Durlu) [1869669]
- [s390] s390/qeth: Switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qeth: Register switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qdio: propagate error when cancelling a ccw fails (Mete Durlu) [1869669]
- [s390] s390/qdio: improve roll-back after error on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qdio: cancel the ESTABLISH ccw after timeout (Mete Durlu) [1869669]
- [s390] s390/qdio: fix roll-back after timeout on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qeth: remove OSN support (Mete Durlu) [1869669]
- [s390] s390: add HWCAP_S390_PCI_MIO to ELF hwcaps (Mete Durlu) [2030640]
- [s390] s390: make PCI mio support a machine flag (Mete Durlu) [2030640]
- ima: silence measurement list hexdump during kexec (Bruno Meneguele) [2034157]
- scsi: lpfc: Update lpfc version to 14.0.0.4 (Dick Kennedy) [2034278]
- scsi: lpfc: Add additional debugfs support for CMF (Dick Kennedy) [2034278]
- scsi: lpfc: Cap CMF read bytes to MBPI (Dick Kennedy) [2034278]
- scsi: lpfc: Adjust CMF total bytes and rxmonitor (Dick Kennedy) [2034278]
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver cleanup (Dick Kennedy) [2034278]
- scsi: lpfc: Fix NPIV port deletion crash (Dick Kennedy) [2034278]
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance (Dick Kennedy) [2034278]
- scsi: lpfc: Change return code on I/Os received during link bounce (Dick Kennedy) [2034278]
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV (Dick Kennedy) [2034278]
- scsi: lpfc: Fix non-recovery of remote ports following an unsolicited LOGO (Dick Kennedy) [2039036]
- mm/memcg: Exclude mem_cgroup pointer from kABI signature computation (Waiman Long) [2036995]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Steve Dickson) [2016699]

* Sat Jan 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-47.el9]
- nvmet: register discovery subsystem as 'current' (John Meneghini) [2021672]
- nvme: add new discovery log page entry definitions (John Meneghini) [2021672]
- nvmet: switch check for subsystem type (John Meneghini) [2021672]
- nvme: display correct subsystem NQN (John Meneghini) [2021672]
- nvme: Add connect option 'discovery' (John Meneghini) [2021672]
- nvme: expose subsystem type in sysfs attribute 'subsystype' (John Meneghini) [2021672]
- nvmet: set 'CNTRLTYPE' in the identify controller data (John Meneghini) [2021672]
- nvmet: add nvmet_is_disc_subsys() helper (John Meneghini) [2021672]
- nvme: add CNTRLTYPE definitions for 'identify controller' (John Meneghini) [2021672]
- nvmet: make discovery NQN configurable (John Meneghini) [2021672]
- nitro_enclaves: Use get_user_pages_unlocked() call to handle mmap assert (Vitaly Kuznetsov) [2034619]
- include/linux/pci.h: Exclude struct hotplug_slot from KABI (Prarit Bhargava) [2034338]
- virtio/vsock: fix the transport to work with VMADDR_CID_ANY (Stefano Garzarella) [2026949]
- vhost/vsock: cleanup removing `len` variable (Stefano Garzarella) [2026949]
- vhost/vsock: fix incorrect used length reported to the guest (Stefano Garzarella) [2026949]
- vsock: prevent unnecessary refcnt inc for nonblocking connect (Stefano Garzarella) [2026949]
- vsock_diag_test: remove free_sock_stat() call in test_no_sockets (Stefano Garzarella) [2026949]
- vsock: Enable y2038 safe timeval for timeout (Stefano Garzarella) [2026949]
- vsock: Refactor vsock_*_getsockopt to resemble sock_getsockopt (Stefano Garzarella) [2026949]
- vsock_test: update message bounds test for MSG_EOR (Stefano Garzarella) [2026949]
- af_vsock: rename variables in receive loop (Stefano Garzarella) [2026949]
- virtio/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- vhost/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- virtio/vsock: add 'VIRTIO_VSOCK_SEQ_EOR' bit. (Stefano Garzarella) [2026949]
- virtio/vsock: rename 'EOR' to 'EOM' bit. (Stefano Garzarella) [2026949]
- include/linux/irq*.h: Pad irq structs for KABI (Prarit Bhargava) [2034264]
- include/linux/fwnode.h: Exclude fwnode structs from KABI (Prarit Bhargava) [2033388]
- bpf: Fix toctou on read-only map's constant scalar tracking (Jiri Olsa) [2029198] {CVE-2021-4001}
- ACPI: tables: FPDT: Do not print FW_BUG message if record types are reserved (Mark Langsdorf) [2000202]
- redhat: support virtio-mem on x86-64 as tech-preview (David Hildenbrand) [2014492]
- proc/vmcore: fix clearing user buffer by properly using clear_user() (David Hildenbrand) [2014492]
- virtio-mem: support VIRTIO_MEM_F_UNPLUGGED_INACCESSIBLE (David Hildenbrand) [2014492]
- virtio-mem: disallow mapping virtio-mem memory via /dev/mem (David Hildenbrand) [2014492]
- kernel/resource: disallow access to exclusive system RAM regions (David Hildenbrand) [2014492]
- kernel/resource: clean up and optimize iomem_is_exclusive() (David Hildenbrand) [2014492]
- virtio-mem: kdump mode to sanitize /proc/vmcore access (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_remove() into virtio_mem_deinit_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_probe() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_init() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- proc/vmcore: convert oldmem_pfn_is_ram callback to more generic vmcore callbacks (David Hildenbrand) [2014492]
- proc/vmcore: let pfn_is_ram() return a bool (David Hildenbrand) [2014492]
- x86/xen: print a warning when HVMOP_get_mem_type fails (David Hildenbrand) [2014492]
- x86/xen: simplify xen_oldmem_pfn_is_ram() (David Hildenbrand) [2014492]
- x86/xen: update xen_oldmem_pfn_is_ram() documentation (David Hildenbrand) [2014492]

* Thu Jan 20 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-46.el9]
- crypto: qat - fix definition of ring reset results (Vladis Dronov) [2015145]
- crypto: qat - add support for compression for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - allow detection of dc capabilities for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to enable the reset of ring pairs (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to the GEN4 host driver (Vladis Dronov) [2015145]
- crypto: qat - config VFs based on ring-to-svc mapping (Vladis Dronov) [2015145]
- crypto: qat - exchange ring-to-service mappings over PFVF (Vladis Dronov) [2015145]
- crypto: qat - support fast ACKs in the PFVF protocol (Vladis Dronov) [2015145]
- crypto: qat - exchange device capabilities over PFVF (Vladis Dronov) [2015145]
- crypto: qat - introduce support for PFVF block messages (Vladis Dronov) [2015145]
- crypto: qat - store the ring-to-service mapping (Vladis Dronov) [2015145]
- crypto: qat - store the PFVF protocol version of the endpoints (Vladis Dronov) [2015145]
- crypto: qat - improve the ACK timings in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage read_poll_timeout in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage bitfield.h utils for PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF messages with struct pfvf_message (Vladis Dronov) [2015145]
- crypto: qat - set PFVF_MSGORIGIN just before sending (Vladis Dronov) [2015145]
- crypto: qat - make PFVF send and receive direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - make PFVF message construction direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - add the adf_get_pmisc_base() helper function (Vladis Dronov) [2015145]
- crypto: qat - support the reset of ring pairs on PF (Vladis Dronov) [2015145]
- crypto: qat - extend crypto capability detection for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - set COMPRESSION capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - set CIPHER capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - get compression extended capabilities (Vladis Dronov) [2015145]
- crypto: qat - improve logging of PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - fix VF IDs in PFVF log messages (Vladis Dronov) [2015145]
- crypto: qat - do not rely on min version (Vladis Dronov) [2015145]
- crypto: qat - refactor pfvf version request messages (Vladis Dronov) [2015145]
- crypto: qat - pass the PF2VF responses back to the callers (Vladis Dronov) [2015145]
- crypto: qat - use enums for PFVF protocol codes (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF protocol definitions (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF code (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF receive logic (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF send function (Vladis Dronov) [2015145]
- crypto: qat - differentiate between pf2vf and vf2pf offset (Vladis Dronov) [2015145]
- crypto: qat - add pfvf_ops (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF disabled function (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF VF related logic (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF PF related logic (Vladis Dronov) [2015145]
- crypto: qat - handle retries due to collisions in adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - split PFVF message decoding from handling (Vladis Dronov) [2015145]
- crypto: qat - re-enable interrupts for legacy PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - change PFVF ACK behaviour (Vladis Dronov) [2015145]
- crypto: qat - move interrupt code out of the PFVF handler (Vladis Dronov) [2015145]
- crypto: qat - move VF message handler to adf_vf2pf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - move vf2pf interrupt helpers (Vladis Dronov) [2015145]
- crypto: qat - refactor PF top half for PFVF (Vladis Dronov) [2015145]
- crypto: qat - fix undetected PFVF timeout in ACK loop (Vladis Dronov) [2015145]
- crypto: qat - do not handle PFVF sources for qat_4xxx (Vladis Dronov) [2015145]
- crypto: qat - simplify adf_enable_aer() (Vladis Dronov) [2015145]
- crypto: qat - share adf_enable_pf2vf_comms() from adf_pf2vf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - extract send and wait from adf_vf2pf_request_version() (Vladis Dronov) [2015145]
- crypto: qat - add VF and PF wrappers to common send function (Vladis Dronov) [2015145]
- crypto: qat - rename pfvf collision constants (Vladis Dronov) [2015145]
- crypto: qat - move pfvf collision detection values (Vladis Dronov) [2015145]
- crypto: qat - make pfvf send message direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - use hweight for bit counting (Vladis Dronov) [2015145]
- crypto: qat - remove duplicated logic across GEN2 drivers (Vladis Dronov) [2015145]
- crypto: qat - fix handling of VF to PF interrupts (Vladis Dronov) [2015145]
- crypto: qat - remove unnecessary collision prevention step in PFVF (Vladis Dronov) [2015145]
- crypto: qat - disregard spurious PFVF interrupts (Vladis Dronov) [2015145]
- crypto: qat - detect PFVF collision after ACK (Vladis Dronov) [2015145]
- crypto: qat - power up 4xxx device (Vladis Dronov) [2015145]
- crypto: qat - remove unneeded packed attribute (Vladis Dronov) [2015145]
- crypto: qat - free irq in case of failure (Vladis Dronov) [2015145]
- crypto: qat - free irqs only if allocated (Vladis Dronov) [2015145]
- crypto: qat - remove unmatched CPU affinity to cluster IRQ (Vladis Dronov) [2015145]
- crypto: qat - replace deprecated MSI API (Vladis Dronov) [2015145]
- crypto: qat - store vf.compatible flag (Vladis Dronov) [2015145]
- crypto: qat - do not export adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - flush vf workqueue at driver removal (Vladis Dronov) [2015145]
- crypto: qat - remove the unnecessary get_vintmsk_offset() (Vladis Dronov) [2015145]
- crypto: qat - fix naming of PF/VF enable functions (Vladis Dronov) [2015145]
- crypto: qat - complete all the init steps before service notification (Vladis Dronov) [2015145]
- crypto: qat - move IO virtualization functions (Vladis Dronov) [2015145]
- crypto: qat - fix naming for init/shutdown VF to PF notifications (Vladis Dronov) [2015145]
- crypto: qat - protect interrupt mask CSRs with a spinlock (Vladis Dronov) [2015145]
- crypto: qat - move pf2vf interrupt [en|dis]able to adf_vf_isr.c (Vladis Dronov) [2015145]
- crypto: qat - fix reuse of completion variable (Vladis Dronov) [2015145]
- crypto: qat - remove intermediate tasklet for vf2pf (Vladis Dronov) [2015145]
- crypto: qat - rename compatibility version definition (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in PF (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in VF (Vladis Dronov) [2015145]
- crypto: qat - handle both source of interrupt in VF ISR (Vladis Dronov) [2015145]
- crypto: qat - do not ignore errors from enable_vf2pf_comms() (Vladis Dronov) [2015145]
- crypto: qat - enable interrupts only after ISR allocation (Vladis Dronov) [2015145]
- crypto: qat - remove empty sriov_configure() (Vladis Dronov) [2015145]
- crypto: qat - use proper type for vf_mask (Vladis Dronov) [2015145]
- crypto: qat - fix a typo in a comment (Vladis Dronov) [2015145]
- crypto: qat - disable AER if an error occurs in probe functions (Vladis Dronov) [2015145]
- crypto: qat - set DMA mask to 48 bits for Gen2 (Vladis Dronov) [2015145]
- crypto: qat - simplify code and axe the use of a deprecated API (Vladis Dronov) [2015145]

* Tue Jan 18 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-45.el9]
- workqueue, kasan: avoid alloc_pages() when recording stack (Phil Auld) [2022894]
- kasan: generic: introduce kasan_record_aux_stack_noalloc() (Phil Auld) [2022894]
- kasan: common: provide can_alloc in kasan_save_stack() (Phil Auld) [2022894]
- lib/stackdepot: introduce __stack_depot_save() (Phil Auld) [2022894]
- lib/stackdepot: remove unused function argument (Phil Auld) [2022894]
- lib/stackdepot: include gfp.h (Phil Auld) [2022894]
- workqueue: Introduce show_one_worker_pool and show_one_workqueue. (Phil Auld) [2022894]
- workqueue: make sysfs of unbound kworker cpumask more clever (Phil Auld) [2022894]
- workqueue: fix state-dump console deadlock (Phil Auld) [2022894]
- workqueue: Remove unused WORK_NO_COLOR (Phil Auld) [2022894]
- workqueue: Assign a color to barrier work items (Phil Auld) [2022894]
- workqueue: Mark barrier work with WORK_STRUCT_INACTIVE (Phil Auld) [2022894]
- workqueue: Change the code of calculating work_flags in insert_wq_barrier() (Phil Auld) [2022894]
- workqueue: Change arguement of pwq_dec_nr_in_flight() (Phil Auld) [2022894]
- workqueue: Rename "delayed" (delayed by active management) to "inactive" (Phil Auld) [2022894]
- workqueue: Replace deprecated ida_simple_*() with ida_alloc()/ida_free() (Phil Auld) [2022894]
- workqueue: Fix typo in comments (Phil Auld) [2022894]
- workqueue: Fix possible memory leaks in wq_numa_init() (Phil Auld) [2022894]
- nvme: avoid race in shutdown namespace removal (Ewan D. Milne) [2014529]
- powerpc/xmon: Dump XIVE information for online-only processors. (Steve Best) [2037642]
- ipv4: make exception cache less predictible (Antoine Tenart) [2015112] {CVE-2021-20322}
- [s390] s390/cio: make ccw_device_dma_* more robust (Claudio Imbrenda) [1997541]
- [s390] s390/pci: add s390_iommu_aperture kernel parameter (Claudio Imbrenda) [2034134]
- [s390] s390/pci: fix zpci_zdev_put() on reserve (Claudio Imbrenda) [2034132]
- [s390] s390/pci: cleanup resources only if necessary (Claudio Imbrenda) [2034132]
- [s390] s390/sclp: fix Secure-IPL facility detection (Claudio Imbrenda) [2034116]
- Revert "[redhat] Generate a crashkernel.default for each kernel build" (Coiby Xu) [2034490]
- ibmvnic: Process crqs after enabling interrupts (Diego Domingos) [2020021]
- ibmvnic: delay complete() (Diego Domingos) [2020021]
- ibmvnic: don't stop queue in xmit (Diego Domingos) [2019988]
- bpf/selftests: disable test failing on RHEL9 (Viktor Malik) [2006315]
- bpf/selftests: disable a verifier test for powerpc (Viktor Malik) [2032734]
- bpf/selftests: allow disabling tests (Viktor Malik) [2036656]
- kernel/crash_core: suppress unknown crashkernel parameter warning (Philipp Rudo) [2026570]
- mm/vmalloc: do not adjust the search size for alignment overhead (David Hildenbrand) [2029493]
- Bluetooth: fix use-after-free error in lock_sock_nested() (Gopal Tiwari) [2005691]
- lib: zstd: Don't add -O3 to cflags (Neal Gompa) [2034834]
- lib: zstd: Don't inline functions in zstd_opt.c (Neal Gompa) [2034834]
- lib: zstd: Fix unused variable warning (Neal Gompa) [2034834]
- lib: zstd: Add cast to silence clang's -Wbitwise-instead-of-logical (Neal Gompa) [2034834]
- MAINTAINERS: Add maintainer entry for zstd (Neal Gompa) [2034834]
- lib: zstd: Upgrade to latest upstream zstd version 1.4.10 (Neal Gompa) [2034834]
- lib: zstd: Add decompress_sources.h for decompress_unzstd (Neal Gompa) [2034834]
- lib: zstd: Add kernel-specific API (Neal Gompa) [2034834]

* Mon Jan 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-44.el9]
- dm btree remove: fix use after free in rebalance_children() (Benjamin Marzinski) [2031198]
- dm table: log table creation error code (Benjamin Marzinski) [2031198]
- dm: make workqueue names device-specific (Benjamin Marzinski) [2031198]
- dm writecache: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm crypt: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm: Remove redundant flush_workqueue() calls (Benjamin Marzinski) [2031198]
- dm crypt: log aead integrity violations to audit subsystem (Benjamin Marzinski) [2031198]
- dm integrity: log audit events for dm-integrity target (Benjamin Marzinski) [2031198]
- dm: introduce audit event module for device mapper (Benjamin Marzinski) [2031198]
- dm: fix mempool NULL pointer race when completing IO (Benjamin Marzinski) [2031198]
- dm rq: don't queue request to blk-mq during DM suspend (Benjamin Marzinski) [2031198]
- dm clone: make array 'descs' static (Benjamin Marzinski) [2031198]
- dm verity: skip redundant verity_handle_err() on I/O errors (Benjamin Marzinski) [2031198]
- dm crypt: use in_hardirq() instead of deprecated in_irq() (Benjamin Marzinski) [2031198]
- dm ima: update dm documentation for ima measurement support (Benjamin Marzinski) [2031198]
- dm ima: update dm target attributes for ima measurements (Benjamin Marzinski) [2031198]
- dm ima: add a warning in dm_init if duplicate ima events are not measured (Benjamin Marzinski) [2031198]
- dm ima: prefix ima event name related to device mapper with dm_ (Benjamin Marzinski) [2031198]
- dm ima: add version info to dm related events in ima log (Benjamin Marzinski) [2031198]
- dm ima: prefix dm table hashes in ima log with hash algorithm (Benjamin Marzinski) [2031198]
- dm crypt: Avoid percpu_counter spinlock contention in crypt_page_alloc() (Benjamin Marzinski) [2031198]
- dm: add documentation for IMA measurement support (Benjamin Marzinski) [2031198]
- dm: update target status functions to support IMA measurement (Benjamin Marzinski) [2031198]
- dm ima: measure data on device rename (Benjamin Marzinski) [2031198]
- dm ima: measure data on table clear (Benjamin Marzinski) [2031198]
- dm ima: measure data on device remove (Benjamin Marzinski) [2031198]
- dm ima: measure data on device resume (Benjamin Marzinski) [2031198]
- dm ima: measure data on table load (Benjamin Marzinski) [2031198]
- dm writecache: add event counters (Benjamin Marzinski) [2031198]
- dm writecache: report invalid return from writecache_map helpers (Benjamin Marzinski) [2031198]
- dm writecache: further writecache_map() cleanup (Benjamin Marzinski) [2031198]
- dm writecache: factor out writecache_map_remap_origin() (Benjamin Marzinski) [2031198]
- dm writecache: split up writecache_map() to improve code readability (Benjamin Marzinski) [2031198]
- redhat: Pull in openssl-devel as a build dependency correctly (Neal Gompa) [2034670]
- redhat/configs: Enable ThinkLMI support (Mark Pearson) [2030770]
- platform/x86: think-lmi: Abort probe on analyze failure (Mark Pearson) [2030770]
- platform/x86: think-lmi: add debug_cmd (Mark Pearson) [2030770]
- include/linux/timer.h: Pad timer_list struct for KABI (Prarit Bhargava) [2034452]
- kernel: Include RHEL Ecosystem message (Prarit Bhargava) [2033650]
- include/linux/ioport.h: Pad resource struct for KABI (Prarit Bhargava) [2033475]
- include/linux/hrtimer.h: Pad hrtimer struct for KABI (Prarit Bhargava) [2033473]
- redhat/configs: Add explicit values for ZRAM_DEF_COMP_LZ4* configs (Neal Gompa) [2032758]
- redhat/configs: Enable CONFIG_CRYPTO_ZSTD (Neal Gompa) [2032758]
- redhat/configs: Migrate defaults for ZRAM from pending-common to common (Neal Gompa) [2032758]
- Enable iSER on s390x (Stefan Schulze Frielinghaus) [1965279]

* Fri Jan 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-43.el9]
- mm: COW: restore full accuracy in page reuse (Andrea Arcangeli) [1958742]
- mm: thp: replace the page lock with the seqlock for the THP mapcount (Andrea Arcangeli) [1958742]
- mm: COW: skip the page lock in the COW copy path (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() use can_read_pin_swap_page() (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: FOLL_FAULT_UNSHARE (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE RHEL (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_NOUNSHARE: optimize follow_page (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() (Andrea Arcangeli) [1958742]
- mm: gup: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: thp: introduce page_trans_huge_anon_shared (Andrea Arcangeli) [1958742]
- mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap (Andrea Arcangeli) [1958742]
- mm: thp: make the THP mapcount atomic with a seqlock (Andrea Arcangeli) [1958742]
- mm: thp: consolidate mapcount logic on THP split (David Hildenbrand) [1958742]
- powerpc/xive: Change IRQ domain to a tree domain (Daniel Henrique Barboza) [2008723]
- tcp: fix page frag corruption on page fault (Paolo Abeni) [2028276]
- sock: fix /proc/net/sockstat underflow in sk_clone_lock() (Paolo Abeni) [2028276]
- net: add and use skb_unclone_keeptruesize() helper (Paolo Abeni) [2028276]
- net: stream: don't purge sk_error_queue in sk_stream_kill_queues() (Paolo Abeni) [2028276]
- net, neigh: Fix NTF_EXT_LEARNED in combination with NTF_USE (Paolo Abeni) [2028276]
- net-sysfs: initialize uid and gid before calling net_ns_get_ownership (Paolo Abeni) [2028276]
- net: Prevent infinite while loop in skb_tx_hash() (Paolo Abeni) [2028276]
- napi: fix race inside napi_enable (Paolo Abeni) [2028276]
- skb_expand_head() adjust skb->truesize incorrectly (Paolo Abeni) [2028276]
- bpf: use skb_expand_head in bpf_out_neigh_v4/6 (Paolo Abeni) [2028276]
- ax25: use skb_expand_head (Paolo Abeni) [2028276]
- vrf: fix NULL dereference in vrf_finish_output() (Paolo Abeni) [2028276]
- vrf: use skb_expand_head in vrf_finish_output (Paolo Abeni) [2028276]
- ipv4: use skb_expand_head in ip_finish_output2 (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_xmit (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_finish_output2 (Paolo Abeni) [2028276]
- skbuff: introduce skb_expand_head() (Paolo Abeni) [2028276]
- net/af_unix: fix a data-race in unix_dgram_poll (Paolo Abeni) [2028276]
- net: don't unconditionally copy_from_user a struct ifreq for socket ioctls (Paolo Abeni) [2028276]
- devlink: Clear whole devlink_flash_notify struct (Paolo Abeni) [2028276]
- devlink: Break parameter notification sequence to be before/after unload/load driver (Paolo Abeni) [2028276]
- vhost_net: fix OoB on sendmsg() failure. (Paolo Abeni) [2026821]
- printk: restore flushing of NMI buffers on remote CPUs after NMI backtraces (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: Serialize even messages about idle CPUs (Prarit Bhargava) [2023082]
- printk: syslog: close window between wait and read (Prarit Bhargava) [2023082]
- printk: convert @syslog_lock to mutex (Prarit Bhargava) [2023082]
- printk: remove NMI tracking (Prarit Bhargava) [2023082]
- printk: remove safe buffers (Prarit Bhargava) [2023082]
- printk: track/limit recursion (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: explicitly serialize banner and regs (Prarit Bhargava) [2023082]

* Thu Jan 13 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-42.el9]
- scsi: smartpqi: Update version to 2.1.12-055 (Don Brace) [1869853]
- scsi: smartpqi: Add 3252-8i PCI id (Don Brace) [1869853]
- scsi: smartpqi: Fix duplicate device nodes for tape changers (Don Brace) [1869853]
- scsi: smartpqi: Fix boot failure during LUN rebuild (Don Brace) [1869853]
- scsi: smartpqi: Add extended report physical LUNs (Don Brace) [1869853]
- scsi: smartpqi: Avoid failing I/Os for offline devices (Don Brace) [1869853]
- scsi: smartpqi: Add TEST UNIT READY check for SANITIZE operation (Don Brace) [1869853]
- scsi: smartpqi: Update LUN reset handler (Don Brace) [1869853]
- scsi: smartpqi: Capture controller reason codes (Don Brace) [1869853]
- scsi: smartpqi: Add controller handshake during kdump (Don Brace) [1869853]
- scsi: smartpqi: Update device removal management (Don Brace) [1869853]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [1869853]
- scsi: smartpqi: Fix an error code in pqi_get_raid_map() (Don Brace) [1869853]
- scsi: smartpqi: Update version to 2.1.10-020 (Don Brace) [1869853]
- scsi: smartpqi: Fix ISR accessing uninitialized data (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for new ZTE controllers (Don Brace) [1869853]
- scsi: smartpqi: Add PCI ID for new ntcom controller (Don Brace) [1869853]
- scsi: smartpqi: Add SCSI cmd info for resets (Don Brace) [1869853]
- scsi: smartpqi: Change Kconfig menu entry to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Change driver module macros to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Update copyright notices (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for H3C P4408 controllers (Don Brace) [1869853]
- powerpc/module_64: Fix livepatching for RO modules (Joe Lawrence) [2019205]
- net-sysfs: try not to restart the syscall if it will fail eventually (Antoine Tenart) [2030634]
- CI: Enable realtime checks for baselines (Veronika Kabatova)
- CI: Cleanup residue from ARK (Veronika Kabatova)
- redhat: ignore ksamples and kselftests on the badfuncs rpminspect test (Herton R. Krzesinski)
- redhat: disable upstream check for rpminspect (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_CRYPTO_BLAKE2B (Neal Gompa) [2031547]
- selftests: netfilter: switch zone stress to socat (Florian Westphal) [2030759]
- netfilter: conntrack: set on IPS_ASSURED if flows enters internal stream state (Florian Westphal) [2030759]
- netfilter: conntrack: serialize hash resizes and cleanups (Florian Westphal) [2030759]
- selftests: netfilter: add zone stress test with colliding tuples (Florian Westphal) [2030759]
- selftests: netfilter: add selftest for directional zone support (Florian Westphal) [2030759]
- netfilter: conntrack: include zone id in tuple hash again (Florian Westphal) [2030759]
- netfilter: conntrack: make max chain length random (Florian Westphal) [2030759]
- netfilter: refuse insertion if chain has grown too large (Florian Westphal) [2030759]
- netfilter: conntrack: switch to siphash (Florian Westphal) [2030759]
- netfilter: conntrack: sanitize table size default settings (Florian Westphal) [2030759]
- redhat: configs: increase CONFIG_DEBUG_KMEMLEAK_MEM_POOL_SIZE (Rafael Aquini) [2008118]
- iommu/dma: Fix incorrect error return on iommu deferred attach (Jerry Snitselaar) [2030394]
- RDMA/siw: Mark Software iWARP Driver as tech-preview (Kamal Heib) [2023416]
- genirq: Fix kernel doc indentation (Prarit Bhargava) [2023084]
- genirq: Change force_irqthreads to a static key (Prarit Bhargava) [2023084]
- genirq: Clarify documentation for request_threaded_irq() (Prarit Bhargava) [2023084]

* Wed Jan 12 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-41.el9]
- af_unix: Return errno instead of NULL in unix_create1(). (Balazs Nemeth) [2030037]
- s390/ftrace: remove preempt_disable()/preempt_enable() pair (Wander Lairson Costa) [1938117]
- ftrace: do CPU checking after preemption disabled (Wander Lairson Costa) [1938117]
- ftrace: disable preemption when recursion locked (Wander Lairson Costa) [1938117]
- redhat: build and include memfd to kernel-selftests-internal (Aristeu Rozanski) [2027506]
- netfilter: flowtable: fix IPv6 tunnel addr match (Florian Westphal) [2028203]
- netfilter: ipvs: Fix reuse connection if RS weight is 0 (Florian Westphal) [2028203]
- netfilter: ctnetlink: do not erase error code with EINVAL (Florian Westphal) [2028203]
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY (Florian Westphal) [2028203]
- netfilter: nfnetlink_queue: fix OOB when mac header was cleared (Florian Westphal) [2028203]
- netfilter: core: Fix clang warnings about unused static inlines (Florian Westphal) [2028203]
- netfilter: nft_dynset: relax superfluous check on set updates (Florian Westphal) [2028203]
- netfilter: nf_tables: skip netdev events generated on netns removal (Florian Westphal) [2028203]
- netfilter: Kconfig: use 'default y' instead of 'm' for bool config option (Florian Westphal) [2028203]
- netfilter: xt_IDLETIMER: fix panic that occurs when timer_type has garbage value (Florian Westphal) [2028203]
- netfilter: nf_tables: honor NLM_F_CREATE and NLM_F_EXCL in event notification (Florian Westphal) [2028203]
- netfilter: nf_tables: reverse order in rule replacement expansion (Florian Westphal) [2028203]
- netfilter: nf_tables: add position handle in event notification (Florian Westphal) [2028203]
- netfilter: conntrack: fix boot failure with nf_conntrack.enable_hooks=1 (Florian Westphal) [2028203]
- netfilter: log: work around missing softdep backend module (Florian Westphal) [2028203]
- netfilter: nf_tables: unlink table before deleting it (Florian Westphal) [2028203]
- ipvs: check that ip_vs_conn_tab_bits is between 8 and 20 (Florian Westphal) [2028203]
- netfilter: nft_ct: protect nft_ct_pcpu_template_refcnt with mutex (Florian Westphal) [2028203]
- netfilter: ipvs: make global sysctl readonly in non-init netns (Antoine Tenart) [2008417]
- net/sched: sch_ets: don't remove idle classes from the round-robin list (Davide Caratti) [2025552]
- net/sched: store the last executed chain also for clsact egress (Davide Caratti) [2025552]
- net: sched: act_mirred: drop dst for the direction from egress to ingress (Davide Caratti) [2025552]
- net/sched: sch_ets: don't peek at classes beyond 'nbands' (Davide Caratti) [2025552]
- net/sched: sch_ets: properly init all active DRR list handles (Davide Caratti) [2025552]
- net: Fix offloading indirect devices dependency on qdisc order creation (Davide Caratti) [2025552]
- net/core: Remove unused field from struct flow_indr_dev (Davide Caratti) [2025552]
- net/sched: sch_taprio: fix undefined behavior in ktime_mono_to_any (Davide Caratti) [2025552]
- net/sched: act_ct: Fix byte count on fragmented packets (Davide Caratti) [2025552]
- mqprio: Correct stats in mqprio_dump_class_stats(). (Davide Caratti) [2025552]
- net/sched: sch_taprio: properly cancel timer from taprio_destroy() (Davide Caratti) [2025552]
- net_sched: fix NULL deref in fifo_set_limit() (Davide Caratti) [2025552]
- net: sched: flower: protect fl_walk() with rcu (Davide Caratti) [2025552]
- fq_codel: reject silly quantum parameters (Davide Caratti) [2025552]
- net: sched: Fix qdisc_rate_table refcount leak when get tcf_block failed (Davide Caratti) [2025552]
- sch_htb: Fix inconsistency when leaf qdisc creation fails (Davide Caratti) [2025552]
- redhat/configs: Add two new CONFIGs (Prarit Bhargava) [2022993]
- redhat/configs: Remove dead CONFIG files (Prarit Bhargava) [2022993]
- redhat/configs/evaluate_configs: Add find dead configs option (Prarit Bhargava) [2022993]

* Mon Jan 10 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-40.el9]
- cpu/hotplug: Remove deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- livepatch: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- coresight: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- hwmon: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- tracing: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- padata: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- crypto: virtio - Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- platform/x86: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- powerpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mce/inject: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/microcode: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mtrr: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mmiotrace: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- workqueue: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- net/iucv: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- s390/sclp: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- s390: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- virtio_net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- ACPI: processor: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- PM: sleep: s2idle: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- cpufreq: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- powercap: intel_rapl: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- sgi-xpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- Input: i8042 - Add quirk for Fujitsu Lifebook T725 (Neal Gompa) [2019937]
- sctp: remove unreachable code from sctp_sf_violation_chunk() (Xin Long) [2024909]
- sctp: return true only for pathmtu update in sctp_transport_pl_toobig (Xin Long) [2024909]
- sctp: subtract sctphdr len in sctp_transport_pl_hlen (Xin Long) [2024909]
- sctp: reset probe_timer in sctp_transport_pl_update (Xin Long) [2024909]
- sctp: allow IP fragmentation when PLPMTUD enters Error state (Xin Long) [2024909]
- sctp: fix transport encap_port update in sctp_vtag_verify (Xin Long) [2024909]
- sctp: account stream padding length for reconf chunk (Xin Long) [2024909]
- sctp: break out if skb_header_pointer returns NULL in sctp_rcv_ootb (Xin Long) [2024909]
- sctp: add vtag check in sctp_sf_ootb (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_do_8_5_1_E_sa (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_violation (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for COOKIE_ECHO chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT_ACK chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: use init_tag from inithdr for ABORT chunk (Xin Long) [2003494] {CVE-2021-3772}
- drm/nouveau: clean up all clients on device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: Add a dedicated mutex for the clients list (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: use drm_dev_unplug() during device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- redhat/configs: NFS: disable UDP, insecure enctypes (Benjamin Coddington) [1952863]

* Fri Dec 24 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-39.el9]
- cpuidle: pseries: Do not cap the CEDE0 latency in fixup_cede0_latency() (Gustavo Walbon) [2029870]
- cpuidle: pseries: Fixup CEDE0 latency only for POWER10 onwards (Gustavo Walbon) [2029870]
- powerpc/mce: Fix access error in mce handler (Gustavo Walbon) [2027829]
- powerpc/pseries/mobility: ignore ibm, platform-facilities updates (Gustavo Walbon) [2023438]
- KVM: SVM: Do not terminate SEV-ES guests on GHCB validation failure (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Fall back to vmalloc for SEV-ES scratch area if necessary (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Return appropriate error codes if SEV-ES scratch setup fails (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Refactor out sev_es_state struct (Vitaly Kuznetsov) [1961151]
- redhat/configs: enable DWARF5 feature if toolchain supports it (Lianbo Jiang) [2009205]
- init: make unknown command line param message clearer (Andrew Halaney) [2004361]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add the new support IDs for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: re-definition for board_id in struct qca_version (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add support using different nvm for variant WCN6855 controller (Gopal Tiwari) [2020943]
- cgroup: Make rebind_subsystems() disable v2 controllers all at once (Waiman Long) [1986734]
- bnxt_en: Event handler for PPS events (Ken Cox) [1990151]
- bnxt_en: 1PPS functions to configure TSIO pins (Ken Cox) [1990151]
- bnxt_en: 1PPS support for 5750X family chips (Ken Cox) [1990151]
- bnxt_en: Do not read the PTP PHC during chip reset (Ken Cox) [1990151]
- bnxt_en: Move bnxt_ptp_init() from bnxt_open() back to bnxt_init_one() (Ken Cox) [1990151]

* Thu Dec 23 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-38.el9]
- x86/fpu/signal: Initialize sw_bytes in save_xstate_epilog() (David Arcari) [2004190]
- iommu/vt-d: Remove unused PASID_DISABLED (David Arcari) [2004190]
- Add CONFIG_STRICT_SIGALTSTACK_SIZE (David Arcari) [2004190]
- selftests/x86/amx: Add context switch test (David Arcari) [2004190]
- selftests/x86/amx: Add test cases for AMX state management (David Arcari) [2004190]
- x86/signal: Use fpu::__state_user_size for sigalt stack validation (David Arcari) [2004190]
- x86/signal: Implement sigaltstack size validation (David Arcari) [2004190]
- signal: Add an optional check for altstack size (David Arcari) [2004190]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [2004190]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [2004190]
- tools headers UAPI: Sync arch prctl headers with the kernel sources (David Arcari) [2004190]
- x86/fpu: Optimize out sigframe xfeatures when in init state (David Arcari) [2004190]
- Documentation/x86: Add documentation for using dynamic XSTATE features (David Arcari) [2004190]
- x86/fpu: Include vmalloc.h for vzalloc() (David Arcari) [2004190]
- x86/fpu/amx: Enable the AMX feature in 64-bit mode (David Arcari) [2004190]
- x86/msr-index: Add MSRs for XFD (David Arcari) [2004190]
- x86/cpufeatures: Add eXtended Feature Disabling (XFD) feature bit (David Arcari) [2004190]
- x86/fpu: Add XFD handling for dynamic states (David Arcari) [2004190]
- x86/fpu: Calculate the default sizes independently (David Arcari) [2004190]
- x86/fpu/amx: Define AMX state components and have it used for boot-time checks (David Arcari) [2004190]
- x86/fpu/xstate: Prepare XSAVE feature table for gaps in state component numbers (David Arcari) [2004190]
- x86/fpu/xstate: Add fpstate_realloc()/free() (David Arcari) [2004190]
- x86/fpu/xstate: Add XFD #NM handler (David Arcari) [2004190]
- x86/fpu: Update XFD state where required (David Arcari) [2004190]
- x86/fpu: Add sanity checks for XFD (David Arcari) [2004190]
- x86/fpu: Add XFD state to fpstate (David Arcari) [2004190]
- x86/fpu: Reset permission and fpstate on exec() (David Arcari) [2004190]
- x86/fpu: Prepare fpu_clone() for dynamically enabled features (David Arcari) [2004190]
- x86/process: Clone FPU in copy_thread() (David Arcari) [2004190]
- x86/fpu/signal: Prepare for variable sigframe length (David Arcari) [2004190]
- x86/fpu: Add basic helpers for dynamically enabled features (David Arcari) [2004190]
- x86/arch_prctl: Add controls for dynamic XSTATE components (David Arcari) [2004190]
- x86/fpu: Add fpu_state_config::legacy_features (David Arcari) [2004190]
- x86/fpu: Add members to struct fpu to cache permission information (David Arcari) [2004190]
- x86/fpu/xstate: Provide xstate_calculate_size() (David Arcari) [2004190]
- x86/fpu: Remove old KVM FPU interface (David Arcari) [2004190]
- x86/kvm: Convert FPU handling to a single swap buffer (David Arcari) [2004190]
- x86/fpu: Provide infrastructure for KVM FPU cleanup (David Arcari) [2004190]
- x86/fpu: Prepare for sanitizing KVM FPU code (David Arcari) [2004190]
- x86/fpu/xstate: Move remaining xfeature helpers to core (David Arcari) [2004190]
- x86/fpu: Rework restore_regs_from_fpstate() (David Arcari) [2004190]
- x86/fpu: Mop up xfeatures_mask_uabi() (David Arcari) [2004190]
- x86/fpu: Move xstate feature masks to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu: Move xstate size to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu/xstate: Cleanup size calculations (David Arcari) [2004190]
- x86/fpu: Cleanup fpu__init_system_xstate_size_legacy() (David Arcari) [2004190]
- x86/fpu: Provide struct fpu_config (David Arcari) [2004190]
- x86/fpu/signal: Use fpstate for size and features (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for copy_uabi_to_xstate() (David Arcari) [2004190]
- x86/fpu: Use fpstate in __copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Use fpstate in fpu_copy_kvm_uabi_to_fpstate() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for os_xsave() (David Arcari) [2004190]
- x86/fpu: Use fpstate::size (David Arcari) [2004190]
- x86/fpu: Add size and mask information to fpstate (David Arcari) [2004190]
- x86/process: Move arch_thread_struct_whitelist() out of line (David Arcari) [2004190]
- x86/fpu: Remove fpu::state (David Arcari) [2004190]
- x86/KVM: Convert to fpstate (David Arcari) [2004190]
- x86/math-emu: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/core: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/signal: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/regset: Convert to fpstate (David Arcari) [2004190]
- x86/fpu: Convert tracing to fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs xstate component clearing (David Arcari) [2004190]
- x86/fpu: Convert restore_fpregs_from_fpstate() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Convert fpstate_init() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Provide struct fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy to user (David Arcari) [2004190]
- x86/fpu: Provide a proper function for ex_handler_fprestore() (David Arcari) [2004190]
- x86/fpu: Replace the includes of fpu/internal.h (David Arcari) [2004190]
- x86/fpu: Mop up the internal.h leftovers (David Arcari) [2004190]
- x86/fpu: Remove internal.h dependency from fpu/signal.h (David Arcari) [2004190]
- x86/fpu: Move fpstate functions to api.h (David Arcari) [2004190]
- x86/fpu: Move mxcsr related code to core (David Arcari) [2004190]
- x86/sev: Include fpu/xcr.h (David Arcari) [2004190]
- x86/fpu: Move fpregs_restore_userregs() to core (David Arcari) [2004190]
- x86/fpu: Make WARN_ON_FPU() private (David Arcari) [2004190]
- x86/fpu: Move legacy ASM wrappers to core (David Arcari) [2004190]
- x86/fpu: Move os_xsave() and os_xrstor() to core (David Arcari) [2004190]
- x86/fpu: Make os_xrstor_booting() private (David Arcari) [2004190]
- x86/fpu: Clean up CPU feature tests (David Arcari) [2004190]
- x86/fpu: Move context switch and exit to user inlines into sched.h (David Arcari) [2004190]
- x86/fpu: Mark fpu__init_prepare_fx_sw_frame() as __init (David Arcari) [2004190]
- x86/fpu: Rework copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy from user (David Arcari) [2004190]
- x86/fpu: Move KVMs FPU swapping to FPU core (David Arcari) [2004190]
- x86/fpu/xstate: Mark all init only functions __init (David Arcari) [2004190]
- x86/fpu/xstate: Provide and use for_each_xfeature() (David Arcari) [2004190]
- x86/fpu: Cleanup xstate xcomp_bv initialization (David Arcari) [2004190]
- x86/fpu: Do not inherit FPU context for kernel and IO worker threads (David Arcari) [2004190]
- x86/fpu: Remove pointless memset in fpu_clone() (David Arcari) [2004190]
- x86/fpu: Cleanup the on_boot_cpu clutter (David Arcari) [2004190]
- x86/fpu: Restrict xsaves()/xrstors() to independent states (David Arcari) [2004190]
- x86/fpu: Update stale comments (David Arcari) [2004190]
- x86/fpu: Remove pointless argument from switch_fpu_finish() (David Arcari) [2004190]
- iommu/vt-d: Clean up unused PASID updating functions (David Arcari) [2004190]
- x86/fpu: Mask out the invalid MXCSR bits properly (David Arcari) [2004190]
- x86/fpu: Restore the masking out of reserved MXCSR bits (David Arcari) [2004190]
- x86/fpu/signal: Fix missed conversion to correct boolean retval in save_xstate_epilog() (David Arcari) [2004190]
- x86/fpu/signal: Change return code of restore_fpregs_from_user() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return code of check_xstate_in_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of __fpu_restore_sig() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of fpu__restore_sig() to boolean (David Arcari) [2004190]
- x86/signal: Change return type of restore_sigcontext() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpregs_to_sigframe() helpers to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpstate_to_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Move xstate clearing out of copy_fpregs_to_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Move header zeroing out of xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Clarify exception handling in restore_fpregs_from_user() (David Arcari) [2004190]
- x86/fpu: Use EX_TYPE_FAULT_MCE_SAFE for exception fixups (David Arcari) [2004190]
- x86/extable: Provide EX_TYPE_DEFAULT_MCE_SAFE and EX_TYPE_FAULT_MCE_SAFE (David Arcari) [2004190]
- x86/extable: Rework the exception table mechanics (David Arcari) [2004190]
- x86/mce: Deduplicate exception handling (David Arcari) [2004190]
- x86/extable: Get rid of redundant macros (David Arcari) [2004190]
- x86/extable: Tidy up redundant handler functions (David Arcari) [2004190]

* Wed Dec 22 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-37.el9]
- sched,x86: Don't use cluster topology for x86 hybrid CPUs (Phil Auld) [2020279]
- sched/uclamp: Fix rq->uclamp_max not set on first enqueue (Phil Auld) [2020279]
- preempt/dynamic: Fix setup_preempt_mode() return value (Phil Auld) [2020279]
- sched/cputime: Fix getrusage(RUSAGE_THREAD) with nohz_full (Phil Auld) [2020279 2029640]
- sched/scs: Reset task stack state in bringup_cpu() (Phil Auld) [2020279]
- Enable CONFIG_SCHED_CLUSTER for RHEL (Phil Auld) [2020279]
- arch_topology: Fix missing clear cluster_cpumask in remove_cpu_topology() (Phil Auld) [2020279]
- mm: move node_reclaim_distance to fix NUMA without SMP (Phil Auld) [2020279]
- sched/core: Mitigate race cpus_share_cache()/update_top_cache_domain() (Phil Auld) [2020279]
- sched/fair: Prevent dead task groups from regaining cfs_rq's (Phil Auld) [2020279]
- x86/smp: Factor out parts of native_smp_prepare_cpus() (Phil Auld) [2020279]
- sched,x86: Fix L2 cache mask (Phil Auld) [2020279]
- sched/fair: Cleanup newidle_balance (Phil Auld) [2020279]
- sched/fair: Remove sysctl_sched_migration_cost condition (Phil Auld) [2020279]
- sched/fair: Wait before decaying max_newidle_lb_cost (Phil Auld) [2020279]
- sched/fair: Skip update_blocked_averages if we are defering load balance (Phil Auld) [2020279]
- sched/fair: Account update_blocked_averages in newidle_balance cost (Phil Auld) [2020279]
- sched/core: Remove rq_relock() (Phil Auld) [2020279]
- sched: Improve wake_up_all_idle_cpus() take #2 (Phil Auld) [2020279]
- sched: Disable -Wunused-but-set-variable (Phil Auld) [2020279]
- irq_work: Handle some irq_work in a per-CPU thread on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Also rcuwait for !IRQ_WORK_HARD_IRQ on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Allow irq_work_sync() to sleep if irq_work() no IRQ support. (Phil Auld) [2020279]
- sched/rt: Annotate the RT balancing logic irqwork as IRQ_WORK_HARD_IRQ (Phil Auld) [2020279]
- sched: Fix DEBUG && !SCHEDSTATS warn (Phil Auld) [2020279]
- sched/numa: Fix a few comments (Phil Auld) [2020279]
- sched/numa: Remove the redundant member numa_group::fault_cpus (Phil Auld) [2020279]
- sched/numa: Replace hard-coded number by a define in numa_task_group() (Phil Auld) [2020279]
- sched: Remove pointless preemption disable in sched_submit_work() (Phil Auld) [2020279]
- sched: Move mmdrop to RCU on RT (Phil Auld) [2020279]
- sched: Move kprobes cleanup out of finish_task_switch() (Phil Auld) [2020279]
- sched: Disable TTWU_QUEUE on RT (Phil Auld) [2020279]
- sched: Limit the number of task migrations per batch on RT (Phil Auld) [2020279]
- sched/fair: Removed useless update of p->recent_used_cpu (Phil Auld) [2020279]
- sched: Add cluster scheduler level for x86 (Phil Auld) [1921343 2020279]
- x86/cpu: Add get_llc_id() helper function (Phil Auld) [2020279]
- x86/smp: Add a per-cpu view of SMT state (Phil Auld) [2020279]
- sched: Add cluster scheduler level in core and related Kconfig for ARM64 (Phil Auld) [2020279]
- topology: Represent clusters of CPUs within a die (Phil Auld) [2020279]
- topology: use bin_attribute to break the size limitation of cpumap ABI (Phil Auld) [2020279]
- cpumask: Omit terminating null byte in cpumap_print_{list,bitmask}_to_buf (Phil Auld) [2020279]
- cpumask: introduce cpumap_print_list/bitmask_to_buf to support large bitmask and list (Phil Auld) [2020279]
- sched: Make cookie functions static (Phil Auld) [2020279]
- sched,livepatch: Use wake_up_if_idle() (Phil Auld) [2020279]
- sched: Simplify wake_up_*idle*() (Phil Auld) [2020279]
- sched,livepatch: Use task_call_func() (Phil Auld) [2020279]
- sched,rcu: Rework try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- sched: Improve try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- kernel/sched: Fix sched_fork() access an invalid sched_task_group (Phil Auld) [2020279]
- sched/topology: Remove unused numa_distance in cpu_attach_domain() (Phil Auld) [2020279]
- sched: Remove unused inline function __rq_clock_broken() (Phil Auld) [2020279]
- sched/fair: Consider SMT in ASYM_PACKING load balance (Phil Auld) [2020279]
- sched/fair: Carve out logic to mark a group for asymmetric packing (Phil Auld) [2020279]
- sched/fair: Provide update_sg_lb_stats() with sched domain statistics (Phil Auld) [2020279]
- sched/fair: Optimize checking for group_asym_packing (Phil Auld) [2020279]
- sched/topology: Introduce sched_group::flags (Phil Auld) [2020279]
- sched/dl: Support schedstats for deadline sched class (Phil Auld) [2020279]
- sched/dl: Support sched_stat_runtime tracepoint for deadline sched class (Phil Auld) [2020279]
- sched/rt: Support schedstats for RT sched class (Phil Auld) [2020279]
- sched/rt: Support sched_stat_runtime tracepoint for RT sched class (Phil Auld) [2020279]
- sched: Introduce task block time in schedstats (Phil Auld) [2020279]
- sched: Make schedstats helpers independent of fair sched class (Phil Auld) [2020279]
- sched: Make struct sched_statistics independent of fair sched class (Phil Auld) [2020279]
- sched/fair: Use __schedstat_set() in set_next_entity() (Phil Auld) [2020279]
- kselftests/sched: cleanup the child processes (Phil Auld) [2020279]
- sched/fair: Add document for burstable CFS bandwidth (Phil Auld) [2020279]
- sched/fair: Add cfs bandwidth burst statistics (Phil Auld) [2020279]
- fs/proc/uptime.c: Fix idle time reporting in /proc/uptime (Phil Auld) [2020279]
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Phil Auld) [2020279]
- sched/core: Simplify core-wide task selection (Phil Auld) [2020279]
- sched/fair: Trigger nohz.next_balance updates when a CPU goes NOHZ-idle (Phil Auld) [2020279]
- sched/fair: Add NOHZ balancer flag for nohz.next_balance updates (Phil Auld) [2020279]
- sched: adjust sleeper credit for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: reduce sched slice for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: Account number of SCHED_IDLE entities on each cfs_rq (Phil Auld) [2020279]
- wait: use LIST_HEAD_INIT() to initialize wait_queue_head (Phil Auld) [2020279]
- kthread: Move prio/affinite change into the newly created thread (Phil Auld) [2020279]

* Tue Dec 21 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-36.el9]
- drivers: base: cacheinfo: Get rid of DEFINE_SMP_CALL_CACHE_FUNCTION() (Vitaly Kuznetsov) [2031644]
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare (Rafael Aquini) [2026378] {CVE-2021-4002}
- bareudp: Add extack support to bareudp_configure() (Guillaume Nault) [2032483]
- bareudp: Move definition of struct bareudp_conf to bareudp.c (Guillaume Nault) [2032483]
- bareudp: Remove bareudp_dev_create() (Guillaume Nault) [2032483]
- scsi: core: Fix shost->cmd_per_lun calculation in scsi_add_host_with_dma() (Cathy Avery) [2030468]
- net: fix GRO skb truesize update (Paolo Abeni) [2028927]
- sk_buff: avoid potentially clearing 'slow_gro' field (Paolo Abeni) [2028927]
- veth: use skb_prepare_for_gro() (Paolo Abeni) [2028927]
- skbuff: allow 'slow_gro' for skb carring sock reference (Paolo Abeni) [2028927]
- net: optimize GRO for the common case. (Paolo Abeni) [2028927]
- sk_buff: track extension status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: track dst status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: introduce 'slow_gro' flags (Paolo Abeni) [2028927]
- selftests: net: veth: add tests for set_channel (Paolo Abeni) [2028927]
- veth: create by default nr_possible_cpus queues (Paolo Abeni) [2028927]
- veth: implement support for set_channel ethtool op (Paolo Abeni) [2028927]
- veth: factor out initialization helper (Paolo Abeni) [2028927]
- veth: always report zero combined channels (Paolo Abeni) [2028927]
- [kernel] bpf: set default value for bpf_jit_harden (Jiri Olsa) [2028734]
- scsi: ibmvfc: Fix up duplicate response detection (Steve Best) [2028709]
- kabi: Add kABI macros for enum type (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation of aux structs (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_USE_AUX_PTR (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_SIZE_AND_EXTEND to AUX (Čestmír Kalina) [2024595]
- kabi: more consistent _RH_KABI_SIZE_AND_EXTEND (Čestmír Kalina) [2024595]
- kabi: use fixed field name for extended part (Čestmír Kalina) [2024595]
- kabi: fix dereference in RH_KABI_CHECK_EXT (Čestmír Kalina) [2024595]
- kabi: fix RH_KABI_SET_SIZE macro (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation (Čestmír Kalina) [2024595]
- kabi: make RH_KABI_USE replace any number of reserved fields (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_USE2 to RH_KABI_USE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE2 to RH_KABI_REPLACE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE_UNSAFE to RH_KABI_BROKEN_REPLACE (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_ADD_MODIFIER (Čestmír Kalina) [2024595]
- kabi: Include kconfig.h (Čestmír Kalina) [2024595]
- kabi: macros for intentional kABI breakage (Čestmír Kalina) [2024595]
- kabi: fix the note about terminating semicolon (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_HIDE_INCLUDE and RH_KABI_FAKE_INCLUDE (Čestmír Kalina) [2024595]

* Mon Dec 20 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-35.el9]
- drm/hyperv: Fix device removal on Gen1 VMs (Mohammed Gamal) [2018067]
- wireguard: device: reset peer src endpoint when netns exits (Hangbin Liu) [1967796]
- nvmet: use IOCB_NOWAIT only if the filesystem supports it (Chris Leech) [2022054]
- nvmet-tcp: fix incomplete data digest send (Chris Leech) [2022054]
- nvmet-tcp: fix memory leak when performing a controller reset (Chris Leech) [2022054]
- nvmet-tcp: add an helper to free the cmd buffers (Chris Leech) [2022054]
- nvmet-tcp: fix a race condition between release_queue and io_work (Chris Leech) [2022054]
- nvmet-tcp: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-rdma: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-tcp: fix header digest verification (Chris Leech) [2022054]
- nvmet-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvmet-tcp: fix a memory leak when releasing a queue (Chris Leech) [2022054]
- nvmet: fix a width vs precision bug in nvmet_subsys_attr_serial_show() (Chris Leech) [2022054]
- nvmet: fixup buffer overrun in nvmet_subsys_attr_serial() (Chris Leech) [2022054]
- nvmet: return bool from nvmet_passthru_ctrl and nvmet_is_passthru_req (Chris Leech) [2022054]
- nvmet: looks at the passthrough controller when initializing CAP (Chris Leech) [2022054]
- nvmet: check that host sqsize does not exceed ctrl MQES (Chris Leech) [2022054]
- nvmet: avoid duplicate qid in connect cmd (Chris Leech) [2022054]
- nvmet: pass back cntlid on successful completion (Chris Leech) [2022054]
- nvmet: remove redundant assignments of variable status (Chris Leech) [2022054]
- nvme-fabrics: ignore invalid fast_io_fail_tmo values (Chris Leech) [2022054]
- nvme-tcp: fix memory leak when freeing a queue (Chris Leech) [2022054]
- nvme-tcp: validate R2T PDU in nvme_tcp_handle_r2t() (Chris Leech) [2022054]
- nvme-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvme-tcp: fix possible req->offset corruption (Chris Leech) [2022054]
- nvme-tcp: fix H2CData PDU send accounting (again) (Chris Leech) [2022054]
- nvme: fix per-namespace chardev deletion (Chris Leech) [2022054]
- nvme: keep ctrl->namespaces ordered (Chris Leech) [2022054]
- nvme-tcp: fix incorrect h2cdata pdu offset accounting (Chris Leech) [2022054]
- nvme-tcp: fix io_work priority inversion (Chris Leech) [2022054]
- nvme-multipath: fix ANA state updates when a namespace is not present (Chris Leech) [2022054]
- nvme: update keep alive interval when kato is modified (Chris Leech) [2022054]
- nvme-tcp: Do not reset transport on data digest errors (Chris Leech) [2022054]
- nvme-rdma: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: pair send_mutex init with destroy (Chris Leech) [2022054]
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data (Chris Leech) [2022054]
- ovl: fix missing negative dentry check in ovl_rename() (Miklos Szeredi) [2011181]
- selftests/bpf/xdp_redirect_multi: Limit the tests in netns (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Give tcpdump a chance to terminate cleanly (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Use arping to accurate the arp number (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Put the logs to tmp folder (Hangbin Liu) [2008895]

* Sat Dec 18 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-34.el9]
- nvdimm/pmem: cleanup the disk if pmem_release_disk() is yet assigned (Ming Lei) [2018403]
- nvdimm/pmem: stop using q_usage_count as external pgmap refcount (Ming Lei) [2018403]
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during unbind (Ming Lei) [2018403]
- nvdimm/pmem: fix creating the dax group (Ming Lei) [2018403]
- md: fix a lock order reversal in md_alloc (Ming Lei) [2018403]
- tools headers UAPI: Sync linux/fs.h with the kernel sources (Ming Lei) [2018403]
- Documentation: raise minimum supported version of GCC to 5.1 (Ming Lei) [2018403]
- loop: Use pr_warn_once() for loop_control_remove() warning (Ming Lei) [2018403]
- zram: only make zram_wb_devops for CONFIG_ZRAM_WRITEBACK (Ming Lei) [2018403]
- block: call rq_qos_done() before ref check in batch completions (Ming Lei) [2018403]
- block: fix parameter not described warning (Ming Lei) [2018403]
- block: avoid to touch unloaded module instance when opening bdev (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKRESETZONE ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKZEROOUT ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKDISCARD ioctl (Ming Lei) [2018403]
- blk-mq: don't insert FUA request with data into scheduler queue (Ming Lei) [2018403]
- blk-cgroup: fix missing put device in error path from blkg_conf_pref() (Ming Lei) [2018403]
- block: avoid to quiesce queue in elevator_init_mq (Ming Lei) [2018403]
- Revert "mark pstore-blk as broken" (Ming Lei) [2018403]
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release() (Ming Lei) [2018403]
- block: fix missing queue put in error path (Ming Lei) [2018403]
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT (Ming Lei) [2018403]
- blk-mq: fix filesystem I/O request allocation (Ming Lei) [2018403]
- blkcg: Remove extra blkcg_bio_issue_init (Ming Lei) [2018403]
- blk-mq: rename blk_attempt_bio_merge (Ming Lei) [2018403]
- blk-mq: don't grab ->q_usage_counter in blk_mq_sched_bio_merge (Ming Lei) [2018403]
- block: fix kerneldoc for disk_register_independent_access__ranges() (Ming Lei) [2018403]
- block: use enum type for blk_mq_alloc_data->rq_flags (Ming Lei) [2018403]
- bcache: Revert "bcache: use bvec_virt" (Ming Lei) [2018403]
- ataflop: Add missing semicolon to return statement (Ming Lei) [2018403]
- floppy: address add_disk() error handling on probe (Ming Lei) [2018403]
- ataflop: address add_disk() error handling on probe (Ming Lei) [2018403]
- block: update __register_blkdev() probe documentation (Ming Lei) [2018403]
- ataflop: remove ataflop_probe_lock mutex (Ming Lei) [2018403]
- mtd/ubi/block: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sunvdc: add error handling support for add_disk() (Ming Lei) [2018403]
- z2ram: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: Remove duplicate assignments (Ming Lei) [2018403]
- drbd: Fix double free problem in drbd_create_device (Ming Lei) [2018403]
- bcache: fix use-after-free problem in bcache_device_free() (Ming Lei) [2018403]
- zram: replace fsync_bdev with sync_blockdev (Ming Lei) [2018403]
- zram: avoid race between zram_remove and disksize_store (Ming Lei) [2018403]
- zram: don't fail to remove zram during unloading module (Ming Lei) [2018403]
- zram: fix race between zram_reset_device() and disksize_store() (Ming Lei) [2018403]
- nbd: error out if socket index doesn't match in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: Fix hungtask when nbd_config_put (Ming Lei) [2018403]
- nbd: Fix incorrect error handle when first_minor is illegal in nbd_dev_add (Ming Lei) [2018403]
- nbd: fix possible overflow for 'first_minor' in nbd_dev_add() (Ming Lei) [2018403]
- nbd: fix max value for 'first_minor' (Ming Lei) [2018403]
- block/brd: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3vram: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3disk: add error handling support for add_disk() (Ming Lei) [2018403]
- zram: add error handling support for add_disk() (Ming Lei) [2018403]
- nvme: wait until quiesce is done (Ming Lei) [2018403]
- scsi: make sure that request queue queiesce and unquiesce balanced (Ming Lei) [2018403]
- scsi: avoid to quiesce sdev->request_queue two times (Ming Lei) [2018403]
- blk-mq: add one API for waiting until quiesce is done (Ming Lei) [2018403]
- blk-mq: don't free tags if the tag_set is used by other device in queue initialztion (Ming Lei) [2018403]
- block: fix device_add_disk() kobject_create_and_add() error handling (Ming Lei) [2018403]
- block: ensure cached plug request matches the current queue (Ming Lei) [2018403]
- block: move queue enter logic into blk_mq_submit_bio() (Ming Lei) [2018403]
- block: make bio_queue_enter() fast-path available inline (Ming Lei) [2018403]
- block: split request allocation components into helpers (Ming Lei) [2018403]
- block: have plug stored requests hold references to the queue (Ming Lei) [2018403]
- blk-mq: update hctx->nr_active in blk_mq_end_request_batch() (Ming Lei) [2018403]
- blk-mq: add RQF_ELV debug entry (Ming Lei) [2018403]
- blk-mq: only try to run plug merge if request has same queue with incoming bio (Ming Lei) [2018403]
- block: move RQF_ELV setting into allocators (Ming Lei) [2018403]
- dm: don't stop request queue after the dm device is suspended (Ming Lei) [2018403]
- block: replace always false argument with 'false' (Ming Lei) [2018403]
- block: assign correct tag before doing prefetch of request (Ming Lei) [2018403]
- blk-mq: fix redundant check of !e expression (Ming Lei) [2018403]
- block: use new bdev_nr_bytes() helper for blkdev_{read,write}_iter() (Ming Lei) [2018403]
- block: add a loff_t cast to bdev_nr_bytes (Ming Lei) [2018403]
- null_blk: Fix handling of submit_queues and poll_queues attributes (Ming Lei) [2018403]
- block: ataflop: Fix warning comparing pointer to 0 (Ming Lei) [2018403]
- bcache: replace snprintf in show functions with sysfs_emit (Ming Lei) [2018403]
- bcache: move uapi header bcache.h to bcache code directory (Ming Lei) [2018403]
- block: ataflop: more blk-mq refactoring fixes (Ming Lei) [2018403]
- block: remove support for cryptoloop and the xor transfer (Ming Lei) [2018403]
- mtd: add add_disk() error handling (Ming Lei) [2018403]
- rnbd: add error handling support for add_disk() (Ming Lei) [2018403]
- um/drivers/ubd_kern: add error handling support for add_disk() (Ming Lei) [2018403]
- m68k/emu/nfblock: add error handling support for add_disk() (Ming Lei) [2018403]
- xen-blkfront: add error handling support for add_disk() (Ming Lei) [2018403]
- bcache: add error handling support for add_disk() (Ming Lei) [2018403]
- dm: add add_disk() error handling (Ming Lei) [2018403]
- block: aoe: fixup coccinelle warnings (Ming Lei) [2018403]
- bcache: remove bch_crc64_update (Ming Lei) [2018403]
- bcache: use bvec_kmap_local in bch_data_verify (Ming Lei) [2018403]
- bcache: remove the backing_dev_name field from struct cached_dev (Ming Lei) [2018403]
- bcache: remove the cache_dev_name field from struct cache (Ming Lei) [2018403]
- bcache: move calc_cached_dev_sectors to proper place on backing device detach (Ming Lei) [2018403]
- bcache: fix error info in register_bcache() (Ming Lei) [2018403]
- bcache: reserve never used bits from bkey.high (Ming Lei) [2018403]
- md: bcache: Fix spelling of 'acquire' (Ming Lei) [2018403]
- s390/dasd: fix possibly missed path verification (Ming Lei) [2018403]
- s390/dasd: fix missing path conf_data after failed allocation (Ming Lei) [2018403]
- s390/dasd: summarize dasd configuration data in a separate structure (Ming Lei) [2018403]
- s390/dasd: move dasd_eckd_read_fc_security (Ming Lei) [2018403]
- s390/dasd: split up dasd_eckd_read_conf (Ming Lei) [2018403]
- s390/dasd: fix kernel doc comment (Ming Lei) [2018403]
- s390/dasd: handle request magic consistently as unsigned int (Ming Lei) [2018403]
- nbd: Fix use-after-free in pid_show (Ming Lei) [2018403]
- block: ataflop: fix breakage introduced at blk-mq refactoring (Ming Lei) [2018403]
- nbd: fix uaf in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: partition nbd_read_stat() into nbd_read_reply() and nbd_handle_reply() (Ming Lei) [2018403]
- nbd: clean up return value checking of sock_xmit() (Ming Lei) [2018403]
- nbd: don't start request if nbd_queue_rq() failed (Ming Lei) [2018403]
- nbd: check sock index in nbd_read_stat() (Ming Lei) [2018403]
- nbd: make sure request completion won't concurrent (Ming Lei) [2018403]
- nbd: don't handle response without a corresponding request message (Ming Lei) [2018403]
- mtip32xx: Remove redundant 'flush_workqueue()' calls (Ming Lei) [2018403]
- swim3: add missing major.h include (Ming Lei) [2018403]
- sx8: fix an error code in carm_init_one() (Ming Lei) [2018403]
- pf: fix error codes in pf_init_unit() (Ming Lei) [2018403]
- pcd: fix error codes in pcd_init_unit() (Ming Lei) [2018403]
- xtensa/platforms/iss/simdisk: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: provide a helper for cleanup up an atari disk (Ming Lei) [2018403]
- block/ataflop: add registration bool before calling del_gendisk() (Ming Lei) [2018403]
- block/ataflop: use the blk_cleanup_disk() helper (Ming Lei) [2018403]
- swim: add error handling support for add_disk() (Ming Lei) [2018403]
- swim: add a floppy registration bool which triggers del_gendisk() (Ming Lei) [2018403]
- swim: add helper for disk cleanup (Ming Lei) [2018403]
- swim: simplify using blk_cleanup_disk() on swim_remove() (Ming Lei) [2018403]
- amiflop: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: fix calling platform_device_unregister() on invalid drives (Ming Lei) [2018403]
- floppy: use blk_cleanup_disk() (Ming Lei) [2018403]
- floppy: fix add_disk() assumption on exit due to new developments (Ming Lei) [2018403]
- block/swim3: add error handling support for add_disk() (Ming Lei) [2018403]
- rbd: add add_disk() error handling (Ming Lei) [2018403]
- cdrom/gdrom: add error handling support for add_disk() (Ming Lei) [2018403]
- pf: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sx8: add error handling support for add_disk() (Ming Lei) [2018403]
- block/rsxx: add error handling support for add_disk() (Ming Lei) [2018403]
- pktcdvd: add error handling support for add_disk() (Ming Lei) [2018403]
- mtip32xx: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: add error handling support for add_disk() (Ming Lei) [2018403]
- pcd: capture errors on cdrom_register() (Ming Lei) [2018403]
- pcd: fix ordering of unregister_cdrom() (Ming Lei) [2018403]
- pcd: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: cleanup initialization (Ming Lei) [2018403]
- pf: cleanup initialization (Ming Lei) [2018403]
- pcd: cleanup initialization (Ming Lei) [2018403]
- pcd: move the identify buffer into pcd_identify (Ming Lei) [2018403]
- n64cart: add error handling support for add_disk() (Ming Lei) [2018403]
- drbd: add error handling support for add_disk() (Ming Lei) [2018403]
- aoe: add error handling support for add_disk() (Ming Lei) [2018403]
- nbd: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: add error handling support for add_disk() (Ming Lei) [2018403]
- null_blk: poll queue support (Ming Lei) [2018403]
- block: simplify the block device syncing code (Ming Lei) [2018403]
- fat: use sync_blockdev_nowait (Ming Lei) [2018403]
- btrfs: use sync_blockdev (Ming Lei) [2018403]
- xen-blkback: use sync_blockdev (Ming Lei) [2018403]
- block: remove __sync_blockdev (Ming Lei) [2018403]
- fs: remove __sync_filesystem (Ming Lei) [2018403]
- cdrom: Remove redundant variable and its assignment (Ming Lei) [2018403]
- cdrom: docs: reformat table in Documentation/userspace-api/ioctl/cdrom.rst (Ming Lei) [2018403]
- drivers/cdrom: improved ioctl for media change detection (Ming Lei) [2018403]
- partitions/ibm: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- partitions/efi: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- block/ioctl: use bdev_nr_sectors and bdev_nr_bytes (Ming Lei) [2018403]
- block: cache inode size in bdev (Ming Lei) [2018403]
- udf: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- reiserfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ntfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- jfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ext4: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- block: add a sb_bdev_nr_blocks helper (Ming Lei) [2018403]
- block: use bdev_nr_bytes instead of open coding it in blkdev_fallocate (Ming Lei) [2018403]
- squashfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- reiserfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- pstore/blk: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nilfs2: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nfs/blocklayout: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- jfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- hfsplus: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- hfs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fat: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- cramfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- btrfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- affs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fs: simplify init_page_buffers (Ming Lei) [2018403]
- fs: use bdev_nr_bytes instead of open coding it in blkdev_max_block (Ming Lei) [2018403]
- target/iblock: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nvmet: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- md: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- dm: use bdev_nr_sectors and bdev_nr_bytes instead of open coding them (Ming Lei) [2018403]
- drbd: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- bcache: remove bdev_sectors (Ming Lei) [2018403]
- block: add a bdev_nr_bytes helper (Ming Lei) [2018403]
- block: move the SECTOR_SIZE related definitions to blk_types.h (Ming Lei) [2018403]
- blk-mq-debugfs: Show active requests per queue for shared tags (Ming Lei) [2018403]
- block: improve readability of blk_mq_end_request_batch() (Ming Lei) [2018403]
- virtio-blk: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- loop: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- nbd: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- block: Add a helper to validate the block size (Ming Lei) [2018403]
- block: re-flow blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: prefetch request to be initialized (Ming Lei) [2018403]
- block: pass in blk_mq_tags to blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: add rq_flags to struct blk_mq_alloc_data (Ming Lei) [2018403]
- block: add async version of bio_set_polled (Ming Lei) [2018403]
- block: kill DIO_MULTI_BIO (Ming Lei) [2018403]
- block: kill unused polling bits in __blkdev_direct_IO() (Ming Lei) [2018403]
- block: avoid extra iter advance with async iocb (Ming Lei) [2018403]
- block: Add independent access ranges support (Ming Lei) [2018403]
- blk-mq: don't issue request directly in case that current is to be blocked (Ming Lei) [2018403]
- sbitmap: silence data race warning (Ming Lei) [2018403]
- blk-cgroup: synchronize blkg creation against policy deactivation (Ming Lei) [2018403]
- block: refactor bio_iov_bvec_set() (Ming Lei) [2018403]
- block: add single bio async direct IO helper (Ming Lei) [2018403]
- sched: make task_struct->plug always defined (Ming Lei) [2018403]
- blk-mq-sched: Don't reference queue tagset in blk_mq_sched_tags_teardown() (Ming Lei) [2018403]
- block: fix req_bio_endio append error handling (Ming Lei) [2018403]
- blk-crypto: update inline encryption documentation (Ming Lei) [2018403]
- blk-crypto: rename blk_keyslot_manager to blk_crypto_profile (Ming Lei) [2018403]
- blk-crypto: rename keyslot-manager files to blk-crypto-profile (Ming Lei) [2018403]
- blk-crypto-fallback: properly prefix function and struct names (Ming Lei) [2018403]
- nbd: Use invalidate_disk() helper on disconnect (Ming Lei) [2018403]
- loop: Remove the unnecessary bdev checks and unused bdev variable (Ming Lei) [2018403]
- loop: Use invalidate_disk() helper to invalidate gendisk (Ming Lei) [2018403]
- block: Add invalidate_disk() helper to invalidate the gendisk (Ming Lei) [2018403]
- block: kill extra rcu lock/unlock in queue enter (Ming Lei) [2018403]
- percpu_ref: percpu_ref_tryget_live() version holding RCU (Ming Lei) [2018403]
- block: convert fops.c magic constants to SHIFT_SECTOR (Ming Lei) [2018403]
- block: clean up blk_mq_submit_bio() merging (Ming Lei) [2018403]
- block: optimise boundary blkdev_read_iter's checks (Ming Lei) [2018403]
- fs: bdev: fix conflicting comment from lookup_bdev (Ming Lei) [2018403]
- blk-mq: Fix blk_mq_tagset_busy_iter() for shared tags (Ming Lei) [2018403]
- block: cleanup the flush plug helpers (Ming Lei) [2018403]
- block: optimise blk_flush_plug_list (Ming Lei) [2018403]
- blk-mq: move blk_mq_flush_plug_list to block/blk-mq.h (Ming Lei) [2018403]
- blk-mq: only flush requests from the plug in blk_mq_submit_bio (Ming Lei) [2018403]
- block: remove inaccurate requeue check (Ming Lei) [2018403]
- block: inline a part of bio_release_pages() (Ming Lei) [2018403]
- block: don't bloat enter_queue with percpu_ref (Ming Lei) [2018403]
- block: optimise req_bio_endio() (Ming Lei) [2018403]
- block: convert leftovers to bdev_get_queue (Ming Lei) [2018403]
- block: turn macro helpers into inline functions (Ming Lei) [2018403]
- blk-mq: support concurrent queue quiesce/unquiesce (Ming Lei) [2018403]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Ming Lei) [2018403]
- nvme: paring quiesce/unquiesce (Ming Lei) [2018403]
- nvme: prepare for pairing quiescing and unquiescing (Ming Lei) [2018403]
- nvme: apply nvme API to quiesce/unquiesce admin queue (Ming Lei) [2018403]
- nvme: add APIs for stopping/starting admin queue (Ming Lei) [2018403]
- block, bfq: fix UAF problem in bfqg_stats_init() (Ming Lei) [2018403]
- block: inline fast path of driver tag allocation (Ming Lei) [2018403]
- blk-mq: don't handle non-flush requests in blk_insert_flush (Ming Lei) [2018403]
- block: attempt direct issue of plug list (Ming Lei) [2018403]
- block: change plugging to use a singly linked list (Ming Lei) [2018403]
- blk-wbt: prevent NULL pointer dereference in wb_timer_fn (Ming Lei) [2018403]
- block: align blkdev_dio inlined bio to a cacheline (Ming Lei) [2018403]
- block: move blk_mq_tag_to_rq() inline (Ming Lei) [2018403]
- block: get rid of plug list sorting (Ming Lei) [2018403]
- block: return whether or not to unplug through boolean (Ming Lei) [2018403]
- block: don't call blk_status_to_errno in blk_update_request (Ming Lei) [2018403]
- block: move bdev_read_only() into the header (Ming Lei) [2018403]
- block: fix too broad elevator check in blk_mq_free_request() (Ming Lei) [2018403]
- block: add support for blk_mq_end_request_batch() (Ming Lei) [2018403]
- sbitmap: add helper to clear a batch of tags (Ming Lei) [2018403]
- block: add a struct io_comp_batch argument to fops->iopoll() (Ming Lei) [2018403]
- block: provide helpers for rq_list manipulation (Ming Lei) [2018403]
- block: remove some blk_mq_hw_ctx debugfs entries (Ming Lei) [2018403]
- block: remove debugfs blk_mq_ctx dispatched/merged/completed attributes (Ming Lei) [2018403]
- block: cache rq_flags inside blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: blk_mq_rq_ctx_init cache ctx/q/hctx (Ming Lei) [2018403]
- block: skip elevator fields init for non-elv queue (Ming Lei) [2018403]
- block: store elevator state in request (Ming Lei) [2018403]
- block: only mark bio as tracked if it really is tracked (Ming Lei) [2018403]
- block: improve layout of struct request (Ming Lei) [2018403]
- block: move update request helpers into blk-mq.c (Ming Lei) [2018403]
- block: remove useless caller argument to print_req_error() (Ming Lei) [2018403]
- block: don't bother iter advancing a fully done bio (Ming Lei) [2018403]
- block: convert the rest of block to bdev_get_queue (Ming Lei) [2018403]
- block: use bdev_get_queue() in blk-core.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bio.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bdev.c (Ming Lei) [2018403]
- block: cache request queue in bdev (Ming Lei) [2018403]
- block: handle fast path of bio splitting inline (Ming Lei) [2018403]
- block: use flags instead of bit fields for blkdev_dio (Ming Lei) [2018403]
- block: cache bdev in struct file for raw bdev IO (Ming Lei) [2018403]
- block: don't allow writing to the poll queue attribute (Ming Lei) [2018403]
- block: switch polling to be bio based (Ming Lei) [2018403]
- block: define 'struct bvec_iter' as packed (Ming Lei) [2018403]
- block: use SLAB_TYPESAFE_BY_RCU for the bio slab (Ming Lei) [2018403]
- block: rename REQ_HIPRI to REQ_POLLED (Ming Lei) [2018403]
- io_uring: don't sleep when polling for I/O (Ming Lei) [2018403]
- block: replace the spin argument to blk_iopoll with a flags argument (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_valid (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_to_tag and blk_qc_t_is_internal (Ming Lei) [2018403]
- blk-mq: factor out a "classic" poll helper (Ming Lei) [2018403]
- blk-mq: factor out a blk_qc_to_hctx helper (Ming Lei) [2018403]
- io_uring: fix a layering violation in io_iopoll_req_issued (Ming Lei) [2018403]
- block: don't try to poll multi-bio I/Os in __blkdev_direct_IO (Ming Lei) [2018403]
- direct-io: remove blk_poll support (Ming Lei) [2018403]
- block: only check previous entry for plug merge attempt (Ming Lei) [2018403]
- block: move CONFIG_BLOCK guard to top Makefile (Ming Lei) [2018403]
- block: move menu "Partition type" to block/partitions/Kconfig (Ming Lei) [2018403]
- block: simplify Kconfig files (Ming Lei) [2018403]
- block: remove redundant =y from BLK_CGROUP dependency (Ming Lei) [2018403]
- block: improve batched tag allocation (Ming Lei) [2018403]
- sbitmap: add __sbitmap_queue_get_batch() (Ming Lei) [2018403]
- blk-mq: optimise *end_request non-stat path (Ming Lei) [2018403]
- block: mark bio_truncate static (Ming Lei) [2018403]
- block: move bio_get_{first,last}_bvec out of bio.h (Ming Lei) [2018403]
- block: mark __bio_try_merge_page static (Ming Lei) [2018403]
- block: move bio_full out of bio.h (Ming Lei) [2018403]
- block: fold bio_cur_bytes into blk_rq_cur_bytes (Ming Lei) [2018403]
- block: move bio_mergeable out of bio.h (Ming Lei) [2018403]
- block: don't include <linux/ioprio.h> in <linux/bio.h> (Ming Lei) [2018403]
- block: remove BIO_BUG_ON (Ming Lei) [2018403]
- blk-mq: inline hot part of __blk_mq_sched_restart (Ming Lei) [2018403]
- block: inline hot paths of blk_account_io_*() (Ming Lei) [2018403]
- block: merge block_ioctl into blkdev_ioctl (Ming Lei) [2018403]
- block: move the *blkdev_ioctl declarations out of blkdev.h (Ming Lei) [2018403]
- block: unexport blkdev_ioctl (Ming Lei) [2018403]
- block: don't dereference request after flush insertion (Ming Lei) [2018403]
- blk-mq: cleanup blk_mq_submit_bio (Ming Lei) [2018403]
- blk-mq: cleanup and rename __blk_mq_alloc_request (Ming Lei) [2018403]
- block: pre-allocate requests if plug is started and is a batch (Ming Lei) [2018403]
- block: bump max plugged deferred size from 16 to 32 (Ming Lei) [2018403]
- block: inherit request start time from bio for BLK_CGROUP (Ming Lei) [2018403]
- block: move blk-throtl fast path inline (Ming Lei) [2018403]
- blk-mq: Change shared sbitmap naming to shared tags (Ming Lei) [2018403]
- blk-mq: Stop using pointers for blk_mq_tags bitmap tags (Ming Lei) [2018403]
- blk-mq: Use shared tags for shared sbitmap support (Ming Lei) [2018403]
- blk-mq: Refactor and rename blk_mq_free_map_and_{requests->rqs}() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_alloc_map_and_rqs() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_tag_update_sched_shared_sbitmap() (Ming Lei) [2018403]
- blk-mq: Don't clear driver tags own mapping (Ming Lei) [2018403]
- blk-mq: Pass driver tags to blk_mq_clear_rq_mapping() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_free_{requests -> rqs}() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_alloc_{tags -> map_and_rqs}() (Ming Lei) [2018403]
- blk-mq: Invert check in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- blk-mq: Relocate shared sbitmap resize in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- block: Rename BLKDEV_MAX_RQ -> BLKDEV_DEFAULT_RQ (Ming Lei) [2018403]
- blk-mq: Change rqs check in blk_mq_free_rqs() (Ming Lei) [2018403]
- block: print the current process in handle_bad_sector (Ming Lei) [2018403]
- block/mq-deadline: Prioritize high-priority requests (Ming Lei) [2018403]
- block/mq-deadline: Stop using per-CPU counters (Ming Lei) [2018403]
- block/mq-deadline: Add an invariant check (Ming Lei) [2018403]
- block/mq-deadline: Improve request accounting further (Ming Lei) [2018403]
- block: move struct request to blk-mq.h (Ming Lei) [2018403]
- block: move integrity handling out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: move a few merge helpers out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/genhd.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/blkdev.h> (Ming Lei) [2018403]
- block: move elevator.h to block/ (Ming Lei) [2018403]
- block: remove the struct blk_queue_ctx forward declaration (Ming Lei) [2018403]
- block: remove the cmd_size field from struct request_queue (Ming Lei) [2018403]
- block: remove the unused blk_queue_state enum (Ming Lei) [2018403]
- block: remove the unused rq_end_sector macro (Ming Lei) [2018403]
- sched: move the <linux/blkdev.h> include out of kernel/sched/sched.h (Ming Lei) [2018403]
- kernel: remove spurious blkdev.h includes (Ming Lei) [2018403]
- arch: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: don't include <linux/blkdev.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/writeback.h> (Ming Lei) [2018403]
- block: nbd: add sanity check for first_minor (Ming Lei) [2018403]
- mmc: core: Store pointer to bio_crypt_ctx in mmc_request (Ming Lei) [2018403]
- iomap: simplify iomap_add_to_ioend (Ming Lei) [2018403]
- iomap: simplify iomap_readpage_actor (Ming Lei) [2018403]
- io_uring: don't halt iopoll too early (Ming Lei) [2018403]
- block: Fix partition check for host-aware zoned block devices (Ming Lei) [2018403]
- block: schedule queue restart after BLK_STS_ZONE_RESOURCE (Ming Lei) [2018403]
- block: drain queue after disk is removed from sysfs (Ming Lei) [2018403]
- block: fix incorrect references to disk objects (Ming Lei) [2018403]
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe operations on blkg->iostat_cpu (Ming Lei) [2018403]
- block, bfq: reset last_bfqq_created on group change (Ming Lei) [2018403]
- block: warn when putting the final reference on a registered disk (Ming Lei) [2018403]
- brd: reduce the brd_devices_mutex scope (Ming Lei) [2018403]
- kyber: avoid q->disk dereferences in trace points (Ming Lei) [2018403]
- block: keep q_usage_counter in atomic mode after del_gendisk (Ming Lei) [2018403]
- block: drain file system I/O on del_gendisk (Ming Lei) [2018403]
- block: split bio_queue_enter from blk_queue_enter (Ming Lei) [2018403]
- block: factor out a blk_try_enter_queue helper (Ming Lei) [2018403]
- block: call submit_bio_checks under q_usage_counter (Ming Lei) [2018403]
- block/rnbd-clt-sysfs: fix a couple uninitialized variable bugs (Ming Lei) [2018403]
- block: decode QUEUE_FLAG_HCTX_ACTIVE in debugfs output (Ming Lei) [2018403]
- block: genhd: fix double kfree() in __alloc_disk_node() (Ming Lei) [2018403]
- nbd: use shifts rather than multiplies (Ming Lei) [2018403]
- Revert "block, bfq: honor already-setup queue merges" (Ming Lei) [2018403]
- block: hold ->invalidate_lock in blkdev_fallocate (Ming Lei) [2018403]
- blktrace: Fix uaf in blk_trace access after removing by sysfs (Ming Lei) [2018403]
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked (Ming Lei) [2018403]
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying blkg pd (Ming Lei) [2018403]
- blkcg: fix memory leak in blk_iolatency_init (Ming Lei) [2018403]
- block: flush the integrity workqueue in blk_integrity_unregister (Ming Lei) [2018403]
- block: check if a profile is actually registered in blk_integrity_unregister (Ming Lei) [2018403]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2018403]
- n64cart: fix return value check in n64cart_probe() (Ming Lei) [2018403]
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for multiple_queues (Ming Lei) [2018403]
- block: move fs/block_dev.c to block/bdev.c (Ming Lei) [2018403]
- block: split out operations on block special files (Ming Lei) [2018403]
- blk-throttle: fix UAF by deleteing timer in blk_throtl_exit() (Ming Lei) [2018403]
- block: genhd: don't call blkdev_show() with major_names_lock held (Ming Lei) [2018403]
- cdrom: update uniform CD-ROM maintainership in MAINTAINERS file (Ming Lei) [2018403]
- loop: reduce the loop_ctl_mutex scope (Ming Lei) [2018403]
- bio: fix kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block, bfq: honor already-setup queue merges (Ming Lei) [2018403]
- block/mq-deadline: Move dd_queued() to fix defined but not used warning (Ming Lei) [2018403]
- bio: improve kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block: provide bio_clear_hipri() helper (Ming Lei) [2018403]
- block: use the percpu bio cache in __blkdev_direct_IO (Ming Lei) [2018403]
- io_uring: enable use of bio alloc cache (Ming Lei) [2018403]
- block: clear BIO_PERCPU_CACHE flag if polling isn't supported (Ming Lei) [2018403]
- bio: add allocation cache abstraction (Ming Lei) [2018403]
- fs: add kiocb alloc cache flag (Ming Lei) [2018403]
- bio: optimize initialization of a bio (Ming Lei) [2018403]
- Revert "floppy: reintroduce O_NDELAY fix" (Ming Lei) [2018403]
- nbd: remove nbd->destroy_complete (Ming Lei) [2018403]
- nbd: only return usable devices from nbd_find_unused (Ming Lei) [2018403]
- nbd: set nbd->index before releasing nbd_index_mutex (Ming Lei) [2018403]
- nbd: prevent IDR lookups from finding partially initialized devices (Ming Lei) [2018403]
- nbd: reset NBD to NULL when restarting in nbd_genl_connect (Ming Lei) [2018403]
- nbd: add missing locking to the nbd_dev_add error path (Ming Lei) [2018403]
- params: lift param_set_uint_minmax to common code (Ming Lei) [2018403]
- nbd: reduce the nbd_index_mutex scope (Ming Lei) [2018403]
- nbd: refactor device search and allocation in nbd_genl_connect (Ming Lei) [2018403]
- nbd: return the allocated nbd_device from nbd_dev_add (Ming Lei) [2018403]
- nbd: remove nbd_del_disk (Ming Lei) [2018403]
- nbd: refactor device removal (Ming Lei) [2018403]
- nbd: do del_gendisk() asynchronously for NBD_DESTROY_ON_DISCONNECT (Ming Lei) [2018403]
- nbd: add the check to prevent overflow in __nbd_ioctl() (Ming Lei) [2018403]
- xen-blkfront: Remove redundant assignment to variable err (Ming Lei) [2018403]
- block/rnbd: Use sysfs_emit instead of s*printf function for sysfs show (Ming Lei) [2018403]
- block/rnbd-clt: Use put_cpu_ptr after get_cpu_ptr (Ming Lei) [2018403]
- sg: pass the device name to blk_trace_setup (Ming Lei) [2018403]
- block, bfq: cleanup the repeated declaration (Ming Lei) [2018403]
- blk-crypto: fix check for too-large dun_bytes (Ming Lei) [2018403]
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN (Ming Lei) [2018403]
- blk-zoned: allow zone management send operations without CAP_SYS_ADMIN (Ming Lei) [2018403]
- block: mark blkdev_fsync static (Ming Lei) [2018403]
- block: refine the disk_live check in del_gendisk (Ming Lei) [2018403]
- mmc: sdhci-tegra: Enable MMC_CAP2_ALT_GPT_TEGRA (Ming Lei) [2018403]
- mmc: block: Support alternative_gpt_sector() operation (Ming Lei) [2018403]
- partitions/efi: Support non-standard GPT location (Ming Lei) [2018403]
- block: Add alternative_gpt_sector() operation (Ming Lei) [2018403]
- bio: fix page leak bio_add_hw_page failure (Ming Lei) [2018403]
- block: remove CONFIG_DEBUG_BLOCK_EXT_DEVT (Ming Lei) [2018403]
- block: remove a pointless call to MINOR() in device_add_disk (Ming Lei) [2018403]
- null_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- virtio_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- block: add error handling for device_add_disk / add_disk (Ming Lei) [2018403]
- block: return errors from disk_alloc_events (Ming Lei) [2018403]
- block: return errors from blk_integrity_add (Ming Lei) [2018403]
- block: call blk_register_queue earlier in device_add_disk (Ming Lei) [2018403]
- block: call blk_integrity_add earlier in device_add_disk (Ming Lei) [2018403]
- block: create the bdi link earlier in device_add_disk (Ming Lei) [2018403]
- block: call bdev_add later in device_add_disk (Ming Lei) [2018403]
- block: fold register_disk into device_add_disk (Ming Lei) [2018403]
- block: add a sanity check for a live disk in del_gendisk (Ming Lei) [2018403]
- block: add an explicit ->disk backpointer to the request_queue (Ming Lei) [2018403]
- block: hold a request_queue reference for the lifetime of struct gendisk (Ming Lei) [2018403]
- block: pass a request_queue to __blk_alloc_disk (Ming Lei) [2018403]
- block: remove the minors argument to __alloc_disk_node (Ming Lei) [2018403]
- block: remove alloc_disk and alloc_disk_node (Ming Lei) [2018403]
- block: cleanup the lockdep handling in *alloc_disk (Ming Lei) [2018403]
- sg: do not allocate a gendisk (Ming Lei) [2018403]
- st: do not allocate a gendisk (Ming Lei) [2018403]
- nvme: use blk_mq_alloc_disk (Ming Lei) [2018403]
- block: add back the bd_holder_dir reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: fix default IO priority handling (Ming Lei) [2018403]
- block: Introduce IOPRIO_NR_LEVELS (Ming Lei) [2018403]
- block: fix IOPRIO_PRIO_CLASS() and IOPRIO_PRIO_VALUE() macros (Ming Lei) [2018403]
- block: change ioprio_valid() to an inline function (Ming Lei) [2018403]
- block: improve ioprio class description comment (Ming Lei) [2018403]
- block: bfq: fix bfq_set_next_ioprio_data() (Ming Lei) [2018403]
- block: unexport blk_register_queue (Ming Lei) [2018403]
- blk-cgroup: stop using seq_get_buf (Ming Lei) [2018403]
- blk-cgroup: refactor blkcg_print_stat (Ming Lei) [2018403]
- nvme: use bvec_virt (Ming Lei) [2018403]
- dcssblk: use bvec_virt (Ming Lei) [2018403]
- dasd: use bvec_virt (Ming Lei) [2018403]
- ps3vram: use bvec_virt (Ming Lei) [2018403]
- ubd: use bvec_virt (Ming Lei) [2018403]
- sd: use bvec_virt (Ming Lei) [2018403]
- bcache: use bvec_virt (Ming Lei) [2018403]
- virtio_blk: use bvec_virt (Ming Lei) [2018403]
- rbd: use bvec_virt (Ming Lei) [2018403]
- squashfs: use bvec_virt (Ming Lei) [2018403]
- dm-integrity: use bvec_virt (Ming Lei) [2018403]
- dm-ebs: use bvec_virt (Ming Lei) [2018403]
- dm: make EBS depend on !HIGHMEM (Ming Lei) [2018403]
- block: use bvec_virt in bio_integrity_{process,free} (Ming Lei) [2018403]
- bvec: add a bvec_virt helper (Ming Lei) [2018403]
- block: ensure the bdi is freed after inode_detach_wb (Ming Lei) [2018403]
- block: free the extended dev_t minor later (Ming Lei) [2018403]
- blk-throtl: optimize IOPS throttle for large IO scenarios (Ming Lei) [2018403]
- block: pass a gendisk to bdev_resize_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_del_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_add_partition (Ming Lei) [2018403]
- block: store a gendisk in struct parsed_partitions (Ming Lei) [2018403]
- block: remove GENHD_FL_UP (Ming Lei) [2018403]
- bcache: move the del_gendisk call out of bcache_device_free (Ming Lei) [2018403]
- bcache: add proper error unwinding in bcache_device_init (Ming Lei) [2018403]
- sx8: use the internal state machine to check if del_gendisk needs to be called (Ming Lei) [2018403]
- nvme: replace the GENHD_FL_UP check in nvme_mpath_shutdown_disk (Ming Lei) [2018403]
- nvme: remove the GENHD_FL_UP check in nvme_ns_remove (Ming Lei) [2018403]
- mmc: block: cleanup gendisk creation (Ming Lei) [2018403]
- mmc: block: let device_add_disk create disk attributes (Ming Lei) [2018403]
- block: move some macros to blkdev.h (Ming Lei) [2018403]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [2018403]
- block: remove the bd_bdi in struct block_device (Ming Lei) [2018403]
- block: move the bdi from the request_queue to the gendisk (Ming Lei) [2018403]
- block: add a queue_has_disk helper (Ming Lei) [2018403]
- block: pass a gendisk to blk_queue_update_readahead (Ming Lei) [2018403]
- block: remove support for delayed queue registrations (Ming Lei) [2018403]
- dm: delay registering the gendisk (Ming Lei) [2018403]
- dm: move setting md->type into dm_setup_md_queue (Ming Lei) [2018403]
- dm: cleanup cleanup_mapped_device (Ming Lei) [2018403]
- block: support delayed holder registration (Ming Lei) [2018403]
- block: look up holders by bdev (Ming Lei) [2018403]
- block: remove the extra kobject reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: make the block holder code optional (Ming Lei) [2018403]
- loop: Select I/O scheduler 'none' from inside add_disk() (Ming Lei) [2018403]
- blk-mq: Introduce the BLK_MQ_F_NO_SCHED_BY_DEFAULT flag (Ming Lei) [2018403]
- block: remove blk-mq-sysfs dead code (Ming Lei) [2018403]
- loop: raise media_change event (Ming Lei) [2018403]
- block: add a helper to raise a media changed event (Ming Lei) [2018403]
- block: export diskseq in sysfs (Ming Lei) [2018403]
- block: add ioctl to read the disk sequence number (Ming Lei) [2018403]
- block: export the diskseq in uevents (Ming Lei) [2018403]
- block: add disk sequence number (Ming Lei) [2018403]
- block: remove cmdline-parser.c (Ming Lei) [2018403]
- block: remove disk_name() (Ming Lei) [2018403]
- block: simplify disk name formatting in check_partition (Ming Lei) [2018403]
- block: simplify printing the device names disk_stack_limits (Ming Lei) [2018403]
- block: use the %%pg format specifier in show_partition (Ming Lei) [2018403]
- block: use the %%pg format specifier in printk_all_partitions (Ming Lei) [2018403]
- block: reduce stack usage in diskstats_show (Ming Lei) [2018403]
- block: remove bdput (Ming Lei) [2018403]
- block: remove bdgrab (Ming Lei) [2018403]
- loop: don't grab a reference to the block device (Ming Lei) [2018403]
- block: change the refcounting for partitions (Ming Lei) [2018403]
- block: allocate bd_meta_info later in add_partitions (Ming Lei) [2018403]
- block: unhash the whole device inode earlier (Ming Lei) [2018403]
- block: assert the locking state in delete_partition (Ming Lei) [2018403]
- block: use bvec_kmap_local in bio_integrity_process (Ming Lei) [2018403]
- block: use bvec_kmap_local in t10_pi_type1_{prepare,complete} (Ming Lei) [2018403]
- block: use memcpy_from_bvec in __blk_queue_bounce (Ming Lei) [2018403]
- block: use memcpy_from_bvec in bio_copy_kern_endio_read (Ming Lei) [2018403]
- block: use memcpy_to_bvec in copy_to_high_bio_irq (Ming Lei) [2018403]
- block: rewrite bio_copy_data_iter to use bvec_kmap_local and memcpy_to_bvec (Ming Lei) [2018403]
- block: remove bvec_kmap_irq and bvec_kunmap_irq (Ming Lei) [2018403]
- ps3disk: use memcpy_{from,to}_bvec (Ming Lei) [2018403]
- dm-writecache: use bvec_kmap_local instead of bvec_kmap_irq (Ming Lei) [2018403]
- rbd: use memzero_bvec (Ming Lei) [2018403]
- block: use memzero_page in zero_fill_bio (Ming Lei) [2018403]
- bvec: add memcpy_{from,to}_bvec and memzero_bvec helper (Ming Lei) [2018403]
- bvec: add a bvec_kmap_local helper (Ming Lei) [2018403]
- bvec: fix the include guards for bvec.h (Ming Lei) [2018403]
- MIPS: don't include <linux/genhd.h> in <asm/mach-rc32434/rb.h> (Ming Lei) [2018403]
- ioprio: move user space relevant ioprio bits to UAPI includes (Ming Lei) [2018403]
- Revert "virtio-blk: Add validation for block size in config space" (Ming Lei) [2018403]
- virtio-blk: remove unneeded "likely" statements (Ming Lei) [2018403]
- Revert "blk-mq: avoid to iterate over stale request" (Ming Lei) [2018403]
- Revert "block: return ELEVATOR_DISCARD_MERGE if possible" (Ming Lei) [2018403]

* Thu Dec 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-33.el9]
- s390/kexec: handle R_390_PLT32DBL rela in arch_kexec_apply_relocations_add() (Philipp Rudo) [2023155]
- s390/kexec_file: fix error handling when applying relocations (Philipp Rudo) [2023155]
- s390/kexec_file: print some more error messages (Philipp Rudo) [2023155]
- udp: Validate checksum in udp_read_sock() (Xin Long) [2026952]
- net: udp: correct the document for udp_mem (Xin Long) [2026952]
- net: udp6: replace __UDP_INC_STATS() with __UDP6_INC_STATS() (Xin Long) [2026952]
- net: prefer socket bound to interface when not in VRF (Xin Long) [2026952]
- udp6: allow SO_MARK ctrl msg to affect routing (Xin Long) [2026952]
- net: udp: annotate data race around udp_sk(sk)->corkflag (Xin Long) [2026952]
- net/ipv4/udp_tunnel_core.c: remove superfluous header files from udp_tunnel_core.c (Xin Long) [2026952]
- udp_tunnel: Fix udp_tunnel_nic work-queue type (Xin Long) [2026952]
- selftests: add a test case for mirred egress to ingress (Hangbin Liu) [2025461]
- selftests/net: udpgso_bench_rx: fix port argument (Hangbin Liu) [2025461]
- selftests: net: test_vxlan_under_vrf: fix HV connectivity test (Hangbin Liu) [2025461]
- selftests: net: tls: remove unused variable and code (Hangbin Liu) [2025461]
- selftests/net: Fix reuseport_bpf_numa by skipping unavailable nodes (Hangbin Liu) [2025461]
- selftests: net: switch to socat in the GSO GRE test (Hangbin Liu) [2025461]
- selftests: net: properly support IPv6 in GSO GRE test (Hangbin Liu) [2025461]
- kselftests/net: add missed vrf_strict_mode_test.sh test to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed setup_loopback.sh/setup_veth.sh to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed icmp.sh test to Makefile (Hangbin Liu) [2025461]
- selftests: udp: test for passing SO_MARK as cmsg (Hangbin Liu) [2025461]
- selftests/net: update .gitignore with newly added tests (Hangbin Liu) [2025461]
- selftests: net: bridge: update IGMP/MLD membership interval value (Hangbin Liu) [2025461]
- selftests: lib: forwarding: allow tests to not require mz and jq (Hangbin Liu) [2025461]
- fcnal-test: kill hanging ping/nettest binaries on cleanup (Hangbin Liu) [2025461]
- selftests: net/fcnal: Test --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: nettest: Add --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE hierarchical tests (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE flat tests (Hangbin Liu) [2025461]
- testing: selftests: tc_common: Add tc_check_at_least_x_packets() (Hangbin Liu) [2025461]
- testing: selftests: forwarding.config.sample: Add tc flag (Hangbin Liu) [2025461]
- selftests: net: fib_nexthops: Wait before checking reported idle time (Hangbin Liu) [2025461]
- selftest: net: fix typo in altname test (Hangbin Liu) [2025461]
- selftests: add simple GSO GRE test (Hangbin Liu) [2025461]
- selftests/net: allow GRO coalesce test on veth (Hangbin Liu) [2025461]
- selftests/net: Use kselftest skip code for skipped tests (Hangbin Liu) [2025461]
- tools/net: Use bitwise instead of arithmetic operator for flags (Hangbin Liu) [2025461]
- selftests: vrf: Add test for SNAT over VRF (Hangbin Liu) [2025461]
- selftests/net: GRO coalesce test (Hangbin Liu) [2025461]
- selftests/net: remove min gso test in packet_snd (Hangbin Liu) [2025461]
- tipc: fix size validations for the MSG_CRYPTO type (Xin Long) [2020513] {CVE-2021-43267}
- redhat/configs: enable CONFIG_RD_ZSTD for rhel (Tao Liu) [2020132]
- powerpc/security: Use a mutex for interrupt exit code patching (Steve Best) [2019202]
- EDAC/mce_amd: Do not load edac_mce_amd module on guests (Aristeu Rozanski) [2000778]

* Thu Dec 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-32.el9]
- redhat: configs: explicitly unset CONFIG_DAMON (Rafael Aquini) [2023396]
- mm/memory_hotplug: restrict CONFIG_MEMORY_HOTPLUG to 64 bit (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_MEMORY_HOTPLUG_SPARSE (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_X86_64_ACPI_NUMA dependency from CONFIG_MEMORY_HOTPLUG (Rafael Aquini) [2023396]
- memory-hotplug.rst: document the "auto-movable" online policy (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix wrong /sys/module/memory_hotplug/parameters/ path (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix two instances of "movablecore" that should be "movable_node" (Rafael Aquini) [2023396]
- selftest/vm: fix ksm selftest to run with different NUMA topologies (Rafael Aquini) [2023396]
- mm/vmalloc: introduce alloc_pages_bulk_array_mempolicy to accelerate memory allocation (Rafael Aquini) [2023396]
- memcg: unify memcg stat flushing (Rafael Aquini) [2023396]
- memcg: flush stats only if updated (Rafael Aquini) [2023396]
- mm/swapfile: fix an integer overflow in swap_show() (Rafael Aquini) [2023396]
- mm/gup: further simplify __gup_device_huge() (Rafael Aquini) [2023396]
- kasan: test: add memcpy test that avoids out-of-bounds write (Rafael Aquini) [2023396]
- tools/testing/selftests/vm/split_huge_page_test.c: fix application of sizeof to pointer (Rafael Aquini) [2023396]
- mm/damon/core-test: fix wrong expectations for 'damon_split_regions_of()' (Rafael Aquini) [2023396]
- mm: khugepaged: skip huge page collapse for special files (Rafael Aquini) [2023396]
- mm, thp: bail out early in collapse_file for writeback page (Rafael Aquini) [2023396]
- mm/vmalloc: fix numa spreading for large hash tables (Rafael Aquini) [2023396]
- mm/secretmem: avoid letting secretmem_users drop to zero (Rafael Aquini) [2023396]
- mm/oom_kill.c: prevent a race between process_mrelease and exit_mmap (Rafael Aquini) [2023396]
- mm: filemap: check if THP has hwpoisoned subpage for PMD page fault (Rafael Aquini) [2023396]
- mm: hwpoison: remove the unnecessary THP check (Rafael Aquini) [2023396]
- memcg: page_alloc: skip bulk allocator for __GFP_ACCOUNT (Rafael Aquini) [2023396]
- secretmem: Prevent secretmem_users from wrapping to zero (Rafael Aquini) [2023396]
- Revert "mm/secretmem: use refcount_t instead of atomic_t" (Rafael Aquini) [2023396]
- memblock: exclude MEMBLOCK_NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- Revert "memblock: exclude NOMAP regions from kmemleak" (Rafael Aquini) [2023396]
- mm/thp: decrease nr_thps in file's mapping on THP split (Rafael Aquini) [2023396]
- mm/secretmem: fix NULL page->mapping dereference in page_is_secretmem() (Rafael Aquini) [2023396]
- mm, slub: fix incorrect memcg slab count for bulk free (Rafael Aquini) [2023396]
- mm, slub: fix potential use-after-free in slab_debugfs_fops (Rafael Aquini) [2023396]
- mm, slub: fix potential memoryleak in kmem_cache_open() (Rafael Aquini) [2023396]
- mm, slub: fix mismatch between reconstructed freelist depth and cnt (Rafael Aquini) [2023396]
- mm, slub: fix two bugs in slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING | MPOL_LOCAL in mbind() (Rafael Aquini) [2023396]
- memblock: check memory total_size (Rafael Aquini) [2023396]
- mm/migrate: fix CPUHP state to update node demotion order (Rafael Aquini) [2023396]
- mm/migrate: add CPU hotplug to demotion #ifdef (Rafael Aquini) [2023396]
- mm/migrate: optimize hotplug-time demotion order updates (Rafael Aquini) [2023396]
- userfaultfd: fix a race between writeprotect and exit_mmap() (Rafael Aquini) [2023396]
- mm/userfaultfd: selftests: fix memory corruption with thp enabled (Rafael Aquini) [2023396]
- memblock: exclude NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- misc: fastrpc: Add missing lock before accessing find_vma() (Rafael Aquini) [2023396]
- mm: fix uninitialized use in overcommit_policy_handler (Rafael Aquini) [2023396]
- mm/memory_failure: fix the missing pte_unmap() call (Rafael Aquini) [2023396]
- kasan: always respect CONFIG_KASAN_STACK (Rafael Aquini) [2023396]
- mm/debug: sync up latest migrate_reason to migrate_reason_names (Rafael Aquini) [2023396]
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN (Rafael Aquini) [2023396]
- mm: fs: invalidate bh_lrus for only cold path (Rafael Aquini) [2023396]
- mm/shmem.c: fix judgment error in shmem_is_huge() (Rafael Aquini) [2023396]
- mm/damon: don't use strnlen() with known-bogus source length (Rafael Aquini) [2023396]
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS (Rafael Aquini) [2023396]
- mm, hwpoison: add is_free_buddy_page() in HWPoisonHandlable() (Rafael Aquini) [2023396]
- memcg: flush lruvec stats in the refault (Rafael Aquini) [2023396]
- netfilter: nf_tables: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Fully initialize invalidate_lock, amend lock class later (Rafael Aquini) [2023396]
- tools/bootconfig: Define memblock_free_ptr() to fix build error (Rafael Aquini) [2023396]
- memblock: introduce saner 'memblock_free_ptr()' interface (Rafael Aquini) [2023396]
- bpf: Add oversize check before call kvcalloc() (Rafael Aquini) [2023396]
- netfilter: ipset: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- bpf, mm: Fix lockdep warning triggered by stack_map_get_build_id_offset() (Rafael Aquini) [2023396]
- tools headers UAPI: Sync files changed by new process_mrelease syscall and the removal of some compat entry points (Rafael Aquini) [2023396]
- arm64: kdump: Skip kmemleak scan reserved memory for kdump (Rafael Aquini) [2023396]
- mm/mempolicy: fix a race between offset_il_node and mpol_rebind_task (Rafael Aquini) [2023396]
- mm/kmemleak: allow __GFP_NOLOCKDEP passed to kmemleak's gfp (Rafael Aquini) [2023396]
- mmap_lock: change trace and locking order (Rafael Aquini) [2023396]
- mm/page_alloc.c: avoid accessing uninitialized pcp page migratetype (Rafael Aquini) [2023396]
- mm,vmscan: fix divide by zero in get_scan_count (Rafael Aquini) [2023396]
- mm/hugetlb: initialize hugetlb_usage in mm_init (Rafael Aquini) [2023396]
- mm/hmm: bypass devmap pte when all pfn requested flags are fulfilled (Rafael Aquini) [2023396]
- arch: remove compat_alloc_user_space (Rafael Aquini) [2023396]
- compat: remove some compat entry points (Rafael Aquini) [2023396]
- mm: simplify compat numa syscalls (Rafael Aquini) [2023396]
- mm: simplify compat_sys_move_pages (Rafael Aquini) [2023396]
- kexec: avoid compat_alloc_user_space (Rafael Aquini) [2023396]
- kexec: move locking into do_kexec_load (Rafael Aquini) [2023396]
- mm: migrate: change to use bool type for 'page_was_mapped' (Rafael Aquini) [2023396]
- mm: migrate: fix the incorrect function name in comments (Rafael Aquini) [2023396]
- mm: migrate: introduce a local variable to get the number of pages (Rafael Aquini) [2023396]
- mm/vmstat: protect per cpu variables with preempt disable on RT (Rafael Aquini) [2023396]
- mm/workingset: correct kernel-doc notations (Rafael Aquini) [2023396]
- percpu: remove export of pcpu_base_addr (Rafael Aquini) [2023396]
- MAINTAINERS: update for DAMON (Rafael Aquini) [2023396]
- mm/damon: add user space selftests (Rafael Aquini) [2023396]
- mm/damon: add kunit tests (Rafael Aquini) [2023396]
- Documentation: add documents for DAMON (Rafael Aquini) [2023396]
- mm/damon/dbgfs: support multiple contexts (Rafael Aquini) [2023396]
- mm/damon/dbgfs: export kdamond pid to the user space (Rafael Aquini) [2023396]
- mm/damon: implement a debugfs-based user space interface (Rafael Aquini) [2023396]
- mm/damon: add a tracepoint (Rafael Aquini) [2023396]
- mm/damon: implement primitives for the virtual memory address spaces (Rafael Aquini) [2023396]
- mm/idle_page_tracking: make PG_idle reusable (Rafael Aquini) [2023396]
- mm/damon: adaptively adjust regions (Rafael Aquini) [2023396]
- mm/damon/core: implement region-based sampling (Rafael Aquini) [2023396]
- mm: introduce Data Access MONitor (DAMON) (Rafael Aquini) [2023396]
- kfence: test: fail fast if disabled at boot (Rafael Aquini) [2023396]
- kfence: show cpu and timestamp in alloc/free info (Rafael Aquini) [2023396]
- mm/secretmem: use refcount_t instead of atomic_t (Rafael Aquini) [2023396]
- mm: introduce PAGEFLAGS_MASK to replace ((1UL << NR_PAGEFLAGS) - 1) (Rafael Aquini) [2023396]
- mm: in_irq() cleanup (Rafael Aquini) [2023396]
- highmem: don't disable preemption on RT in kmap_atomic() (Rafael Aquini) [2023396]
- mm/early_ioremap.c: remove redundant early_ioremap_shutdown() (Rafael Aquini) [2023396]
- mm: don't allow executable ioremap mappings (Rafael Aquini) [2023396]
- mm: move ioremap_page_range to vmalloc.c (Rafael Aquini) [2023396]
- mm: remove redundant compound_head() calling (Rafael Aquini) [2023396]
- mm/memory_hotplug: use helper zone_is_zone_device() to simplify the code (Rafael Aquini) [2023396]
- mm/memory_hotplug: improved dynamic memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- mm/memory_hotplug: memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- virtio-mem: use a single dynamic memory group for a single virtio-mem device (Rafael Aquini) [2023396]
- dax/kmem: use a single static memory group for a single probed unit (Rafael Aquini) [2023396]
- ACPI: memhotplug: use a single static memory group for a single memory device (Rafael Aquini) [2023396]
- mm/memory_hotplug: track present pages in memory groups (Rafael Aquini) [2023396]
- drivers/base/memory: introduce "memory groups" to logically group memory blocks (Rafael Aquini) [2023396]
- mm/memory_hotplug: introduce "auto-movable" online policy (Rafael Aquini) [2023396]
- mm: track present early pages per zone (Rafael Aquini) [2023396]
- ACPI: memhotplug: memory resources cannot be enabled yet (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from remove_memory() and friends (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from arch_remove_memory() (Rafael Aquini) [2023396]
- mm/memory_hotplug: use "unsigned long" for PFN in zone_for_pfn_range() (Rafael Aquini) [2023396]
- mm: memory_hotplug: cleanup after removal of pfn_valid_within() (Rafael Aquini) [2023396]
- mm: remove pfn_valid_within() and CONFIG_HOLES_IN_ZONE (Rafael Aquini) [2023396]
- memory-hotplug.rst: complete admin-guide overhaul (Rafael Aquini) [2023396]
- memory-hotplug.rst: remove locking details from admin-guide (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for pollfd and select bits arrays" (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for file lock caches" (Rafael Aquini) [2023396]
- Revert "mm/gup: remove try_get_page(), call try_get_compound_head() directly" (Rafael Aquini) [2023396]
- binfmt: a.out: Fix bogus semicolon (Rafael Aquini) [2023396]
- mm, slub: convert kmem_cpu_slab protection to local_lock (Rafael Aquini) [2023396]
- mm, slub: use migrate_disable() on PREEMPT_RT (Rafael Aquini) [2023396]
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Rafael Aquini) [2023396]
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Rafael Aquini) [2023396]
- mm: slub: make object_map_lock a raw_spinlock_t (Rafael Aquini) [2023396]
- mm: slub: move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Rafael Aquini) [2023396]
- mm, slab: split out the cpu offline variant of flush_slab() (Rafael Aquini) [2023396]
- mm, slub: don't disable irqs in slub_cpu_dead() (Rafael Aquini) [2023396]
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Rafael Aquini) [2023396]
- mm, slub: detach whole partial list at once in unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Rafael Aquini) [2023396]
- mm, slub: move irq control into unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: call deactivate_slab() without disabling irqs (Rafael Aquini) [2023396]
- mm, slub: make locking in deactivate_slab() irq-safe (Rafael Aquini) [2023396]
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Rafael Aquini) [2023396]
- mm, slub: stop disabling irqs around get_partial() (Rafael Aquini) [2023396]
- mm, slub: check new pages with restored irqs (Rafael Aquini) [2023396]
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Rafael Aquini) [2023396]
- mm, slub: restore irqs around calling new_slab() (Rafael Aquini) [2023396]
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Rafael Aquini) [2023396]
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: simplify kmem_cache_cpu and tid setup (Rafael Aquini) [2023396]
- mm, slub: restructure new page checks in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: return slab page from get_partial() and set c->page afterwards (Rafael Aquini) [2023396]
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: extract get_partial() from new_slab_objects() (Rafael Aquini) [2023396]
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Rafael Aquini) [2023396]
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for validate_slab_cache() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for debugfs listings (Rafael Aquini) [2023396]
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/madvise: add MADV_WILLNEED to process_madvise() (Rafael Aquini) [2023396]
- mm/vmstat: remove unneeded return value (Rafael Aquini) [2023396]
- mm/vmstat: simplify the array size calculation (Rafael Aquini) [2023396]
- mm/vmstat: correct some wrong comments (Rafael Aquini) [2023396]
- mm/percpu,c: remove obsolete comments of pcpu_chunk_populated() (Rafael Aquini) [2023396]
- selftests: vm: add COW time test for KSM pages (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging time test (Rafael Aquini) [2023396]
- mm: KSM: fix data type (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging across nodes test (Rafael Aquini) [2023396]
- selftests: vm: add KSM zero page merging test (Rafael Aquini) [2023396]
- selftests: vm: add KSM unmerge test (Rafael Aquini) [2023396]
- selftests: vm: add KSM merge test (Rafael Aquini) [2023396]
- mm/migrate: correct kernel-doc notation (Rafael Aquini) [2023396]
- mm: wire up syscall process_mrelease (Rafael Aquini) [2023396]
- mm: introduce process_mrelease system call (Rafael Aquini) [2023396]
- memblock: make memblock_find_in_range method private (Rafael Aquini) [2023396]
- mm/mempolicy.c: use in_task() in mempolicy_slab_node() (Rafael Aquini) [2023396]
- mm/mempolicy: unify the create() func for bind/interleave/prefer-many policies (Rafael Aquini) [2023396]
- mm/mempolicy: advertise new MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/hugetlb: add support for mempolicy MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/memplicy: add page allocation function for MPOL_PREFERRED_MANY policy (Rafael Aquini) [2023396]
- mm/mempolicy: add MPOL_PREFERRED_MANY for multiple preferred nodes (Rafael Aquini) [2023396]
- mm/mempolicy: use readable NUMA_NO_NODE macro instead of magic number (Rafael Aquini) [2023396]
- mm: compaction: support triggering of proactive compaction by user (Rafael Aquini) [2023396]
- mm: compaction: optimize proactive compaction deferrals (Rafael Aquini) [2023396]
- mm, vmscan: guarantee drop_slab_node() termination (Rafael Aquini) [2023396]
- mm/vmscan: add 'else' to remove check_pending label (Rafael Aquini) [2023396]
- mm/vmscan: remove unneeded return value of kswapd_run() (Rafael Aquini) [2023396]
- mm/vmscan: remove misleading setting to sc->priority (Rafael Aquini) [2023396]
- mm/vmscan: remove the PageDirty check after MADV_FREE pages are page_ref_freezed (Rafael Aquini) [2023396]
- mm/vmpressure: replace vmpressure_to_css() with vmpressure_to_memcg() (Rafael Aquini) [2023396]
- mm/migrate: add sysfs interface to enable reclaim migration (Rafael Aquini) [2023396]
- mm/vmscan: never demote for memcg reclaim (Rafael Aquini) [2023396]
- mm/vmscan: Consider anonymous pages without swap (Rafael Aquini) [2023396]
- mm/vmscan: add helper for querying ability to age anonymous pages (Rafael Aquini) [2023396]
- mm/vmscan: add page demotion counter (Rafael Aquini) [2023396]
- mm/migrate: demote pages during reclaim (Rafael Aquini) [2023396]
- mm/migrate: enable returning precise migrate_pages() success count (Rafael Aquini) [2023396]
- mm/migrate: update node demotion order on hotplug events (Rafael Aquini) [2023396]
- mm/numa: automatically generate node migration order (Rafael Aquini) [2023396]
- selftests/vm/userfaultfd: wake after copy failure (Rafael Aquini) [2023396]
- userfaultfd: prevent concurrent API initialization (Rafael Aquini) [2023396]
- userfaultfd: change mmap_changing to atomic (Rafael Aquini) [2023396]
- hugetlb: fix hugetlb cgroup refcounting during vma split (Rafael Aquini) [2023396]
- hugetlb: before freeing hugetlb page set dtor to appropriate value (Rafael Aquini) [2023396]
- hugetlb: drop ref count earlier after page allocation (Rafael Aquini) [2023396]
- hugetlb: simplify prep_compound_gigantic_page ref count racing code (Rafael Aquini) [2023396]
- mm: fix panic caused by __page_handle_poison() (Rafael Aquini) [2023396]
- mm: hwpoison: dump page for unhandlable page (Rafael Aquini) [2023396]
- doc: hwpoison: correct the support for hugepage (Rafael Aquini) [2023396]
- mm: hwpoison: don't drop slab caches for offlining non-LRU page (Rafael Aquini) [2023396]
- mm/hwpoison: fix some obsolete comments (Rafael Aquini) [2023396]
- mm/hwpoison: change argument struct page **hpagep to *hpage (Rafael Aquini) [2023396]
- mm/hwpoison: fix potential pte_unmap_unlock pte error (Rafael Aquini) [2023396]
- mm/hwpoison: remove unneeded variable unmap_success (Rafael Aquini) [2023396]
- mm/page_isolation: tracing: trace all test_pages_isolated failures (Rafael Aquini) [2023396]
- mm/page_alloc.c: use in_task() (Rafael Aquini) [2023396]
- mm/page_alloc: make alloc_node_mem_map() __init rather than __ref (Rafael Aquini) [2023396]
- mm/page_alloc.c: fix 'zone_id' may be used uninitialized in this function warning (Rafael Aquini) [2023396]
- memblock: stop poisoning raw allocations (Rafael Aquini) [2023396]
- mm: introduce memmap_alloc() to unify memory map allocation (Rafael Aquini) [2023396]
- mm/page_alloc: always initialize memory map for the holes (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in kasan_rcu_uaf (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in copy_user_test (Rafael Aquini) [2023396]
- kasan: test: clean up ksize_uaf (Rafael Aquini) [2023396]
- kasan: test: only do kmalloc_uaf_memset for generic mode (Rafael Aquini) [2023396]
- kasan: test: disable kmalloc_memmove_invalid_size for HW_TAGS (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory via memset (Rafael Aquini) [2023396]
- kasan: test: avoid writing invalid memory (Rafael Aquini) [2023396]
- kasan: test: rework kmalloc_oob_right (Rafael Aquini) [2023396]
- mm/kasan: move kasan.fault to mm/kasan/report.c (Rafael Aquini) [2023396]
- mm/vmalloc: fix wrong behavior in vread (Rafael Aquini) [2023396]
- lib/test_vmalloc.c: add a new 'nr_pages' parameter (Rafael Aquini) [2023396]
- mm/vmalloc: remove gfpflags_allow_blocking() check (Rafael Aquini) [2023396]
- mm/vmalloc: use batched page requests in bulk-allocator (Rafael Aquini) [2023396]
- mm/sparse: clarify pgdat_to_phys (Rafael Aquini) [2023396]
- include/linux/mmzone.h: avoid a warning in sparse memory support (Rafael Aquini) [2023396]
- mm/sparse: set SECTION_NID_SHIFT to 6 (Rafael Aquini) [2023396]
- mm: sparse: remove __section_nr() function (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to find_memory_block (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to section_mark_present (Rafael Aquini) [2023396]
- mm/bootmem_info.c: mark __init on register_page_bootmem_info_section (Rafael Aquini) [2023396]
- mm/mremap: fix memory account on do_munmap() failure (Rafael Aquini) [2023396]
- remap_file_pages: Use vma_lookup() instead of find_vma() (Rafael Aquini) [2023396]
- mm/pagemap: add mmap_assert_locked() annotations to find_vma*() (Rafael Aquini) [2023396]
- mm: change fault_in_pages_* to have an unsigned size parameter (Rafael Aquini) [2023396]
- mm,do_huge_pmd_numa_page: remove unnecessary TLB flushing code (Rafael Aquini) [2023396]
- mm: remove flush_kernel_dcache_page (Rafael Aquini) [2023396]
- scatterlist: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: mmc_spi: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: JZ4740: remove the flush_kernel_dcache_page call in jz4740_mmc_read_data (Rafael Aquini) [2023396]
- selftests: Fix spelling mistake "cann't" -> "cannot" (Rafael Aquini) [2023396]
- selftests/vm: use kselftest skip code for skipped tests (Rafael Aquini) [2023396]
- memcg: make memcg->event_list_lock irqsafe (Rafael Aquini) [2023396]
- memcg: fix up drain_local_stock comment (Rafael Aquini) [2023396]
- mm, memcg: save some atomic ops when flush is already true (Rafael Aquini) [2023396]
- mm, memcg: remove unused functions (Rafael Aquini) [2023396]
- mm: memcontrol: set the correct memcg swappiness restriction (Rafael Aquini) [2023396]
- memcg: replace in_interrupt() by !in_task() in active_memcg() (Rafael Aquini) [2023396]
- memcg: cleanup racy sum avoidance code (Rafael Aquini) [2023396]
- memcg: enable accounting for ldt_struct objects (Rafael Aquini) [2023396]
- memcg: enable accounting for posix_timers_cache slab (Rafael Aquini) [2023396]
- memcg: enable accounting for signals (Rafael Aquini) [2023396]
- memcg: enable accounting for new namesapces and struct nsproxy (Rafael Aquini) [2023396]
- memcg: enable accounting for fasync_cache (Rafael Aquini) [2023396]
- memcg: enable accounting for file lock caches (Rafael Aquini) [2023396]
- memcg: enable accounting for pollfd and select bits arrays (Rafael Aquini) [2023396]
- memcg: enable accounting for mnt_cache entries (Rafael Aquini) [2023396]
- memcg: charge fs_context and legacy_fs_context (Rafael Aquini) [2023396]
- memcg: infrastructure to flush memcg stats (Rafael Aquini) [2023396]
- memcg: switch lruvec stats to rstat (Rafael Aquini) [2023396]
- mm, memcg: inline swap-related functions to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: inline mem_cgroup_{charge/uncharge} to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: add mem_cgroup_disabled checks in vmpressure and swap-related functions (Rafael Aquini) [2023396]
- huge tmpfs: decide stat.st_blksize by shmem_is_huge() (Rafael Aquini) [2023396]
- huge tmpfs: shmem_is_huge(vma, inode, index) (Rafael Aquini) [2023396]
- huge tmpfs: SGP_NOALLOC to stop collapse_file() on race (Rafael Aquini) [2023396]
- huge tmpfs: move shmem_huge_enabled() upwards (Rafael Aquini) [2023396]
- huge tmpfs: revert shmem's use of transhuge_vma_enabled() (Rafael Aquini) [2023396]
- huge tmpfs: remove shrinklist addition from shmem_setattr() (Rafael Aquini) [2023396]
- huge tmpfs: fix split_huge_page() after FALLOC_FL_KEEP_SIZE (Rafael Aquini) [2023396]
- huge tmpfs: fix fallocate(vanilla) advance over huge pages (Rafael Aquini) [2023396]
- shmem: shmem_writepage() split unlikely i915 THP (Rafael Aquini) [2023396]
- shmem: include header file to declare swap_info (Rafael Aquini) [2023396]
- shmem: remove unneeded function forward declaration (Rafael Aquini) [2023396]
- shmem: remove unneeded header file (Rafael Aquini) [2023396]
- shmem: remove unneeded variable ret (Rafael Aquini) [2023396]
- shmem: use raw_spinlock_t for ->stat_lock (Rafael Aquini) [2023396]
- mm/gup: remove try_get_page(), call try_get_compound_head() directly (Rafael Aquini) [2023396]
- mm/gup: small refactoring: simplify try_grab_page() (Rafael Aquini) [2023396]
- mm/gup: documentation corrections for gup/pup (Rafael Aquini) [2023396]
- mm: gup: use helper PAGE_ALIGNED in populate_vma_page_range() (Rafael Aquini) [2023396]
- mm: gup: fix potential pgmap refcnt leak in __gup_device_huge() (Rafael Aquini) [2023396]
- mm: gup: remove useless BUG_ON in __get_user_pages() (Rafael Aquini) [2023396]
- mm: gup: remove unneed local variable orig_refs (Rafael Aquini) [2023396]
- mm: gup: remove set but unused local variable major (Rafael Aquini) [2023396]
- mm: delete unused get_kernel_page() (Rafael Aquini) [2023396]
- include/linux/buffer_head.h: fix boolreturn.cocci warnings (Rafael Aquini) [2023396]
- fs, mm: fix race in unlinking swapfile (Rafael Aquini) [2023396]
- fs: inode: count invalidated shadow pages in pginodesteal (Rafael Aquini) [2023396]
- fs: drop_caches: fix skipping over shadow cache inodes (Rafael Aquini) [2023396]
- fs: update documentation of get_write_access() and friends (Rafael Aquini) [2023396]
- filesystems/locking: fix Malformed table warning (Rafael Aquini) [2023396]
- writeback: memcg: simplify cgroup_writeback_by_id (Rafael Aquini) [2023396]
- writeback: use READ_ONCE for unlocked reads of writeback stats (Rafael Aquini) [2023396]
- writeback: rename domain_update_bandwidth() (Rafael Aquini) [2023396]
- writeback: fix bandwidth estimate for spiky workload (Rafael Aquini) [2023396]
- writeback: reliably update bandwidth estimation (Rafael Aquini) [2023396]
- writeback: track number of inodes under writeback (Rafael Aquini) [2023396]
- writeback: make the laptop_mode prototypes available unconditionally (Rafael Aquini) [2023396]
- mm: remove irqsave/restore locking from contexts with irqs enabled (Rafael Aquini) [2023396]
- mm: add kernel_misc_reclaimable in show_free_areas (Rafael Aquini) [2023396]
- mm: report a more useful address for reclaim acquisition (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: fix corrupted page flag (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: remove unused code (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PGD and P4D modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PUD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PMD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PTE modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in migration and thp tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in soft_dirty and swap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in protnone and devmap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in leaf and savewrite tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in basic tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: introduce struct pgtable_debug_args (Rafael Aquini) [2023396]
- mm: ignore MAP_DENYWRITE in ksys_mmap_pgoff() (Rafael Aquini) [2023396]
- mm: remove VM_DENYWRITE (Rafael Aquini) [2023396]
- binfmt: remove in-tree usage of MAP_DENYWRITE (Rafael Aquini) [2023396]
- kernel/fork: always deny write access to current MM exe_file (Rafael Aquini) [2023396]
- kernel/fork: factor out replacing the current MM exe_file (Rafael Aquini) [2023396]
- binfmt: don't use MAP_DENYWRITE when loading shared libraries via uselib() (Rafael Aquini) [2023396]
- ARM: 9115/1: mm/maccess: fix unaligned copy_{from,to}_kernel_nofault (Rafael Aquini) [2023396]
- net-memcg: pass in gfp_t mask to mem_cgroup_charge_skmem() (Rafael Aquini) [2023396]
- memblock: Check memory add/cap ordering (Rafael Aquini) [2023396]
- memblock: Add missing debug code to memblock_add_node() (Rafael Aquini) [2023396]
- mm: don't allow oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Add kvrealloc() (Rafael Aquini) [2023396]
- mm: hide laptop_mode_wb_timer entirely behind the BDI API (Rafael Aquini) [2023396]
- mm: Add functions to lock invalidate_lock for two mappings (Rafael Aquini) [2023396]
- mm: Protect operations adding pages to page cache with invalidate_lock (Rafael Aquini) [2023396]
- mm: Fix comments mentioning i_mutex (Rafael Aquini) [2023396]
- exit/bdflush: Remove the deprecated bdflush system call (Rafael Aquini) [2023396]

* Tue Dec 14 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-31.el9]
- Disable CONFIG_DEBUG_PREEMPT to restore performance (Phil Auld) [2030877]
- tcp: seq_file: Avoid skipping sk during tcp_seek_last_pos (Paolo Abeni) [2028279]
- tcp: fix tp->undo_retrans accounting in tcp_sacktag_one() (Paolo Abeni) [2028279]
- tcp: md5: Fix overlap between vrf and non-vrf keys (Paolo Abeni) [2028279]
- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb() (Paolo Abeni) [2028279]
- tcp: Fix uninitialized access in skb frags array for Rx 0cp. (Paolo Abeni) [2028279]
- tcp_cubic: fix spurious Hystart ACK train detections for not-cwnd-limited flows (Paolo Abeni) [2028279]
- Revert "ibmvnic: check failover_pending in login response" (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- kernfs: don't create a negative dentry if inactive node exists (Ian Kent) [2004858]
- kernfs: also call kernfs_set_rev() for positive dentry (Ian Kent) [2004858]
- kernfs: dont call d_splice_alias() under kernfs node lock (Ian Kent) [2004858]
- kernfs: use i_lock to protect concurrent inode updates (Ian Kent) [2004858]
- kernfs: switch kernfs to use an rwsem (Ian Kent) [2004858]
- kernfs: use VFS negative dentry caching (Ian Kent) [2004858]
- kernfs: add a revision to identify directory node changes (Ian Kent) [2004858]
- drm/hyperv: Fix double mouse pointers (Vitaly Kuznetsov) [1999697]
- Revert "watchdog: iTCO_wdt: Account for rebooting on second timeout" (Frantisek Sumsal) [2020918]
- watchdog: iTCO_wdt: Fix detection of SMI-off case (Frantisek Sumsal) [2020918]
- redhat/kernel.spec.template: enable dependencies generation (Eugene Syromiatnikov) [1975927]
- redhat: configs: Update configs for vmware (Kamal Heib) [1991676 2009344]
- redhat/configs: Enable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1992253]

* Mon Dec 13 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-30.el9]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix when shadow_root_level=5 && guest root_level<4 (Vitaly Kuznetsov) [2009338]
- KVM: x86: inhibit APICv when KVM_GUESTDBG_BLOCKIRQ active (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix get_attr of KVM_XEN_ATTR_TYPE_SHARED_INFO (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use rw_semaphore for APICv lock to allow vCPU parallelism (Vitaly Kuznetsov) [2009338]
- KVM: selftests: test KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: implement SGX_IOC_VEPC_REMOVE ioctl (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: extract sgx_vepc_remove_page (Vitaly Kuznetsov) [2009338]
- KVM: x86: Do not mark all registers as avail/dirty during RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Complete prefetch for trailing SPTEs for direct, legacy MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: don't set VMLOAD/VMSAVE intercepts on vCPU reset (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix mismatched fclose() after popen() (Vitaly Kuznetsov) [2009338]
- KVM: selftests: set CPUID before setting sregs in vcpu creation (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Unregister posted interrupt wakeup handler on hardware unsetup (Vitaly Kuznetsov) [2009338]
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Cache CR3 in prev_roots when PCID is disabled (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix tlb flush for tdp in kvm_invalidate_pcid() (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when toggling X86_CR4_PGE (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when X86_CR4_PCIDE 1->0 (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: kvm_faultin_pfn has to return false if pfh is returned (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant, broken remote TLB flush (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant remote TLB flush in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Take srcu lock in post_kvm_run_save() (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix another issue with string I/O VMGEXITs (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix kvm_xen_has_interrupt() sleeping in kvm_vcpu_block() (Vitaly Kuznetsov) [2009338]
- KVM: x86: switch pvclock_gtod_sync_lock to a raw spinlock (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- KVM: kvm_stat: do not show halt_wait_ns (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: go over the sev_pio_data buffer in multiple passes if needed (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: keep INS functions together (Vitaly Kuznetsov) [2009338]
- KVM: x86: remove unnecessary arguments from complete_emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: x86: split the two parts of emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: clean up kvm_sev_es_ins/outs (Vitaly Kuznetsov) [2009338]
- KVM: x86: leave vcpu->arch.pio.count alone in emulator_pio_in_out (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: rename guest_ins_data to sev_pio_data (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Flush cache on non-coherent systems before RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: MMU: Reset mmu->pkru_mask to avoid stale data (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: promptly process interrupts delivered while in guest mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: check for interrupts before deciding whether to exit the fast path (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: reduce ghcb_sa_len to 32 bits (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant handling of bus lock vmexit (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if APIC HW/SW disable static keys are non-zero on unload (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET" (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: Set guest_state_protected after VMSA update (Vitaly Kuznetsov) [2009338]
- KVM: X86: fix lazy allocation of rmaps (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix length of string I/O (Vitaly Kuznetsov) [2009338]
- kvm: fix objtool relocation warning (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Ensure all migrations are performed when test is affined (Vitaly Kuznetsov) [2009338]
- KVM: x86: Swap order of CPUID entry "index" vs. "significant flag" checks (Vitaly Kuznetsov) [2009338]
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Don't clobber XMM register when read (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fix a TSX_CTRL_CPUID_CLEAR field mask issue (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Explicitly use movq to read xmm registers (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Call ucall_init when setting up in rseq_test (Vitaly Kuznetsov) [2009338]
- KVM: Remove tlbs_dirty (Vitaly Kuznetsov) [2009338]
- KVM: X86: Synchronize the shadow pagetable before link it (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix missed remote tlb flush in rmap_write_protect() (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: don't copy virt_ext from vmcb12 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: test eax for 4K alignment for GP errata workaround (Vitaly Kuznetsov) [2009338]
- KVM: x86: selftests: test simultaneous uses of V_IRQ from L1 and L0 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore int_vector in svm_clear_vintr (Vitaly Kuznetsov) [2009338]
- kvm: x86: Add AMD PMU MSRs to msrs_to_save_all[] (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: re-evaluate emulation_required on nested VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: don't fail nested VM entry on invalid guest state if !from_vmentry (Vitaly Kuznetsov) [2009338]
- KVM: x86: VMX: synthesize invalid VM exit when emulating invalid guest state (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: refactor svm_leave_smm and smm_enter_smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: call KVM_REQ_GET_NESTED_STATE_PAGES on exit from SMM mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: reset pdptrs_from_userspace when exiting smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore the L1 host state prior to resuming nested guest on SMM exit (Vitaly Kuznetsov) [2009338]
- KVM: KVM: Use cpumask_available() to check for NULL cpumask when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: Clean up benign vcpu->cpu data races when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Create a separate dirty bitmap per slot (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Refactor help message for -s backing_src (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Change backing_src flag to -s in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Allow some commands for mirror VM (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Update svm_vm_copy_asid_from for SEV-ES (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Fix nested bus lock VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Identify vCPU0 by its vcpu_idx instead of its vCPUs array entry (Vitaly Kuznetsov) [2009338]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor (Vitaly Kuznetsov) [2009338]
- kvm: fix wrong exception emulation in check_rdtsc (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Pin guest memory for write for RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: SVM: fix missing sev_decommission in sev_receive_start (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Acquire vcpu mutex when updating VMSA (Vitaly Kuznetsov) [2009338]
- KVM: do not shrink halt_poll_ns below grow_start (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: fix comments of handle_vmon() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Handle SRCU initialization failure during page track init (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove defunct "nr_active_uret_msrs" field (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Align SMCCC call with the spec in steal_time (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Fix check for !POLLIN in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clear KVM's cached guest CR3 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Mark all registers as avail/dirty at vCPU creation (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add a test for KVM_RUN+rseq to detect task migration bugs (Vitaly Kuznetsov) [2009338]
- tools: Move x86 syscall number fallbacks to .../uapi/ (Vitaly Kuznetsov) [2009338]
- KVM: rseq: Update rseq when processing NOTIFY_RESUME on xfer to KVM guest (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix get_run_delay() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests: kvm: move get_run_delay() into lib/test_util (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_trans_hugepagesz() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_warnings_count() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- tools: rename bitmap_alloc() to bitmap_zalloc() (Vitaly Kuznetsov) [2009338]
- KVM: Drop unused kvm_dirty_gfn_invalid() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Update vCPU's hv_clock before back to guest when tsc_offset is adjusted (Vitaly Kuznetsov) [2009338]
- KVM: MMU: mark role_regs and role accessors as maybe unused (Vitaly Kuznetsov) [2009338]
- x86/kvm: Don't enable IRQ when IRQ enabled in kvm_wait (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add VM stat for remote tlb flush requests (Vitaly Kuznetsov) [2009338]
- KVM: Remove unnecessary export of kvm_{inc,dec}_notifier_count() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Move lpage_disallowed_link further "down" in kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Relocate kvm_mmu_page.tdp_mmu_page for better cache locality (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: mmu: Add guest physical address check in translate_gpa()" (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove unused field mmio_cached in struct kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase KVM_SOFT_MAX_VCPUS to 710 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase MAX_VCPUS to 1024 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Set KVM_MAX_VCPU_ID to 4*KVM_MAX_VCPUS (Vitaly Kuznetsov) [2009338]
- KVM: VMX: avoid running vmx_handle_exit_irqoff in case of emulation (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Don't freak out if pml5_root is NULL on 4-level host (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Add 5-level page table support for SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Support shadowing NPT when 5-level paging is enabled in host (Vitaly Kuznetsov) [2009338]
- KVM: x86: Allow CPU to force vendor-specific TDP level (Vitaly Kuznetsov) [2009338]
- KVM: x86: clamp host mapping level to max_level in kvm_mmu_max_mapping_level (Vitaly Kuznetsov) [2009338]
- KVM: x86: implement KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- KVM: SVM: split svm_handle_invalid_exit (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop 'shared' param from tdp_mmu_link_page() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Add detailed page size stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Avoid collision with !PRESENT SPTEs in TDP MMU lpage stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove redundant spte present check in mmu_set_spte (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt polling related histogram stats (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt_wait_ns stats for all architectures (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add checks for histogram stats bucket_size field (Vitaly Kuznetsov) [2009338]
- KVM: stats: Update doc for histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: stats: Support linear and logarithmic histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: SVM: AVIC: drop unsupported AVIC base relocation code (Vitaly Kuznetsov) [2009338]
- KVM: SVM: call avic_vcpu_load/avic_vcpu_put when enabling/disabling AVIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: move check for kvm_vcpu_apicv_active outside of avic_vcpu_{put|load} (Vitaly Kuznetsov) [2009338]
- KVM: SVM: avoid refreshing avic if its state didn't change (Vitaly Kuznetsov) [2009338]
- KVM: SVM: remove svm_toggle_avic_for_irq_window (Vitaly Kuznetsov) [2009338]
- KVM: x86: hyper-v: Deactivate APICv only when AutoEOI feature is in use (Vitaly Kuznetsov) [2009338]
- KVM: SVM: add warning for mistmatch between AVIC vcpu state and AVIC inhibition (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: fix race in kvm_request_apicv_update on SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86: don't disable APICv memslot when inhibited (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow APICv memslot to be enabled but invisible (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow kvm_faultin_pfn to return page fault handling code (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: rename try_async_pf to kvm_faultin_pfn (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: bump mmu notifier count in kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: add comment explaining arguments to kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fix parameters to kvm_flush_remote_tlbs_with_address (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86/mmu: Allow zap gfn range to operate under the mmu read lock" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce mmu_rmaps_stat per-vm debugfs file (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce kvm_mmu_slot_lpages() helpers (Vitaly Kuznetsov) [2009338]
- KVM: Allow to have arch-specific per-vm debugfs files (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested VM-Enter (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clean up redundant ROL16(val, n) macro definition (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move declaration of kvm_spurious_fault() to x86.h (Vitaly Kuznetsov) [2009338]
- KVM: x86: Kill off __ex() and __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Hide VMCS control calculators in vmx.c (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Drop caching of KVM's desired sec exec controls for vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Pull KVM L0's desired controls directly from vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: stats: remove dead stores (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Reset DR6 only when KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Set host DR6 only on VMX and for KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Remove unneeded KVM_DEBUGREG_RELOAD (Vitaly Kuznetsov) [2009338]
- x86: Fix typo s/ECLR/ELCR/ for the PIC register (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Move vcpu_args_set into perf_test_util (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Support multiple slots in dirty_log_perf_test (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename __gfn_to_rmap to gfn_to_rmap (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot for rmap_add and rmap_recycle (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot in tdp_mmu_map_handle_target_level (Vitaly Kuznetsov) [2009338]
- KVM: Cache the last used slot index per vCPU (Vitaly Kuznetsov) [2009338]
- KVM: Move last_used_slot logic out of search_memslots (Vitaly Kuznetsov) [2009338]
- KVM: xen: do not use struct gfn_to_hva_cache (Vitaly Kuznetsov) [2009338]
- KVM: x86/pmu: Introduce pmc->is_paused to reduce the call time of perf interfaces (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize zapping rmap (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize pte_list_desc with per-array counter (Vitaly Kuznetsov) [2009338]
- KVM: X86: MMU: Tune PTE_LIST_EXT to be bigger (Vitaly Kuznetsov) [2009338]
- KVM: const-ify all relevant uses of struct kvm_memory_slot (Vitaly Kuznetsov) [2009338]
- KVM: Don't take mmu_lock for range invalidation unless necessary (Vitaly Kuznetsov) [2009338]
- KVM: Block memslot updates across range_start() and range_end() (Vitaly Kuznetsov) [2009338]
- KVM: nSVM: remove useless kvm_clear_*_queue (Vitaly Kuznetsov) [2009338]
- KVM: x86: Preserve guest's CR0.CD/NW on INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant clearing of vcpu->arch.hflags at INIT/RESET (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Emulate #INIT in response to triple fault shutdown (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Move RESET-only VMWRITE sequences to init_vmcs() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant write to set vCPU as active at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Smush x2APIC MSR bitmap adjustments into single function (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove unnecessary initialization of msr_bitmap_mode (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't redo x2APIC MSR bitmaps when userspace filter is changed (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Remove obsolete MSR bitmap refresh at nested transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove obsolete MSR bitmap refresh at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move setting of sregs during vCPU RESET/INIT to common x86 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't _explicitly_ reconfigure user return MSRs on vCPU INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Refresh list of user return MSRs after setting guest CPUID (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip pointless MSR bitmap update when setting EFER (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Stuff save->dr6 at during VMSA sync, not at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant writes to vmcb->save.cr4 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Tweak order of cr0/cr4/efer writes at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Don't evaluate "emulation required" on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip emulation required checks during pmode/rmode transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Process CR0.PG side effects after setting CR0 assets (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Skip the permission_fault() check on MMIO if CR0.PG=0 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Pull GUEST_CR3 from the VMCS iff CR3 load exiting is disabled (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Do not clear CR3 load/store exiting bits if L1 wants 'em (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fold ept_update_paging_mode_cr0() back into vmx_set_cr0() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove direct write to vcpu->arch.cr0 during vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Invert handling of CR0.WP for EPT without unrestricted guest (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Don't bother writing vmcb->save.rip at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move EDX initialization at vCPU RESET to common code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Consolidate APIC base RESET initialization code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Stuff vcpu->arch.apic_base directly at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: x86: Set BSP bit in reset BSP vCPU's APIC base by default (Vitaly Kuznetsov) [2009338]
- KVM: x86: Don't force set BSP bit when local APIC is managed by userspace (Vitaly Kuznetsov) [2009338]
- KVM: x86: Migrate the PIT only if vcpu0 is migrated, not any BSP (Vitaly Kuznetsov) [2009338]
- KVM: x86: Remove defunct BSP "update" in local APIC reset (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if the APIC map is dirty without an in-kernel local APIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop explicit MMU reset at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove explicit MMU reset in enter_rmode() (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Fall back to KVM's hardcoded value for EDX at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Require exact CPUID.0x1 match when stuffing EDX at INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Set EDX at INIT with CPUID.0x1, Family-Model-Stepping (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Zero out GDTR.base and IDTR.base on INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Set LDTR to its architecturally defined value on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Flush the guest's TLB on INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: drop immediate APICv disablement on current vCPU (Vitaly Kuznetsov) [2009338]
- KVM: x86: enable TDP MMU by default (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fast_page_fault support for the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Make walk_shadow_page_lockless_{begin,end} interoperate with the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Fix use of enums in trace_fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename cr2_or_gpa to gpa in fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: Introduce kvm_get_kvm_safe() (Vitaly Kuznetsov) [2009338]
- x86/kvm: remove non-x86 stuff from arch/x86/kvm/ioapic.h (Vitaly Kuznetsov) [2009338]
- KVM: X86: Add per-vm stat for max rmap list size (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Return old SPTE from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Refactor shadow walk in __direct_map() to reduce indentation (Vitaly Kuznetsov) [2009338]
- KVM: x86: Hoist kvm_dirty_regs check out of sync_regs() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Mark VM as bugged if page fault returns RET_PF_INVALID (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use KVM_BUG/KVM_BUG_ON to handle bugs that are fatal to the VM (Vitaly Kuznetsov) [2009338]
- KVM: Export kvm_make_all_cpus_request() for use in marking VMs as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Add infrastructure and macro to mark VM as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Get rid of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- KVM: arm64: Use get_page() instead of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- docs: kvm: properly format code blocks and lists (Vitaly Kuznetsov) [2009338]
- docs: kvm: fix build warnings (Vitaly Kuznetsov) [2009338]

* Thu Dec 09 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-29.el9]
- posix-cpu-timers: Prevent spuriously armed 0-value itimer (Phil Auld) [2022896]
- hrtimer: Unbreak hrtimer_force_reprogram() (Phil Auld) [2022896]
- hrtimer: Use raw_cpu_ptr() in clock_was_set() (Phil Auld) [2022896]
- clocksource: Make clocksource watchdog test safe for slow-HZ systems (Phil Auld) [2022896]
- posix-cpu-timers: Recalc next expiration when timer_settime() ends up not queueing (Phil Auld) [2022896]
- posix-cpu-timers: Consolidate timer base accessor (Phil Auld) [2022896]
- posix-cpu-timers: Remove confusing return value override (Phil Auld) [2022896]
- posix-cpu-timers: Force next expiration recalc after itimer reset (Phil Auld) [2022896]
- posix-cpu-timers: Force next_expiration recalc after timer deletion (Phil Auld) [2022896]
- posix-cpu-timers: Assert task sighand is locked while starting cputime counter (Phil Auld) [2022896]
- posix-timers: Remove redundant initialization of variable ret (Phil Auld) [2022896]
- hrtimer: Avoid more SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Avoid unnecessary SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Add bases argument to clock_was_set() (Phil Auld) [2022896]
- time/timekeeping: Avoid invoking clock_was_set() twice (Phil Auld) [2022896]
- timekeeping: Distangle resume and clock-was-set events (Phil Auld) [2022896]
- timerfd: Provide timerfd_resume() (Phil Auld) [2022896]
- hrtimer: Force clock_was_set() handling for the HIGHRES=n, NOHZ=y case (Phil Auld) [2022896]
- hrtimer: Ensure timerfd notification for HIGHRES=n (Phil Auld) [2022896]
- hrtimer: Consolidate reprogramming code (Phil Auld) [2022896]
- hrtimer: Avoid double reprogramming in __hrtimer_start_range_ns() (Phil Auld) [2022896]

* Wed Dec 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-28.el9]
- rcu: Fix rcu_dynticks_curr_cpu_in_eqs() vs noinstr (Waiman Long) [2022806]
- efi: Change down_interruptible() in virt_efi_reset_system() to down_trylock() (Waiman Long) [2022806]
- Documentation: core-api/cpuhotplug: Rewrite the API section (Waiman Long) [2022806]
- docs/core-api: Modify document layout (Waiman Long) [2022806]
- futex: Avoid redundant task lookup (Waiman Long) [2022806]
- futex: Clarify comment for requeue_pi_wake_futex() (Waiman Long) [2022806]
- cgroup: Avoid compiler warnings with no subsystems (Waiman Long) [2022806]
- media/atomisp: Use lockdep instead of *mutex_is_locked() (Waiman Long) [2022806]
- debugobjects: Make them PREEMPT_RT aware (Waiman Long) [2022806]
- cgroup/cpuset: Enable event notification when partition state changes (Waiman Long) [2022806]
- cgroup: cgroup-v1: clean up kernel-doc notation (Waiman Long) [2022806]
- locking/semaphore: Add might_sleep() to down_*() family (Waiman Long) [2022806]
- static_call: Update API documentation (Waiman Long) [2022806]
- torture: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- clocksource: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- smpboot: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- rcu: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- genirq/affinity: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- cgroup: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- mm: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- thermal: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- md/raid5: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- perf/hw_breakpoint: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- perf/x86/intel: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- Documentation: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- Documentation/atomic_t: Document forward progress expectations (Waiman Long) [2022806]
- eventfd: Make signal recursion protection a task bit (Waiman Long) [2022806]
- locking/atomic: simplify non-atomic wrappers (Waiman Long) [2022806]
- cgroup/cpuset: Fix violation of cpuset locking rule (Waiman Long) [2022806]
- cgroup/cpuset: Fix a partition bug with hotplug (Waiman Long) [2022806]
- cgroup/cpuset: Miscellaneous code cleanup (Waiman Long) [2022806]
- rcu: Mark accesses to rcu_state.n_force_qs (Waiman Long) [2022806]
- rcu: Print human-readable message for schedule() in RCU reader (Waiman Long) [2022806]
- cgroup: remove cgroup_mount from comments (Waiman Long) [2022806]
- doc: Update stallwarn.rst with recent changes (Waiman Long) [2022806]
- locking/atomic: add generic arch_*() bitops (Waiman Long) [2022806]
- locking/atomic: add arch_atomic_long*() (Waiman Long) [2022806]
- locking/atomic: centralize generated headers (Waiman Long) [2022806]
- locking/atomic: remove ARCH_ATOMIC remanants (Waiman Long) [2022806]
- locking/atomic: simplify ifdef generation (Waiman Long) [2022806]
- rcu: Fix macro name CONFIG_TASKS_RCU_TRACE (Waiman Long) [2022806]
- scftorture: Avoid NULL pointer exception on early exit (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh check for reboot loops (Waiman Long) [2022806]
- torture: Add timestamps to kvm-test-1-run-qemu.sh output (Waiman Long) [2022806]
- torture: Don't use "test" command's "-a" argument (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-batch.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Consistently name "qemu*" test output files (Waiman Long) [2022806]
- torture: Use numeric taskset argument in jitter.sh (Waiman Long) [2022806]
- rcutorture: Upgrade two-CPU scenarios to four CPUs (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh apply affinity (Waiman Long) [2022806]
- torture: Don't redirect qemu-cmd comment lines (Waiman Long) [2022806]
- torture: Make kvm.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Put kvm.sh batch-creation awk script into a temp file (Waiman Long) [2022806]
- locking/rwsem: Remove an unused parameter of rwsem_wake() (Waiman Long) [2022806]
- rcu: Explain why rcu_all_qs() is a stub in preemptible TREE RCU (Waiman Long) [2022806]
- Documentation/atomic_t: Document cmpxchg() vs try_cmpxchg() (Waiman Long) [2022806]
- rcu: Use per_cpu_ptr to get the pointer of per_cpu variable (Waiman Long) [2022806]
- rcu: Remove useless "ret" update in rcu_gp_fqs_loop() (Waiman Long) [2022806]
- scftorture: Add RPC-like IPI tests (Waiman Long) [2022806]
- tools/nolibc: Implement msleep() (Waiman Long) [2022806]
- tools: include: nolibc: Fix a typo occured to occurred in the file nolibc.h (Waiman Long) [2022806]
- torture: Move parse-console.sh call to PATH-aware scripts (Waiman Long) [2022806]
- torture: Make kvm-recheck.sh skip kcsan.sum for build-only runs (Waiman Long) [2022806]
- rcu-tasks: Fix synchronize_rcu_rude() typo in comment (Waiman Long) [2022806]
- rcuscale: Console output claims too few grace periods (Waiman Long) [2022806]
- torture: Protect kvm-remote.sh directory trees from /tmp reaping (Waiman Long) [2022806]
- torture: Log more kvm-remote.sh information (Waiman Long) [2022806]
- torture: Make kvm-recheck-lock.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- torture: Make kvm-recheck-scf.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- rcu/doc: Add a quick quiz to explain further why we need smp_mb__after_unlock_lock() (Waiman Long) [2022806]
- rcu: Make rcu_gp_init() and rcu_gp_fqs_loop noinline to conserve stack (Waiman Long) [2022806]
- torture: Create KCSAN summaries for torture.sh runs (Waiman Long) [2022806]
- torture: Enable KCSAN summaries over groups of torture-test runs (Waiman Long) [2022806]
- rcu: Mark lockless ->qsmask read in rcu_check_boost_fail() (Waiman Long) [2022806]
- srcutiny: Mark read-side data races (Waiman Long) [2022806]
- locktorture: Count lock readers (Waiman Long) [2022806]
- locktorture: Mark statistics data races (Waiman Long) [2022806]
- docs: Fix a typo in Documentation/RCU/stallwarn.rst (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_special.b.need_qs data races (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_nesting data races (Waiman Long) [2022806]
- rcu-tasks: Add comments explaining task_struct strategy (Waiman Long) [2022806]
- rcu: Start timing stall repetitions after warning complete (Waiman Long) [2022806]
- rcu: Do not disable GP stall detection in rcu_cpu_stall_reset() (Waiman Long) [2022806]
- rcu/tree: Handle VM stoppage in stall detection (Waiman Long) [2022806]
- rculist: Unify documentation about missing list_empty_rcu() (Waiman Long) [2022806]
- rcu: Mark accesses in tree_stall.h (Waiman Long) [2022806]
- Documentation/RCU: Fix nested inline markup (Waiman Long) [2022806]
- rcu: Mark accesses to ->rcu_read_lock_nesting (Waiman Long) [2022806]
- Documentation/RCU: Fix emphasis markers (Waiman Long) [2022806]
- rcu: Weaken ->dynticks accesses and updates (Waiman Long) [2022806]
- rcu: Remove special bit at the bottom of the ->dynticks counter (Waiman Long) [2022806]
- rcu/nocb: Remove NOCB deferred wakeup from rcutree_dead_cpu() (Waiman Long) [2022806]
- rcu/nocb: Start moving nocb code to its own plugin file (Waiman Long) [2022806]
- rcutorture: Preempt rather than block when testing task stalls (Waiman Long) [2022806]
- rcu: Fix stall-warning deadlock due to non-release of rcu_node ->lock (Waiman Long) [2022806]
- rcu: Fix to include first blocked task in stall warning (Waiman Long) [2022806]
- torture: Make torture.sh accept --do-all and --donone (Waiman Long) [2022806]
- torture: Add clocksource-watchdog testing to torture.sh (Waiman Long) [2022806]
- refscale: Add measurement of clock readout (Waiman Long) [2022806]

* Tue Dec 07 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-27.el9]
- x86: change default to spec_store_bypass_disable=prctl spectre_v2_user=prctl (Wander Lairson Costa) [2002637]
- Enable PREEMPT_DYNAMIC for all but s390x (Phil Auld) [2019472]
- preempt: Restore preemption model selection configs (Phil Auld) [2019472]
- sched: Provide Kconfig support for default dynamic preempt mode (Phil Auld) [2019472]
- x86/sgx: Add TAINT_TECH_PREVIEW for virtual EPC (Wander Lairson Costa) [2025959]
- x86/sgx: mark tech preview (Wander Lairson Costa) [2025959]
- ipv6: When forwarding count rx stats on the orig netdev (Hangbin Liu) [2025457]
- ipv6: make exception cache less predictible (Hangbin Liu) [2025457]
- icmp: fix icmp_ext_echo_iio parsing in icmp_build_probe (Guillaume Nault) [2024572]
- net: prefer socket bound to interface when not in VRF (Guillaume Nault) [2024572]
- net: ipv4: Fix rtnexthop len when RTA_FLOW is present (Guillaume Nault) [2024572]
- nexthop: Fix memory leaks in nexthop notification chain listeners (Guillaume Nault) [2024572]
- nexthop: Fix division by zero while replacing a resilient group (Guillaume Nault) [2024572]
- ipv4: fix endianness issue in inet_rtm_getroute_build_skb() (Guillaume Nault) [2024572]
- crypto: ccp - Make use of the helper macro kthread_run() (Vladis Dronov) [1997595]
- crypto: ccp - Fix whitespace in sev_cmd_buffer_len() (Vladis Dronov) [1997595]
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd() (Vladis Dronov) [1997595] {CVE-2021-3744 CVE-2021-3764}
- net/l2tp: Fix reference count leak in l2tp_udp_recv_core (Guillaume Nault) [2023271]
- scsi: megaraid: Clean up some inconsistent indenting (Tomas Henzl) [1879402]
- scsi: megaraid: Fix Coccinelle warning (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Driver version update to 07.719.03.00-rc1 (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Add helper functions for irq_context (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Fix concurrent access to ISR between IRQ polling and real interrupt (Tomas Henzl) [1879402]
- tpm: ibmvtpm: Avoid error message when process gets signal while waiting (Štěpán Horáček) [1983089]
- char: tpm: cr50_i2c: convert to new probe interface (Štěpán Horáček) [1983089]
- char: tpm: Kconfig: remove bad i2c cr50 select (Štěpán Horáček) [1983089]

* Mon Dec 06 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-26.el9]
- redhat/configs: enable CONFIG_CEPH_FSCACHE (Jeffrey Layton) [2017798]
- ceph: add a new metric to keep track of remote object copies (Jeffrey Layton) [2017798]
- libceph, ceph: move ceph_osdc_copy_from() into cephfs code (Jeffrey Layton) [2017798]
- ceph: clean-up metrics data structures to reduce code duplication (Jeffrey Layton) [2017798]
- ceph: split 'metric' debugfs file into several files (Jeffrey Layton) [2017798]
- ceph: return the real size read when it hits EOF (Jeffrey Layton) [2017798]
- ceph: properly handle statfs on multifs setups (Jeffrey Layton) [2017798]
- ceph: shut down mount on bad mdsmap or fsmap decode (Jeffrey Layton) [2017798]
- ceph: fix mdsmap decode when there are MDS's beyond max_mds (Jeffrey Layton) [2017798]
- ceph: ignore the truncate when size won't change with Fx caps issued (Jeffrey Layton) [2017798]
- ceph: don't rely on error_string to validate blocklisted session. (Jeffrey Layton) [2017798]
- ceph: just use ci->i_version for fscache aux info (Jeffrey Layton) [2017798]
- ceph: shut down access to inode when async create fails (Jeffrey Layton) [2017798]
- ceph: refactor remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: fix auth cap handling logic in remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: drop private list from remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: don't use -ESTALE as special return code in try_get_cap_refs (Jeffrey Layton) [2017798]
- ceph: print inode numbers instead of pointer values (Jeffrey Layton) [2017798]
- ceph: enable async dirops by default (Jeffrey Layton) [2017798]
- libceph: drop ->monmap and err initialization (Jeffrey Layton) [2017798]
- ceph: convert to noop_direct_IO (Jeffrey Layton) [2017798]
- ceph: fix handling of "meta" errors (Jeffrey Layton) [2017798]
- ceph: skip existing superblocks that are blocklisted or shut down when mounting (Jeffrey Layton) [2017798]
- ceph: fix off by one bugs in unsafe_request_wait() (Jeffrey Layton) [2017798]
- ceph: fix dereference of null pointer cf (Jeffrey Layton) [2017798]
- ceph: drop the mdsc_get_session/put_session dout messages (Jeffrey Layton) [2017798]
- ceph: lockdep annotations for try_nonblocking_invalidate (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're forcibly removing the session caps (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're force umounting (Jeffrey Layton) [2017798]
- ceph: remove the capsnaps when removing caps (Jeffrey Layton) [2017798]
- ceph: request Fw caps before updating the mtime in ceph_write_iter (Jeffrey Layton) [2017798]
- ceph: reconnect to the export targets on new mdsmaps (Jeffrey Layton) [2017798]
- ceph: print more information when we can't find snaprealm (Jeffrey Layton) [2017798]
- ceph: add ceph_change_snap_realm() helper (Jeffrey Layton) [2017798]
- ceph: remove redundant initializations from mdsc and session (Jeffrey Layton) [2017798]
- ceph: cancel delayed work instead of flushing on mdsc teardown (Jeffrey Layton) [2017798]
- ceph: add a new vxattr to return auth mds for an inode (Jeffrey Layton) [2017798]
- ceph: remove some defunct forward declarations (Jeffrey Layton) [2017798]
- ceph: flush the mdlog before waiting on unsafe reqs (Jeffrey Layton) [2017798]
- ceph: flush mdlog before umounting (Jeffrey Layton) [2017798]
- ceph: make iterate_sessions a global symbol (Jeffrey Layton) [2017798]
- ceph: make ceph_create_session_msg a global symbol (Jeffrey Layton) [2017798]
- ceph: fix comment about short copies in ceph_write_end (Jeffrey Layton) [2017798]
- ceph: fix memory leak on decode error in ceph_handle_caps (Jeffrey Layton) [2017798]

* Fri Dec 03 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-25.el9]
- x86: Pin task-stack in __get_wchan() (Chris von Recklinghausen) [2022169]
- x86: Fix __get_wchan() for !STACKTRACE (Chris von Recklinghausen) [2022169]
- sched: Add wrapper for get_wchan() to keep task blocked (Chris von Recklinghausen) [2022169]
- x86: Fix get_wchan() to support the ORC unwinder (Chris von Recklinghausen) [2022169]
- proc: Use task_is_running() for wchan in /proc/$pid/stat (Chris von Recklinghausen) [2022169]
- leaking_addresses: Always print a trailing newline (Chris von Recklinghausen) [2022169]
- Revert "proc/wchan: use printk format instead of lookup_symbol_name()" (Chris von Recklinghausen) [2022169]
- sched: Fill unconditional hole induced by sched_entity (Chris von Recklinghausen) [2022169]
- powerpc/bpf: Fix write protecting JIT code (Jiri Olsa) [2023618]
- vfs: check fd has read access in kernel_read_file_from_fd() (Carlos Maiolino) [2022893]
- Disable idmapped mounts (Alexey Gladkov) [2018141]
- KVM: s390: Fix handle_sske page fault handling (Thomas Huth) [1870686]
- KVM: s390: Simplify SIGP Set Arch handling (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls when making pages secure (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm (Thomas Huth) [1870686]
- KVM: s390: pv: avoid double free of sida page (Thomas Huth) [1870686]
- KVM: s390: pv: add macros for UVC CC values (Thomas Huth) [1870686]
- s390/uv: fully validate the VMA before calling follow_page() (Thomas Huth) [1870686]
- s390/gmap: don't unconditionally call pte_unmap_unlock() in __gmap_zap() (Thomas Huth) [1870686]
- s390/gmap: validate VMA in __gmap_zap() (Thomas Huth) [1870686]
- KVM: s390: preserve deliverable_mask in __airqs_kick_single_vcpu (Thomas Huth) [1870686]
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (Thomas Huth) [1870686]
- KVM: s390: clear kicked_mask before sleeping again (Thomas Huth) [1870686]
- KVM: s390: Function documentation fixes (Thomas Huth) [1870686]
- s390/mm: fix kernel doc comments (Thomas Huth) [1870686]
- KVM: s390: generate kvm hypercall functions (Thomas Huth) [1870686]
- s390/vfio-ap: replace open coded locks for VFIO_GROUP_NOTIFY_SET_KVM notification (Thomas Huth) [1870686]
- s390/vfio-ap: r/w lock for PQAP interception handler function pointer (Thomas Huth) [1870686]
- KVM: Rename lru_slot to last_used_slot (Thomas Huth) [1870686]
- s390/uv: de-duplicate checks for Protected Host Virtualization (Thomas Huth) [1870686]
- s390/boot: disable Secure Execution in dump mode (Thomas Huth) [1870686]
- s390/boot: move uv function declarations to boot/uv.h (Thomas Huth) [1870686]
- s390/boot: move all linker symbol declarations from c to h files (Thomas Huth) [1870686]
- redhat/configs: Remove CONFIG_INFINIBAND_I40IW (Kamal Heib) [1920720]

* Wed Dec 01 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-24.el9]
- perf test: Handle fd gaps in test__dso_data_reopen (Michael Petlan) [1937209]
- perf tests vmlinux-kallsyms: Ignore hidden symbols (Michael Petlan) [1975103]
- perf script: Fix PERF_SAMPLE_WEIGHT_STRUCT support (Michael Petlan) [2009378]
- redhat/kernel.spec.template: Link perf with --export-dynamic (Michael Petlan) [2006775]
- xfs: fix I_DONTCACHE (Carlos Maiolino) [2022435]
- virtio: write back F_VERSION_1 before validate (Thomas Huth) [2008401]
- net/tls: Fix flipped sign in tls_err_abort() calls (Sabrina Dubroca) [2022006]
- net/tls: Fix flipped sign in async_wait.err assignment (Sabrina Dubroca) [2022006]
- hyper-v: Replace uuid.h with types.h (Mohammed Gamal) [2008572]
- Drivers: hv: vmbus: Remove unused code to check for subchannels (Mohammed Gamal) [2008572]
- hv: hyperv.h: Remove unused inline functions (Mohammed Gamal) [2008572]
- asm-generic/hyperv: provide cpumask_to_vpset_noself (Mohammed Gamal) [2008572]
- asm-generic/hyperv: Add missing #include of nmi.h (Mohammed Gamal) [2008572]
- x86/hyperv: Avoid erroneously sending IPI to 'self' (Mohammed Gamal) [2008572]
- x86/hyperv: remove on-stack cpumask from hv_send_ipi_mask_allbutself (Mohammed Gamal) [2008572]
- [s390] net/smc: improved fix wait on already cleared link (Mete Durlu) [1869652]
- [s390] net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work (Mete Durlu) [1869652]
- [s390] net/smc: add missing error check in smc_clc_prfx_set() (Mete Durlu) [1869652]
- cifs: enable SMB_DIRECT in RHEL9 (Ronnie Sahlberg) [1965209]
- scsi: mpt3sas: Clean up some inconsistent indenting (Tomas Henzl) [1876119]
- scsi: mpt3sas: Call cpu_relax() before calling udelay() (Tomas Henzl) [1876119]
- scsi: mpt3sas: Introduce sas_ncq_prio_supported sysfs sttribute (Tomas Henzl) [1876119]
- scsi: mpt3sas: Update driver version to 39.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Use firmware recommended queue depth (Tomas Henzl) [1876119]
- scsi: mpt3sas: Bump driver version to 38.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Add io_uring iopoll support (Tomas Henzl) [1876119]
- serial: 8250_lpss: Extract dw8250_do_set_termios() for common use (David Arcari) [1880032]
- serial: 8250_lpss: Enable DMA on Intel Elkhart Lake (David Arcari) [1880032]
- dmaengine: dw: Convert members to u32 in platform data (David Arcari) [1880032]
- dmaengine: dw: Simplify DT property parser (David Arcari) [1880032]
- dmaengine: dw: Remove error message from DT parsing code (David Arcari) [1880032]
- dmaengine: dw: Program xBAR hardware for Elkhart Lake (David Arcari) [1880032]
- vmxnet3: switch from 'pci_' to 'dma_' API (Kamal Heib) [2003297]
- vmxnet3: update to version 6 (Kamal Heib) [2003297]
- vmxnet3: increase maximum configurable mtu to 9190 (Kamal Heib) [2003297]
- vmxnet3: set correct hash type based on rss information (Kamal Heib) [2003297]
- vmxnet3: add support for ESP IPv6 RSS (Kamal Heib) [2003297]
- vmxnet3: remove power of 2 limitation on the queues (Kamal Heib) [2003297]
- vmxnet3: add support for 32 Tx/Rx queues (Kamal Heib) [2003297]
- vmxnet3: prepare for version 6 changes (Kamal Heib) [2003297]

* Mon Nov 29 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-23.el9]
- PCI/VPD: Defer VPD sizing until first access (Myron Stowe) [2021298]
- PCI/VPD: Use unaligned access helpers (Myron Stowe) [2021298]
- PCI/VPD: Clean up public VPD defines and inline functions (Myron Stowe) [2021298]
- cxgb4: Use pci_vpd_find_id_string() to find VPD ID string (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_id_string() (Myron Stowe) [2021298]
- PCI/VPD: Include post-processing in pci_vpd_find_tag() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_tag() (Myron Stowe) [2021298]
- scsi: cxlflash: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Remove unused vpd_param member ec (Myron Stowe) [2021298]
- cxgb4: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnxt: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2x: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnx2x: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2: Replace open-coded byte swapping with swab32s() (Myron Stowe) [2021298]
- bnx2: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- tg3: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- tg3: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- tg3: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- sfc: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_check_csum() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Treat invalid VPD like missing VPD capability (Myron Stowe) [2021298]
- PCI/VPD: Determine VPD size in pci_vpd_init() (Myron Stowe) [2021298]
- PCI/VPD: Embed struct pci_vpd in struct pci_dev (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.valid member (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd_ops (Myron Stowe) [2021298]
- PCI/VPD: Reorder pci_read_vpd(), pci_write_vpd() (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.flag (Myron Stowe) [2021298]
- PCI/VPD: Make pci_vpd_wait() uninterruptible (Myron Stowe) [2021298]
- PCI/VPD: Remove pci_vpd_size() old_size argument (Myron Stowe) [2021298]
- PCI/VPD: Allow access to valid parts of VPD if some is invalid (Myron Stowe) [2021298]
- PCI/VPD: Don't check Large Resource Item Names for validity (Myron Stowe) [2021298]
- PCI/VPD: Reject resource tags with invalid size (Myron Stowe) [2021298]
- PCI/VPD: Treat initial 0xff as missing EEPROM (Myron Stowe) [2021298]
- PCI/VPD: Check Resource Item Names against those valid for type (Myron Stowe) [2021298]
- PCI/VPD: Correct diagnostic for VPD read failure (Myron Stowe) [2021298]

* Fri Nov 26 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-22.el9]
- Add automotive CI jobs (Michael Hofmann)
- sched/scs: Reset the shadow stack when idle_task_exit (Phil Auld) [1992256]
- sched/fair: Null terminate buffer when updating tunable_scaling (Phil Auld) [1992256]
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq (Phil Auld) [1981743 1992256]
- cpufreq: schedutil: Destroy mutex before kobject_put() frees the memory (Phil Auld) [1992256]
- sched/idle: Make the idle timer expire in hard interrupt context (Phil Auld) [1992256]
- sched: Prevent balance_push() on remote runqueues (Phil Auld) [1992256]
- sched/fair: Mark tg_is_idle() an inline in the !CONFIG_FAIR_GROUP_SCHED case (Phil Auld) [1992256]
- sched/topology: Skip updating masks for non-online nodes (Phil Auld) [1992256]
- sched: Skip priority checks with SCHED_FLAG_KEEP_PARAMS (Phil Auld) [1992256]
- sched: Fix UCLAMP_FLAG_IDLE setting (Phil Auld) [1992256]
- cpufreq: schedutil: Use kobject release() method to free sugov_tunables (Phil Auld) [1992256]
- sched/deadline: Fix missing clock update in migrate_task_rq_dl() (Phil Auld) [1992256]
- sched/fair: Avoid a second scan of target in select_idle_cpu (Phil Auld) [1992256]
- sched/fair: Use prev instead of new target as recent_used_cpu (Phil Auld) [1992256]
- sched: Replace deprecated CPU-hotplug functions. (Phil Auld) [1992256]
- sched: Introduce dl_task_check_affinity() to check proposed affinity (Phil Auld) [1992256]
- sched: Allow task CPU affinity to be restricted on asymmetric systems (Phil Auld) [1992256]
- sched: Split the guts of sched_setaffinity() into a helper function (Phil Auld) [1992256]
- sched: Introduce task_struct::user_cpus_ptr to track requested affinity (Phil Auld) [1992256]
- sched: Reject CPU affinity changes based on task_cpu_possible_mask() (Phil Auld) [1992256]
- cpuset: Cleanup cpuset_cpus_allowed_fallback() use in select_fallback_rq() (Phil Auld) [1992256]
- cpuset: Honour task_cpu_possible_mask() in guarantee_online_cpus() (Phil Auld) [1992256]
- cpuset: Don't use the cpu_possible_mask as a last resort for cgroup v1 (Phil Auld) [1992256]
- sched: Introduce task_cpu_possible_mask() to limit fallback rq selection (Phil Auld) [1992256]
- sched: Cgroup SCHED_IDLE support (Phil Auld) [1992256]
- sched: Don't report SCHED_FLAG_SUGOV in sched_getattr() (Phil Auld) [1992256]
- sched/deadline: Fix reset_on_fork reporting of DL tasks (Phil Auld) [1992256]
- sched/numa: Fix is_core_idle() (Phil Auld) [1992256]
- sched: remove redundant on_rq status change (Phil Auld) [1992256]
- sched: Optimize housekeeping_cpumask() in for_each_cpu_and() (Phil Auld) [1992256]
- sched/sysctl: Move extern sysctl declarations to sched.h (Phil Auld) [1992256]
- sched/debug: Don't update sched_domain debug directories before sched_debug_init() (Phil Auld) [1992256]

* Thu Nov 25 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-21.el9]
- clocksource: Increase WATCHDOG_MAX_SKEW (Waiman Long) [2017164]
- x86/hpet: Use another crystalball to evaluate HPET usability (Waiman Long) [2017164]
- scsi: target: Fix the pgr/alua_support_store functions (Maurizio Lombardi) [2023439]
- redhat: fix typo and make the output more silent for dist-git sync (Herton R. Krzesinski)
- x86: ACPI: cstate: Optimize C3 entry on AMD CPUs (David Arcari) [1998526]
- scsi: lpfc: Update lpfc version to 14.0.0.3 (Dick Kennedy) [2021327]
- scsi: lpfc: Allow fabric node recovery if recovery is in progress before devloss (Dick Kennedy) [2021327]
- scsi: lpfc: Fix link down processing to address NULL pointer dereference (Dick Kennedy) [2021327]
- scsi: lpfc: Allow PLOGI retry if previous PLOGI was aborted (Dick Kennedy) [2021327]
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine (Dick Kennedy) [2021327]
- scsi: lpfc: Correct sysfs reporting of loop support after SFP status change (Dick Kennedy) [2021327]
- scsi: lpfc: Wait for successful restart of SLI3 adapter during host sg_reset (Dick Kennedy) [2021327]
- scsi: lpfc: Revert LOG_TRACE_EVENT back to LOG_INIT prior to driver_resource_setup() (Dick Kennedy) [2021327]
- x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT automatically (Prarit Bhargava) [2021200]
- ucounts: Move get_ucounts from cred_alloc_blank to key_change_session_keyring (Alexey Gladkov) [2018142]
- ucounts: Proper error handling in set_cred_ucounts (Alexey Gladkov) [2018142]
- ucounts: Pair inc_rlimit_ucounts with dec_rlimit_ucoutns in commit_creds (Alexey Gladkov) [2018142]
- ucounts: Fix signal ucount refcounting (Alexey Gladkov) [2018142]
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL (Vitaly Kuznetsov) [2016959]
- ip6_gre: Revert "ip6_gre: add validation for csum_start" (Guillaume Nault) [2014993]
- ip_gre: validate csum_start only on pull (Guillaume Nault) [2014993]
- redhat/configs: enable KEXEC_IMAGE_VERIFY_SIG for RHEL (Coiby Xu) [1994858]
- redhat/configs: enable KEXEC_SIG for aarch64 RHEL (Coiby Xu) [1994858]
- kernel.spec: add bpf_testmod.ko to kselftests/bpf (Viktor Malik) [2006318 2006319]
- netfilter: Add deprecation notices for xtables (Phil Sutter) [1945179]
- redhat: Add mark_driver_deprecated() (Phil Sutter) [1945179]

* Tue Nov 23 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-20.el9]
- powerpc/svm: Don't issue ultracalls if !mem_encrypt_active() (Herton R. Krzesinski) [2025186]

* Fri Nov 19 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-19.el9]
- net: core: don't call SIOCBRADD/DELIF for non-bridge devices (Ivan Vecera) [2008927]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2008927]
- net: bridge: fix ioctl locking (Ivan Vecera) [2008927]
- ethtool: Fix rxnfc copy to user buffer overflow (Ivan Vecera) [2008927]
- net: bonding: move ioctl handling to private ndo operation (Ivan Vecera) [2008927]
- net: bridge: move bridge ioctls out of .ndo_do_ioctl (Ivan Vecera) [2008927]
- net: socket: return changed ifreq from SIOCDEVPRIVATE (Ivan Vecera) [2008927]
- net: split out ndo_siowandev ioctl (Ivan Vecera) [2008927]
- dev_ioctl: split out ndo_eth_ioctl (Ivan Vecera) [2008927]
- dev_ioctl: pass SIOCDEVPRIVATE data separately (Ivan Vecera) [2008927]
- wan: cosa: remove dead cosa_net_ioctl() function (Ivan Vecera) [2008927]
- wan: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ppp: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- sb1000: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hippi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ip_tunnel: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- airo: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamradio: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- cxgb3: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- qeth: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- slip/plip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- net: usb: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- fddi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- eql: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- tehuti: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamachi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- appletalk: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- bonding: use siocdevprivate (Ivan Vecera) [2008927]
- tulip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- phonet: use siocdevprivate (Ivan Vecera) [2008927]
- bridge: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hostap: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- staging: wlan-ng: use siocdevprivate (Ivan Vecera) [2008927]
- staging: rtlwifi: use siocdevprivate (Ivan Vecera) [2008927]
- net: split out SIOCDEVPRIVATE handling from dev_ioctl (Ivan Vecera) [2008927]
- net: socket: rework compat_ifreq_ioctl() (Ivan Vecera) [2008927]
- net: socket: simplify dev_ifconf handling (Ivan Vecera) [2008927]
- net: socket: remove register_gifconf (Ivan Vecera) [2008927]
- net: socket: rework SIOC?IFMAP ioctls (Ivan Vecera) [2008927]
- ethtool: improve compat ioctl handling (Ivan Vecera) [2008927]
- compat: make linux/compat.h available everywhere (Ivan Vecera) [2008927]

* Thu Nov 18 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-18.el9]
- CI: Add template for baseline gcov build (c9s repos) (Michael Hofmann)
- PCI: vmd: depend on !UML (Myron Stowe) [1994932]
- PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU (Myron Stowe) [1994932]
- PCI: vmd: Assign a number to each VMD controller (Myron Stowe) [1994932]
- PCI: VMD: ACPI: Make ACPI companion lookup work for VMD bus (Myron Stowe) [1994932]
- swiotlb-xen: drop DEFAULT_NSLABS (Jerry Snitselaar) [2004348]
- swiotlb-xen: arrange to have buffer info logged (Jerry Snitselaar) [2004348]
- swiotlb-xen: drop leftover __ref (Jerry Snitselaar) [2004348]
- swiotlb-xen: limit init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: suppress certain init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: maintain slab count properly (Jerry Snitselaar) [2004348]
- swiotlb-xen: fix late init retry (Jerry Snitselaar) [2004348]
- swiotlb-xen: avoid double free (Jerry Snitselaar) [2004348]
- dma-debug: teach add_dma_entry() about DMA_ATTR_SKIP_CPU_SYNC (Jerry Snitselaar) [2004348]
- dma-debug: fix sg checks in debug_dma_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sgtable() (Jerry Snitselaar) [2004348]
- dma-debug: prevent an error message from causing runtime problems (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sg_attrs (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop "0x" prefix from PCI bus & device addresses (Jerry Snitselaar) [2004348]
- iommu: Clarify default domain Kconfig (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix a deadlock in intel_svm_drain_prq() (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix PASID leak in intel_svm_unbind_mm() (Jerry Snitselaar) [2004348]
- iommu/amd: Remove iommu_init_ga() (Jerry Snitselaar) [2004348]
- iommu/amd: Relocate GAMSup check to early_enable_iommus (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Abstract iommu_iotlb_gather access (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add present bit check in pasid entry setup helpers (Jerry Snitselaar) [2004348]
- iommu/vt-d: Use pasid_pte_is_present() helper function (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop the kernel doc annotation (Jerry Snitselaar) [2004348]
- iommu/vt-d: Allow devices to have more than 32 outstanding PRs (Jerry Snitselaar) [1921363]
- iommu/vt-d: Preset A/D bits for user space DMA usage (Jerry Snitselaar) [2004348]
- iomm/vt-d: Enable Intel IOMMU scalable mode by default (Jerry Snitselaar) [2004348]
- iommu/vt-d: Refactor Kconfig a bit (Jerry Snitselaar) [2004348]
- iommu/vt-d: Remove unnecessary oom message (Jerry Snitselaar) [2004348]
- iommu/vt-d: Update the virtual command related registers (Jerry Snitselaar) [2004348]
- iommu: Allow enabling non-strict mode dynamically (Jerry Snitselaar) [2004348]
- iommu: Merge strictness and domain type configs (Jerry Snitselaar) [2004348]
- iommu: Only log strictness for DMA domains (Jerry Snitselaar) [2004348]
- iommu: Expose DMA domain strictness via sysfs (Jerry Snitselaar) [2004348]
- iommu: Express DMA strictness via the domain type (Jerry Snitselaar) [2004348]
- iommu/vt-d: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/amd: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu: Introduce explicit type for non-strict DMA domains (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Remove non-strict quirk (Jerry Snitselaar) [2004348]
- iommu: Indicate queued flushes via gather data (Jerry Snitselaar) [2004348]
- iommu/dma: Remove redundant "!dev" checks (Jerry Snitselaar) [2004348]
- iommu/virtio: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/amd: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu: Pull IOVA cookie management into the core (Jerry Snitselaar) [2004348]
- iommu/amd: Remove stale amd_iommu_unmap_flush usage (Jerry Snitselaar) [2004348]
- iommu/amd: Use only natural aligned flushes in a VM (Jerry Snitselaar) [2004348]
- iommu/amd: Sync once for scatter-gather operations (Jerry Snitselaar) [2004348]
- iommu/amd: Tailored gather logic for AMD (Jerry Snitselaar) [2004348]
- iommu: Factor iommu_iotlb_gather_is_disjoint() out (Jerry Snitselaar) [2004348]
- iommu: Improve iommu_iotlb_gather helpers (Jerry Snitselaar) [2004348]
- iommu/amd: Do not use flush-queue when NpCache is on (Jerry Snitselaar) [2004348]
- iommu/amd: Selective flush on unmap (Jerry Snitselaar) [2004348]
- iommu/amd: Fix printing of IOMMU events when rate limiting kicks in (Jerry Snitselaar) [2004348]
- iommu/amd: Convert from atomic_t to refcount_t on pasid_state->count (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix missing unlock on error in arm_smmu_device_group() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Extract reusable function __arm_smmu_cmdq_skip_err() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_get_cmdq() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_cmdq_issue_cmd_with_sync() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Use command queue batching helpers to improve performance (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Optimize ->tlb_flush_walk() for qcom implementation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix race condition during iommu_group creation (Jerry Snitselaar) [2004348]
- iommu: Fix race condition during default domain allocation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Add clk_bulk_{prepare/unprepare} to system pm callbacks (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Remove some unneeded init in arm_smmu_cmdq_issue_cmdlist() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu-v3: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Move clflush'es from iotlb_sync_map() to map_pages() (Jerry Snitselaar) [1971978]
- iommu/vt-d: Implement map/unmap_pages() iommu_ops callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Report real pgsize bitmap to iommu core (Jerry Snitselaar) [1971978]
- iommu: Streamline iommu_iova_to_phys() (Jerry Snitselaar) [2004348]
- iommu: Remove mode argument from iommu_set_dma_strict() (Jerry Snitselaar) [2004348]
- redhat/configs: Use new iommu default dma config options (Jerry Snitselaar) [2004348]
- iommu/amd: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Enhance IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Print strict or lazy mode at init time (Jerry Snitselaar) [2004348]
- iommu: Deprecate Intel and AMD cmdline methods to enable strict mode (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Prepare PTE methods for handling multiple entries (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce map_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce unmap_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu: Add support for the map_pages() callback (Jerry Snitselaar) [1971978]
- iommu: Hook up '->unmap_pages' driver callback (Jerry Snitselaar) [1971978]
- iommu: Split 'addr_merge' argument to iommu_pgsize() into separate parts (Jerry Snitselaar) [1971978]
- iommu: Use bitmap to calculate page size in iommu_pgsize() (Jerry Snitselaar) [1971978]
- iommu: Add a map_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- iommu: Add an unmap_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- swiotlb: use depends on for DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Free tbl memory in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Emit diagnostic in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Convert io_default_tlb_mem to static allocation (Jerry Snitselaar) [2004348]
- swiotlb: add overflow checks to swiotlb_bounce (Jerry Snitselaar) [2004348]
- swiotlb: fix implicit debugfs declarations (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA pool initialization (Jerry Snitselaar) [2004348]
- redhat/configs: Add CONFIG_DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA alloc/free support (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_tbl_unmap_single (Jerry Snitselaar) [2004348]
- swiotlb: Move alloc_size to swiotlb_find_slots (Jerry Snitselaar) [2004348]
- swiotlb: Use is_swiotlb_force_bounce for swiotlb data bouncing (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_active to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_buffer to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Set dev->dma_io_tlb_mem to the swiotlb pool used (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_create_debugfs (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb init functions (Jerry Snitselaar) [2004348]
- dma-mapping: make the global coherent pool conditional (Jerry Snitselaar) [2004348]
- dma-mapping: add a dma_init_global_coherent helper (Jerry Snitselaar) [2004348]
- dma-mapping: simplify dma_init_coherent_memory (Jerry Snitselaar) [2004348]
- dma-mapping: allow using the global coherent pool for !ARM (Jerry Snitselaar) [2004348]
- dma-direct: add support for dma_coherent_default_memory (Jerry Snitselaar) [2004348]
- dma-mapping: return an unsigned int from dma_map_sg{,_attrs} (Jerry Snitselaar) [2004348]
- dma-mapping: disallow .map_sg operations from returning zero on error (Jerry Snitselaar) [2004348]
- dma-mapping: return error code from dma_dummy_map_sg() (Jerry Snitselaar) [2004348]
- xen: swiotlb: return error code from xen_swiotlb_map_sg() (Jerry Snitselaar) [2004348]
- s390/pci: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- s390/pci: return error code from s390_dma_map_sg() (Jerry Snitselaar) [2004348]
- powerpc/iommu: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- powerpc/iommu: return error code from .map_sg() ops (Jerry Snitselaar) [2004348]
- iommu/dma: return error code from iommu_dma_map_sg() (Jerry Snitselaar) [2004348]
- iommu: return full error code from iommu_map_sg[_atomic]() (Jerry Snitselaar) [2004348]
- dma-direct: return appropriate error code from dma_direct_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: allow map_sg() ops to return negative error codes (Jerry Snitselaar) [2004348]
- dma-debug: fix debugfs initialization order (Jerry Snitselaar) [2004348]
- dma-debug: use memory_intersects() directly (Jerry Snitselaar) [2004348]

* Tue Nov 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-17.el9]
- net: mana: Support hibernation and kexec (Mohammed Gamal) [2011883]
- net: mana: Improve the HWC error handling (Mohammed Gamal) [2011883]
- net: mana: Report OS info to the PF driver (Mohammed Gamal) [2011883]
- net: mana: Fix the netdev_err()'s vPort argument in mana_init_port() (Mohammed Gamal) [2011883]
- net: mana: Allow setting the number of queues while the NIC is down (Mohammed Gamal) [2011883]
- net: mana: Fix error handling in mana_create_rxq() (Mohammed Gamal) [2011883]
- net: mana: Use kcalloc() instead of kzalloc() (Mohammed Gamal) [2011883]
- net: mana: Prefer struct_size over open coded arithmetic (Mohammed Gamal) [2011883]
- net: mana: Add WARN_ON_ONCE in case of CQE read overflow (Mohammed Gamal) [2011883]
- net: mana: Add support for EQ sharing (Mohammed Gamal) [2011883]
- net: mana: Move NAPI from EQ to CQ (Mohammed Gamal) [2011883]
- PCI: hv: Fix sleep while in non-sleep context when removing child devices from the bus (Mohammed Gamal) [2008571]
- objtool: Remove redundant 'len' field from struct section (C. Erastus Toe) [2002440]
- objtool: Make .altinstructions section entry size consistent (C. Erastus Toe) [2002440]
- s390/topology: fix topology information when calling cpu hotplug notifiers (Phil Auld) [2003998]
- fs: remove leftover comments from mandatory locking removal (Jeffrey Layton) [2017438]
- locks: remove changelog comments (Jeffrey Layton) [2017438]
- docs: fs: locks.rst: update comment about mandatory file locking (Jeffrey Layton) [2017438]
- Documentation: remove reference to now removed mandatory-locking doc (Jeffrey Layton) [2017438]
- locks: remove LOCK_MAND flock lock support (Jeffrey Layton) [2017438]
- fs: clean up after mandatory file locking support removal (Jeffrey Layton) [2017438]
- fs: remove mandatory file locking support (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlock for &fasync_struct.fa_lock (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlocks for &fown_struct.lock (Jeffrey Layton) [2017438]
- KVM: s390: Enable specification exception interpretation (Thomas Huth) [2001770]
- redhat/configs: enable CONFIG_BCMGENET as module (Joel Savitz) [2011025]

* Fri Nov 12 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-16.el9]
- CI: Add template for baseline gcov build for RHEL (Israel Santana Aleman)
- redhat/configs: Enable Nitro Enclaves on Aarch64 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch blank line reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch spell check reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch match open parenthesis reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update copyright statement to include 2021 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fix for the kernel-doc report (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update documentation for Arm64 support (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Enable Arm64 support (Vitaly Kuznetsov) [2001582]
- redhat/configs: Enable Hyper-V support on ARM (Vitaly Kuznetsov) [1949613]
- redhat/configs: enable CONFIG_INPUT_KEYBOARD for AARCH64 (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Enable Hyper-V code to be built on ARM64 (Vitaly Kuznetsov) [1949613]
- arm64: efi: Export screen_info (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Initialize hypervisor on boot (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add panic handler (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add Hyper-V hypercall and register access utilities (Vitaly Kuznetsov) [1949613]
- PCI: hv: Turn on the host bridge probing on ARM64 (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set up MSI domain at bridge probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set ->domain_nr of pci_host_bridge at probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Generify PCI probing (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Support root bridge preparation for Hyper-V (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Restructure pcibios_root_bridge_prepare() (Vitaly Kuznetsov) [1949613]
- PCI: Support populating MSI domains of root buses via bridges (Vitaly Kuznetsov) [1949613]
- PCI: Introduce domain_nr in pci_host_bridge (Vitaly Kuznetsov) [1949613]
- drivers: hv: Decouple Hyper-V clock/timer code from VMbus drivers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Move Hyper-V misc functionality to arch-neutral code (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Add arch independent default functions for some Hyper-V handlers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Make portions of Hyper-V init code be arch neutral (Vitaly Kuznetsov) [1949613]
- asm-generic/hyperv: Add missing #include of nmi.h (Vitaly Kuznetsov) [1949613]
- PCI: hv: Support for create interrupt v3 (Vitaly Kuznetsov) [1949613]
- x86_64: Enable Elkhart Lake Quadrature Encoder Peripheral support (Prarit Bhargava) [1874997]

* Thu Nov 11 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-15.el9]
- scsi: lpfc: Fix memory overwrite during FC-GS I/O abort handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix gcc -Wstringop-overread warning, again (Dick Kennedy) [1879528]
- scsi: lpfc: Use correct scnprintf() limit (Dick Kennedy) [1879528]
- scsi: lpfc: Fix sprintf() overflow in lpfc_display_fpin_wwpn() (Dick Kennedy) [1879528]
- scsi: lpfc: Fix compilation errors on kernels with no CONFIG_DEBUG_FS (Dick Kennedy) [1879528]
- scsi: lpfc: Fix CPU to/from endian warnings introduced by ELS processing (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.2 (Dick Kennedy) [1879528]
- scsi: lpfc: Improve PBDE checks during SGL processing (Dick Kennedy) [1879528]
- scsi: lpfc: Zero CGN stats only during initial driver load and stat reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix I/O block after enabling managed congestion mode (Dick Kennedy) [1879528]
- scsi: lpfc: Adjust bytes received vales during cmf timer interval (Dick Kennedy) [1879528]
- scsi: lpfc: Fix EEH support for NVMe I/O (Dick Kennedy) [1879528]
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path (Dick Kennedy) [1879528]
- scsi: lpfc: Don't remove ndlp on PRLI errors in P2P mode (Dick Kennedy) [1879528]
- scsi: lpfc: Fix rediscovery of tape device after LIP (Dick Kennedy) [1879528]
- scsi: lpfc: Fix hang on unload due to stuck fport node (Dick Kennedy) [1879528]
- scsi: lpfc: Fix premature rpi release for unsolicited TPLS and LS_RJT (Dick Kennedy) [1879528]
- scsi: lpfc: Don't release final kref on Fport node while ABTS outstanding (Dick Kennedy) [1879528]
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq() (Dick Kennedy) [1879528]
- scsi: fc: Add EDC ELS definition (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.1 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.1 (Dick Kennedy) [1879528]
- scsi: lpfc: Add bsg support for retrieving adapter cmf data (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmf_info sysfs entry (Dick Kennedy) [1879528]
- scsi: lpfc: Add debugfs support for cm framework buffers (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for maintaining the cm statistics buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add rx monitoring statistics (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for the CM framework (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmfsync WQE support (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for cm enablement buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add cm statistics buffer support (Dick Kennedy) [1879528]
- scsi: lpfc: Add EDC ELS support (Dick Kennedy) [1879528]
- scsi: lpfc: Expand FPIN and RDF receive logging (Dick Kennedy) [1879528]
- scsi: lpfc: Add MIB feature enablement support (Dick Kennedy) [1879528]
- scsi: lpfc: Add SET_HOST_DATA mbox cmd to pass date/time info to firmware (Dick Kennedy) [1879528]
- scsi: lpfc: Fix possible ABBA deadlock in nvmet_xri_aborted() (Dick Kennedy) [1879528]
- scsi: lpfc: Remove redundant assignment to pointer pcmd (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.0 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.0 (Dick Kennedy) [1879528]
- scsi: lpfc: Add 256 Gb link speed support (Dick Kennedy) [1879528]
- scsi: lpfc: Revise Topology and RAS support checks for new adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Fix cq_id truncation in rq create (Dick Kennedy) [1879528]
- scsi: lpfc: Add PCI ID support for LPe37000/LPe38000 series adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 12.8.0.11 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 12.8.0.11 (Dick Kennedy) [1879528]
- scsi: lpfc: Skip issuing ADISC when node is in NPR state (Dick Kennedy) [1879528]
- scsi: lpfc: Skip reg_vpi when link is down for SLI3 in ADISC cmpl path (Dick Kennedy) [1879528]
- scsi: lpfc: Call discovery state machine when handling PLOGI/ADISC completions (Dick Kennedy) [1879528]
- scsi: lpfc: Delay unregistering from transport until GIDFT or ADISC completes (Dick Kennedy) [1879528]
- scsi: lpfc: Enable adisc discovery after RSCN by default (Dick Kennedy) [1879528]
- scsi: lpfc: Use PBDE feature enabled bit to determine PBDE support (Dick Kennedy) [1879528]
- scsi: lpfc: Clear outstanding active mailbox during PCI function reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix KASAN slab-out-of-bounds in lpfc_unreg_rpi() routine (Dick Kennedy) [1879528]
- scsi: lpfc: Remove REG_LOGIN check requirement to issue an ELS RDF (Dick Kennedy) [1879528]
- scsi: lpfc: Fix memory leaks in error paths while issuing ELS RDF/SCR request (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NULL ptr dereference with NPIV ports for RDF handling (Dick Kennedy) [1879528]
- scsi: lpfc: Keep NDLP reference until after freeing the IOCB after ELS handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix target reset handler from falsely returning FAILURE (Dick Kennedy) [1879528]
- scsi: lpfc: Discovery state machine fixes for LOGO handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix function description comments for vmid routines (Dick Kennedy) [1879528]
- scsi: lpfc: Improve firmware download logging (Dick Kennedy) [1879528]
- scsi: lpfc: Remove use of kmalloc() in trace event logging (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe support reporting in log message (Dick Kennedy) [1879528]

* Wed Nov 10 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-14.el9]
- evm: mark evm_fixmode as __ro_after_init (Bruno Meneguele) [2017160]
- IMA: remove -Wmissing-prototypes warning (Bruno Meneguele) [2017160]
- perf flamegraph: flamegraph.py script improvements (Michael Petlan) [2010271]
- redhat/configs/evaluate_configs: insert EMPTY tags at correct place (Jan Stancek) [2015082]
- redhat/configs/evaluate_configs: walk cfgvariants line by line (Jan Stancek) [2015082]
- redhat/configs: create a separate config for gcov options (Jan Stancek) [2015082]
- redhat/kernel.spec.template: don't hardcode gcov arches (Jan Stancek) [2015082]
- i40e: fix endless loop under rtnl (Stefan Assmann) [1992939]
- selftests/bpf: Use nanosleep tracepoint in perf buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix possible/online index mismatch in perf_buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix perf_buffer test on system with offline cpus (Jiri Olsa) [2006310]
- KVM: x86: Fix stack-out-of-bounds memory access from ioapic_write_indirect() (Vitaly Kuznetsov) [1965145]
- selftest/bpf: Switch recursion test to use htab_map_delete_elem (Jiri Olsa) [2006313]

* Mon Nov 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-13.el9]
- futex: Remove unused variable 'vpid' in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- futex: Prevent inconsistent state and exit race (Waiman Long) [2007032]
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Waiman Long) [2007032]
- futex: Return error code instead of assigning it without effect (Waiman Long) [2007032]
- locking/rwbase: Take care of ordering guarantee for fastpath reader (Waiman Long) [2007032]
- locking/rwbase: Extract __rwbase_write_trylock() (Waiman Long) [2007032]
- locking/rwbase: Properly match set_and_save_state() to restore_state() (Waiman Long) [2007032]
- locking/rtmutex: Fix ww_mutex deadlock check (Waiman Long) [2007032]
- locking/rwsem: Add missing __init_rwsem() for PREEMPT_RT (Waiman Long) [2007032]
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Waiman Long) [2007032]
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Waiman Long) [2007032]
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Waiman Long) [2007032]
- locking/rtmutex: Dont dereference waiter lockless (Waiman Long) [2007032]
- locking/local_lock: Add PREEMPT_RT support (Waiman Long) [2007032]
- locking/spinlock/rt: Prepare for RT local_lock (Waiman Long) [2007032]
- locking/rtmutex: Add adaptive spinwait mechanism (Waiman Long) [2007032]
- locking/rtmutex: Implement equal priority lock stealing (Waiman Long) [2007032]
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Waiman Long) [2007032]
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Waiman Long) [2007032]
- futex: Prevent requeue_pi() lock nesting issue on RT (Waiman Long) [2007032]
- futex: Simplify handle_early_requeue_pi_wakeup() (Waiman Long) [2007032]
- futex: Reorder sanity checks in futex_requeue() (Waiman Long) [2007032]
- futex: Clarify comment in futex_requeue() (Waiman Long) [2007032]
- futex: Restructure futex_requeue() (Waiman Long) [2007032]
- futex: Correct the number of requeued waiters for PI (Waiman Long) [2007032]
- futex: Remove bogus condition for requeue PI (Waiman Long) [2007032]
- futex: Clarify futex_requeue() PI handling (Waiman Long) [2007032]
- futex: Clean up stale comments (Waiman Long) [2007032]
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- lib/test_lockup: Adapt to changed variables (Waiman Long) [2007032]
- locking/rtmutex: Add mutex variant for RT (Waiman Long) [2007032]
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Waiman Long) [2007032]
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Waiman Long) [2007032]
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Waiman Long) [2007032]
- locking/ww_mutex: Add RT priority to W/W order (Waiman Long) [2007032]
- locking/ww_mutex: Implement rt_mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out internal lock accesses (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex types (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out waiter enqueueing (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out the waiter iteration (Waiman Long) [2007032]
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Waiman Long) [2007032]
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Waiman Long) [2007032]
- locking/ww_mutex: Split up ww_mutex_unlock() (Waiman Long) [2007032]
- locking/ww_mutex: Gather mutex_waiter initialization (Waiman Long) [2007032]
- locking/ww_mutex: Simplify lockdep annotations (Waiman Long) [2007032]
- locking/mutex: Make mutex::wait_lock raw (Waiman Long) [2007032]
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Waiman Long) [2007032]
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Waiman Long) [2007032]
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Waiman Long) [2007032]
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Waiman Long) [2007032]
- locking/rwlock: Provide RT variant (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant (Waiman Long) [2007032]
- locking/rtmutex: Provide the spin/rwlock core lock function (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Waiman Long) [2007032]
- locking/spinlock: Provide RT specific spinlock_t (Waiman Long) [2007032]
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Waiman Long) [2007032]
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Waiman Long) [2007032]
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Waiman Long) [2007032]
- locking/rtmutex: Prevent future include recursion hell (Waiman Long) [2007032]
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Waiman Long) [2007032]
- locking/rtmutex: Guard regular sleeping locks specific functions (Waiman Long) [2007032]
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Waiman Long) [2007032]
- locking/rtmutex: Use rt_mutex_wake_q_head (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_wake_q_head and helpers (Waiman Long) [2007032]
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Waiman Long) [2007032]
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Waiman Long) [2007032]
- locking/rt: Add base code for RT rw_semaphore and rwlock (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Waiman Long) [2007032]
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Waiman Long) [2007032]
- locking/rtmutex: Split API from implementation (Waiman Long) [2007032]
- locking/rtmutex: Switch to from cmpxchg_*() to try_cmpxchg_*() (Waiman Long) [2007032]
- locking/rtmutex: Convert macros to inlines (Waiman Long) [2007032]
- locking/rtmutex: Remove rt_mutex_is_locked() (Waiman Long) [2007032]
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Waiman Long) [2007032]
- sched/core: Provide a scheduling point for RT locks (Waiman Long) [2007032]
- sched/core: Rework the __schedule() preempt argument (Waiman Long) [2007032]
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Waiman Long) [2007032]
- sched/wakeup: Reorganize the current::__state helpers (Waiman Long) [2007032]
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Waiman Long) [2007032]
- sched/wakeup: Split out the wakeup ->__state check (Waiman Long) [2007032]
- locking/rtmutex: Set proper wait context for lockdep (Waiman Long) [2007032]
- locking/local_lock: Add missing owner initialization (Waiman Long) [2007032]
- locking/mutex: Add MUTEX_WARN_ON (Waiman Long) [2007032]
- locking/mutex: Introduce __mutex_trylock_or_handoff() (Waiman Long) [2007032]
- locking/mutex: Fix HANDOFF condition (Waiman Long) [2007032]
- locking/mutex: Use try_cmpxchg() (Waiman Long) [2007032]

* Thu Nov 04 2021 Jarod Wilson <jarod@redhat.com> [5.14.0-12.el9]
- redhat: make dist-srpm-gcov add to BUILDOPTS (Jan Stancek) [2017628]
- redhat: Fix dist-srpm-gcov (Jan Stancek) [2017628]
- s390: report more CPU capabilities (Robin Dapp) [2012095]
- s390/disassembler: add instructions (Robin Dapp) [2012095]
- audit: move put_tree() to avoid trim_trees refcount underflow and UAF (Richard Guy Briggs) [1985904]
- libbpf: Properly ignore STT_SECTION symbols in legacy map definitions (Jiri Olsa) [1998266]
- libbpf: Ignore STT_SECTION symbols in 'maps' section (Jiri Olsa) [1998266]
- selftests, bpf: test_lwt_ip_encap: Really disable rp_filter (Jiri Benc) [2006328]

* Thu Oct 28 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-11.el9]
- selinux: remove the SELinux lockdown implementation (Ondrej Mosnacek) [1940843 1945581]
- bpf: Fix integer overflow in prealloc_elems_and_freelist() (Yauheni Kaliuta) [2010494] {CVE-2021-41864}
- seltests: bpf: test_tunnel: Use ip neigh (Jiri Benc) [2006326]

* Tue Oct 26 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-10.el9]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [1991958]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2009110]
- redhat/configs: enable CONFIG_IMA_WRITE_POLICY (Bruno Meneguele) [2006320]
- CI: Update deprecated configs (Veronika Kabatova)

* Wed Oct 20 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-9.el9]
- powerpc/pseries: Prevent free CPU ids being reused on another node (Desnes A. Nunes do Rosario) [2004809]
- pseries/drmem: update LMBs after LPM (Desnes A. Nunes do Rosario) [2004809]
- powerpc/numa: Consider the max NUMA node for migratable LPAR (Desnes A. Nunes do Rosario) [2004809]
- selftests: bpf: disable test_lirc_mode2 (Jiri Benc) [2006359]
- selftests: bpf: disable test_doc_build.sh (Jiri Benc) [2006359]
- selftests: bpf: define SO_RCVTIMEO and SO_SNDTIMEO properly for ppc64le (Jiri Benc) [2006359]
- selftests: bpf: skip FOU tests in test_tc_tunnel (Jiri Benc) [2006359]
- selftests: bpf: disable test_seg6_loop test (Jiri Benc) [2006359]
- selftests: bpf: disable test_lwt_seg6local (Jiri Benc) [2006359]
- selftests: bpf: disable test_bpftool_build.sh (Jiri Benc) [2006359]
- selftests: add option to skip specific tests in RHEL (Jiri Benc) [2006359]

* Fri Oct 15 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-8.el9]
- selftests/powerpc: Add scv versions of the basic TM syscall tests (Desnes A. Nunes do Rosario) [1986651]
- powerpc/64s: system call scv tabort fix for corrupt irq soft-mask state (Desnes A. Nunes do Rosario) [1986651]
- mm/swap: consider max pages in iomap_swapfile_add_extent (Carlos Maiolino) [2005191]
- platform/x86/intel: pmc/core: Add GBE Package C10 fix for Alder Lake PCH (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alder Lake low power mode support for pmc core (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Latency Tolerance Reporting (LTR) support to Alder Lake (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alderlake support to pmc core driver (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Move to intel sub-directory (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Prevent possibile overflow (David Arcari) [2007707]
- Clean-up CONFIG_X86_PLATFORM_DRIVERS_INTEL (David Arcari) [2007707]
- KVM: nVMX: Filter out all unsupported controls when eVMCS was activated (Vitaly Kuznetsov) [2001912]
- ipc: remove memcg accounting for sops objects in do_semtimedop() (Rafael Aquini) [1999707] {CVE-2021-3759}
- memcg: enable accounting of ipc resources (Rafael Aquini) [1999707] {CVE-2021-3759}
- redhat: BUILDID parameter must come last in genspec.sh (Herton R. Krzesinski)
- redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0 (Prarit Bhargava) [2009545]
- redhat: Remove fedora configs directories and files. (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Cleanup source numbering (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Add include_fedora and include_rhel variables (Prarit Bhargava) [2009545]
- redhat/Makefile: Make kernel-local global (Prarit Bhargava) [2009545]
- redhat/Makefile: Use flavors file (Prarit Bhargava) [2009545]

* Mon Oct 11 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-7.el9]
- redhat: Enable Nitro Enclaves driver on x86 for real (Vitaly Kuznetsov) [2011739]
- redhat/.gitignore: Add rhel9 KABI files (Prarit Bhargava) [2009489]
- hwmon: (k10temp) Add support for yellow carp (David Arcari) [1987069]
- hwmon: (k10temp) Rework the temperature offset calculation (David Arcari) [1987069]
- hwmon: (k10temp) Don't show Tdie for all Zen/Zen2/Zen3 CPU/APU (David Arcari) [1987069]
- hwmon: (k10temp) Add additional missing Zen2 and Zen3 APUs (David Arcari) [1987069]
- hwmon: (k10temp) support Zen3 APUs (David Arcari) [1987069]
- selinux,smack: fix subjective/objective credential use mixups (Ondrej Mosnacek) [2008145]
- redhat: kernel.spec: selftests: abort on build failure (Jiri Benc) [2004012]
- Revert "bpf, selftests: Disable tests that need clang13" (Jiri Benc) [2004012]
- selftests, bpf: Fix makefile dependencies on libbpf (Jiri Benc) [2004012]

* Fri Oct 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-6.el9]
- pinctrl: Bulk conversion to generic_handle_domain_irq() (David Arcari) [2000232]
- pinctrl: amd: Handle wake-up interrupt (David Arcari) [2000232]
- pinctrl: amd: Add irq field data (David Arcari) [2000232]
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Jan Stancek)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- redhat/configs: Disable FIREWIRE (Prarit Bhargava) [1871862]
- Enable e1000 in rhel9 as unsupported (Ken Cox) [2002344]

* Mon Oct 04 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.6.1.el9]
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Jan Stancek)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- redhat/configs: Disable FIREWIRE (Prarit Bhargava) [1871862]
- Enable e1000 in rhel9 as unsupported (Ken Cox) [2002344]

* Thu Sep 30 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-5.el9]
- redhat/configs: enable CONFIG_SQUASHFS_ZSTD which is already enabled in Fedora 34 (Tao Liu) [1998953]
- fs: dlm: fix return -EINTR on recovery stopped (Alexander Aring) [2004213]
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Jan Stancek) [2002499]
- redhat: define _rhel variable because pesign macro now needs it (Jan Stancek) [2002499]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Jan Stancek) [1994849]
- redhat: correct file name of redhatsecurebootca1 (Jan Stancek) [2002499]
- redhat: align file names with names of signing keys for ppc and s390 (Jan Stancek) [2002499]
- redhat: restore sublevel in changelog (Jan Stancek)
- fs: dlm: avoid comms shutdown delay in release_lockspace (Alexander Aring) [1994749]
- redhat/configs: Enable CONFIG_BLK_CGROUP_IOLATENCY & CONFIG_BLK_CGROUP_FC_APPID (Waiman Long) [1996675]
- redhat/configs: remove conflicting SYSTEM_BLACKLIST_KEYRING (Bruno Meneguele) [2002350]
- Enable "inter server to server" NFSv4.2 COPY (Steve Dickson) [1487367]

* Wed Sep 29 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.5.1.el9]
- fs: dlm: fix return -EINTR on recovery stopped (Alexander Aring) [2004213]
- redhat/configs: Update configs for secure IPL (Claudio Imbrenda) [1976884]
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Jan Stancek) [2002499]
- redhat: define _rhel variable because pesign macro now needs it (Jan Stancek) [2002499]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Jan Stancek) [1994849]
- redhat: correct file name of redhatsecurebootca1 (Jan Stancek) [2002499]
- redhat: align file names with names of signing keys for ppc and s390 (Jan Stancek) [2002499]

* Mon Sep 27 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.4.1.el9]
- redhat: restore sublevel in changelog (Jan Stancek)
- fs: dlm: avoid comms shutdown delay in release_lockspace (Alexander Aring) [1994749]
- redhat/configs: Enable CONFIG_BLK_CGROUP_IOLATENCY & CONFIG_BLK_CGROUP_FC_APPID (Waiman Long) [1996675]

* Wed Sep 22 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-4.el9]
- Drivers: hv: vmbus: Fix kernel crash upon unbinding a device from uio_hv_generic driver (Vitaly Kuznetsov) [1999535]
- ipc: replace costly bailout check in sysvipc_find_ipc() (Rafael Aquini) [1987130 2003270] {CVE-2021-3669}
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1996993]
- redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta (Jan Stancek)
- redhat: add option to use DIST tag in sources (Jan Stancek)
- CI: Enable notification messages for RHEL9 (Veronika Kabatova)
- CI: Enable private pipelines for RT branches (Veronika Kabatova)
- CI: Remove ARK leftovers (Veronika Kabatova)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Herton R. Krzesinski)
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1988451]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1988451]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1988451]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [1980430]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [1980430]
- iscsi_ibft: Fix isa_bus_to_virt not working under ARM (Maurizio Lombardi) [1963801]
- x86/setup: Explicitly include acpi.h (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix warning in reserve_ibft_region() (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix crash due to KASLR physical memory remapping (Maurizio Lombardi) [1963801]
- redhat: fix chronological order in the changelog file (Herton R. Krzesinski)

* Wed Sep 22 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.3.1.el9]
- redhat/configs: remove conflicting SYSTEM_BLACKLIST_KEYRING (Bruno Meneguele) [2002350]
- Enable "inter server to server" NFSv4.2 COPY (Steve Dickson) [1487367]

* Fri Sep 17 2021 Jan Stancek <jstancek@redhat.com> [5.14-1.2.1.el9]
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1996993]
- redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta (Jan Stancek)
- redhat: add option to use DIST tag in sources (Jan Stancek)
- CI: Enable notification messages for RHEL9 (Veronika Kabatova)
- CI: Enable private pipelines for RT branches (Veronika Kabatova)
- CI: Remove ARK leftovers (Veronika Kabatova)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Herton R. Krzesinski)
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1988451]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1988451]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1988451]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [1980430]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [1980430]
- iscsi_ibft: Fix isa_bus_to_virt not working under ARM (Maurizio Lombardi) [1963801]
- x86/setup: Explicitly include acpi.h (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix warning in reserve_ibft_region() (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix crash due to KASLR physical memory remapping (Maurizio Lombardi) [1963801]

* Thu Sep 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-3]
- misc/pvpanic-pci: Allow automatic loading (Eric Auger) [1977192]
- md/raid10: Remove unnecessary rcu_dereference in raid10_handle_discard (Nigel Croxon) [1965294]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1998549]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)
- CI: use 9.0-beta-rt branch for -rt pipeline (Jan Stancek)
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [1987099]
- crypto: ccp - shutdown SEV firmware on kexec (Vladis Dronov) [1987099]

* Tue Sep 14 2021 Jan Stancek <jstancek@redhat.com> [5.14-1.1.1]
- md/raid10: Remove unnecessary rcu_dereference in raid10_handle_discard (Nigel Croxon) [1965294]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1998549]

* Mon Sep 13 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-2]
- redhat: update branches/targets after 9 Beta fork (Herton R. Krzesinski)
- hv_utils: Set the maximum packet size for VSS driver to the length of the receive buffer (Vitaly Kuznetsov) [1996628]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)

* Mon Aug 30 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-1]
- redhat: drop Patchlist.changelog for RHEL (Jan Stancek) [1997494]
- redhat: update Makefile.variables for centos/rhel9 fork (Herton R. Krzesinski)
- redhat: add support for stream profile in koji/brew (Herton R. Krzesinski)
- redhat: make DIST default to .el9 (Herton R. Krzesinski)
- redhat: set default values in Makefiles for RHEL 9 Beta (Jan Stancek) [1997494]
- arm64: use common CONFIG_MAX_ZONEORDER for arm kernel (Mark Salter)
- Create Makefile.variables for a single point of configuration change (Justin M. Forbes)
- rpmspec: drop traceevent files instead of just excluding them from files list (Herton R. Krzesinski) [1967640]
- redhat/config: Enablement of CONFIG_PAPR_SCM for PowerPC (Gustavo Walbon) [1962936]
- Attempt to fix Intel PMT code (David Arcari)
- CI: Enable realtime branch testing (Veronika Kabatova)
- CI: Enable realtime checks for c9s and RHEL9 (Veronika Kabatova)
- [fs] dax: mark tech preview (Bill O'Donnell)
- ark: wireless: enable all rtw88 pcie wirless variants (Peter Robinson)
- wireless: rtw88: move debug options to common/debug (Peter Robinson)
- fedora: minor PTP clock driver cleanups (Peter Robinson)
- common: x86: enable VMware PTP support on ark (Peter Robinson)
- arm64: dts: rockchip: Disable CDN DP on Pinebook Pro (Matthias Brugger)
- arm64: dts: rockchip: Setup USB typec port as datarole on (Dan Johansen)
- [scsi] megaraid_sas: re-add certain pci-ids (Tomas Henzl)
- xfs: drop experimental warnings for bigtime and inobtcount (Bill O'Donnell) [1995321]
- Disable liquidio driver on ark/rhel (Herton R. Krzesinski) [1993393]
- More Fedora config updates (Justin M. Forbes)
- Fedora config updates for 5.14 (Justin M. Forbes)
- CI: Rename ARK CI pipeline type (Veronika Kabatova)
- CI: Finish up c9s config (Veronika Kabatova)
- CI: Update ppc64le config (Veronika Kabatova)
- CI: use more templates (Veronika Kabatova)
- Filter updates for aarch64 (Justin M. Forbes)
- increase CONFIG_NODES_SHIFT for aarch64 (Chris von Recklinghausen) [1890304]
- redhat: configs: Enable CONFIG_WIRELESS_HOTKEY (Hans de Goede)
- redhat/configs: Update CONFIG_NVRAM (Desnes A. Nunes do Rosario) [1988254]
- common: serial: build in SERIAL_8250_LPSS for x86 (Peter Robinson)
- powerpc: enable CONFIG_FUNCTION_PROFILER (Diego Domingos) [1831065]
- crypto: rng - Override drivers/char/random in FIPS mode (Herbert Xu)
- random: Add hook to override device reads and getrandom(2) (Herbert Xu)
- redhat/configs: Disable Soft-RoCE driver (Kamal Heib)
- redhat/configs/evaluate_configs: Update help output (Prarit Bhargava)
- redhat/configs: Double MAX_LOCKDEP_CHAINS (Justin M. Forbes)
- fedora: configs: Fix WM5102 Kconfig (Hans de Goede)
- powerpc: enable CONFIG_POWER9_CPU (Diego Domingos) [1876436]
- redhat/configs: Fix CONFIG_VIRTIO_IOMMU to 'y' on aarch64 (Eric Auger) [1972795]
- filter-modules.sh: add more sound modules to filter (Jaroslav Kysela)
- redhat/configs: sound configuration cleanups and updates (Jaroslav Kysela)
- common: Update for CXL (Compute Express Link) configs (Peter Robinson)
- redhat: configs: disable CRYPTO_SM modules (Herton R. Krzesinski) [1990040]
- Remove fedora version of the LOCKDEP_BITS, we should use common (Justin M. Forbes)
- Re-enable sermouse for x86 (rhbz 1974002) (Justin M. Forbes)
- Fedora 5.14 configs round 1 (Justin M. Forbes)
- redhat: add gating configuration for centos stream/rhel9 (Herton R. Krzesinski)
- x86: configs: Enable CONFIG_TEST_FPU for debug kernels (Vitaly Kuznetsov) [1988384]
- redhat/configs: Move CHACHA and POLY1305 to core kernel to allow BIG_KEYS=y (root) [1983298]
- kernel.spec: fix build of samples/bpf (Jiri Benc)
- Enable OSNOISE_TRACER and TIMERLAT_TRACER (Jerome Marchand) [1979379]
- rpmspec: switch iio and gpio tools to use tools_make (Herton R. Krzesinski) [1956988]
- configs/process_configs.sh: Handle config items with no help text (Patrick Talbert)
- fedora: sound config updates for 5.14 (Peter Robinson)
- fedora: Only enable FSI drivers on POWER platform (Peter Robinson)
- The CONFIG_RAW_DRIVER has been removed from upstream (Peter Robinson)
- fedora: updates for 5.14 with a few disables for common from pending (Peter Robinson)
- fedora: migrate from MFD_TPS68470 -> INTEL_SKL_INT3472 (Peter Robinson)
- fedora: Remove STAGING_GASKET_FRAMEWORK (Peter Robinson)
- Fedora: move DRM_VMWGFX configs from ark -> common (Peter Robinson)
- fedora: arm: disabled unused FB drivers (Peter Robinson)
- fedora: don't enable FB_VIRTUAL (Peter Robinson)
- redhat/configs: Double MAX_LOCKDEP_ENTRIES (Waiman Long) [1940075]
- rpmspec: fix verbose output on kernel-devel installation (Herton R. Krzesinski) [1981406]
- Build Fedora x86s kernels with bytcr-wm5102 (Marius Hoch)
- Deleted redhat/configs/fedora/generic/x86/CONFIG_FB_HYPERV (Patrick Lang)
- rpmspec: correct the ghost initramfs attributes (Herton R. Krzesinski) [1977056]
- rpmspec: amend removal of depmod created files to include modules.builtin.alias.bin (Herton R. Krzesinski) [1977056]
- configs: remove duplicate CONFIG_DRM_HYPERV file (Patrick Talbert)
- CI: use common code for merge and release (Don Zickus)
- rpmspec: add release string to kernel doc directory name (Jan Stancek)
- redhat/configs: Add CONFIG_INTEL_PMT_CRASHLOG (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_INTEL_PMT_TELEMETRY (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_MFD_INTEL_PMT (Michael Petlan) [1880486]
- redhat/configs: enable CONFIG_BLK_DEV_ZONED (Ming Lei) [1638087]
- Add --with clang_lto option to build the kernel with Link Time Optimizations (Tom Stellard)
- common: disable DVB_AV7110 and associated pieces (Peter Robinson)
- Fix fedora-only config updates (Don Zickus)
- Fedor config update for new option (Justin M. Forbes)
- redhat/configs: Enable stmmac NIC for x86_64 (Mark Salter)
- all: hyperv: use the DRM driver rather than FB (Peter Robinson)
- all: hyperv: unify the Microsoft HyperV configs (Peter Robinson)
- all: VMWare: clean up VMWare configs (Peter Robinson)
- Update CONFIG_ARM_FFA_TRANSPORT (Patrick Talbert)
- CI: Handle all mirrors (Veronika Kabatova)
- Turn on CONFIG_STACKTRACE for s390x zfpcdump kernels (Justin M. Forbes)
- arm64: switch ark kernel to 4K pagesize (Mark Salter)
- Disable AMIGA_PARTITION and KARMA_PARTITION (Prarit Bhargava) [1802694]
- all: unify and cleanup i2c TPM2 modules (Peter Robinson)
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on aarch64 (Eric Auger) [1972795]
- redhat/configs: Disable CONFIG_RT_GROUP_SCHED in rhel config (Phil Auld)
- redhat/configs: enable KEXEC_SIG which is already enabled in RHEL8 for s390x and x86_64 (Coiby Xu) [1976835]
- rpmspec: do not BuildRequires bpftool on noarch (Herton R. Krzesinski)
- redhat/configs: disable {IMA,EVM}_LOAD_X509 (Bruno Meneguele) [1977529]
- redhat: add secureboot CA certificate to trusted kernel keyring (Bruno Meneguele)
- redhat/configs: enable IMA_ARCH_POLICY for aarch64 and s390x (Bruno Meneguele)
- redhat/configs: Enable CONFIG_MLXBF_GIGE on aarch64 (Alaa Hleihel) [1858599]
- common: enable STRICT_MODULE_RWX everywhere (Peter Robinson)
- COMMON_CLK_STM32MP157_SCMI is bool and selects COMMON_CLK_SCMI (Justin M. Forbes)
- kernel.spec: Add kernel{,-debug}-devel-matched meta packages (Timothée Ravier)
- Turn off with_selftests for Fedora (Justin M. Forbes)
- Don't build bpftool on Fedora (Justin M. Forbes)
- Fix location of syscall scripts for kernel-devel (Justin M. Forbes)
- fedora: arm: Enable some i.MX8 options (Peter Robinson)
- Enable Landlock for Fedora (Justin M. Forbes)
- Filter update for Fedora aarch64 (Justin M. Forbes)
- rpmspec: only build debug meta packages where we build debug ones (Herton R. Krzesinski)
- rpmspec: do not BuildRequires bpftool on nobuildarches (Herton R. Krzesinski)
- redhat/configs: Consolidate CONFIG_HMC_DRV in the common s390x folder (Thomas Huth) [1976270]
- redhat/configs: Consolidate CONFIG_EXPOLINE_OFF in the common folder (Thomas Huth) [1976270]
- redhat/configs: Move CONFIG_HW_RANDOM_S390 into the s390x/ subfolder (Thomas Huth) [1976270]
- redhat/configs: Disable CONFIG_HOTPLUG_PCI_SHPC in the Fedora settings (Thomas Huth) [1976270]
- redhat/configs: Remove the non-existent CONFIG_NO_BOOTMEM switch (Thomas Huth) [1976270]
- redhat/configs: Compile the virtio-console as a module on s390x (Thomas Huth) [1976270]
- redhat/configs: Enable CONFIG_S390_CCW_IOMMU and CONFIG_VFIO_CCW for ARK, too (Thomas Huth) [1976270]
- Revert "Merge branch 'ec_fips' into 'os-build'" (Vladis Dronov) [1947240]
- Fix typos in fedora filters (Justin M. Forbes)
- More filtering for Fedora (Justin M. Forbes)
- Fix Fedora module filtering for spi-altera-dfl (Justin M. Forbes)
- Fedora 5.13 config updates (Justin M. Forbes)
- fedora: cleanup TCG_TIS_I2C_CR50 (Peter Robinson)
- fedora: drop duplicate configs (Peter Robinson)
- More Fedora config updates for 5.13 (Justin M. Forbes)
- redhat/configs: Enable needed drivers for BlueField SoC on aarch64 (Alaa Hleihel) [1858592 1858594 1858596]
- redhat: Rename mod-blacklist.sh to mod-denylist.sh (Prarit Bhargava)
- redhat/configs: enable CONFIG_NET_ACT_MPLS (Marcelo Ricardo Leitner)
- configs: Enable CONFIG_DEBUG_KERNEL for zfcpdump (Jiri Olsa)
- kernel.spec: Add support to use vmlinux.h (Don Zickus)
- spec: Add vmlinux.h to kernel-devel package (Jiri Olsa)
- Turn off DRM_XEN_FRONTEND for Fedora as we had DRM_XEN off already (Justin M. Forbes)
- Fedora 5.13 config updates pt 3 (Justin M. Forbes)
- all: enable ath11k wireless modules (Peter Robinson)
- all: Enable WWAN and associated MHI bus pieces (Peter Robinson)
- spec: Enable sefltests rpm build (Jiri Olsa)
- spec: Allow bpf selftest/samples to fail (Jiri Olsa)
- bpf, selftests: Disable tests that need clang13 (Toke Høiland-Jørgensen)
- kvm: Add kvm_stat.service file and kvm_stat logrotate config to the tools (Jiri Benc)
- kernel.spec: Add missing source files to kernel-selftests-internal (Jiri Benc)
- kernel.spec: selftests: add net/forwarding to TARGETS list (Jiri Benc)
- kernel.spec: selftests: add build requirement on libmnl-devel (Jiri Benc)
- kernel.spec: add action.o to kernel-selftests-internal (Jiri Benc)
- kernel.spec: avoid building bpftool repeatedly (Jiri Benc)
- kernel.spec: selftests require python3 (Jiri Benc)
- kernel.spec: skip selftests that failed to build (Jiri Benc)
- kernel.spec: fix installation of bpf selftests (Jiri Benc)
- redhat: fix samples and selftests make options (Jiri Benc)
- kernel.spec: enable mptcp selftests for kernel-selftests-internal (Jiri Benc)
- kernel.spec: Do not export shared objects from libexecdir to RPM Provides (Jiri Benc)
- kernel.spec: add missing dependency for the which package (Jiri Benc)
- kernel.spec: add netfilter selftests to kernel-selftests-internal (Jiri Benc)
- kernel.spec: move slabinfo and page_owner_sort debuginfo to tools-debuginfo (Jiri Benc)
- kernel.spec: package and ship VM tools (Jiri Benc)
- configs: enable CONFIG_PAGE_OWNER (Jiri Benc)
- kernel.spec: add coreutils (Jiri Benc)
- kernel.spec: add netdevsim driver selftests to kernel-selftests-internal (Jiri Benc)
- redhat/Makefile: Clean out the --without flags from the baseonly rule (Jiri Benc)
- kernel.spec: Stop building unnecessary rpms for baseonly builds (Jiri Benc)
- kernel.spec: disable more kabi switches for gcov build (Jiri Benc)
- kernel.spec: Rename kabi-dw base (Jiri Benc)
- kernel.spec: Fix error messages during build of zfcpdump kernel (Jiri Benc)
- kernel.spec: perf: remove bpf examples (Jiri Benc)
- kernel.spec: selftests should not depend on modules-internal (Jiri Benc)
- kernel.spec: build samples (Jiri Benc)
- kernel.spec: tools: sync missing options with RHEL 8 (Jiri Benc)
- redhat/configs: nftables: Enable extra flowtable symbols (Phil Sutter)
- redhat/configs: Sync netfilter options with RHEL8 (Phil Sutter)
- Fedora 5.13 config updates pt 2 (Justin M. Forbes)
- Move CONFIG_ARCH_INTEL_SOCFPGA up a level for Fedora (Justin M. Forbes)
- fedora: enable the Rockchip rk3399 pcie drivers (Peter Robinson)
- Fedora 5.13 config updates pt 1 (Justin M. Forbes)
- Fix version requirement from opencsd-devel buildreq (Justin M. Forbes)
- configs/ark/s390: set CONFIG_MARCH_Z14 and CONFIG_TUNE_Z15 (Philipp Rudo) [1876435]
- configs/common/s390: Clean up CONFIG_{MARCH,TUNE}_Z* (Philipp Rudo)
- configs/process_configs.sh: make use of dummy-tools (Philipp Rudo)
- configs/common: disable CONFIG_INIT_STACK_ALL_{PATTERN,ZERO} (Philipp Rudo)
- configs/common/aarch64: disable CONFIG_RELR (Philipp Rudo)
- redhat/config: enable STMICRO nic for RHEL (Mark Salter)
- redhat/configs: Enable ARCH_TEGRA on RHEL (Mark Salter)
- redhat/configs: enable IMA_KEXEC for supported arches (Bruno Meneguele)
- redhat/configs: enable INTEGRITY_SIGNATURE to all arches (Bruno Meneguele)
- configs: enable CONFIG_LEDS_BRIGHTNESS_HW_CHANGED (Benjamin Tissoires)
- RHEL: disable io_uring support (Jeff Moyer)
- all: Changing CONFIG_UV_SYSFS to build uv_sysfs.ko as a loadable module. (Frank Ramsay)
- Enable NITRO_ENCLAVES on RHEL (Vitaly Kuznetsov)
- Update the Quick Start documentation (David Ward)
- redhat/configs: Set PVPANIC_MMIO for x86 and PVPANIC_PCI for aarch64 (Eric Auger) [1961178]
- bpf: Fix unprivileged_bpf_disabled setup (Jiri Olsa)
- Enable CONFIG_BPF_UNPRIV_DEFAULT_OFF (Jiri Olsa)
- configs/common/s390: disable CONFIG_QETH_{OSN,OSX} (Philipp Rudo) [1903201]
- nvme: nvme_mpath_init remove multipath check (Mike Snitzer)
- team: mark team driver as deprecated (Hangbin Liu) [1945477]
- Make CRYPTO_EC also builtin (Simo Sorce) [1947240]
- Do not hard-code a default value for DIST (David Ward)
- Override %%{debugbuildsenabled} if the --with-release option is used (David Ward)
- Improve comments in SPEC file, and move some option tests and macros (David Ward)
- configs: enable CONFIG_EXFAT_FS (Pavel Reichl) [1943423]
- Revert s390x/zfcpdump part of a9d179c40281 and ecbfddd98621 (Vladis Dronov)
- Embed crypto algos, modes and templates needed in the FIPS mode (Vladis Dronov) [1947240]
- configs: Add and enable CONFIG_HYPERV_TESTING for debug kernels (Mohammed Gamal)
- mm/cma: mark CMA on x86_64 tech preview and print RHEL-specific infos (David Hildenbrand) [1945002]
- configs: enable CONFIG_CMA on x86_64 in ARK (David Hildenbrand) [1945002]
- rpmspec: build debug-* meta-packages if debug builds are disabled (Herton R. Krzesinski)
- UIO: disable unused config options (Aristeu Rozanski) [1957819]
- ARK-config: Make amd_pinctrl module builtin (Hans de Goede)
- rpmspec: revert/drop content hash for kernel-headers (Herton R. Krzesinski)
- rpmspec: fix check that calls InitBuildVars (Herton R. Krzesinski)
- fedora: enable zonefs (Damien Le Moal)
- redhat: load specific ARCH keys to INTEGRITY_PLATFORM_KEYRING (Bruno Meneguele)
- redhat: enable INTEGRITY_TRUSTED_KEYRING across all variants (Bruno Meneguele)
- redhat: enable SYSTEM_BLACKLIST_KEYRING across all variants (Bruno Meneguele)
- redhat: enable INTEGRITY_ASYMMETRIC_KEYS across all variants (Bruno Meneguele)
- Remove unused boot loader specification files (David Ward)
- redhat/configs: Enable mlx5 IPsec and TLS offloads (Alaa Hleihel) [1869674 1957636]
- Force DWARF4 because crash does not support DWARF5 yet (Justin M. Forbes)
- common: disable Apple Silicon generally (Peter Robinson)
- cleanup Intel's FPGA configs (Peter Robinson)
- common: move PTP KVM support from ark to common (Peter Robinson)
- Enable CONFIG_DRM_AMDGPU_USERPTR for everyone (Justin M. Forbes)
- redhat: add initial rpminspect configuration (Herton R. Krzesinski)
- fedora: arm updates for 5.13 (Peter Robinson)
- fedora: Enable WWAN and associated MHI bits (Peter Robinson)
- Update CONFIG_MODPROBE_PATH to /usr/sbin (Justin Forbes)
- Fedora set modprobe path (Justin M. Forbes)
- Keep sctp and l2tp modules in modules-extra (Don Zickus)
- Fix ppc64le cross build packaging (Don Zickus)
- Fedora: Make amd_pinctrl module builtin (Hans de Goede)
- Keep CONFIG_KASAN_HW_TAGS off for aarch64 debug configs (Justin M. Forbes)
- New configs in drivers/bus (Fedora Kernel Team)
- RHEL: Don't build KVM PR module on ppc64 (David Gibson) [1930649]
- Flip CONFIG_USB_ROLE_SWITCH from m to y (Justin M. Forbes)
- Set valid options for CONFIG_FW_LOADER_USER_HELPER (Justin M. Forbes)
- Clean up CONFIG_FB_MODE_HELPERS (Justin M. Forbes)
- Turn off CONFIG_VFIO for the s390x zfcpdump kernel (Justin M. Forbes)
- Delete unused CONFIG_SND_SOC_MAX98390 pending-common (Justin M. Forbes)
- Update pending-common configs, preparing to set correctly (Justin M. Forbes)
- Update fedora filters for surface (Justin M. Forbes)
- Build CONFIG_CRYPTO_ECDSA inline for s390x zfcpdump (Justin M. Forbes)
- Replace "flavour" where "variant" is meant instead (David Ward)
- Drop the %%{variant} macro and fix --with-vanilla (David Ward)
- Fix syntax of %%kernel_variant_files (David Ward)
- Change description of --without-vdso-install to fix typo (David Ward)
- Config updates to work around mismatches (Justin M. Forbes)
- CONFIG_SND_SOC_FSL_ASOC_CARD selects CONFIG_MFD_WM8994 now (Justin M. Forbes)
- wireguard: disable in FIPS mode (Hangbin Liu) [1940794]
- Enable mtdram for fedora (rhbz 1955916) (Justin M. Forbes)
- Remove reference to bpf-helpers man page (Justin M. Forbes)
- Fedora: enable more modules for surface devices (Dave Olsthoorn)
- Fix Fedora config mismatch for CONFIG_FSL_ENETC_IERB (Justin M. Forbes)
- hardlink is in /usr/bin/ now (Justin M. Forbes)
- Ensure CONFIG_KVM_BOOK3S_64_PR stays on in Fedora, even if it is turned off in RHEL (Justin M. Forbes)
- Set date in package release from repository commit, not system clock (David Ward)
- Use a better upstream tarball filename for snapshots (David Ward)
- Don't create empty pending-common files on pending-fedora commits (Don Zickus)
- nvme: decouple basic ANA log page re-read support from native multipathing (Mike Snitzer)
- nvme: allow local retry and proper failover for REQ_FAILFAST_TRANSPORT (Mike Snitzer)
- nvme: Return BLK_STS_TARGET if the DNR bit is set (Mike Snitzer)
- Add redhat/configs/pending-common/generic/s390x/zfcpdump/CONFIG_NETFS_SUPPORT (Justin M. Forbes)
- Create ark-latest branch last for CI scripts (Don Zickus)
- Replace /usr/libexec/platform-python with /usr/bin/python3 (David Ward)
- Turn off ADI_AXI_ADC and AD9467 which now require CONFIG_OF (Justin M. Forbes)
- Export ark infrastructure files (Don Zickus)
- docs: Update docs to reflect newer workflow. (Don Zickus)
- Use upstream/master for merge-base with fallback to master (Don Zickus)
- Fedora: Turn off the SND_INTEL_BYT_PREFER_SOF option (Hans de Goede)
- filter-modules.sh.fedora: clean up "netprots" (Paul Bolle)
- filter-modules.sh.fedora: clean up "scsidrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "ethdrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "driverdirs" (Paul Bolle)
- filter-*.sh.fedora: remove incorrect entries (Paul Bolle)
- filter-*.sh.fedora: clean up "singlemods" (Paul Bolle)
- filter-modules.sh.fedora: drop unused list "iiodrvs" (Paul Bolle)
- Update mod-internal to fix depmod issue (Nico Pache)
- Turn on CONFIG_VDPA_SIM_NET (rhbz 1942343) (Justin M. Forbes)
- New configs in drivers/power (Fedora Kernel Team)
- Turn on CONFIG_NOUVEAU_DEBUG_PUSH for debug configs (Justin M. Forbes)
- Turn off KFENCE sampling by default for Fedora (Justin M. Forbes)
- Fedora config updates round 2 (Justin M. Forbes)
- New configs in drivers/soc (Jeremy Cline)
- filter-modules.sh: Fix copy/paste error 'input' (Paul Bolle)
- Update module filtering for 5.12 kernels (Justin M. Forbes)
- Fix genlog.py to ensure that comments retain "%%" characters. (Mark Mielke)
- New configs in drivers/leds (Fedora Kernel Team)
- Limit CONFIG_USB_CDNS_SUPPORT to x86_64 and arm in Fedora (David Ward)
- Fedora: Enable CHARGER_GPIO on aarch64 too (Peter Robinson)
- Fedora config updates (Justin M. Forbes)
- wireguard: mark as Tech Preview (Hangbin Liu) [1613522]
- configs: enable CONFIG_WIREGUARD in ARK (Hangbin Liu) [1613522]
- Remove duplicate configs acroos fedora, ark and common (Don Zickus)
- Combine duplicate configs across ark and fedora into common (Don Zickus)
- common/ark: cleanup and unify the parport configs (Peter Robinson)
- iommu/vt-d: enable INTEL_IDXD_SVM for both fedora and rhel (Jerry Snitselaar)
- REDHAT: coresight: etm4x: Disable coresight on HPE Apollo 70 (Jeremy Linton)
- configs/common/generic: disable CONFIG_SLAB_MERGE_DEFAULT (Rafael Aquini)
- Remove _legacy_common_support (Justin M. Forbes)
- redhat/mod-blacklist.sh: Fix floppy blacklisting (Hans de Goede)
- New configs in fs/pstore (CKI@GitLab)
- New configs in arch/powerpc (Fedora Kernel Team)
- configs: enable BPF LSM on Fedora and ARK (Ondrej Mosnacek)
- configs: clean up LSM configs (Ondrej Mosnacek)
- New configs in drivers/platform (CKI@GitLab)
- New configs in drivers/firmware (CKI@GitLab)
- New configs in drivers/mailbox (Fedora Kernel Team)
- New configs in drivers/net/phy (Justin M. Forbes)
- Update CONFIG_DM_MULTIPATH_IOA (Augusto Caringi)
- New configs in mm/Kconfig (CKI@GitLab)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in drivers/input (Fedora Kernel Team)
- New configs in net/bluetooth (Justin M. Forbes)
- New configs in drivers/clk (Fedora Kernel Team)
- New configs in init/Kconfig (Jeremy Cline)
- redhat: allow running fedora-configs and rh-configs targets outside of redhat/ (Herton R. Krzesinski)
- all: unify the disable of goldfish (android emulation platform) (Peter Robinson)
- common: minor cleanup/de-dupe of dma/dmabuf debug configs (Peter Robinson)
- common/ark: these drivers/arches were removed in 5.12 (Peter Robinson)
- Correct kernel-devel make prepare build for 5.12. (Paulo E. Castro)
- redhat: add initial support for centos stream dist-git sync on Makefiles (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_SCHED_STACK_END_CHECK for Fedora and ARK (Josh Poimboeuf) [1856174]
- CONFIG_VFIO now selects IOMMU_API instead of depending on it, causing several config mismatches for the zfcpdump kernel (Justin M. Forbes)
- Turn off weak-modules for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_FW_LOADER_COMPRESS for ARK (Herton R. Krzesinski) [1939095]
- Fedora: filters: update to move dfl-emif to modules (Peter Robinson)
- drop duplicate DEVFREQ_GOV_SIMPLE_ONDEMAND config (Peter Robinson)
- efi: The EFI_VARS is legacy and now x86 only (Peter Robinson)
- common: enable RTC_SYSTOHC to supplement update_persistent_clock64 (Peter Robinson)
- generic: arm: enable SCMI for all options (Peter Robinson)
- fedora: the PCH_CAN driver is x86-32 only (Peter Robinson)
- common: disable legacy CAN device support (Peter Robinson)
- common: Enable Microchip MCP251x/MCP251xFD CAN controllers (Peter Robinson)
- common: Bosch MCAN support for Intel Elkhart Lake (Peter Robinson)
- common: enable CAN_PEAK_PCIEFD PCI-E driver (Peter Robinson)
- common: disable CAN_PEAK_PCIEC PCAN-ExpressCard (Peter Robinson)
- common: enable common CAN layer 2 protocols (Peter Robinson)
- ark: disable CAN_LEDS option (Peter Robinson)
- Fedora: Turn on SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC option (Hans de Goede)
- Fedora: enable modules for surface devices (Dave Olsthoorn)
- Turn on SND_SOC_INTEL_SOUNDWIRE_SOF_MACH for Fedora again (Justin M. Forbes)
- common: fix WM8804 codec dependencies (Peter Robinson)
- Build SERIO_SERPORT as a module (Peter Robinson)
- input: touchscreen: move ELO and Wacom serial touchscreens to x86 (Peter Robinson)
- Sync serio touchscreens for non x86 architectures to the same as ARK (Peter Robinson)
- Only enable SERIO_LIBPS2 on x86 (Peter Robinson)
- Only enable PC keyboard controller and associated keyboard on x86 (Peter Robinson)
- Generic: Mouse: Tweak generic serial mouse options (Peter Robinson)
- Only enable PS2 Mouse options on x86 (Peter Robinson)
- Disable bluetooth highspeed by default (Peter Robinson)
- Fedora: A few more general updates for 5.12 window (Peter Robinson)
- Fedora: Updates for 5.12 merge window (Peter Robinson)
- Fedora: remove dead options that were removed upstream (Peter Robinson)
- redhat: remove CONFIG_DRM_PANEL_XINGBANGDA_XBD599 (Herton R. Krzesinski)
- New configs in arch/powerpc (Fedora Kernel Team)
- Turn on CONFIG_PPC_QUEUED_SPINLOCKS as it is default upstream now (Justin M. Forbes)
- Update pending-common configs to address new upstream config deps (Justin M. Forbes)
- rpmspec: ship gpio-watch.debug in the proper debuginfo package (Herton R. Krzesinski)
- Removed description text as a comment confuses the config generation (Justin M. Forbes)
- New configs in drivers/dma-buf (Jeremy Cline)
- Fedora: ARMv7: build for 16 CPUs. (Peter Robinson)
- Fedora: only enable DEBUG_HIGHMEM on debug kernels (Peter Robinson)
- process_configs.sh: fix find/xargs data flow (Ondrej Mosnacek)
- Fedora config update (Justin M. Forbes)
- fedora: minor arm sound config updates (Peter Robinson)
- Fix trailing white space in redhat/configs/fedora/generic/CONFIG_SND_INTEL_BYT_PREFER_SOF (Justin M. Forbes)
- Add a redhat/rebase-notes.txt file (Hans de Goede)
- Turn on SND_INTEL_BYT_PREFER_SOF for Fedora (Hans de Goede)
- CI: Drop MR ID from the name variable (Veronika Kabatova)
- redhat: add DUP and kpatch certificates to system trusted keys for RHEL build (Herton R. Krzesinski)
- The comments in CONFIG_USB_RTL8153_ECM actually turn off CONFIG_USB_RTL8152 (Justin M. Forbes)
- Update CKI pipeline project (Veronika Kabatova)
- Turn off additional KASAN options for Fedora (Justin M. Forbes)
- Rename the master branch to rawhide for Fedora (Justin M. Forbes)
- Makefile targets for packit integration (Ben Crocker)
- Turn off KASAN for rawhide debug builds (Justin M. Forbes)
- New configs in arch/arm64 (Justin Forbes)
- Remove deprecated Intel MIC config options (Peter Robinson)
- redhat: replace inline awk script with genlog.py call (Herton R. Krzesinski)
- redhat: add genlog.py script (Herton R. Krzesinski)
- kernel.spec.template - fix use_vdso usage (Ben Crocker)
- redhat: remove remaining references of CONFIG_RH_DISABLE_DEPRECATED (Herton R. Krzesinski)
- Turn off vdso_install for ppc (Justin M. Forbes)
- Remove bpf-helpers.7 from bpftool package (Jiri Olsa)
- New configs in lib/Kconfig.debug (Fedora Kernel Team)
- Turn off CONFIG_VIRTIO_CONSOLE for s390x zfcpdump (Justin M. Forbes)
- New configs in drivers/clk (Justin M. Forbes)
- Keep VIRTIO_CONSOLE on s390x available. (Jakub Čajka)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- Fedora 5.11 config updates part 4 (Justin M. Forbes)
- Fedora 5.11 config updates part 3 (Justin M. Forbes)
- Fedora 5.11 config updates part 2 (Justin M. Forbes)
- Update internal (test) module list from RHEL-8 (Joe Lawrence) [1915073]
- Fix USB_XHCI_PCI regression (Justin M. Forbes)
- fedora: fixes for ARMv7 build issue by disabling HIGHPTE (Peter Robinson)
- all: s390x: Increase CONFIG_PCI_NR_FUNCTIONS to 512 (#1888735) (Dan Horák)
- Fedora 5.11 configs pt 1 (Justin M. Forbes)
- redhat: avoid conflict with mod-blacklist.sh and released_kernel defined (Herton R. Krzesinski)
- redhat: handle certificate files conditionally as done for src.rpm (Herton R. Krzesinski)
- specfile: add %%{?_smp_mflags} to "make headers_install" in tools/testing/selftests (Denys Vlasenko)
- specfile: add %%{?_smp_mflags} to "make samples/bpf/" (Denys Vlasenko)
- Run MR testing in CKI pipeline (Veronika Kabatova)
- Reword comment (Nicolas Chauvet)
- Add with_cross_arm conditional (Nicolas Chauvet)
- Redefines __strip if with_cross (Nicolas Chauvet)
- fedora: only enable ACPI_CONFIGFS, ACPI_CUSTOM_METHOD in debug kernels (Peter Robinson)
- fedora: User the same EFI_CUSTOM_SSDT_OVERLAYS as ARK (Peter Robinson)
- all: all arches/kernels enable the same DMI options (Peter Robinson)
- all: move SENSORS_ACPI_POWER to common/generic (Peter Robinson)
- fedora: PCIE_HISI_ERR is already in common (Peter Robinson)
- all: all ACPI platforms enable ATA_ACPI so move it to common (Peter Robinson)
- all: x86: move shared x86 acpi config options to generic (Peter Robinson)
- All: x86: Move ACPI_VIDEO to common/x86 (Peter Robinson)
- All: x86: Enable ACPI_DPTF (Intel DPTF) (Peter Robinson)
- All: enable ACPI_BGRT for all ACPI platforms. (Peter Robinson)
- All: Only build ACPI_EC_DEBUGFS for debug kernels (Peter Robinson)
- All: Disable Intel Classmate PC ACPI_CMPC option (Peter Robinson)
- cleanup: ACPI_PROCFS_POWER was removed upstream (Peter Robinson)
- All: ACPI: De-dupe the ACPI options that are the same across ark/fedora on x86/arm (Peter Robinson)
- Enable the vkms module in Fedora (Jeremy Cline)
- Fedora: arm updates for 5.11 and general cross Fedora cleanups (Peter Robinson)
- Add gcc-c++ to BuildRequires (Justin M. Forbes)
- Update CONFIG_KASAN_HW_TAGS (Justin M. Forbes)
- fedora: arm: move generic power off/reset to all arm (Peter Robinson)
- fedora: ARMv7: build in DEVFREQ_GOV_SIMPLE_ONDEMAND until I work out why it's changed (Peter Robinson)
- fedora: cleanup joystick_adc (Peter Robinson)
- fedora: update some display options (Peter Robinson)
- fedora: arm: enable TI PRU options (Peter Robinson)
- fedora: arm: minor exynos plaform updates (Peter Robinson)
- arm: SoC: disable Toshiba Visconti SoC (Peter Robinson)
- common: disable ARCH_BCM4908 (NFC) (Peter Robinson)
- fedora: minor arm config updates (Peter Robinson)
- fedora: enable Tegra 234 SoC (Peter Robinson)
- fedora: arm: enable new Hikey 3xx options (Peter Robinson)
- Fedora: USB updates (Peter Robinson)
- fedora: enable the GNSS receiver subsystem (Peter Robinson)
- Remove POWER_AVS as no longer upstream (Peter Robinson)
- Cleanup RESET_RASPBERRYPI (Peter Robinson)
- Cleanup GPIO_CDEV_V1 options. (Peter Robinson)
- fedora: arm crypto updates (Peter Robinson)
- CONFIG_KASAN_HW_TAGS for aarch64 (Justin M. Forbes)
- Fedora: cleanup PCMCIA configs, move to x86 (Peter Robinson)
- New configs in drivers/rtc (Fedora Kernel Team)
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK_BYREF_ALL (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGINS on ARK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_KASAN on Fedora (Josh Poimboeuf) [1856176]
- New configs in init/Kconfig (Fedora Kernel Team)
- build_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- genspec.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- mod-blacklist.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Enable Speakup accessibility driver (Justin M. Forbes)
- New configs in init/Kconfig (Fedora Kernel Team)
- Fix fedora config mismatch due to dep changes (Justin M. Forbes)
- New configs in drivers/crypto (Jeremy Cline)
- Remove duplicate ENERGY_MODEL configs (Peter Robinson)
- This is selected by PCIE_QCOM so must match (Justin M. Forbes)
- drop unused BACKLIGHT_GENERIC (Peter Robinson)
- Remove cp instruction already handled in instruction below. (Paulo E. Castro)
- Add all the dependencies gleaned from running `make prepare` on a bloated devel kernel. (Paulo E. Castro)
- Add tools to path mangling script. (Paulo E. Castro)
- Remove duplicate cp statement which is also not specific to x86. (Paulo E. Castro)
- Correct orc_types failure whilst running `make prepare` https://bugzilla.redhat.com/show_bug.cgi?id=1882854 (Paulo E. Castro)
- redhat: ark: enable CONFIG_IKHEADERS (Jiri Olsa)
- Add missing '$' sign to (GIT) in redhat/Makefile (Augusto Caringi)
- Remove filterdiff and use native git instead (Don Zickus)
- New configs in net/sched (Justin M. Forbes)
- New configs in drivers/mfd (CKI@GitLab)
- New configs in drivers/mfd (Fedora Kernel Team)
- New configs in drivers/firmware (Fedora Kernel Team)
- Temporarily backout parallel xz script (Justin M. Forbes)
- redhat: explicitly disable CONFIG_IMA_APPRAISE_SIGNED_INIT (Bruno Meneguele)
- redhat: enable CONFIG_EVM_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM_ATTR_FSUUID on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM in all arches and flavors (Bruno Meneguele)
- redhat: enable CONFIG_IMA_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: set CONFIG_IMA_DEFAULT_HASH to SHA256 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT (Bruno Meneguele)
- redhat: enable CONFIG_IMA_READ_POLICY on ARK (Bruno Meneguele)
- redhat: set default IMA template for all ARK arches (Bruno Meneguele)
- redhat: enable CONFIG_IMA_DEFAULT_HASH_SHA256 for all flavors (Bruno Meneguele)
- redhat: disable CONFIG_IMA_DEFAULT_HASH_SHA1 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_ARCH_POLICY for ppc and x86 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_MODSIG (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_BOOTPARAM (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE (Bruno Meneguele)
- redhat: enable CONFIG_INTEGRITY for aarch64 (Bruno Meneguele)
- kernel: Update some missing KASAN/KCSAN options (Jeremy Linton)
- kernel: Enable coresight on aarch64 (Jeremy Linton)
- Update CONFIG_INET6_ESPINTCP (Justin Forbes)
- New configs in net/ipv6 (Justin M. Forbes)
- fedora: move CONFIG_RTC_NVMEM options from ark to common (Peter Robinson)
- configs: Enable CONFIG_DEBUG_INFO_BTF (Don Zickus)
- fedora: some minor arm audio config tweaks (Peter Robinson)
- Ship xpad with default modules on Fedora and RHEL (Bastien Nocera)
- Fedora: Only enable legacy serial/game port joysticks on x86 (Peter Robinson)
- Fedora: Enable the options required for the Librem 5 Phone (Peter Robinson)
- Fedora config update (Justin M. Forbes)
- Fedora config change because CONFIG_FSL_DPAA2_ETH now selects CONFIG_FSL_XGMAC_MDIO (Justin M. Forbes)
- redhat: generic  enable CONFIG_INET_MPTCP_DIAG (Davide Caratti)
- Fedora config update (Justin M. Forbes)
- Enable NANDSIM for Fedora (Justin M. Forbes)
- Re-enable CONFIG_ACPI_TABLE_UPGRADE for Fedora since upstream disables this if secureboot is active (Justin M. Forbes)
- Ath11k related config updates (Justin M. Forbes)
- Fedora config updates for ath11k (Justin M. Forbes)
- Turn on ATH11K for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_INTEL_IOMMU_SVM (Jerry Snitselaar)
- More Fedora config fixes (Justin M. Forbes)
- Fedora 5.10 config updates (Justin M. Forbes)
- Fedora 5.10 configs round 1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Allow kernel-tools to build without selftests (Don Zickus)
- Allow building of kernel-tools standalone (Don Zickus)
- redhat: ark: disable CONFIG_NET_ACT_CTINFO (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_TEQL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_SFB (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_QFQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PLUG (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PIE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_HHF (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DSMARK (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DRR (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CODEL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CHOKE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CBQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_ATM (Davide Caratti)
- redhat: ark: disable CONFIG_NET_EMATCH and sub-targets (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_TCINDEX (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP6 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_ROUTE4 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_BASIC (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SKBMOD (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SIMP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_NAT (Davide Caratti)
- arm64/defconfig: Enable CONFIG_KEXEC_FILE (Bhupesh Sharma) [1821565]
- redhat/configs: Cleanup CONFIG_CRYPTO_SHA512 (Prarit Bhargava)
- New configs in drivers/mfd (Fedora Kernel Team)
- Fix LTO issues with kernel-tools (Don Zickus)
- Point pathfix to the new location for gen_compile_commands.py (Justin M. Forbes)
- configs: Disable CONFIG_SECURITY_SELINUX_DISABLE (Ondrej Mosnacek)
- [Automatic] Handle config dependency changes (Don Zickus)
- configs/iommu: Add config comment to empty CONFIG_SUN50I_IOMMU file (Jerry Snitselaar)
- New configs in kernel/trace (Fedora Kernel Team)
- Fix Fedora config locations (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- configs: enable CONFIG_CRYPTO_CTS=y so cts(cbc(aes)) is available in FIPS mode (Vladis Dronov) [1855161]
- Partial revert: Add master merge check (Don Zickus)
- Update Maintainers doc to reflect workflow changes (Don Zickus)
- WIP: redhat/docs: Update documentation for single branch workflow (Prarit Bhargava)
- Add CONFIG_ARM64_MTE which is not picked up by the config scripts for some reason (Justin M. Forbes)
- Disable Speakup synth DECEXT (Justin M. Forbes)
- Enable Speakup for Fedora since it is out of staging (Justin M. Forbes)
- Modify patchlist changelog output (Don Zickus)
- process_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- generate_all_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- redhat/self-test: Initial commit (Ben Crocker)
- Fixes "acpi: prefer booting with ACPI over DTS" to be RHEL only (Peter Robinson)
- arch/x86: Remove vendor specific CPU ID checks (Prarit Bhargava)
- redhat: Replace hardware.redhat.com link in Unsupported message (Prarit Bhargava) [1810301]
- x86: Fix compile issues with rh_check_supported() (Don Zickus)
- KEYS: Make use of platform keyring for module signature verify (Robert Holmes)
- Input: rmi4 - remove the need for artificial IRQ in case of HID (Benjamin Tissoires)
- ARM: tegra: usb no reset (Peter Robinson)
- arm: make CONFIG_HIGHPTE optional without CONFIG_EXPERT (Jon Masters)
- redhat: rh_kabi: deduplication friendly structs (Jiri Benc)
- redhat: rh_kabi add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc)
- redhat: rh_kabi: introduce RH_KABI_EXTEND_WITH_SIZE (Jiri Benc)
- redhat: rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile)
- redhat: rh_kabi: Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso)
- redhat: rh_kabi: Add macros to size and extend structs (Prarit Bhargava)
- Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy)
- mptsas: pci-id table changes (Laura Abbott)
- mptsas: Taint kernel if mptsas is loaded (Laura Abbott)
- mptspi: pci-id table changes (Laura Abbott)
- qla2xxx: Remove PCI IDs of deprecated adapter (Jeremy Cline)
- be2iscsi: remove unsupported device IDs (Chris Leech)
- mptspi: Taint kernel if mptspi is loaded (Laura Abbott)
- hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek)
- qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis)
- aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta)
- megaraid_sas: remove deprecated pci-ids (Tomas Henzl)
- mpt*: remove certain deprecated pci-ids (Jeremy Cline)
- kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl)
- Rename RH_DISABLE_DEPRECATED to RHEL_DIFFERENCES (Don Zickus)
- Add option of 13 for FORCE_MAX_ZONEORDER (Peter Robinson)
- s390: Lock down the kernel when the IPL secure flag is set (Jeremy Cline)
- efi: Lock down the kernel if booted in secure boot mode (David Howells)
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (David Howells)
- security: lockdown: expose a hook to lock the kernel down (Jeremy Cline)
- Make get_cert_list() use efi_status_to_str() to print error messages. (Peter Jones)
- Add efi_status_to_str() and rework efi_status_to_err(). (Peter Jones)
- Add support for deprecating processors (Laura Abbott) [1565717 1595918 1609604 1610493]
- arm: aarch64: Drop the EXPERT setting from ARM64_FORCE_52BIT (Jeremy Cline)
- iommu/arm-smmu: workaround DMA mode issues (Laura Abbott)
- rh_kabi: introduce RH_KABI_EXCLUDE (Jakub Racek)
- ipmi: do not configure ipmi for HPE m400 (Laura Abbott) [1670017]
- kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- add pci_hw_vendor_status() (Maurizio Lombardi)
- ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter)
- Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter)
- bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- tags.sh: Ignore redhat/rpm (Jeremy Cline)
- put RHEL info into generated headers (Laura Abbott) [1663728]
- acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- modules: add rhelversion MODULE_INFO tag (Laura Abbott)
- ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- Add Red Hat tainting (Laura Abbott) [1565704]
- Introduce CONFIG_RH_DISABLE_DEPRECATED (Laura Abbott)
- Stop merging ark-patches for release (Don Zickus)
- Fix path location for ark-update-configs.sh (Don Zickus)
- Combine Red Hat patches into single patch (Don Zickus)
- New configs in drivers/misc (Jeremy Cline)
- New configs in drivers/net/wireless (Justin M. Forbes)
- New configs in drivers/phy (Fedora Kernel Team)
- New configs in drivers/tty (Fedora Kernel Team)
- Set SquashFS decompression options for all flavors to match RHEL (Bohdan Khomutskyi)
- configs: Enable CONFIG_ENERGY_MODEL (Phil Auld)
- New configs in drivers/pinctrl (Fedora Kernel Team)
- Update CONFIG_THERMAL_NETLINK (Justin Forbes)
- Separate merge-upstream and release stages (Don Zickus)
- Re-enable CONFIG_IR_SERIAL on Fedora (Prarit Bhargava)
- Create Patchlist.changelog file (Don Zickus)
- Filter out upstream commits from changelog (Don Zickus)
- Merge Upstream script fixes (Don Zickus)
- kernel.spec: Remove kernel-keys directory on rpm erase (Prarit Bhargava)
- Add mlx5_vdpa to module filter for Fedora (Justin M. Forbes)
- Add python3-sphinx_rtd_theme buildreq for docs (Justin M. Forbes)
- redhat/configs/process_configs.sh: Remove *.config.orig files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add process_configs_known_broken flag (Prarit Bhargava)
- redhat/Makefile: Fix '*-configs' targets (Prarit Bhargava)
- dist-merge-upstream: Checkout known branch for ci scripts (Don Zickus)
- kernel.spec: don't override upstream compiler flags for ppc64le (Dan Horák)
- Fedora config updates (Justin M. Forbes)
- Fedora confi gupdate (Justin M. Forbes)
- mod-sign.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Swap how ark-latest is built (Don Zickus)
- Add extra version bump to os-build branch (Don Zickus)
- dist-release: Avoid needless version bump. (Don Zickus)
- Add dist-fedora-release target (Don Zickus)
- Remove redundant code in dist-release (Don Zickus)
- Makefile.common rename TAG to _TAG (Don Zickus)
- Fedora config change (Justin M. Forbes)
- Fedora filter update (Justin M. Forbes)
- Config update for Fedora (Justin M. Forbes)
- enable PROTECTED_VIRTUALIZATION_GUEST for all s390x kernels (Dan Horák)
- redhat: ark: enable CONFIG_NET_SCH_TAPRIO (Davide Caratti)
- redhat: ark: enable CONFIG_NET_SCH_ETF (Davide Caratti)
- More Fedora config updates (Justin M. Forbes)
- New config deps (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- First half of config updates for Fedora (Justin M. Forbes)
- Updates for Fedora arm architectures for the 5.9 window (Peter Robinson)
- Merge 5.9 config changes from Peter Robinson (Justin M. Forbes)
- Add config options that only show up when we prep on arm (Justin M. Forbes)
- Config updates for Fedora (Justin M. Forbes)
- fedora: enable enery model (Peter Robinson)
- Use the configs/generic config for SND_HDA_INTEL everywhere (Peter Robinson)
- Enable ZSTD compression algorithm on all kernels (Peter Robinson)
- Enable ARM_SMCCC_SOC_ID on all aarch64 kernels (Peter Robinson)
- iio: enable LTR-559 light and proximity sensor (Peter Robinson)
- iio: chemical: enable some popular chemical and partical sensors (Peter Robinson)
- More mismatches (Justin M. Forbes)
- Fedora config change due to deps (Justin M. Forbes)
- CONFIG_SND_SOC_MAX98390 is now selected by SND_SOC_INTEL_DA7219_MAX98357A_GENERIC (Justin M. Forbes)
- Config change required for build part 2 (Justin M. Forbes)
- Config change required for build (Justin M. Forbes)
- Fedora config update (Justin M. Forbes)
- Add ability to sync upstream through Makefile (Don Zickus)
- Add master merge check (Don Zickus)
- Replace hardcoded values 'os-build' and project id with variables (Don Zickus)
- redhat/Makefile.common: Fix MARKER (Prarit Bhargava)
- gitattributes: Remove unnecesary export restrictions (Prarit Bhargava)
- Add new certs for dual signing with boothole (Justin M. Forbes)
- Update secureboot signing for dual keys (Justin M. Forbes)
- fedora: enable LEDS_SGM3140 for arm configs (Peter Robinson)
- Enable CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG (Justin M. Forbes)
- redhat/configs: Fix common CONFIGs (Prarit Bhargava)
- redhat/configs: General CONFIG cleanups (Prarit Bhargava)
- redhat/configs: Update & generalize evaluate_configs (Prarit Bhargava)
- fedora: arm: Update some meson config options (Peter Robinson)
- redhat/docs: Add Fedora RPM tagging date (Prarit Bhargava)
- Update config for renamed panel driver. (Peter Robinson)
- Enable SERIAL_SC16IS7XX for SPI interfaces (Peter Robinson)
- s390x-zfcpdump: Handle missing Module.symvers file (Don Zickus)
- Fedora config updates (Justin M. Forbes)
- redhat/configs: Add .tmp files to .gitignore (Prarit Bhargava)
- disable uncommon TCP congestion control algorithms (Davide Caratti)
- Add new bpf man pages (Justin M. Forbes)
- Add default option for CONFIG_ARM64_BTI_KERNEL to pending-common so that eln kernels build (Justin M. Forbes)
- redhat/Makefile: Add fedora-configs and rh-configs make targets (Prarit Bhargava)
- redhat/configs: Use SHA512 for module signing (Prarit Bhargava)
- genspec.sh: 'touch' empty Patchlist file for single tarball (Don Zickus)
- Fedora config update for rc1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- redhat/Makefile.common: fix RPMKSUBLEVEL condition (Ondrej Mosnacek)
- redhat/Makefile: silence KABI tar output (Ondrej Mosnacek)
- One more Fedora config update (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix PATCHLEVEL for merge window (Justin M. Forbes)
- Change ark CONFIG_COMMON_CLK to yes, it is selected already by other options (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More module filtering for Fedora (Justin M. Forbes)
- Update filters for rnbd in Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix up module filtering for 5.8 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More Fedora config work (Justin M. Forbes)
- RTW88BE and CE have been extracted to their own modules (Justin M. Forbes)
- Set CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK for Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Arm64 Use Branch Target Identification for kernel (Justin M. Forbes)
- Change value of CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix configs for Fedora (Justin M. Forbes)
- Add zero-commit to format-patch options (Justin M. Forbes)
- Copy Makefile.rhelver as a source file rather than a patch (Jeremy Cline)
- Move the sed to clear the patch templating outside of conditionals (Justin M. Forbes)
- Match template format in kernel.spec.template (Justin M. Forbes)
- Break out the Patches into individual files for dist-git (Justin M. Forbes)
- Break the Red Hat patch into individual commits (Jeremy Cline)
- Fix update_scripts.sh unselective pattern sub (David Howells)
- Add cec to the filter overrides (Justin M. Forbes)
- Add overrides to filter-modules.sh (Justin M. Forbes)
- redhat/configs: Enable CONFIG_SMC91X and disable CONFIG_SMC911X (Prarit Bhargava) [1722136]
- Include bpftool-struct_ops man page in the bpftool package (Jeremy Cline)
- Add sharedbuffer_configuration.py to the pathfix.py script (Jeremy Cline)
- Use __make macro instead of make (Tom Stellard)
- Sign off generated configuration patches (Jeremy Cline)
- Drop the static path configuration for the Sphinx docs (Jeremy Cline)
- redhat: Add dummy-module kernel module (Prarit Bhargava)
- redhat: enable CONFIG_LWTUNNEL_BPF (Jiri Benc)
- Remove typoed config file aarch64CONFIG_SM_GCC_8150 (Justin M. Forbes)
- Add Documentation back to kernel-devel as it has Kconfig now (Justin M. Forbes)
- Copy distro files rather than moving them (Jeremy Cline)
- kernel.spec: fix 'make scripts' for kernel-devel package (Brian Masney)
- Makefile: correct help text for dist-cross-<arch>-rpms (Brian Masney)
- redhat/Makefile: Fix RHEL8 python warning (Prarit Bhargava)
- redhat: Change Makefile target names to dist- (Prarit Bhargava)
- configs: Disable Serial IR driver (Prarit Bhargava)
- Fix "multiple %%files for package kernel-tools" (Pablo Greco)
- Introduce a Sphinx documentation project (Jeremy Cline)
- Build ARK against ELN (Don Zickus)
- Drop the requirement to have a remote called linus (Jeremy Cline)
- Rename 'internal' branch to 'os-build' (Don Zickus)
- Only include open merge requests with "Include in Releases" label (Jeremy Cline)
- Package gpio-watch in kernel-tools (Jeremy Cline)
- Exit non-zero if the tag already exists for a release (Jeremy Cline)
- Adjust the changelog update script to not push anything (Jeremy Cline)
- Drop --target noarch from the rh-rpms make target (Jeremy Cline)
- Add a script to generate release tags and branches (Jeremy Cline)
- Set CONFIG_VDPA for fedora (Justin M. Forbes)
- Add a README to the dist-git repository (Jeremy Cline)
- Provide defaults in ark-rebase-patches.sh (Jeremy Cline)
- Default ark-rebase-patches.sh to not report issues (Jeremy Cline)
- Drop DIST from release commits and tags (Jeremy Cline)
- Place the buildid before the dist in the release (Jeremy Cline)
- Sync up with Fedora arm configuration prior to merging (Jeremy Cline)
- Disable CONFIG_PROTECTED_VIRTUALIZATION_GUEST for zfcpdump (Jeremy Cline)
- Add RHMAINTAINERS file and supporting conf (Don Zickus)
- Add a script to test if all commits are signed off (Jeremy Cline)
- Fix make rh-configs-arch (Don Zickus)
- Drop RH_FEDORA in favor of the now-merged RHEL_DIFFERENCES (Jeremy Cline)
- Sync up Fedora configs from the first week of the merge window (Jeremy Cline)
- Migrate blacklisting floppy.ko to mod-blacklist.sh (Don Zickus)
- kernel packaging: Combine mod-blacklist.sh and mod-extra-blacklist.sh (Don Zickus)
- kernel packaging: Fix extra namespace collision (Don Zickus)
- mod-extra.sh: Rename to mod-blacklist.sh (Don Zickus)
- mod-extra.sh: Make file generic (Don Zickus)
- Fix a painfully obvious YAML syntax error in .gitlab-ci.yml (Jeremy Cline)
- Add in armv7hl kernel header support (Don Zickus)
- Disable all BuildKernel commands when only building headers (Don Zickus)
- Drop any gitlab-ci patches from ark-patches (Jeremy Cline)
- Build the srpm for internal branch CI using the vanilla tree (Jeremy Cline)
- Pull in the latest ARM configurations for Fedora (Jeremy Cline)
- Fix xz memory usage issue (Neil Horman)
- Use ark-latest instead of master for update script (Jeremy Cline)
- Move the CI jobs back into the ARK repository (Jeremy Cline)
- Sync up ARK's Fedora config with the dist-git repository (Jeremy Cline)
- Pull in the latest configuration changes from Fedora (Jeremy Cline)
- configs: enable CONFIG_NET_SCH_CBS (Marcelo Ricardo Leitner)
- Drop configuration options in fedora/ that no longer exist (Jeremy Cline)
- Set RH_FEDORA for ARK and Fedora (Jeremy Cline)
- redhat/kernel.spec: Include the release in the kernel COPYING file (Jeremy Cline)
- redhat/kernel.spec: add scripts/jobserver-exec to py3_shbang_opts list (Jeremy Cline)
- redhat/kernel.spec: package bpftool-gen man page (Jeremy Cline)
- distgit-changelog: handle multiple y-stream BZ numbers (Bruno Meneguele)
- redhat/kernel.spec: remove all inline comments (Bruno Meneguele)
- redhat/genspec: awk unknown whitespace regex pattern (Bruno Meneguele)
- Improve the readability of gen_config_patches.sh (Jeremy Cline)
- Fix some awkward edge cases in gen_config_patches.sh (Jeremy Cline)
- Update the CI environment to use Fedora 31 (Jeremy Cline)
- redhat: drop whitespace from with_gcov macro (Jan Stancek)
- configs: Enable CONFIG_KEY_DH_OPERATIONS on ARK (Ondrej Mosnacek)
- configs: Adjust CONFIG_MPLS_ROUTING and CONFIG_MPLS_IPTUNNEL (Laura Abbott)
- New configs in lib/crypto (Jeremy Cline)
- New configs in drivers/char (Jeremy Cline)
- Turn on BLAKE2B for Fedora (Jeremy Cline)
- kernel.spec.template: Clean up stray *.h.s files (Laura Abbott)
- Build the SRPM in the CI job (Jeremy Cline)
- New configs in net/tls (Jeremy Cline)
- New configs in net/tipc (Jeremy Cline)
- New configs in lib/kunit (Jeremy Cline)
- Fix up released_kernel case (Laura Abbott)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- New configs in drivers/ptp (Jeremy Cline)
- New configs in drivers/nvme (Jeremy Cline)
- New configs in drivers/net/phy (Jeremy Cline)
- New configs in arch/arm64 (Jeremy Cline)
- New configs in drivers/crypto (Jeremy Cline)
- New configs in crypto/Kconfig (Jeremy Cline)
- Add label so the Gitlab to email bridge ignores the changelog (Jeremy Cline)
- Temporarily switch TUNE_DEFAULT to y (Jeremy Cline)
- Run config test for merge requests and internal (Jeremy Cline)
- Add missing licensedir line (Laura Abbott)
- redhat/scripts: Remove redhat/scripts/rh_get_maintainer.pl (Prarit Bhargava)
- configs: Take CONFIG_DEFAULT_MMAP_MIN_ADDR from Fedra (Laura Abbott)
- configs: Turn off ISDN (Laura Abbott)
- Add a script to generate configuration patches (Laura Abbott)
- Introduce rh-configs-commit (Laura Abbott)
- kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava)
- configs: Enable CONFIG_DEBUG_WX (Laura Abbott)
- configs: Disable wireless USB (Laura Abbott)
- Clean up some temporary config files (Laura Abbott)
- configs: New config in drivers/gpu for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/powerpc for v5.4-rc1 (Jeremy Cline)
- configs: New config in crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/usb for v5.4-rc1 (Jeremy Cline)
- AUTOMATIC: New configs (Jeremy Cline)
- Skip ksamples for bpf, they are broken (Jeremy Cline)
- configs: New config in fs/erofs for v5.4-rc1 (Jeremy Cline)
- configs: New config in mm for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/md for v5.4-rc1 (Jeremy Cline)
- configs: New config in init for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/fuse for v5.4-rc1 (Jeremy Cline)
- merge.pl: Avoid comments but do not skip them (Don Zickus)
- configs: New config in drivers/net/ethernet/pensando for v5.4-rc1 (Jeremy Cline)
- Update a comment about what released kernel means (Laura Abbott)
- Provide both Fedora and RHEL files in the SRPM (Laura Abbott)
- kernel.spec.template: Trim EXTRAVERSION in the Makefile (Laura Abbott)
- kernel.spec.template: Add macros for building with nopatches (Laura Abbott)
- kernel.spec.template: Add some macros for Fedora differences (Laura Abbott)
- kernel.spec.template: Consolodate the options (Laura Abbott)
- configs: Add pending direcory to Fedora (Laura Abbott)
- kernel.spec.template: Don't run hardlink if rpm-ostree is in use (Laura Abbott)
- configs: New config in net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/phy for v5.4-rc1 (Jeremy Cline)
- configs: Increase x86_64 NR_UARTS to 64 (Prarit Bhargava) [1730649]
- configs: turn on ARM64_FORCE_52BIT for debug builds (Jeremy Cline)
- kernel.spec.template: Tweak the python3 mangling (Laura Abbott)
- kernel.spec.template: Add --with verbose option (Laura Abbott)
- kernel.spec.template: Switch to using %%install instead of %%__install (Laura Abbott)
- kernel.spec.template: Make the kernel.org URL https (Laura Abbott)
- kernel.spec.template: Update message about secure boot signing (Laura Abbott)
- kernel.spec.template: Move some with flags definitions up (Laura Abbott)
- kernel.spec.template: Update some BuildRequires (Laura Abbott)
- kernel.spec.template: Get rid of %%clean (Laura Abbott)
- configs: New config in drivers/char for v5.4-rc1 (Jeremy Cline)
- configs: New config in net/sched for v5.4-rc1 (Jeremy Cline)
- configs: New config in lib for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/verity for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/aarch64 for v5.4-rc4 (Jeremy Cline)
- configs: New config in arch/arm64 for v5.4-rc1 (Jeremy Cline)
- Flip off CONFIG_ARM64_VA_BITS_52 so the bundle that turns it on applies (Jeremy Cline)
- New configuration options for v5.4-rc4 (Jeremy Cline)
- Correctly name tarball for single tarball builds (Laura Abbott)
- configs: New config in drivers/pci for v5.4-rc1 (Jeremy Cline)
- Allow overriding the dist tag on the command line (Laura Abbott)
- Allow scratch branch target to be overridden (Laura Abbott)
- Remove long dead BUILD_DEFAULT_TARGET (Laura Abbott)
- Amend the changelog when rebasing (Laura Abbott)
- configs: New config in drivers/platform for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/pinctrl for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/wireless for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/ethernet/mellanox for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hid for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/dma-buf for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in block for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/cpuidle for v5.4-rc1 (Jeremy Cline)
- redhat: configs: Split CONFIG_CRYPTO_SHA512 (Laura Abbott)
- redhat: Set Fedora options (Laura Abbott)
- Set CRYPTO_SHA3_*_S390 to builtin on zfcpdump (Jeremy Cline)
- configs: New config in drivers/edac for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/firmware for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hwmon for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/iio for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/mmc for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/tty for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/bus for v5.4-rc1 (Jeremy Cline)
- Add option to allow mismatched configs on the command line (Laura Abbott)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/pci for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/soc for v5.4-rc1 (Jeremy Cline)
- gitlab: Add CI job for packaging scripts (Major Hayden)
- Speed up CI with CKI image (Major Hayden)
- Disable e1000 driver in ARK (Neil Horman)
- configs: Fix the pending default for CONFIG_ARM64_VA_BITS_52 (Jeremy Cline)
- configs: Turn on OPTIMIZE_INLINING for everything (Jeremy Cline)
- configs: Set valid pending defaults for CRYPTO_ESSIV (Jeremy Cline)
- Add an initial CI configuration for the internal branch (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- Pull the RHEL version defines out of the Makefile (Jeremy Cline)
- Sync up the ARK build scripts (Jeremy Cline)
- Sync up the Fedora Rawhide configs (Jeremy Cline)
- Sync up the ARK config files (Jeremy Cline)
- configs: Adjust CONFIG_FORCE_MAX_ZONEORDER for Fedora (Laura Abbott)
- configs: Add README for some other arches (Laura Abbott)
- configs: Sync up Fedora configs (Laura Abbott)
- [initial commit] Add structure for building with git (Laura Abbott)
- [initial commit] Add Red Hat variables in the top level makefile (Laura Abbott)
- [initial commit] Red Hat gitignore and attributes (Laura Abbott)
- [initial commit] Add changelog (Laura Abbott)
- [initial commit] Add makefile (Laura Abbott)
- [initial commit] Add files for generating the kernel.spec (Laura Abbott)
- [initial commit] Add rpm directory (Laura Abbott)
- [initial commit] Add files for packaging (Laura Abbott)
- [initial commit] Add kabi files (Laura Abbott)
- [initial commit] Add scripts (Laura Abbott)
- [initial commit] Add configs (Laura Abbott)
- [initial commit] Add Makefiles (Laura Abbott)

# The following bit is important for automation so please do not remove
# END OF CHANGELOG

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
